package com.unis.auth.modular.login.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.auth.core.enums.SaClientTypeEnum;
import com.unis.auth.modular.login.param.AuthAccountPasswordLoginParam;
import com.unis.auth.modular.login.param.DepotPasswordLoginParam;
import com.unis.auth.modular.login.param.IpadLoginParam;
import com.unis.auth.modular.login.param.UserCollectPasswordLoginParam;
import com.unis.auth.modular.login.service.AuthService;
import com.unis.auth.modular.login.vo.AppCarLoginVO;
import com.unis.auth.modular.login.vo.DepotLoginVO;
import com.unis.auth.modular.login.vo.IpadLoginVO;
import com.unis.common.pojo.CommonResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 移动端登录管理
 *
 * @author weiyinbin
 * @date 2024/04/02 15:40
 */
@Api(tags = "移动端登录管理")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class UserCollectLoginController {

    @Autowired
    private AuthService authService;

    @ApiOperationSupport(order = 1)
    @ApiOperation("人员采集登录密码登录")
    @PostMapping("/auth/c/userCollect/login")
    public CommonResult<String> doLogin(@RequestBody @Valid UserCollectPasswordLoginParam userCollectPasswordLoginParam) {
        return CommonResult.data(authService.userLogin(userCollectPasswordLoginParam));
    }



    @ApiOperationSupport(order = 2)
    @ApiOperation("车辆信息登录密码登录")
    @PostMapping("/auth/c/userCollect/appCarLogin")
    public CommonResult<AppCarLoginVO> appLogin(@RequestBody @Valid UserCollectPasswordLoginParam userCollectPasswordLoginParam){
        return CommonResult.data(authService.appCarLogin(userCollectPasswordLoginParam));
    }



    @ApiOperationSupport(order = 3)
    @ApiOperation("车辆信息登录密码注册")
    @PostMapping("/auth/c/userCollect/appCarEnroll")
    public CommonResult<String> appEnroll(@RequestBody @Valid UserCollectPasswordLoginParam userCollectPasswordLoginParam){
        return CommonResult.data(authService.appCarEnroll(userCollectPasswordLoginParam));
    }


    @ApiOperationSupport(order = 4)
    @ApiOperation("移动应用密码登录")
    @PostMapping("/auth/c/orgInfo/depotLogin")
    public CommonResult<DepotLoginVO> depotLogin(@RequestBody @Valid DepotPasswordLoginParam depotPasswordLoginParam) {
        return CommonResult.data(authService.depotLogin(depotPasswordLoginParam));
    }


    /**
     * ipad账号密码登录
     *
     * @author xuyuxiang
     * @date 2021/10/15 13:12
     **/
    @ApiOperationSupport(order = 5)
    @ApiOperation("ipad账号密码登录")
    @PostMapping("/auth/c/ipad/doLogin")
    public CommonResult<IpadLoginVO> ipadLogin(@RequestBody @Valid IpadLoginParam ipadLoginParam) {
        return CommonResult.data(authService.ipadLogin(ipadLoginParam));
    }
}
