/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.aisleInfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoPageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.aisleInfo.entity.AisleInfo;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoAddParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoEditParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoIdParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoPageParam;
import com.unis.basic.info.modular.aisleInfo.service.AisleInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.Map;

/**
 * 廒间信息表控制器
 *
 * @author shine
 * @date  2024/04/28 11:54
 */
@Api(tags = "廒间信息表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class AisleInfoController {

    @Resource
    private AisleInfoService aisleInfoService;

    /**
     * 获取廒间信息表分页
     *
     * @author shine
     * @date  2024/04/28 11:54
     */
   /* @ApiOperationSupport(order = 1)
    @ApiOperation("获取廒间信息表分页")
    //@SaCheckPermission("/aisleInfo/aisle/page")
    @GetMapping("/aisleInfo/aisle/page")
    public CommonResult<Page<AisleInfo>> page(AisleInfoPageParam aisleInfoPageParam) {
        return CommonResult.data(aisleInfoService.page(aisleInfoPageParam));
    }*/

    @ApiOperationSupport(order = 1)
    @ApiOperation("获取廒间信息表分页")
    //@SaCheckPermission("/aisleInfo/aisle/page")
    @GetMapping("/aisleInfo/aisle/page")
    public CommonResult<IPage<Map<String,Object>>> findPage(AisleInfoPageParam aisleInfoPageParam) {
        return CommonResult.data(aisleInfoService.findPage(aisleInfoPageParam));
    }





    /**
     * 添加廒间信息表
     *
     * @author shine
     * @date  2024/04/28 11:54
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加廒间信息表")
    @CommonLog("添加廒间信息表")
    //@SaCheckPermission("/aisleInfo/aisle/add")
    @PostMapping("/aisleInfo/aisle/add")
    public CommonResult<String> add(@RequestBody @Valid AisleInfoAddParam aisleInfoAddParam) {
        aisleInfoService.add(aisleInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑廒间信息表
     *
     * @author shine
     * @date  2024/04/28 11:54
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑廒间信息表")
    @CommonLog("编辑廒间信息表")
    //@SaCheckPermission("/aisleInfo/aisle/edit")
    @PostMapping("/aisleInfo/aisle/edit")
    public CommonResult<String> edit(@RequestBody @Valid AisleInfoEditParam aisleInfoEditParam) {
        aisleInfoService.edit(aisleInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除廒间信息表
     *
     * @author shine
     * @date  2024/04/28 11:54
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除廒间信息表")
    @CommonLog("删除廒间信息表")
    //@SaCheckPermission("/aisleInfo/aisle/delete")
    @PostMapping("/aisleInfo/aisle/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<AisleInfoIdParam> aisleInfoIdParamList) {
        aisleInfoService.delete(aisleInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取廒间信息表详情
     *
     * @author shine
     * @date  2024/04/28 11:54
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取廒间信息表详情")
    //@SaCheckPermission("/aisleInfo/aisle/detail")
    @GetMapping("/aisleInfo/aisle/detail")
    public CommonResult<AisleInfo> detail(@Valid AisleInfoIdParam aisleInfoIdParam) {
        return CommonResult.data(aisleInfoService.detail(aisleInfoIdParam));
    }
}
