/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.aisleInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.aisleInfo.entity.AisleInfo;
import com.unis.basic.info.modular.aisleInfo.mapper.AisleInfoMapper;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoAddParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoEditParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoIdParam;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoPageParam;
import com.unis.basic.info.modular.aisleInfo.service.AisleInfoService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 廒间信息表Service接口实现类
 *
 * @author shine
 * @date  2024/04/28 11:54
 **/
@Service
public class AisleInfoServiceImpl extends ServiceImpl<AisleInfoMapper, AisleInfo> implements AisleInfoService {

    @Resource
    private AisleInfoMapper aisleInfoMapper;

    @Override
    public Page<AisleInfo> page(AisleInfoPageParam aisleInfoPageParam) {
        QueryWrapper<AisleInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(aisleInfoPageParam.getBasicStorehouseId())) {
            queryWrapper.lambda().eq(AisleInfo::getBasicStorehouseId, aisleInfoPageParam.getBasicStorehouseId());
        }
        if(ObjectUtil.isNotEmpty(aisleInfoPageParam.getTyajbm())) {
            queryWrapper.lambda().like(AisleInfo::getTyajbm, aisleInfoPageParam.getTyajbm());
        }
        if(ObjectUtil.isNotEmpty(aisleInfoPageParam.getAjmc())) {
            queryWrapper.lambda().like(AisleInfo::getAjmc, aisleInfoPageParam.getAjmc());
        }
        if(ObjectUtil.isAllNotEmpty(aisleInfoPageParam.getSortField(), aisleInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(aisleInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, aisleInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(aisleInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(AisleInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(AisleInfoAddParam aisleInfoAddParam) {
        AisleInfo aisleInfo = BeanUtil.toBean(aisleInfoAddParam, AisleInfo.class);
        this.save(aisleInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AisleInfoEditParam aisleInfoEditParam) {
        AisleInfo aisleInfo = this.queryEntity(aisleInfoEditParam.getId());
        BeanUtil.copyProperties(aisleInfoEditParam, aisleInfo);
        this.updateById(aisleInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AisleInfoIdParam> aisleInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(aisleInfoIdParamList, AisleInfoIdParam::getId));
    }

    @Override
    public AisleInfo detail(AisleInfoIdParam aisleInfoIdParam) {
        return this.queryEntity(Integer.valueOf(aisleInfoIdParam.getId()));
    }

    @Override
    public AisleInfo queryEntity(Integer id) {
        AisleInfo aisleInfo = this.getById(id);
        if(ObjectUtil.isEmpty(aisleInfo)) {
            throw new CommonException("廒间信息表不存在，id值为：{}", id);
        }
        return aisleInfo;
    }

    @Override
    public IPage<Map<String, Object>> findPage(AisleInfoPageParam aisleInfoPageParam) {
        QueryWrapper<AisleInfo> queryWrapper = new QueryWrapper<>();
        //分页相关
        if (aisleInfoPageParam.getAjmc() != null) {
            queryWrapper.like("a.ajmc", aisleInfoPageParam.getAjmc());
        }
        if (aisleInfoPageParam.getOrgName() != null) {
            queryWrapper.like("c.org_name", aisleInfoPageParam.getOrgName());
        }

        Page<AisleInfo> p = new Page<>(aisleInfoPageParam.getCurrent(), aisleInfoPageParam.getSize());

        IPage<Map<String, Object>> page = aisleInfoMapper.findPage(p, queryWrapper);
        return page;
    }
}
