/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.enumInfo.controller;


import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.enumInfo.entity.BasicEnum;
import com.unis.basic.info.modular.enumInfo.param.BasicEnumAddParam;
import com.unis.basic.info.modular.enumInfo.param.BasicEnumEditParam;
import com.unis.basic.info.modular.enumInfo.param.BasicEnumIdParam;
import com.unis.basic.info.modular.enumInfo.param.BasicEnumPageParam;
import com.unis.basic.info.modular.enumInfo.service.BasicEnumService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;


import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 数据字典大类控制器
 *
 * @author shine
 * @date  2024/05/10 14:06
 */
@Api(tags = "数据字典大类控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BasicEnumController {

    @Resource
    private BasicEnumService basicEnumService;

    /**
     * 获取数据字典大类分页
     *
     * @author shine
     * @date  2024/05/10 14:06
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取数据字典大类分页")
    @SaCheckPermission("/biz/enum/page")
    @GetMapping("/biz/enum/page")
    public CommonResult<Page<BasicEnum>> page(BasicEnumPageParam basicEnumPageParam) {
        return CommonResult.data(basicEnumService.page(basicEnumPageParam));
    }

    /**
     * 添加数据字典大类
     *
     * @author shine
     * @date  2024/05/10 14:06
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加数据字典大类")
    @CommonLog("添加数据字典大类")
    //@SaCheckPermission("/biz/enum/add")
    @PostMapping("/biz/enum/add")
    public CommonResult<String> add(@RequestBody @Valid BasicEnumAddParam basicEnumAddParam) {
        basicEnumService.add(basicEnumAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑数据字典大类
     *
     * @author shine
     * @date  2024/05/10 14:06
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑数据字典大类")
    @CommonLog("编辑数据字典大类")
    @SaCheckPermission("/biz/enum/edit")
    @PostMapping("/biz/enum/edit")
    public CommonResult<String> edit(@RequestBody @Valid BasicEnumEditParam basicEnumEditParam) {
        basicEnumService.edit(basicEnumEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除数据字典大类
     *
     * @author shine
     * @date  2024/05/10 14:06
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除数据字典大类")
    @CommonLog("删除数据字典大类")
    @SaCheckPermission("/biz/enum/delete")
    @PostMapping("/biz/enum/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BasicEnumIdParam> basicEnumIdParamList) {
        basicEnumService.delete(basicEnumIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取数据字典大类详情
     *
     * @author shine
     * @date  2024/05/10 14:06
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取数据字典大类详情")
    @SaCheckPermission("/biz/enum/detail")
    @GetMapping("/biz/enum/detail")
    public CommonResult<BasicEnum> detail(@Valid BasicEnumIdParam basicEnumIdParam) {
        return CommonResult.data(basicEnumService.detail(basicEnumIdParam));
    }


    @ApiOperationSupport(order = 6)
    @ApiOperation("获取枚举字典数据统一对外接口")
    @GetMapping("/Enum/findEnumObj")
    public CommonResult<Map<String, Object>> findEnumObj() {
        Map<String, Object> map = new HashMap<>();
        Map<Integer, List<BasicEnum>> parentMap = basicEnumService.findEnumObjParentId();
        Map<Object,Object> enumMap = basicEnumService.findEnumObjEnumId();
        map.put("parentMap", parentMap);
        map.put("enumMap", enumMap);
        return CommonResult.data(map);
    }

    /**
     * B端根据id获取子节点数据
     * @param enumid 节点id
     * @return
     */
    @ApiOperation(value="B端根据id获取子节点数据")
    @GetMapping("")
    @ApiImplicitParams({
            @ApiImplicitParam(name="enumid", value="字典id", paramType="query"),
            @ApiImplicitParam(name="isQueryFristNode", value="是否只查询第一级", paramType="query")
    })
    public CommonResult<List<BasicEnum>> getAllChildren(String  enumid, Boolean isQueryFristNode) {
        List<BasicEnum> list  = basicEnumService.queryAllChildren(enumid,isQueryFristNode);
        return CommonResult.data(list);
    }


}
