/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.grainPriceCollectCategory.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.grainPriceCollectCategory.entity.GrainPriceCollectCategory;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryAddParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryEditParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryIdParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryPageParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.service.GrainPriceCollectCategoryService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 粮食价格采集-品种控制器
 *
 * @author TS
 * @date  2024/04/03 10:41
 */
@Api(tags = "粮食价格采集-品种控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainPriceCollectCategoryController {

    @Resource
    private GrainPriceCollectCategoryService grainPriceCollectCategoryService;

    /**
     * 获取粮食价格采集-品种分页
     *
     * @author TS
     * @date  2024/04/03 10:41
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮食价格采集-品种分页")
    @SaCheckPermission("/basic.info/grainPriceCollectCategory/page")
    @GetMapping("/basic.info/grainPriceCollectCategory/page")
    public CommonResult<Page<GrainPriceCollectCategory>> page(GrainPriceCollectCategoryPageParam grainPriceCollectCategoryPageParam) {
        return CommonResult.data(grainPriceCollectCategoryService.page(grainPriceCollectCategoryPageParam));
    }

    /**
     * 添加粮食价格采集-品种
     *
     * @author TS
     * @date  2024/04/03 10:41
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加粮食价格采集-品种")
    @CommonLog("添加粮食价格采集-品种")
    @SaCheckPermission("/basic.info/grainPriceCollectCategory/add")
    @PostMapping("/basic.info/grainPriceCollectCategory/add")
    public CommonResult<String> add(@RequestBody @Valid GrainPriceCollectCategoryAddParam grainPriceCollectCategoryAddParam) {
        grainPriceCollectCategoryService.add(grainPriceCollectCategoryAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食价格采集-品种
     *
     * @author TS
     * @date  2024/04/03 10:41
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮食价格采集-品种")
    @CommonLog("编辑粮食价格采集-品种")
    @SaCheckPermission("/basic.info/grainPriceCollectCategory/edit")
    @PostMapping("/basic.info/grainPriceCollectCategory/edit")
    public CommonResult<String> edit(@RequestBody @Valid GrainPriceCollectCategoryEditParam grainPriceCollectCategoryEditParam) {
        grainPriceCollectCategoryService.edit(grainPriceCollectCategoryEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食价格采集-品种
     *
     * @author TS
     * @date  2024/04/03 10:41
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除粮食价格采集-品种")
    @CommonLog("删除粮食价格采集-品种")
    @SaCheckPermission("/basic.info/grainPriceCollectCategory/delete")
    @PostMapping("/basic.info/grainPriceCollectCategory/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<GrainPriceCollectCategoryIdParam> grainPriceCollectCategoryIdParamList) {
        grainPriceCollectCategoryService.delete(grainPriceCollectCategoryIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮食价格采集-品种详情
     *
     * @author TS
     * @date  2024/04/03 10:41
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮食价格采集-品种详情")
    @SaCheckPermission("/basic.info/grainPriceCollectCategory/detail")
    @GetMapping("/basic.info/grainPriceCollectCategory/detail")
    public CommonResult<GrainPriceCollectCategory> detail(@Valid GrainPriceCollectCategoryIdParam grainPriceCollectCategoryIdParam) {
        return CommonResult.data(grainPriceCollectCategoryService.detail(grainPriceCollectCategoryIdParam));
    }
}
