/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.grainPriceCollectCategory.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.grainPriceCollectCategory.entity.GrainPriceCollectCategory;
import com.unis.basic.info.modular.grainPriceCollectCategory.mapper.GrainPriceCollectCategoryMapper;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryAddParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryEditParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryIdParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.param.GrainPriceCollectCategoryPageParam;
import com.unis.basic.info.modular.grainPriceCollectCategory.service.GrainPriceCollectCategoryService;

import java.util.List;

/**
 * 粮食价格采集-品种Service接口实现类
 *
 * @author TS
 * @date  2024/04/03 10:41
 **/
@Service
public class GrainPriceCollectCategoryServiceImpl extends ServiceImpl<GrainPriceCollectCategoryMapper, GrainPriceCollectCategory> implements GrainPriceCollectCategoryService {

    @Override
    public Page<GrainPriceCollectCategory> page(GrainPriceCollectCategoryPageParam grainPriceCollectCategoryPageParam) {
        QueryWrapper<GrainPriceCollectCategory> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(grainPriceCollectCategoryPageParam.getSortField(), grainPriceCollectCategoryPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(grainPriceCollectCategoryPageParam.getSortOrder());
            queryWrapper.orderBy(true, grainPriceCollectCategoryPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(grainPriceCollectCategoryPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GrainPriceCollectCategory::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GrainPriceCollectCategoryAddParam grainPriceCollectCategoryAddParam) {
        GrainPriceCollectCategory grainPriceCollectCategory = BeanUtil.toBean(grainPriceCollectCategoryAddParam, GrainPriceCollectCategory.class);
        this.save(grainPriceCollectCategory);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GrainPriceCollectCategoryEditParam grainPriceCollectCategoryEditParam) {
        GrainPriceCollectCategory grainPriceCollectCategory = this.queryEntity(grainPriceCollectCategoryEditParam.getId());
        BeanUtil.copyProperties(grainPriceCollectCategoryEditParam, grainPriceCollectCategory);
        this.updateById(grainPriceCollectCategory);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GrainPriceCollectCategoryIdParam> grainPriceCollectCategoryIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(grainPriceCollectCategoryIdParamList, GrainPriceCollectCategoryIdParam::getId));
    }

    @Override
    public GrainPriceCollectCategory detail(GrainPriceCollectCategoryIdParam grainPriceCollectCategoryIdParam) {
        return this.queryEntity(grainPriceCollectCategoryIdParam.getId());
    }

    @Override
    public GrainPriceCollectCategory queryEntity(String id) {
        GrainPriceCollectCategory grainPriceCollectCategory = this.getById(id);
        if(ObjectUtil.isEmpty(grainPriceCollectCategory)) {
            throw new CommonException("粮食价格采集-品种不存在，id值为：{}", id);
        }
        return grainPriceCollectCategory;
    }
}
