/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.orgInfo.service.impl;


import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.grainPriceCollectCitySum.entity.GrainPriceCollectCitySum;
import com.unis.basic.info.modular.grainPriceCollectProvinceSum.entity.GrainPriceCollectProvinceSum;
import com.unis.basic.info.modular.grainPriceCollectProvinceSum.mapper.GrainPriceCollectProvinceSumMapper;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.basic.info.modular.orgInfo.service.OrgInfoService;
import com.unis.basic.info.modular.unitInfo.entity.UnitInfo;
import com.unis.basic.info.modular.unitInfo.mapper.UnitInfoMapper;
import com.unis.basic.info.modular.unitInfo.service.impl.UnitInfoServiceImpl;
import com.unis.reserveLayout.modular.dataSystemInfo.param.DataPageParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;

import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoPageParam;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoAddParam;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoEditParam;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoIdParam;


import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 组织机构信息表Service接口实现类
 *
 * @author shine
 * @date  2024/04/28 11:47
 **/
@Service
public class OrgInfoServiceImpl extends ServiceImpl<OrgInfoMapper, OrgInfo> implements OrgInfoService {

    @Autowired
    private com.unis.basic.info.modular.unitInfo.service.impl.UnitInfoServiceImpl unitInfoServiceImpl;

    @Resource
    private OrgInfoMapper orgInfoMapper;

    @Override
    public Page<OrgInfo> page(OrgInfoPageParam orgInfoPageParam) {
        QueryWrapper<OrgInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(orgInfoPageParam.getOrgName())) {
            queryWrapper.lambda().like(OrgInfo::getOrgName, orgInfoPageParam.getOrgName());
        }
        if(ObjectUtil.isNotEmpty(orgInfoPageParam.getUnitInfoId())) {
            queryWrapper.lambda().eq(OrgInfo::getUnitInfoId, orgInfoPageParam.getUnitInfoId());
        }
        if(ObjectUtil.isAllNotEmpty(orgInfoPageParam.getSortField(), orgInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(orgInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, orgInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(orgInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(OrgInfo::getOrgId);
        }
        Page<OrgInfo>  pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(OrgInfo orgInfo:pageList.getRecords()){
            if(orgInfo.getUnitInfoId() != "" && orgInfo.getUnitInfoId() != null){
                UnitInfo unitInfo = unitInfoServiceImpl.queryEntity(orgInfo.getUnitInfoId());
                if (unitInfo != null){
                    orgInfo.setQymc(unitInfo.getDwmc());
                }
            }
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OrgInfoAddParam orgInfoAddParam) {
        OrgInfo orgInfo = BeanUtil.toBean(orgInfoAddParam, OrgInfo.class);
        this.save(orgInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OrgInfoEditParam orgInfoEditParam) {
        OrgInfo orgInfo = this.queryEntity(orgInfoEditParam.getOrgId());
        BeanUtil.copyProperties(orgInfoEditParam, orgInfo);
        this.updateById(orgInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OrgInfoIdParam> orgInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(orgInfoIdParamList, OrgInfoIdParam::getOrgId));
    }

    @Override
    public OrgInfo detail(OrgInfoIdParam orgInfoIdParam) {
        return this.queryEntity(Integer.valueOf(orgInfoIdParam.getOrgId()));
    }

    @Override
    public OrgInfo queryEntity(Integer id) {
        OrgInfo orgInfo = this.getById(id);
        if(ObjectUtil.isEmpty(orgInfo)) {
            throw new CommonException("组织机构信息表不存在，id值为：{}", id);
        }
        if(StringUtils.isNotBlank(orgInfo.getUnitInfoId())){
            UnitInfo unitInfo = unitInfoServiceImpl.queryEntity(orgInfo.getUnitInfoId());
            if (unitInfo != null){
                orgInfo.setQymc(unitInfo.getDwmc());
            }
        }
        return orgInfo;
    }

    @Override
    public IPage<Map<String, Object>> findPage(OrgInfoPageParam orgInfoPageParam) {

        QueryWrapper<OrgInfo> queryWrapper = new QueryWrapper<>();
        //分页相关
        if (orgInfoPageParam.getOrgName() != null) {
            queryWrapper.like("a.org_name", orgInfoPageParam.getOrgName());
        }

        Page<OrgInfo> p = new Page<>(orgInfoPageParam.getCurrent(), orgInfoPageParam.getSize());

        IPage<Map<String, Object>> page = orgInfoMapper.findPage(p, queryWrapper);
        return page;

    }

    @Override
    public List<OrgInfo> getAllList() {
        QueryWrapper<OrgInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.ne("parent_id", 0);
        return this.list(queryWrapper);
    }

    @Override
    public Integer selectOrgInfoCount() {
        return orgInfoMapper.findCountPage();
    }

    /**
     * 储备布局地理信息-仓房基本情况汇总
     * @param orgInfoPageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> selectStoreHousePage(OrgInfoPageParam orgInfoPageParam) {
        QueryWrapper<OrgInfo> queryWrapper = new QueryWrapper<>();
        //分页相关
        if (orgInfoPageParam.getOrgName() != null) {
            queryWrapper.like("oi.org_name", orgInfoPageParam.getOrgName());
        }

        Page<OrgInfo> p = new Page<>(orgInfoPageParam.getCurrent(), orgInfoPageParam.getSize());

        IPage<Map<String, Object>> page = orgInfoMapper.selectStoreHousePage(p, queryWrapper);
        return page;
    }

    /**
     * 储备布局地理信息-仓房数量
     * @return
     */
    @Override
    public Integer selectStoreHouseCount() {
        return orgInfoMapper.selectStoreHouseCount();
    }

    @Override
    public Integer selectInventoryCount() {
      return  orgInfoMapper.selectInventoryCount();
    }

    @Override
    public  List<Map<String, Object>> selectGrainNatureName(DataPageParam dataPageParam) {

        return  orgInfoMapper.selectGrainNatureName(dataPageParam);
    }

    @Override
    public IPage<Map<String, Object>> selectKcCountPage(DataPageParam dataPageParam) {
        Page<Map> p =new Page<>(dataPageParam.getCurrent(),dataPageParam.getSize());
        return  orgInfoMapper.selectKcCountPage(p,dataPageParam);
    }

    @Override
    public List<Map<String, Object>> selectKcChart(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcChart(dataPageParam);
    }

    @Override
    public List<Map<String, Object>> selectKcGrainNatureChart(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcGrainNatureChart(dataPageParam);
    }

    @Override
    public Map<String, Object> selectKcSumRepot(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcSumRepot(dataPageParam);
    }

    @Override
    public List<Map<String, Object>> selectKcGrainGradeRepot(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcGrainGradeRepot(dataPageParam);
    }

    @Override
    public List<Map<String, Object>> selectKcGrainNatureRepot(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcGrainNatureRepot(dataPageParam);
    }

    @Override
    public List<Map<String, Object>> selectKcYearRepot(DataPageParam dataPageParam) {
        return orgInfoMapper.selectKcYearRepot(dataPageParam);
    }

    @Override
    public Map<String, Object> selectByOrgInfo(DataPageParam dataPageParam) {
        return orgInfoMapper.selectByOrgInfo(dataPageParam);
    }
}
