/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.priceMoitorRecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.priceMoitorRecord.entity.PriceMoitorRecord;
import com.unis.basic.info.modular.priceMoitorRecord.mapper.PriceMoitorRecordMapper;
import com.unis.basic.info.modular.priceMoitorRecord.param.PriceMoitorRecordAddParam;
import com.unis.basic.info.modular.priceMoitorRecord.param.PriceMoitorRecordEditParam;
import com.unis.basic.info.modular.priceMoitorRecord.param.PriceMoitorRecordIdParam;
import com.unis.basic.info.modular.priceMoitorRecord.param.PriceMoitorRecordPageParam;
import com.unis.basic.info.modular.priceMoitorRecord.service.PriceMoitorRecordService;
import com.unis.basic.info.modular.priceMoitorRecord.vo.PriceMonitorRecordVo;
import com.unis.basic.info.modular.pricemonitor.entity.PriceMonitor;
import com.unis.basic.info.modular.pricemonitor.mapper.PriceMonitorMapper;
import com.unis.basic.info.modular.pricemonitor.service.PriceMonitorService;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 价格监测-操作记录Service接口实现类
 *
 * @author hujinachun
 * @date 2024/04/11 19:08
 **/
@Service
public class PriceMoitorRecordServiceImpl extends ServiceImpl<PriceMoitorRecordMapper, PriceMoitorRecord> implements PriceMoitorRecordService {


    @Autowired
    private PriceMonitorMapper priceMonitorMapper;

    @Autowired
    private PriceMonitorService priceMonitorService;

    @Autowired
    private PriceMoitorRecordMapper priceMoitorRecordMapper;

    @Override
    public Page<PriceMonitorRecordVo> page(PriceMoitorRecordPageParam priceMoitorRecordPageParam) {
    /*    List<PriceMonitor> priceMonitors = new ArrayList<>();
        if (ObjectUtil.isNotEmpty(priceMoitorRecordPageParam.getName())) {
            //获取对应的站点id
            priceMonitors = priceMonitorMapper.selectList(new LambdaQueryWrapper<PriceMonitor>()
                    .like(PriceMonitor::getName, priceMoitorRecordPageParam.getName()));
        }
        //获取每个id
        List<String> idList = priceMonitors.stream().map(PriceMonitor::getName).collect(Collectors.toList());


        QueryWrapper<PriceMoitorRecord> queryWrapper = new QueryWrapper<>();
        if (CollectionUtils.isEmpty(priceMonitors)) {
            queryWrapper.lambda().eq(PriceMoitorRecord::getDeleteFlag, "NOT_DELETE");
            queryWrapper.lambda().orderByDesc(PriceMoitorRecord::getUpdateTime);
        } else {
            queryWrapper.in("price_monitor_id", idList);
            queryWrapper.lambda().eq(PriceMoitorRecord::getDeleteFlag, "NOT_DELETE");
            queryWrapper.lambda().orderByDesc(PriceMoitorRecord::getUpdateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);*/

        Page<PriceMonitorRecordVo> priceMonitorRecordVoPage = new Page<>(priceMoitorRecordPageParam.getCurrent(), priceMoitorRecordPageParam.getSize());

        return priceMoitorRecordMapper.selectPriceMonitorRecordList(priceMonitorRecordVoPage, priceMoitorRecordPageParam.getName());


    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 新增
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PriceMoitorRecordAddParam priceMoitorRecordAddParam) {

        //设置开关
        PriceMonitor priceMonitor =priceMonitorService.queryEntity(priceMoitorRecordAddParam.getPriceMonitorId());
        priceMonitor.setLocationSwitch(priceMoitorRecordAddParam.getLocationSwitch());
        if (!priceMonitorService.updateById(priceMonitor)){
            throw new CommonException("修改价格监测点失败");
        }
        //新增操作记录
        PriceMoitorRecord priceMoitor = BeanUtil.toBean(priceMoitorRecordAddParam, PriceMoitorRecord.class);
        priceMoitor.setDeleteFlag("NOT_DELETE");
        priceMoitor.setLocationSwitch(priceMoitorRecordAddParam.getLocationSwitch());
        priceMoitor.setUpdateTime(new Date());
        priceMoitor.setCreateTime(new Date());
        this.save(priceMoitor);

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PriceMoitorRecordEditParam priceMoitorRecordEditParam) {
        PriceMoitorRecord priceMoitorRecord = this.queryEntity(priceMoitorRecordEditParam.getId());
        BeanUtil.copyProperties(priceMoitorRecordEditParam, priceMoitorRecord);
        this.updateById(priceMoitorRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PriceMoitorRecordIdParam> priceMoitorRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(priceMoitorRecordIdParamList, PriceMoitorRecordIdParam::getPriceMonitorId));
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 查看详情
     */
    @Override
    public PriceMoitorRecord detail(PriceMoitorRecordIdParam priceMoitorRecordIdParam) {
        return this.queryEntity(priceMoitorRecordIdParam.getPriceMonitorId());

    }

    @Override
    public PriceMoitorRecord queryEntity(String id) {
        PriceMoitorRecord priceMoitorRecord = this.getById(id);
        if (ObjectUtil.isEmpty(priceMoitorRecord)) {
            throw new CommonException("价格监测-操作记录不存在，id值为：{}", id);
        }
        return priceMoitorRecord;
    }

   /* *
     * |
     * 获取详情
     *
     * @param priceMoitorRecordIdParam
     * @return*/

    @Override
    public List<PriceMoitorRecord> fandDetail(PriceMoitorRecordIdParam priceMoitorRecordIdParam) {
        LambdaQueryWrapper<PriceMoitorRecord> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(PriceMoitorRecord::getPriceMonitorId, priceMoitorRecordIdParam.getPriceMonitorId());
        return list(wrapper);
    }
}
