/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.remindcycle.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.remindcycle.entity.RemindCycle;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleAddParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleEditParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleIdParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCyclePageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.remindcycle.entity.RemindCycle;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleAddParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleEditParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCycleIdParam;
import com.unis.basic.info.modular.remindcycle.param.RemindCyclePageParam;
import com.unis.basic.info.modular.remindcycle.service.RemindCycleService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 报送周期控制器
 *
 * @author weiyinbin
 * @date  2024/04/02 14:45
 */
@Api(tags = "报送周期控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class RemindCycleController {

    @Resource
    private RemindCycleService remindCycleService;

    /**
     * 获取报送周期分页
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取报送周期分页")
   // @SaCheckPermission("/basic.info/remindcycle/page")
    @GetMapping("/basic.info/remindcycle/page")
    public CommonResult<Page<RemindCycle>> page(RemindCyclePageParam remindCyclePageParam) {
        return CommonResult.data(remindCycleService.page(remindCyclePageParam));
    }

    /**
     * 添加报送周期
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加报送周期")
    @CommonLog("添加报送周期")
   // @SaCheckPermission("/basic.info/remindcycle/add")
    @PostMapping("/basic.info/remindcycle/add")
    public CommonResult<String> add(@RequestBody @Valid RemindCycleAddParam remindCycleAddParam) {
        remindCycleService.add(remindCycleAddParam);
        return CommonResult.ok();


    }

    /**
     * 编辑报送周期
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑报送周期")
    @CommonLog("编辑报送周期")
   // @SaCheckPermission("/basic.info/remindcycle/edit")
    @PostMapping("/basic.info/remindcycle/edit")
    public CommonResult<String> edit(@RequestBody @Valid RemindCycleEditParam remindCycleEditParam) {
        remindCycleService.edit(remindCycleEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除报送周期
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除报送周期")
    @CommonLog("删除报送周期")
  //  @SaCheckPermission("/basic.info/remindcycle/delete")
    @PostMapping("/basic.info/remindcycle/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<RemindCycleIdParam> remindCycleIdParamList) {
        remindCycleService.delete(remindCycleIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取报送周期详情
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取报送周期详情")
   // @SaCheckPermission("/basic.info/remindcycle/detail")
    @GetMapping("/basic.info/remindcycle/detail")
    public CommonResult<RemindCycle> detail(@Valid RemindCycleIdParam remindCycleIdParam) {
        return CommonResult.data(remindCycleService.detail(remindCycleIdParam));
    }

    /**
     * 前端调用定时报送周期的专用接口
     *
     * @author weiyinbin
     * @date  2024/04/02 14:45
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("前端调用定时报送周期的专用接口")
    //@SaCheckPermission("/client/c/remindcycle/task")
    @GetMapping("/client/c/remindcycle/task")
    public CommonResult<String> task() {
        return CommonResult.ok(remindCycleService.task());
    }
}
