/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.storehouseInfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.storehouseInfo.entity.StorehouseInfo;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoAddParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoEditParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoIdParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoPageParam;
import com.unis.basic.info.modular.storehouseInfo.service.StorehouseInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 库点仓房信息控制器
 *
 * @author shine
 * @date  2024/04/28 11:51
 */
@Api(tags = "库点仓房信息控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class StorehouseInfoController {

    @Resource
    private StorehouseInfoService storehouseInfoService;

    /**
     * 获取库点仓房信息分页
     *
     * @author shine
     * @date  2024/04/28 11:51
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取库点仓房信息分页")
    //@SaCheckPermission("/storehouseInfo/storehouse/page")
    @GetMapping("/storehouseInfo/storehouse/page")
    public CommonResult<Page<StorehouseInfo>> page(StorehouseInfoPageParam storehouseInfoPageParam) {
        return CommonResult.data(storehouseInfoService.page(storehouseInfoPageParam));
    }

    /**
     * 添加库点仓房信息
     *
     * @author shine
     * @date  2024/04/28 11:51
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加库点仓房信息")
    @CommonLog("添加库点仓房信息")
    //@SaCheckPermission("/storehouseInfo/storehouse/add")
    @PostMapping("/storehouseInfo/storehouse/add")
    public CommonResult<String> add(@RequestBody @Valid StorehouseInfoAddParam storehouseInfoAddParam) {
        storehouseInfoService.add(storehouseInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑库点仓房信息
     *
     * @author shine
     * @date  2024/04/28 11:51
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑库点仓房信息")
    @CommonLog("编辑库点仓房信息")
    //@SaCheckPermission("/storehouseInfo/storehouse/edit")
    @PostMapping("/storehouseInfo/storehouse/edit")
    public CommonResult<String> edit(@RequestBody @Valid StorehouseInfoEditParam storehouseInfoEditParam) {
        storehouseInfoService.edit(storehouseInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除库点仓房信息
     *
     * @author shine
     * @date  2024/04/28 11:51
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除库点仓房信息")
    @CommonLog("删除库点仓房信息")
    //@SaCheckPermission("/storehouseInfo/storehouse/delete")
    @PostMapping("/storehouseInfo/storehouse/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<StorehouseInfoIdParam> storehouseInfoIdParamList) {
        storehouseInfoService.delete(storehouseInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取库点仓房信息详情
     *
     * @author shine
     * @date  2024/04/28 11:51
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取库点仓房信息详情")
    //@SaCheckPermission("/storehouseInfo/storehouse/detail")
    @GetMapping("/storehouseInfo/storehouse/detail")
    public CommonResult<StorehouseInfo> detail(@Valid StorehouseInfoIdParam storehouseInfoIdParam) {
        return CommonResult.data(storehouseInfoService.detail(storehouseInfoIdParam));
    }
}
