/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.storehouseInfo.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 库点仓房信息编辑参数
 *
 * @author shine
 * @date  2024/04/28 11:51
 **/
@Getter
@Setter
public class StorehouseInfoEditParam {

    /** STOREHOUSE_ID */
    @ApiModelProperty(value = "STOREHOUSE_ID", required = true, position = 1)
    @NotNull(message = "storehouseId不能为空")
    private Integer storehouseId;

    /** 与一体化系统对接使用的主键 */
    @ApiModelProperty(value = "与一体化系统对接使用的主键", position = 2)
    private String uuid;

    /** 所属库点ID */
    @ApiModelProperty(value = "所属库点ID", position = 3)
    private Integer depotId;

    /** 所属库点名称 */
    @ApiModelProperty(value = "所属库点名称", position = 4)
    private String depotName;

    /** 部门ID */
    @ApiModelProperty(value = "部门ID", position = 5)
    private Integer orgId;

    /** 部门名称 */
    @ApiModelProperty(value = "部门名称", position = 6)
    private String orgName;

    /** 仓房编号 */
    @ApiModelProperty(value = "仓房编号", position = 7)
    private String storehouseCode;

    /** 仓房名称 */
    @ApiModelProperty(value = "仓房名称", position = 8)
    private String storehouseName;

    /** 仓房类型编号（立筒仓等） */
    @ApiModelProperty(value = "仓房类型编号（立筒仓等）", position = 9)
    private Integer storehouseType;

    /** 仓房类型明细 */
    @ApiModelProperty(value = "仓房类型明细", position = 10)
    private Integer storehouseTypeMx;

    /** 建筑类型 */
    @ApiModelProperty(value = "建筑类型", position = 11)
    private String architectureType;

    /** 仓房图 */
    @ApiModelProperty(value = "仓房图", position = 12)
    private String storeImg;

    /** 仓房结构_地面 */
    @ApiModelProperty(value = "仓房结构_地面", position = 13)
    private String ground;

    /** 仓房结构_墙体 */
    @ApiModelProperty(value = "仓房结构_墙体", position = 14)
    private Integer wall;

    /** 仓房结构_房顶 */
    @ApiModelProperty(value = "仓房结构_房顶", position = 15)
    private String roof;

    /** 仓房结构_房架 */
    @ApiModelProperty(value = "仓房结构_房架", position = 16)
    private String house;

    /** 设计容量（数字，单位吨） */
    @ApiModelProperty(value = "设计容量（数字，单位吨）", position = 17)
    private BigDecimal designCapacity;

    /** 保管方式 */
    @ApiModelProperty(value = "保管方式", position = 18)
    private Integer keepingWay;

    /** 装粮高度 */
    @ApiModelProperty(value = "装粮高度", position = 19)
    private BigDecimal grainHeigth;

    /** 仓外_长（米） */
    @ApiModelProperty(value = "仓外_长（米）", position = 20)
    private BigDecimal storeOutsideLength;

    /** 仓外_宽（米） */
    @ApiModelProperty(value = "仓外_宽（米）", position = 21)
    private BigDecimal storeOutsideWidth;

    /** 仓外_檐高（米） */
    @ApiModelProperty(value = "仓外_檐高（米）", position = 22)
    private BigDecimal storeOutsideHeigth;

    /** 仓外_顶高(米) */
    @ApiModelProperty(value = "仓外_顶高(米)", position = 23)
    private BigDecimal storeOutsideTopHeigth;

    /** 筒仓外径(米) */
    @ApiModelProperty(value = "筒仓外径(米)", position = 24)
    private BigDecimal outsideSiloDiameter;

    /** 外墙面积(平方米) */
    @ApiModelProperty(value = "外墙面积(平方米)", position = 25)
    private BigDecimal outerWallArea;

    /** 扣除体积 */
    @ApiModelProperty(value = "扣除体积", position = 26)
    private BigDecimal deductVolume;

    /** 仓内长度（米） */
    @ApiModelProperty(value = "仓内长度（米）", position = 27)
    private BigDecimal length;

    /** 仓内宽度（米） */
    @ApiModelProperty(value = "仓内宽度（米）", position = 28)
    private BigDecimal width;

    /** 仓内檐高（米） */
    @ApiModelProperty(value = "仓内檐高（米）", position = 29)
    private BigDecimal heigth;

    /** 仓内装粮线高 */
    @ApiModelProperty(value = "仓内装粮线高", position = 30)
    private BigDecimal grainLineHeigth;

    /** 筒仓内径 */
    @ApiModelProperty(value = "筒仓内径", position = 31)
    private BigDecimal siloDiameter;

    /** 仓内体积 */
    @ApiModelProperty(value = "仓内体积", position = 32)
    private BigDecimal binVolume;

    /** 粮堆体积 */
    @ApiModelProperty(value = "粮堆体积", position = 33)
    private BigDecimal grainPileVolume;

    /** 仓门数量 */
    @ApiModelProperty(value = "仓门数量", position = 34)
    private Integer houseDoorNum;

    /** 仓门位置 */
    @ApiModelProperty(value = "仓门位置", position = 35)
    private String houseDootPosition;

    /** 仓门宽度（米） */
    @ApiModelProperty(value = "仓门宽度（米）", position = 36)
    private BigDecimal houseDoorWidth;

    /** 仓门高度（米） */
    @ApiModelProperty(value = "仓门高度（米）", position = 37)
    private BigDecimal houseDoorHeigth;

    /** 通风方式 */
    @ApiModelProperty(value = "通风方式", position = 38)
    private Integer drafttype;

    /** 隔热方式_仓顶 */
    @ApiModelProperty(value = "隔热方式_仓顶", position = 39)
    private String heatinsulationstepRoof;

    /** 隔热方式_仓窗 */
    @ApiModelProperty(value = "隔热方式_仓窗", position = 40)
    private String heatinsulationstepWindow;

    /** 隔热保温措施 */
    @ApiModelProperty(value = "隔热保温措施", position = 41)
    private String grbwcs;

    /** 能否散装储存(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "能否散装储存(1:能,0:否,9:其他或不确定)", position = 42)
    private Integer nfszcc;

    /** 有无防鼠防雀防虫装置及设施(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "有无防鼠防雀防虫装置及设施(1:能,0:否,9:其他或不确定)", position = 43)
    private Integer ywfsfqfczz;

    /** 有无防火防爆防盗设施(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "有无防火防爆防盗设施(1:能,0:否,9:其他或不确定)", position = 44)
    private Integer ywfhfbfdss;

    /** 有无粮情检测设施(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "有无粮情检测设施(1:能,0:否,9:其他或不确定)", position = 45)
    private Integer ywlqjcss;

    /** 有无机械通风设施(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "有无机械通风设施(1:能,0:否,9:其他或不确定)", position = 46)
    private Integer ywjxtfss;

    /** 能否环流熏蒸杀虫(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "能否环流熏蒸杀虫(1:能,0:否,9:其他或不确定)", position = 47)
    private Integer nfhlxzsc;

    /** 能否富氮低氧气调储粮(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "能否富氮低氧气调储粮(1:能,0:否,9:其他或不确定)", position = 48)
    private Integer nffddyqtcl;

    /** 能否仓外测虫(1:能,0:否,9:其他或不确定) */
    @ApiModelProperty(value = "能否仓外测虫(1:能,0:否,9:其他或不确定)", position = 49)
    private Integer nfcwcc;

    /** 实际容量（数字，单位吨） */
    @ApiModelProperty(value = "实际容量（数字，单位吨）", position = 50)
    private BigDecimal actualCapacity;

    /** 建成日期 */
    @ApiModelProperty(value = "建成日期", position = 51)
    private Date completionDate;

    /** 启用日期 */
    @ApiModelProperty(value = "启用日期", position = 52)
    private Date usedate;

    /** 仓房状态 */
    @ApiModelProperty(value = "仓房状态", position = 53)
    private Integer storehouseState;

    /** 储粮方式 */
    @ApiModelProperty(value = "储粮方式", position = 54)
    private Integer storeWay;

    /** 仓房使用状态 */
    @ApiModelProperty(value = "仓房使用状态", position = 55)
    private Integer currenttype;

    /** 责任保管员 */
    @ApiModelProperty(value = "责任保管员", position = 56)
    private String dutystoreman;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 57)
    private String remark;

    /** 创建人 */
    @ApiModelProperty(value = "创建人", position = 58)
    private String createname;

    /** 创建日期 */
    @ApiModelProperty(value = "创建日期", position = 59)
    private Date createdate;

    /** 更新人 */
    @ApiModelProperty(value = "更新人", position = 60)
    private String updatename;

    /** 更新日期 */
    @ApiModelProperty(value = "更新日期", position = 61)
    private Date updatedate;

    /** 粮食作业状态 */
    @ApiModelProperty(value = "粮食作业状态", position = 62)
    private Integer workingStatus;

    /** 删除状态(1.正常，2.删除) */
    @ApiModelProperty(value = "删除状态(1.正常，2.删除)", position = 63)
    private Integer delFlag;

    /** 库类型，0.主粮库，1.代储点粮库 */
    @ApiModelProperty(value = "库类型，0.主粮库，1.代储点粮库", position = 64)
    private String libraryType;

    /** UPDATETIME */
    @ApiModelProperty(value = "UPDATETIME", position = 65)
    private Date updatetime;

    /** 数据类型(0仓房,1油罐) */
    @ApiModelProperty(value = "数据类型(0仓房,1油罐)", position = 66)
    private String datatype;

    /** CFBM */
    @ApiModelProperty(value = "CFBM", position = 67)
    private String cfbm;

    /** AJBM */
    @ApiModelProperty(value = "AJBM", position = 68)
    private String ajbm;

    /** 储粮功效 */
    @ApiModelProperty(value = "储粮功效", position = 69)
    private Integer clgx;

    /** 结构材料 */
    @ApiModelProperty(value = "结构材料", position = 70)
    private Integer jgcl;

    /** 隔热性能 */
    @ApiModelProperty(value = "隔热性能", position = 71)
    private Integer grxn;

    /** 气密性 */
    @ApiModelProperty(value = "气密性", position = 72)
    private Integer qmx;

    /** 粮情技术 */
    @ApiModelProperty(value = "粮情技术", position = 73)
    private Integer lqjs;

    /** 通风技术 */
    @ApiModelProperty(value = "通风技术", position = 74)
    private Integer tfjs;

    /** 杀虫技术 */
    @ApiModelProperty(value = "杀虫技术", position = 75)
    private Integer scjs;

    /** 控温技术 */
    @ApiModelProperty(value = "控温技术", position = 76)
    private Integer kwjs;

    /** 是否已进行信息化改造 */
    @ApiModelProperty(value = "是否已进行信息化改造", position = 77)
    private Integer sfyjxxxhgz;

    /** 挡粮门型式 */
    @ApiModelProperty(value = "挡粮门型式", position = 78)
    private String dlmxs;

    /** 建设单位 */
    @ApiModelProperty(value = "建设单位", position = 79)
    private String jsdw;

    /** 设计使用年限 */
    @ApiModelProperty(value = "设计使用年限", position = 80)
    private String sjsynx;

    /** 设计单位 */
    @ApiModelProperty(value = "设计单位", position = 81)
    private String sjdw;

    /** 监理单位 */
    @ApiModelProperty(value = "监理单位", position = 82)
    private String jldw;

    /** 能否隔热保温 */
    @ApiModelProperty(value = "能否隔热保温", position = 83)
    private Integer nfgrbw;

    /** 通风系统型式 */
    @ApiModelProperty(value = "通风系统型式", position = 84)
    private Integer tfxtxs;

    /** 害虫检测方式 */
    @ApiModelProperty(value = "害虫检测方式", position = 85)
    private String hcjcfs;

}
