/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.storehouseInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.storehouseInfo.entity.StorehouseInfo;
import com.unis.basic.info.modular.storehouseInfo.mapper.StorehouseInfoMapper;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoAddParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoEditParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoIdParam;
import com.unis.basic.info.modular.storehouseInfo.param.StorehouseInfoPageParam;
import com.unis.basic.info.modular.storehouseInfo.service.StorehouseInfoService;

import java.util.List;

/**
 * 库点仓房信息Service接口实现类
 *
 * @author shine
 * @date  2024/04/28 11:51
 **/
@Service
public class StorehouseInfoServiceImpl extends ServiceImpl<StorehouseInfoMapper, StorehouseInfo> implements StorehouseInfoService {

    @Override
    public Page<StorehouseInfo> page(StorehouseInfoPageParam storehouseInfoPageParam) {
        QueryWrapper<StorehouseInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(storehouseInfoPageParam.getDepotId())) {
            queryWrapper.lambda().eq(StorehouseInfo::getDepotId, storehouseInfoPageParam.getDepotId());
        }
        if(ObjectUtil.isNotEmpty(storehouseInfoPageParam.getDepotName())) {
            queryWrapper.lambda().like(StorehouseInfo::getDepotName, storehouseInfoPageParam.getDepotName());
        }
        if(ObjectUtil.isNotEmpty(storehouseInfoPageParam.getOrgId())) {
            queryWrapper.lambda().eq(StorehouseInfo::getOrgId, storehouseInfoPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(storehouseInfoPageParam.getOrgName())) {
            queryWrapper.lambda().like(StorehouseInfo::getOrgName, storehouseInfoPageParam.getOrgName());
        }
        if(ObjectUtil.isNotEmpty(storehouseInfoPageParam.getStorehouseName())) {
            queryWrapper.lambda().like(StorehouseInfo::getStorehouseName, storehouseInfoPageParam.getStorehouseName());
        }
        if(ObjectUtil.isAllNotEmpty(storehouseInfoPageParam.getSortField(), storehouseInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(storehouseInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, storehouseInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(storehouseInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(StorehouseInfo::getStorehouseId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(StorehouseInfoAddParam storehouseInfoAddParam) {
        StorehouseInfo storehouseInfo = BeanUtil.toBean(storehouseInfoAddParam, StorehouseInfo.class);
        this.save(storehouseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(StorehouseInfoEditParam storehouseInfoEditParam) {
        StorehouseInfo storehouseInfo = this.queryEntity(storehouseInfoEditParam.getStorehouseId());
        BeanUtil.copyProperties(storehouseInfoEditParam, storehouseInfo);
        this.updateById(storehouseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<StorehouseInfoIdParam> storehouseInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(storehouseInfoIdParamList, StorehouseInfoIdParam::getStorehouseId));
    }

    @Override
    public StorehouseInfo detail(StorehouseInfoIdParam storehouseInfoIdParam) {
        return this.queryEntity(Integer.valueOf(storehouseInfoIdParam.getStorehouseId()));
    }

    @Override
    public StorehouseInfo queryEntity(Integer id) {
        StorehouseInfo storehouseInfo = this.getById(id);
        if(ObjectUtil.isEmpty(storehouseInfo)) {
            throw new CommonException("库点仓房信息不存在，id值为：{}", id);
        }
        return storehouseInfo;
    }
}
