/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.tankInfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoPageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.tankInfo.entity.TankInfo;
import com.unis.basic.info.modular.tankInfo.param.TankInfoAddParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoEditParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoIdParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoPageParam;
import com.unis.basic.info.modular.tankInfo.service.TankInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.Map;

/**
 * 油罐基本信息主表控制器
 *
 * @author shine
 * @date  2024/04/28 11:59
 */
@Api(tags = "油罐基本信息主表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class TankInfoController {

    @Resource
    private TankInfoService tankInfoService;

    /**
     * 获取油罐基本信息主表分页
     *
     * @author shine
     * @date  2024/04/28 11:59
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取油罐基本信息主表分页")
    //@SaCheckPermission("/tank/tank/page")
    @GetMapping("/tank/tank/page")
    public CommonResult<Page<TankInfo>> page(TankInfoPageParam tankInfoPageParam) {
        return CommonResult.data(tankInfoService.page(tankInfoPageParam));
    }

    /**
     * 获取油罐信息表分页
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取油罐信息表分页--自定义")
    @GetMapping("/tank/tank/pageList")
    public CommonResult<IPage<Map<String,Object>>> pageList(TankInfoPageParam tankInfoPageParam) {
        return CommonResult.data(tankInfoService.pageList(tankInfoPageParam));
    }
    /**
     * 添加油罐基本信息主表
     *
     * @author shine
     * @date  2024/04/28 11:59
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加油罐基本信息主表")
    @CommonLog("添加油罐基本信息主表")
    //@SaCheckPermission("/tank/tank/add")
    @PostMapping("/tank/tank/add")
    public CommonResult<String> add(@RequestBody @Valid TankInfoAddParam tankInfoAddParam) {
        tankInfoService.add(tankInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑油罐基本信息主表
     *
     * @author shine
     * @date  2024/04/28 11:59
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑油罐基本信息主表")
    @CommonLog("编辑油罐基本信息主表")
    //@SaCheckPermission("/tank/tank/edit")
    @PostMapping("/tank/tank/edit")
    public CommonResult<String> edit(@RequestBody @Valid TankInfoEditParam tankInfoEditParam) {
        tankInfoService.edit(tankInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除油罐基本信息主表
     *
     * @author shine
     * @date  2024/04/28 11:59
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除油罐基本信息主表")
    @CommonLog("删除油罐基本信息主表")
    //@SaCheckPermission("/tank/tank/delete")
    @PostMapping("/tank/tank/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<TankInfoIdParam> tankInfoIdParamList) {
        tankInfoService.delete(tankInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取油罐基本信息主表详情
     *
     * @author shine
     * @date  2024/04/28 11:59
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取油罐基本信息主表详情")
    //@SaCheckPermission("/tank/tank/detail")
    @GetMapping("/tank/tank/detail")
    public CommonResult<TankInfo> detail(@Valid TankInfoIdParam tankInfoIdParam) {
        return CommonResult.data(tankInfoService.detail(tankInfoIdParam));
    }
}
