/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.tankInfo.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 油罐基本信息主表编辑参数
 *
 * @author shine
 * @date  2024/04/28 11:59
 **/
@Getter
@Setter
public class TankInfoEditParam {

    /** 主键ID */
    @ApiModelProperty(value = "主键ID", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 油罐编码 */
    @ApiModelProperty(value = "油罐编码", position = 2)
    private String storagetankCode;

    /** 油罐名称 */
    @ApiModelProperty(value = "油罐名称", position = 3)
    private String storagetankName;

    /** 库区编码 */
    @ApiModelProperty(value = "库区编码", position = 4)
    private String orgCode;

    /** 油罐容量 */
    @ApiModelProperty(value = "油罐容量", position = 5)
    private BigDecimal tankCapacity;

    /** 创建时间 */
    @ApiModelProperty(value = "创建时间", position = 6)
    private Date createdate;

    /** 附属设施是否完好 */
    @ApiModelProperty(value = "附属设施是否完好", position = 7)
    private Integer facilitiesType;

    /** 有无加热装置 */
    @ApiModelProperty(value = "有无加热装置", position = 8)
    private Integer heatingType;

    /** 油罐类型 */
    @ApiModelProperty(value = "油罐类型", position = 9)
    private Integer tankType;

    /** 直径(米) */
    @ApiModelProperty(value = "直径(米)", position = 10)
    private BigDecimal diameter;

    /** 高度(米) */
    @ApiModelProperty(value = "高度(米)", position = 11)
    private BigDecimal height;

    /** 建造日期 */
    @ApiModelProperty(value = "建造日期", position = 12)
    private Date builddate;

    /** 检定方式 */
    @ApiModelProperty(value = "检定方式", position = 13)
    private Integer checkWay;

    /** 焊接方式 */
    @ApiModelProperty(value = "焊接方式", position = 14)
    private Integer weldWay;

    /** 油罐使用情况(已弃用) */
    @ApiModelProperty(value = "油罐使用情况(已弃用)", position = 15)
    private Integer tankApply;

    /** 油罐状态 */
    @ApiModelProperty(value = "油罐状态", position = 16)
    private Integer tankStatus;

    /** 组织机构ID */
    @ApiModelProperty(value = "组织机构ID", position = 17)
    private Integer orgId;

    /** 删除状态(1:在用,0:弃用) */
    @ApiModelProperty(value = "删除状态(1:在用,0:弃用)", position = 18)
    private Integer delFlag;

    /** 更新时间 */
    @ApiModelProperty(value = "更新时间", position = 19)
    private Date updatetime;

    /** 底面积(平方米) */
    @ApiModelProperty(value = "底面积(平方米)", position = 20)
    private BigDecimal bottomArea;

    /** 设计储油高度(米) */
    @ApiModelProperty(value = "设计储油高度(米)", position = 21)
    private BigDecimal designHeight;

    /** 出油口高度(米) */
    @ApiModelProperty(value = "出油口高度(米)", position = 22)
    private BigDecimal oilHeight;

    /** 检查口高度(米) */
    @ApiModelProperty(value = "检查口高度(米)", position = 23)
    private BigDecimal insportHeight;

    /** 油罐图 */
    @ApiModelProperty(value = "油罐图", position = 24)
    private String tankChart;

    /** 油罐库区图 */
    @ApiModelProperty(value = "油罐库区图", position = 25)
    private String tanklibChart;

    /** 是否代储(0:否,1:是) */
    @ApiModelProperty(value = "是否代储(0:否,1:是)", position = 26)
    private String libraryType;

    /** BASIC_TRUCK_TYPE */
    @ApiModelProperty(value = "BASIC_TRUCK_TYPE", position = 27)
    private String basicTruckType;

    /** 出入库状态(1空仓,2入库中,3封仓,4出库中) */
    @ApiModelProperty(value = "出入库状态(1空仓,2入库中,3封仓,4出库中)", position = 28)
    private String crkStatus;

    /** 油罐标准编码 */
    @ApiModelProperty(value = "油罐标准编码", position = 29)
    private String ygdm;

    /** 油罐廒间标准编码 */
    @ApiModelProperty(value = "油罐廒间标准编码", position = 30)
    private String ygajdm;

    /** 存放粮油类型(0:原粮,1:成品粮) */
    @ApiModelProperty(value = "存放粮油类型(0:原粮,1:成品粮)", position = 31)
    private String lylx;

    /** 建设单位 */
    @ApiModelProperty(value = "建设单位", position = 32)
    private String jsdw;

    /** 设计单位 */
    @ApiModelProperty(value = "设计单位", position = 33)
    private String sjdw;

    /** 监理单位 */
    @ApiModelProperty(value = "监理单位", position = 34)
    private String jldw;

    /** 市平台油罐数据主键ID */
    @ApiModelProperty(value = "市平台油罐数据主键ID", position = 35)
    private String sptDataid;

}
