/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.tankInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.aisleInfo.entity.AisleInfo;
import com.unis.basic.info.modular.aisleInfo.mapper.AisleInfoMapper;
import com.unis.basic.info.modular.aisleInfo.param.AisleInfoPageParam;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.basic.info.modular.orgInfo.service.impl.OrgInfoServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.tankInfo.entity.TankInfo;
import com.unis.basic.info.modular.tankInfo.mapper.TankInfoMapper;
import com.unis.basic.info.modular.tankInfo.param.TankInfoAddParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoEditParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoIdParam;
import com.unis.basic.info.modular.tankInfo.param.TankInfoPageParam;
import com.unis.basic.info.modular.tankInfo.service.TankInfoService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 油罐基本信息主表Service接口实现类
 *
 * @author shine
 * @date  2024/04/28 11:59
 **/
@Service
public class TankInfoServiceImpl extends ServiceImpl<TankInfoMapper, TankInfo> implements TankInfoService {

    @Resource
    private TankInfoMapper tankInfoMapper;

    @Resource
    private OrgInfoServiceImpl orgInfoServiceImpl;



    @Override
    public Page<TankInfo> page(TankInfoPageParam tankInfoPageParam) {
        QueryWrapper<TankInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(tankInfoPageParam.getStoragetankName())) {
            queryWrapper.lambda().like(TankInfo::getStoragetankName, tankInfoPageParam.getStoragetankName());
        }
        if(ObjectUtil.isNotEmpty(tankInfoPageParam.getOrgId())) {
            queryWrapper.lambda().eq(TankInfo::getOrgId, tankInfoPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(tankInfoPageParam.getDelFlag())) {
            queryWrapper.lambda().eq(TankInfo::getDelFlag, tankInfoPageParam.getDelFlag());
        }
        if(ObjectUtil.isNotEmpty(tankInfoPageParam.getLibraryType())) {
            queryWrapper.lambda().eq(TankInfo::getLibraryType, tankInfoPageParam.getLibraryType());
        }
        if(ObjectUtil.isAllNotEmpty(tankInfoPageParam.getSortField(), tankInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(tankInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, tankInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(tankInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(TankInfo::getId);
        }

        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(TankInfoAddParam tankInfoAddParam) {
        TankInfo tankInfo = BeanUtil.toBean(tankInfoAddParam, TankInfo.class);
        this.save(tankInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(TankInfoEditParam tankInfoEditParam) {
        TankInfo tankInfo = this.queryEntity(tankInfoEditParam.getId());
        BeanUtil.copyProperties(tankInfoEditParam, tankInfo);
        this.updateById(tankInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<TankInfoIdParam> tankInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(tankInfoIdParamList, TankInfoIdParam::getId));
    }

    @Override
    public TankInfo detail(TankInfoIdParam tankInfoIdParam) {
        return this.queryEntity(tankInfoIdParam.getId());
    }

    @Override
    public TankInfo queryEntity(String id) {
        TankInfo tankInfo = this.getById(id);
        if(ObjectUtil.isEmpty(tankInfo)) {
            throw new CommonException("油罐基本信息主表不存在，id值为：{}", id);
        }
        return tankInfo;
    }

    @Override
    public IPage<Map<String, Object>> pageList(TankInfoPageParam tankInfoPageParam) {
        //条形查询器
        QueryWrapper<TankInfo> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(tankInfoPageParam.getOrgName())) {
            queryWrapper.like("o.org_name", tankInfoPageParam.getOrgName());
        }
        Page<TankInfo> p = new Page<TankInfo>(tankInfoPageParam.getCurrent(), tankInfoPageParam.getSize());

        IPage<Map<String, Object>> page = tankInfoMapper.selectMyMapsPage(p, queryWrapper);
        return page;
    }
}
