/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.usercollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.usercollect.vo.PricemonitorVO;
import com.unis.basic.info.modular.usercollect.vo.UserCollectVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.usercollect.entity.UserCollect;
import com.unis.basic.info.modular.usercollect.param.UserCollectAddParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectEditParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectIdParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectPageParam;
import com.unis.basic.info.modular.usercollect.service.UserCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 采集人员控制器
 *
 * @author weiyinbin
 * @date 2024/04/02 15:40
 */
@Slf4j
@Api(tags = "采集人员控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class UserCollectController {

    @Resource
    private UserCollectService userCollectService;

    /**
     * 获取采集人员分页
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取采集人员分页")
   // @SaCheckPermission("/basic.info/usercollect/page")
    @GetMapping("/basic.info/usercollect/page")
    public CommonResult<IPage<UserCollectVO>> page(UserCollectPageParam userCollectPageParam) {
        return CommonResult.data(userCollectService.page(userCollectPageParam));
    }

    /**
     * 添加采集人员
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */

    @ApiOperationSupport(order = 2)
    @ApiOperation("添加采集人员")
    @CommonLog("添加采集人员")
    //@SaCheckPermission("/basic.info/usercollect/add")
    @PostMapping("/basic.info/usercollect/add")
    public CommonResult<String> add(@RequestBody @Valid UserCollectAddParam userCollectAddParam) {
        userCollectService.add(userCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑采集人员
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑采集人员")
    @CommonLog("编辑采集人员")
   // @SaCheckPermission("/basic.info/usercollect/edit")
    @PostMapping("/basic.info/usercollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid UserCollectEditParam userCollectEditParam) {
        userCollectService.edit(userCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除采集人员
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除采集人员")
    @CommonLog("删除采集人员")
    //@SaCheckPermission("/basic.info/usercollect/delete")
    @PostMapping("/basic.info/usercollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<UserCollectIdParam> userCollectIdParamList) {
        userCollectService.delete(userCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取采集人员详情
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取采集人员详情")
   // @SaCheckPermission("/basic.info/usercollect/detail")
    @GetMapping("/basic.info/usercollect/detail")
    public CommonResult<UserCollectVO> detail(@Valid UserCollectIdParam userCollectIdParam) {
        return CommonResult.data(userCollectService.detail(userCollectIdParam));
    }

    /**
     * 获取监测点信息
     *
     * @author weiyinbin
     * @date 2024/04/02 15:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取监测点信息")
    //@SaCheckPermission("/basic.info/usercollect/getPricemonitor")
    @GetMapping("/basic.info/usercollect/getPricemonitor")
    public CommonResult<List<PricemonitorVO>> getPricemonitor(String orgId) {
        return CommonResult.data(userCollectService.getPricemonitor(orgId));
    }


}
