/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.usercollect.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.auth.modular.login.enums.AuthExceptionEnum;
import com.unis.basic.info.modular.grainPriceCollect.entity.GrainPriceCollect;
import com.unis.basic.info.modular.grainPriceCollect.mapper.GrainPriceCollectMapper;
import com.unis.basic.info.modular.grainPriceCollectCitySum.mapper.GrainPriceCollectCitySumMapper;
import com.unis.basic.info.modular.pricemonitor.entity.PriceMonitor;
import com.unis.basic.info.modular.pricemonitor.mapper.PriceMonitorMapper;
import com.unis.basic.info.modular.usercollect.entity.UserPrice;
import com.unis.basic.info.modular.usercollect.mapper.UserPriceMapper;
import com.unis.basic.info.modular.usercollect.vo.PricemonitorVO;
import com.unis.basic.info.modular.usercollect.vo.UserCollectVO;
import com.unis.common.util.CommonCryptogramUtil;
import com.unis.sys.modular.org.entity.SysOrg;
import com.unis.sys.modular.org.mapper.SysOrgMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.usercollect.entity.UserCollect;
import com.unis.basic.info.modular.usercollect.mapper.UserCollectMapper;
import com.unis.basic.info.modular.usercollect.param.UserCollectAddParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectEditParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectIdParam;
import com.unis.basic.info.modular.usercollect.param.UserCollectPageParam;
import com.unis.basic.info.modular.usercollect.service.UserCollectService;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 采集人员Service接口实现类
 *
 * @author weiyinbin
 * @date 2024/04/02 15:40
 **/
@Service
@Slf4j
public class UserCollectServiceImpl extends ServiceImpl<UserCollectMapper, UserCollect> implements UserCollectService {


    @Autowired
    private UserCollectMapper userCollectMapper;

    @Autowired
    private UserPriceMapper userPriceMapper;

    @Autowired
    private PriceMonitorMapper priceMonitorMapper;

    @Autowired
    private GrainPriceCollectMapper grainPriceCollectMapper;

    @Autowired
    private SysOrgMapper sysOrgMapper;


    @Override
    public IPage<UserCollectVO> page(UserCollectPageParam userCollectPageParam) {

      /*  QueryWrapper<UserCollect> queryWrapper = new QueryWrapper<>();
        if (!StringUtils.isEmpty(userCollectPageParam.getName())) {
            queryWrapper.like("name", userCollectPageParam.getName());
        }
        if (!StringUtils.isEmpty(userCollectPageParam.getSysOrgId())){
            queryWrapper.eq("sys_org_id",userCollectPageParam.getSysOrgId());
        }*/

       /* if (ObjectUtil.isAllNotEmpty(userCollectPageParam.getSortField(), userCollectPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(userCollectPageParam.getSortOrder());
            queryWrapper.orderBy(true, userCollectPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(userCollectPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(UserCollect::getCreateTime);
        }
         return this.page(CommonPageRequest.defaultPage(), queryWrapper);
        */

        Page<UserCollectVO> page = new Page<>(userCollectPageParam.getCurrent(), userCollectPageParam.getSize());

        IPage<UserCollectVO> p = userCollectMapper.selectUserPage(page, userCollectPageParam.getName(), userCollectPageParam.getOrgName());

        return p;

    }

    /**
     * @author: hujianchun
     * @Description: 新增采集人员信息
     * @param:
     * @return:
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(UserCollectAddParam userCollectAddParam) {

        //参数校验
        String phone = userCollectAddParam.getPhone();
        if (phone.length() != 11) {
            throw new CommonException("手机格式错误,请输入11位！");
        }

        UserCollect userCollect = new UserCollect();
        BeanUtils.copyProperties(userCollectAddParam, userCollect);
        userCollect.setCreateTime(new DateTime());
        userCollect.setUpdateTime(new DateTime());

        // 做哈希值存储
        String passwordHash = CommonCryptogramUtil.doHashValue("123456");
        userCollect.setPassword(passwordHash);
        userCollect.setType("1");

        userCollectMapper.insert(userCollect);


        String[] monitorIdList = userCollectAddParam.getPriceMonitorName().split(",");

        for (String monitorId : monitorIdList) {

            /*List<PriceMonitor> priceMonitors = priceMonitorMapper.selectList(Wrappers.lambdaQuery(PriceMonitor.class)
                    .eq(PriceMonitor::getName, monitorName));
            if (CollectionUtils.isEmpty(priceMonitors)) {
                throw new CommonException("暂无站点数据");
            }*/
            //添加中间表数据
            UserPrice userPrice = new UserPrice();
            userPrice.setUserCollectId(userCollect.getId());
            userPrice.setPriceMonitorId(monitorId);
            userPriceMapper.insert(userPrice);
        }

       /* //获取价格监测的orgId
        LambdaQueryWrapper<SysOrg> wrapper = new LambdaQueryWrapper<>();
        wrapper.eq(SysOrg::getName, userCollectAddParam.getOrgName());
        List<SysOrg> orgList = sysOrgMapper.selectList(wrapper);
        if (CollectionUtils.isEmpty(orgList)) {
            log.error("暂无市州信息，名称[{}]", userCollectAddParam.getOrgName());
            throw new CommonException("暂无对应市州信息，请重试");
        }

        PriceMonitor priceMonitor = priceMonitorMapper.selectOne(Wrappers.lambdaQuery(PriceMonitor.class)
                .eq(PriceMonitor::getName, userCollectAddParam.getPriceMonitorName()));
        if (ObjectUtil.isEmpty(priceMonitor)) {
            throw new CommonException("暂无对应监测站点信息，请重试");
        }


        if (!priceMonitor.getSysOrgId().equals(orgList.get(0).getId())) {
            throw new CommonException("所属机构下无该站点信息");
        }

        //插入中间表数据
        UserPrice userPrice = new UserPrice();
        userPrice.setUserCollectId(String.valueOf(userCollect.getId()));
        userPrice.setPriceMonitorId(String.valueOf(priceMonitor.getId()));

        try {
            userPriceMapper.insert(userPrice);
        } catch (Exception e) {
            log.error("新增采集人员和价格监测关系,数据库异常[{}]", e.getMessage());
            throw new CommonException("新增采集人员和价格监测关系失败");

        }*/
    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 编辑
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(UserCollectEditParam userCollectEditParam) {
      /*  UserCollect userCollect = this.queryEntity(userCollectEditParam.getId());
        BeanUtil.copyProperties(userCollectEditParam, userCollect);
        this.updateById(userCollect);*/
        UserCollect DBuserCollect = userCollectMapper.selectOne(Wrappers.lambdaQuery(UserCollect.class)
                .eq(UserCollect::getPhone, userCollectEditParam.getPhone()));
        if (!ObjectUtil.isEmpty(DBuserCollect) && !Objects.equals(DBuserCollect.getId(), userCollectEditParam.getId())) {
            throw new CommonException("手机号已存在，请重新输入");
        }
        UserCollect userCollect = userCollectMapper.selectById(userCollectEditParam.getId());
        if (ObjectUtil.isEmpty(userCollect)) {
            throw new CommonException("暂无找到相关信息,id为{}", userCollectEditParam.getId());
        }

        BeanUtils.copyProperties(userCollectEditParam, userCollect);

        //删除数据
        QueryWrapper<UserPrice> deleteQu = new QueryWrapper<>();
        deleteQu.eq("user_collect_id", userCollect.getId());
        userPriceMapper.delete(deleteQu);

        // userCollect.setUpdateTime(new Date());
        String[] monitorIdList = userCollectEditParam.getPriceMonitorName().split(",");

        for (String monitorId : monitorIdList) {

            /*List<PriceMonitor> priceMonitors = priceMonitorMapper.selectList(Wrappers.lambdaQuery(PriceMonitor.class)
                    .eq(PriceMonitor::getName, monitorName));
            if (CollectionUtils.isEmpty(priceMonitors)) {
                throw new CommonException("暂无站点数据");
            }*/
            //添加中间表数据
            UserPrice userPrice = new UserPrice();
            userPrice.setUserCollectId(userCollect.getId());
            userPrice.setPriceMonitorId(monitorId);
            userPriceMapper.insert(userPrice);
        }

        try {
            //更新采集人员表
            this.updateById(userCollect);

        } catch (Exception e) {
            log.error("采集人员操作数据库，修改失败,人员id:[{}]", userCollectEditParam.getId());
            throw new CommonException("采集人员操作数据库，修改失败");
        }


    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 删除
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<UserCollectIdParam> userCollectIdParamList) {

        UserCollectIdParam userCollectIdParam = userCollectIdParamList.get(0);
        String id = userCollectIdParam.getId();

        List<GrainPriceCollect> grainPriceCollects = grainPriceCollectMapper.selectList(Wrappers.lambdaQuery(GrainPriceCollect.class)
                .eq(GrainPriceCollect::getUserCollectId, id));
        if (!CollectionUtils.isEmpty(grainPriceCollects)) {
            throw new CommonException("该数据与粮食价格采集相关联，不能删除");
        }

        // 执行删除
        this.removeByIds(CollStreamUtil.toList(userCollectIdParamList, UserCollectIdParam::getId));


    }

    /**
     * @author: hujianchun
     * @Description:
     * @param:
     * @return: 获取详情
     */
    @Override
    public UserCollectVO detail(UserCollectIdParam userCollectIdParam) {
        // return this.queryEntity(userCollectIdParam.getId());

        return userCollectMapper.selectByUserId(userCollectIdParam.getId());

    }

    @Override
    public UserCollect queryEntity(String id) {
        UserCollect userCollect = this.getById(id);
        if (ObjectUtil.isEmpty(userCollect)) {
            throw new CommonException("采集人员不存在，id值为：{}", id);
        }
        return userCollect;
    }


    @Override
    public List<PricemonitorVO> getPricemonitor(String orgId) {

        return priceMonitorMapper.selectPricemonitorVO(orgId);
    }
}
