/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.warehouseInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.aisleInfo.entity.AisleInfo;
import com.unis.basic.info.modular.aisleInfo.mapper.AisleInfoMapper;
import com.unis.basic.info.modular.aisleInfo.service.impl.AisleInfoServiceImpl;
import com.unis.basic.info.modular.storehouseInfo.entity.StorehouseInfo;
import com.unis.basic.info.modular.storehouseInfo.service.impl.StorehouseInfoServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.warehouseInfo.entity.WarehouseInfo;
import com.unis.basic.info.modular.warehouseInfo.mapper.WarehouseInfoMapper;
import com.unis.basic.info.modular.warehouseInfo.param.WarehouseInfoAddParam;
import com.unis.basic.info.modular.warehouseInfo.param.WarehouseInfoEditParam;
import com.unis.basic.info.modular.warehouseInfo.param.WarehouseInfoIdParam;
import com.unis.basic.info.modular.warehouseInfo.param.WarehouseInfoPageParam;
import com.unis.basic.info.modular.warehouseInfo.service.WarehouseInfoService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 库中仓房下的货位信息Service接口实现类
 *
 * @author shine
 * @date  2024/04/28 11:56
 **/
@Service
public class WarehouseInfoServiceImpl extends ServiceImpl<WarehouseInfoMapper, WarehouseInfo> implements WarehouseInfoService {

    @Resource
    private AisleInfoServiceImpl aisleInfoServiceImpl;

    @Resource
    private StorehouseInfoServiceImpl storehouseInfoServiceImpl;
    @Override
    public Page<WarehouseInfo> page(WarehouseInfoPageParam warehouseInfoPageParam) {
        QueryWrapper<WarehouseInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getDepotId())) {
            queryWrapper.lambda().eq(WarehouseInfo::getDepotId, warehouseInfoPageParam.getDepotId());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getDepotName())) {
            queryWrapper.lambda().like(WarehouseInfo::getDepotName, warehouseInfoPageParam.getDepotName());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getStorehouseId())) {
            queryWrapper.lambda().eq(WarehouseInfo::getStorehouseId, warehouseInfoPageParam.getStorehouseId());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getWarehouseName())) {
            queryWrapper.lambda().like(WarehouseInfo::getWarehouseName, warehouseInfoPageParam.getWarehouseName());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getDelFlag())) {
            queryWrapper.lambda().eq(WarehouseInfo::getDelFlag, warehouseInfoPageParam.getDelFlag());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getOrgId())) {
            queryWrapper.lambda().eq(WarehouseInfo::getOrgId, warehouseInfoPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(warehouseInfoPageParam.getUnitAisleId())) {
            queryWrapper.lambda().eq(WarehouseInfo::getAisleId, warehouseInfoPageParam.getUnitAisleId());
        }
        if(ObjectUtil.isAllNotEmpty(warehouseInfoPageParam.getSortField(), warehouseInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(warehouseInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, warehouseInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(warehouseInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(WarehouseInfo::getWarehouseId);
        }
        Page<WarehouseInfo> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(WarehouseInfo warehouseInfo:pageList.getRecords()){
            if(warehouseInfo.getAisleId() != null){
                AisleInfo aisleInfo =  aisleInfoServiceImpl.queryEntity(warehouseInfo.getAisleId());
                if(aisleInfo != null){
                    warehouseInfo.setAjmc(aisleInfo.getAjmc());
                }
            }
            if(warehouseInfo.getStorehouseId() != null){
                StorehouseInfo storehouseInfo = storehouseInfoServiceImpl.queryEntity(warehouseInfo.getStorehouseId());
                if(storehouseInfo != null){
                    warehouseInfo.setCfmc(storehouseInfo.getStorehouseName());
                }
            }
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(WarehouseInfoAddParam warehouseInfoAddParam) {
        WarehouseInfo warehouseInfo = BeanUtil.toBean(warehouseInfoAddParam, WarehouseInfo.class);
        this.save(warehouseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(WarehouseInfoEditParam warehouseInfoEditParam) {
        WarehouseInfo warehouseInfo = this.queryEntity(warehouseInfoEditParam.getWarehouseId());
        BeanUtil.copyProperties(warehouseInfoEditParam, warehouseInfo);
        this.updateById(warehouseInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<WarehouseInfoIdParam> warehouseInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(warehouseInfoIdParamList, WarehouseInfoIdParam::getWarehouseId));
    }

    @Override
    public WarehouseInfo detail(WarehouseInfoIdParam warehouseInfoIdParam) {
        return this.queryEntity(Integer.valueOf(warehouseInfoIdParam.getWarehouseId()));
    }

    @Override
    public WarehouseInfo queryEntity(Integer id) {
        WarehouseInfo warehouseInfo = this.getById(id);
        if(ObjectUtil.isEmpty(warehouseInfo)) {
            throw new CommonException("库中仓房下的货位信息不存在，id值为：{}", id);
        }
        return warehouseInfo;
    }
}
