/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.dataDockCollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.circulateMonitor.modular.dataDockCollect.entity.DataDockCollect;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectAddParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectEditParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectIdParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectPageParam;
import com.unis.circulateMonitor.modular.dataDockCollect.service.DataDockCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 数据对接采集管理控制器
 *
 * @author QSHan
 * @date  2024/06/17 15:27
 */
@Api(tags = "数据对接采集管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DataDockCollectController {

    @Resource
    private DataDockCollectService dataDockCollectService;

    /**
     * 获取数据对接采集管理分页
     *
     * @author QSHan
     * @date  2024/06/17 15:27
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取数据对接采集管理分页")
//    @SaCheckPermission("/circulateMonitor/dataDockCollect/page")
    @GetMapping("/circulateMonitor/dataDockCollect/page")
    public CommonResult<Page<DataDockCollect>> page(DataDockCollectPageParam dataDockCollectPageParam) {
        return CommonResult.data(dataDockCollectService.page(dataDockCollectPageParam));
    }

    /**
     * 添加数据对接采集管理
     *
     * @author QSHan
     * @date  2024/06/17 15:27
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加数据对接采集管理")
    @CommonLog("添加数据对接采集管理")
//    @SaCheckPermission("/circulateMonitor/dataDockCollect/add")
    @PostMapping("/circulateMonitor/dataDockCollect/add")
    public CommonResult<String> add(@RequestBody @Valid DataDockCollectAddParam dataDockCollectAddParam) {
        dataDockCollectService.add(dataDockCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑数据对接采集管理
     *
     * @author QSHan
     * @date  2024/06/17 15:27
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑数据对接采集管理")
    @CommonLog("编辑数据对接采集管理")
//    @SaCheckPermission("/circulateMonitor/dataDockCollect/edit")
    @PostMapping("/circulateMonitor/dataDockCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid DataDockCollectEditParam dataDockCollectEditParam) {
        dataDockCollectService.edit(dataDockCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除数据对接采集管理
     *
     * @author QSHan
     * @date  2024/06/17 15:27
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除数据对接采集管理")
    @CommonLog("删除数据对接采集管理")
//    @SaCheckPermission("/circulateMonitor/dataDockCollect/delete")
    @PostMapping("/circulateMonitor/dataDockCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<DataDockCollectIdParam> dataDockCollectIdParamList) {
        dataDockCollectService.delete(dataDockCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取数据对接采集管理详情
     *
     * @author QSHan
     * @date  2024/06/17 15:27
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取数据对接采集管理详情")
//    @SaCheckPermission("/circulateMonitor/dataDockCollect/detail")
    @GetMapping("/circulateMonitor/dataDockCollect/detail")
    public CommonResult<DataDockCollect> detail(@Valid DataDockCollectIdParam dataDockCollectIdParam) {
        return CommonResult.data(dataDockCollectService.detail(dataDockCollectIdParam));
    }
}
