/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.dataDockCollect.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.circulateMonitor.modular.dataDockCollect.entity.DataDockCollect;
import com.unis.circulateMonitor.modular.dataDockCollect.mapper.DataDockCollectMapper;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectAddParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectEditParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectIdParam;
import com.unis.circulateMonitor.modular.dataDockCollect.param.DataDockCollectPageParam;
import com.unis.circulateMonitor.modular.dataDockCollect.service.DataDockCollectService;

import java.util.List;

/**
 * 数据对接采集管理Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/17 15:27
 **/
@Service
public class DataDockCollectServiceImpl extends ServiceImpl<DataDockCollectMapper, DataDockCollect> implements DataDockCollectService {

    @Override
    public Page<DataDockCollect> page(DataDockCollectPageParam dataDockCollectPageParam) {
        QueryWrapper<DataDockCollect> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isAllNotEmpty(dataDockCollectPageParam.getSortField(), dataDockCollectPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(dataDockCollectPageParam.getSortOrder());
            queryWrapper.orderBy(true, dataDockCollectPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(dataDockCollectPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(DataDockCollect::getId);
        }
        if (StringUtils.isNotEmpty(dataDockCollectPageParam.getEnterpriseName())) {
            queryWrapper.lambda().like(DataDockCollect::getEnterpriseName, dataDockCollectPageParam.getEnterpriseName());
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(DataDockCollectAddParam dataDockCollectAddParam) {
        DataDockCollect dataDockCollect = BeanUtil.toBean(dataDockCollectAddParam, DataDockCollect.class);
        this.save(dataDockCollect);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(DataDockCollectEditParam dataDockCollectEditParam) {
        DataDockCollect dataDockCollect = this.queryEntity(dataDockCollectEditParam.getId());
        BeanUtil.copyProperties(dataDockCollectEditParam, dataDockCollect);
        this.updateById(dataDockCollect);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<DataDockCollectIdParam> dataDockCollectIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(dataDockCollectIdParamList, DataDockCollectIdParam::getId));
    }

    @Override
    public DataDockCollect detail(DataDockCollectIdParam dataDockCollectIdParam) {
        return this.queryEntity(dataDockCollectIdParam.getId());
    }

    @Override
    public DataDockCollect queryEntity(String id) {
        DataDockCollect dataDockCollect = this.getById(id);
        if (ObjectUtil.isEmpty(dataDockCollect)) {
            throw new CommonException("数据对接采集管理不存在，id值为：{}", id);
        }
        return dataDockCollect;
    }
}
