/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.easeEnterprise.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.circulateMonitor.modular.easeEnterprise.entity.EaseEnterprise;
import com.unis.circulateMonitor.modular.easeEnterprise.param.EaseEnterpriseAddParam;
import com.unis.circulateMonitor.modular.easeEnterprise.param.EaseEnterpriseEditParam;
import com.unis.circulateMonitor.modular.easeEnterprise.param.EaseEnterpriseIdParam;
import com.unis.circulateMonitor.modular.easeEnterprise.param.EaseEnterprisePageParam;
import com.unis.circulateMonitor.modular.easeEnterprise.service.EaseEnterpriseService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 放心粮油企业管理控制器
 *
 * @author QSHan
 * @date  2024/06/18 10:06
 */
@Api(tags = "放心粮油企业管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EaseEnterpriseController {
    @Resource
    private EaseEnterpriseService easeEnterpriseService;

    /**
     * 获取放心粮油企业管理分页
     *
     * @author QSHan
     * @date  2024/06/18 10:06
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取放心粮油企业管理分页")
//    @SaCheckPermission("/circulateMonitor/easeEnterprise/page")
    @GetMapping("/circulateMonitor/easeEnterprise/page")
    public CommonResult<Page<EaseEnterprise>> page(EaseEnterprisePageParam easeEnterprisePageParam) {
        return CommonResult.data(easeEnterpriseService.page(easeEnterprisePageParam));
    }

    /**
     * 添加放心粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:06
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加放心粮油企业管理")
    @CommonLog("添加放心粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/easeEnterprise/add")
    @PostMapping("/circulateMonitor/easeEnterprise/add")
    public CommonResult<String> add(@RequestBody @Valid EaseEnterpriseAddParam easeEnterpriseAddParam) {
        easeEnterpriseService.add(easeEnterpriseAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑放心粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:06
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑放心粮油企业管理")
    @CommonLog("编辑放心粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/easeEnterprise/edit")
    @PostMapping("/circulateMonitor/easeEnterprise/edit")
    public CommonResult<String> edit(@RequestBody @Valid EaseEnterpriseEditParam easeEnterpriseEditParam) {
        easeEnterpriseService.edit(easeEnterpriseEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除放心粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:06
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除放心粮油企业管理")
    @CommonLog("删除放心粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/easeEnterprise/delete")
    @PostMapping("/circulateMonitor/easeEnterprise/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EaseEnterpriseIdParam> easeEnterpriseIdParamList) {
        easeEnterpriseService.delete(easeEnterpriseIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取放心粮油企业管理详情
     *
     * @author QSHan
     * @date  2024/06/18 10:06
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取放心粮油企业管理详情")
//    @SaCheckPermission("/circulateMonitor/easeEnterprise/detail")
    @GetMapping("/circulateMonitor/easeEnterprise/detail")
    public CommonResult<EaseEnterprise> detail(@Valid EaseEnterpriseIdParam easeEnterpriseIdParam) {
        return CommonResult.data(easeEnterpriseService.detail(easeEnterpriseIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("企业名称下拉")
    @GetMapping("/circulateMonitor/easeEnterprise/getEnterpriseList")
    public CommonResult<List<Map<String, Object>>> getEnterpriseList() {
        return CommonResult.data(easeEnterpriseService.getEnterpriseList());
    }

    @ApiOperationSupport(order = 7)
    @ApiOperation("汇总查询及分析列表-统计")
    @GetMapping("/circulateMonitor/easeEnterprise/getCountNumber")
    public CommonResult<Map<String, Object>> getCountNumber() {
        return CommonResult.data(easeEnterpriseService.getCountNumber());
    }
}
