/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.goodEnterprise.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.circulateMonitor.modular.goodEnterprise.entity.GoodEnterprise;
import com.unis.circulateMonitor.modular.goodEnterprise.param.GoodEnterpriseAddParam;
import com.unis.circulateMonitor.modular.goodEnterprise.param.GoodEnterpriseEditParam;
import com.unis.circulateMonitor.modular.goodEnterprise.param.GoodEnterpriseIdParam;
import com.unis.circulateMonitor.modular.goodEnterprise.param.GoodEnterprisePageParam;
import com.unis.circulateMonitor.modular.goodEnterprise.service.GoodEnterpriseService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 好粮油企业管理控制器
 *
 * @author QSHan
 * @date  2024/06/18 10:02
 */
@Api(tags = "好粮油企业管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GoodEnterpriseController {

    @Resource
    private GoodEnterpriseService goodEnterpriseService;

    /**
     * 获取好粮油企业管理分页
     *
     * @author QSHan
     * @date  2024/06/18 10:02
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取好粮油企业管理分页")
//    @SaCheckPermission("/circulateMonitor/goodEnterprise/page")
    @GetMapping("/circulateMonitor/goodEnterprise/page")
    public CommonResult<Page<GoodEnterprise>> page(GoodEnterprisePageParam goodEnterprisePageParam) {
        return CommonResult.data(goodEnterpriseService.page(goodEnterprisePageParam));
    }

    /**
     * 添加好粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加好粮油企业管理")
    @CommonLog("添加好粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/goodEnterprise/add")
    @PostMapping("/circulateMonitor/goodEnterprise/add")
    public CommonResult<String> add(@RequestBody @Valid GoodEnterpriseAddParam goodEnterpriseAddParam) {
        goodEnterpriseService.add(goodEnterpriseAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑好粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:02
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑好粮油企业管理")
    @CommonLog("编辑好粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/goodEnterprise/edit")
    @PostMapping("/circulateMonitor/goodEnterprise/edit")
    public CommonResult<String> edit(@RequestBody @Valid GoodEnterpriseEditParam goodEnterpriseEditParam) {
        goodEnterpriseService.edit(goodEnterpriseEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除好粮油企业管理
     *
     * @author QSHan
     * @date  2024/06/18 10:02
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除好粮油企业管理")
    @CommonLog("删除好粮油企业管理")
//    @SaCheckPermission("/circulateMonitor/goodEnterprise/delete")
    @PostMapping("/circulateMonitor/goodEnterprise/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<GoodEnterpriseIdParam> goodEnterpriseIdParamList) {
        goodEnterpriseService.delete(goodEnterpriseIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取好粮油企业管理详情
     *
     * @author QSHan
     * @date  2024/06/18 10:02
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取好粮油企业管理详情")
//    @SaCheckPermission("/circulateMonitor/goodEnterprise/detail")
    @GetMapping("/circulateMonitor/goodEnterprise/detail")
    public CommonResult<GoodEnterprise> detail(@Valid GoodEnterpriseIdParam goodEnterpriseIdParam) {
        return CommonResult.data(goodEnterpriseService.detail(goodEnterpriseIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("企业名称下拉")
    @GetMapping("/circulateMonitor/goodEnterprise/getEnterpriseList")
    public CommonResult<List<Map<String, Object>>> getEnterpriseList() {
        return CommonResult.data(goodEnterpriseService.getEnterpriseList());
    }
}
