/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.realTimeQueryStatistic.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.entity.RealTimeQueryStatistic;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.param.RealTimeQueryStatisticAddParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.param.RealTimeQueryStatisticEditParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.param.RealTimeQueryStatisticIdParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.param.RealTimeQueryStatisticPageParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatistic.service.RealTimeQueryStatisticService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 流通监测控制器
 *
 * @author QSHan
 * @date  2024/06/17 09:41
 */
@Api(tags = "粮油流通统计-实时查询统计")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class RealTimeQueryStatisticController {

    @Resource
    private RealTimeQueryStatisticService realTimeQueryStatisticService;

    /**
     * 获取流通监测分页
     *
     * @author QSHan
     * @date  2024/06/17 09:41
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("分页")
//    @SaCheckPermission("/circulateMonitor/realTimeQueryStatistic/page")
    @GetMapping("/circulateMonitor/realTimeQueryStatistic/page")
    public CommonResult<Page<RealTimeQueryStatistic>> page(RealTimeQueryStatisticPageParam realTimeQueryStatisticPageParam) {
        return CommonResult.data(realTimeQueryStatisticService.page(realTimeQueryStatisticPageParam));
    }

    /**
     * 添加流通监测
     *
     * @author QSHan
     * @date  2024/06/17 09:41
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加")
    @CommonLog("添加粮油流通统计-实时查询统计")
//    @SaCheckPermission("/circulateMonitor/realTimeQueryStatistic/add")
    @PostMapping("/circulateMonitor/realTimeQueryStatistic/add")
    public CommonResult<String> add(@RequestBody @Valid RealTimeQueryStatisticAddParam realTimeQueryStatisticAddParam) {
        realTimeQueryStatisticService.add(realTimeQueryStatisticAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑流通监测
     *
     * @author QSHan
     * @date  2024/06/17 09:41
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑")
    @CommonLog("编辑粮油流通统计-实时查询统计")
//    @SaCheckPermission("/circulateMonitor/realTimeQueryStatistic/edit")
    @PostMapping("/circulateMonitor/realTimeQueryStatistic/edit")
    public CommonResult<String> edit(@RequestBody @Valid RealTimeQueryStatisticEditParam realTimeQueryStatisticEditParam) {
        realTimeQueryStatisticService.edit(realTimeQueryStatisticEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除流通监测
     *
     * @author QSHan
     * @date  2024/06/17 09:41
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除")
    @CommonLog("删除粮油流通统计-实时查询统计")
//    @SaCheckPermission("/circulateMonitor/realTimeQueryStatistic/delete")
    @PostMapping("/circulateMonitor/realTimeQueryStatistic/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<RealTimeQueryStatisticIdParam> realTimeQueryStatisticIdParamList) {
        realTimeQueryStatisticService.delete(realTimeQueryStatisticIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取流通监测详情
     *
     * @author QSHan
     * @date  2024/06/17 09:41
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("详情")
//    @SaCheckPermission("/circulateMonitor/realTimeQueryStatistic/detail")
    @GetMapping("/circulateMonitor/realTimeQueryStatistic/detail")
    public CommonResult<RealTimeQueryStatistic> detail(@Valid RealTimeQueryStatisticIdParam realTimeQueryStatisticIdParam) {
        return CommonResult.data(realTimeQueryStatisticService.detail(realTimeQueryStatisticIdParam));
    }
}
