/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.entity.RealTimeQueryStatisticItem;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.mapper.RealTimeQueryStatisticItemMapper;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.param.RealTimeQueryStatisticItemAddParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.param.RealTimeQueryStatisticItemEditParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.param.RealTimeQueryStatisticItemIdParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.param.RealTimeQueryStatisticItemPageParam;
import com.unis.circulateMonitor.modular.realTimeQueryStatisticItem.service.RealTimeQueryStatisticItemService;

import java.util.List;

/**
 * 实时查询统计-粮食品种Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/17 09:46
 **/
@Service
public class RealTimeQueryStatisticItemServiceImpl extends ServiceImpl<RealTimeQueryStatisticItemMapper, RealTimeQueryStatisticItem> implements RealTimeQueryStatisticItemService {

    @Override
    public Page<RealTimeQueryStatisticItem> page(RealTimeQueryStatisticItemPageParam realTimeQueryStatisticItemPageParam) {
        QueryWrapper<RealTimeQueryStatisticItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(realTimeQueryStatisticItemPageParam.getSortField(), realTimeQueryStatisticItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(realTimeQueryStatisticItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, realTimeQueryStatisticItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(realTimeQueryStatisticItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(RealTimeQueryStatisticItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RealTimeQueryStatisticItemAddParam realTimeQueryStatisticItemAddParam) {
        RealTimeQueryStatisticItem realTimeQueryStatisticItem = BeanUtil.toBean(realTimeQueryStatisticItemAddParam, RealTimeQueryStatisticItem.class);
        this.save(realTimeQueryStatisticItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RealTimeQueryStatisticItemEditParam realTimeQueryStatisticItemEditParam) {
        RealTimeQueryStatisticItem realTimeQueryStatisticItem = this.queryEntity(realTimeQueryStatisticItemEditParam.getId());
        BeanUtil.copyProperties(realTimeQueryStatisticItemEditParam, realTimeQueryStatisticItem);
        this.updateById(realTimeQueryStatisticItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RealTimeQueryStatisticItemIdParam> realTimeQueryStatisticItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(realTimeQueryStatisticItemIdParamList, RealTimeQueryStatisticItemIdParam::getId));
    }

    @Override
    public RealTimeQueryStatisticItem detail(RealTimeQueryStatisticItemIdParam realTimeQueryStatisticItemIdParam) {
        return this.queryEntity(realTimeQueryStatisticItemIdParam.getId());
    }

    @Override
    public RealTimeQueryStatisticItem queryEntity(String id) {
        RealTimeQueryStatisticItem realTimeQueryStatisticItem = this.getById(id);
        if(ObjectUtil.isEmpty(realTimeQueryStatisticItem)) {
            throw new CommonException("实时查询统计-粮食品种不存在，id值为：{}", id);
        }
        return realTimeQueryStatisticItem;
    }
}
