/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.entity.DqaCountryInterface;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceAddParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceEditParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceIdParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfacePageParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.service.DqaCountryInterfaceService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 数据质量考核-统计分析-国家局映射接口控制器
 *
 * @author TS
 * @date  2024/05/21 15:23
 */
@Api(tags = "数据质量考核-统计分析-国家局映射接口控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DqaCountryInterfaceController {

    @Resource
    private DqaCountryInterfaceService dqaCountryInterfaceService;

    /**
     * 获取数据质量考核-统计分析-国家局映射接口分页
     *
     * @author TS
     * @date  2024/05/21 15:23
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取数据质量考核-统计分析-国家局映射接口分页")
//    @SaCheckPermission("/dataQualityAssessmen.info/dqaCountryInterface/page")
    @GetMapping("/dataQualityAssessmen.info/dqaCountryInterface/page")
    public CommonResult<Page<DqaCountryInterface>> page(DqaCountryInterfacePageParam dqaCountryInterfacePageParam) {
        return CommonResult.data(dqaCountryInterfaceService.page(dqaCountryInterfacePageParam));
    }

    /**
     * 添加数据质量考核-统计分析-国家局映射接口
     *
     * @author TS
     * @date  2024/05/21 15:23
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加数据质量考核-统计分析-国家局映射接口")
    @CommonLog("添加数据质量考核-统计分析-国家局映射接口")
//    @SaCheckPermission("/dataQualityAssessmen.info/dqaCountryInterface/add")
    @PostMapping("/dataQualityAssessmen.info/dqaCountryInterface/add")
    public CommonResult<String> add(@RequestBody @Valid DqaCountryInterfaceAddParam dqaCountryInterfaceAddParam) {
        dqaCountryInterfaceService.add(dqaCountryInterfaceAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑数据质量考核-统计分析-国家局映射接口
     *
     * @author TS
     * @date  2024/05/21 15:23
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑数据质量考核-统计分析-国家局映射接口")
    @CommonLog("编辑数据质量考核-统计分析-国家局映射接口")
    @SaCheckPermission("/dataQualityAssessmen.info/dqaCountryInterface/edit")
//    @PostMapping("/dataQualityAssessmen.info/dqaCountryInterface/edit")
    public CommonResult<String> edit(@RequestBody @Valid DqaCountryInterfaceEditParam dqaCountryInterfaceEditParam) {
        dqaCountryInterfaceService.edit(dqaCountryInterfaceEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除数据质量考核-统计分析-国家局映射接口
     *
     * @author TS
     * @date  2024/05/21 15:23
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除数据质量考核-统计分析-国家局映射接口")
    @CommonLog("删除数据质量考核-统计分析-国家局映射接口")
//    @SaCheckPermission("/dataQualityAssessmen.info/dqaCountryInterface/delete")
    @PostMapping("/dataQualityAssessmen.info/dqaCountryInterface/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<DqaCountryInterfaceIdParam> dqaCountryInterfaceIdParamList) {
        dqaCountryInterfaceService.delete(dqaCountryInterfaceIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取数据质量考核-统计分析-国家局映射接口详情
     *
     * @author TS
     * @date  2024/05/21 15:23
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取数据质量考核-统计分析-国家局映射接口详情")
//    @SaCheckPermission("/dataQualityAssessmen.info/dqaCountryInterface/detail")
    @GetMapping("/dataQualityAssessmen.info/dqaCountryInterface/detail")
    public CommonResult<DqaCountryInterface> detail(@Valid DqaCountryInterfaceIdParam dqaCountryInterfaceIdParam) {
        return CommonResult.data(dqaCountryInterfaceService.detail(dqaCountryInterfaceIdParam));
    }
}
