/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.entity.DqaCountryInterface;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.mapper.DqaCountryInterfaceMapper;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceAddParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceEditParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfaceIdParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.param.DqaCountryInterfacePageParam;
import com.unis.dataQualityAssessmen.info.modular.dqaCountryInterface.service.DqaCountryInterfaceService;

import java.util.List;

/**
 * 数据质量考核-统计分析-国家局映射接口Service接口实现类
 *
 * @author TS
 * @date  2024/05/21 15:23
 **/
@Service
public class DqaCountryInterfaceServiceImpl extends ServiceImpl<DqaCountryInterfaceMapper, DqaCountryInterface> implements DqaCountryInterfaceService {

    @Override
    public Page<DqaCountryInterface> page(DqaCountryInterfacePageParam dqaCountryInterfacePageParam) {
        QueryWrapper<DqaCountryInterface> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(dqaCountryInterfacePageParam.getSortField(), dqaCountryInterfacePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(dqaCountryInterfacePageParam.getSortOrder());
            queryWrapper.orderBy(true, dqaCountryInterfacePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(dqaCountryInterfacePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(DqaCountryInterface::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(DqaCountryInterfaceAddParam dqaCountryInterfaceAddParam) {
        DqaCountryInterface dqaCountryInterface = BeanUtil.toBean(dqaCountryInterfaceAddParam, DqaCountryInterface.class);
        this.save(dqaCountryInterface);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(DqaCountryInterfaceEditParam dqaCountryInterfaceEditParam) {
        DqaCountryInterface dqaCountryInterface = this.queryEntity(dqaCountryInterfaceEditParam.getId());
        BeanUtil.copyProperties(dqaCountryInterfaceEditParam, dqaCountryInterface);
        this.updateById(dqaCountryInterface);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<DqaCountryInterfaceIdParam> dqaCountryInterfaceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(dqaCountryInterfaceIdParamList, DqaCountryInterfaceIdParam::getId));
    }

    @Override
    public DqaCountryInterface detail(DqaCountryInterfaceIdParam dqaCountryInterfaceIdParam) {
        return this.queryEntity(dqaCountryInterfaceIdParam.getId());
    }

    @Override
    public DqaCountryInterface queryEntity(String id) {
        DqaCountryInterface dqaCountryInterface = this.getById(id);
        if(ObjectUtil.isEmpty(dqaCountryInterface)) {
            throw new CommonException("数据质量考核-统计分析-国家局映射接口不存在，id值为：{}", id);
        }
        return dqaCountryInterface;
    }
}
