/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupport.modular.es.entity.EsDeliveryEnterpriseGrain;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.es.service.EsDeliveryEnterpriseGrainService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 应急保障-应急配送企业管理-粮食品种控制器
 *
 * @author ZeroLiYi
 * @date  2024/06/01 11:36
 */
@Api(tags = "应急保障-应急配送企业管理-粮食品种控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EsDeliveryEnterpriseGrainController {

    @Resource
    private EsDeliveryEnterpriseGrainService esDeliveryEnterpriseGrainService;

    /**
     * 获取应急保障-应急配送企业管理-粮食品种分页
     *
     * @author ZeroLiYi
     * @date  2024/06/01 11:36
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急保障-应急配送企业管理-粮食品种分页")
    @SaCheckPermission("/emergencySupport/es/page")
    @GetMapping("/emergencySupport/es/page")
    public CommonResult<Page<EsDeliveryEnterpriseGrain>> page(EsDeliveryEnterpriseGrainPageParam esDeliveryEnterpriseGrainPageParam) {
        return CommonResult.data(esDeliveryEnterpriseGrainService.page(esDeliveryEnterpriseGrainPageParam));
    }

    /**
     * 添加应急保障-应急配送企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/06/01 11:36
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急保障-应急配送企业管理-粮食品种")
    @CommonLog("添加应急保障-应急配送企业管理-粮食品种")
    @SaCheckPermission("/emergencySupport/es/add")
    @PostMapping("/emergencySupport/es/add")
    public CommonResult<String> add(@RequestBody @Valid EsDeliveryEnterpriseGrainAddParam esDeliveryEnterpriseGrainAddParam) {
        esDeliveryEnterpriseGrainService.add(esDeliveryEnterpriseGrainAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急保障-应急配送企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/06/01 11:36
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急保障-应急配送企业管理-粮食品种")
    @CommonLog("编辑应急保障-应急配送企业管理-粮食品种")
    @SaCheckPermission("/emergencySupport/es/edit")
    @PostMapping("/emergencySupport/es/edit")
    public CommonResult<String> edit(@RequestBody @Valid EsDeliveryEnterpriseGrainEditParam esDeliveryEnterpriseGrainEditParam) {
        esDeliveryEnterpriseGrainService.edit(esDeliveryEnterpriseGrainEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急保障-应急配送企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/06/01 11:36
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急保障-应急配送企业管理-粮食品种")
    @CommonLog("删除应急保障-应急配送企业管理-粮食品种")
    @SaCheckPermission("/emergencySupport/es/delete")
    @PostMapping("/emergencySupport/es/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EsDeliveryEnterpriseGrainIdParam> esDeliveryEnterpriseGrainIdParamList) {
        esDeliveryEnterpriseGrainService.delete(esDeliveryEnterpriseGrainIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取应急保障-应急配送企业管理-粮食品种详情
     *
     * @author ZeroLiYi
     * @date  2024/06/01 11:36
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急保障-应急配送企业管理-粮食品种详情")
    @SaCheckPermission("/emergencySupport/es/detail")
    @GetMapping("/emergencySupport/es/detail")
    public CommonResult<EsDeliveryEnterpriseGrain> detail(@Valid EsDeliveryEnterpriseGrainIdParam esDeliveryEnterpriseGrainIdParam) {
        return CommonResult.data(esDeliveryEnterpriseGrainService.detail(esDeliveryEnterpriseGrainIdParam));
    }
}
