/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupport.modular.es.entity.EsProcessEnterpriseGrain;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.es.service.EsProcessEnterpriseGrainService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 应急保障-应急加工企业管理-粮食品种控制器
 *
 * @author ZeroLiYi
 * @date  2024/05/30 16:39
 */
@Api(tags = "应急保障-应急加工企业管理-粮食品种控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EsProcessEnterpriseGrainController {

    @Resource
    private EsProcessEnterpriseGrainService esProcessEnterpriseGrainService;

    /**
     * 获取应急保障-应急加工企业管理-粮食品种分页
     *
     * @author ZeroLiYi
     * @date  2024/05/30 16:39
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急保障-应急加工企业管理-粮食品种分页")
    @SaCheckPermission("/emergencySupportesProcessEnterpriseGrain/page")
    @GetMapping("/emergencySupportesProcessEnterpriseGrain/page")
    public CommonResult<Page<EsProcessEnterpriseGrain>> page(EsProcessEnterpriseGrainPageParam esProcessEnterpriseGrainPageParam) {
        return CommonResult.data(esProcessEnterpriseGrainService.page(esProcessEnterpriseGrainPageParam));
    }

    /**
     * 添加应急保障-应急加工企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/05/30 16:39
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急保障-应急加工企业管理-粮食品种")
    @CommonLog("添加应急保障-应急加工企业管理-粮食品种")
    @SaCheckPermission("/emergencySupportesProcessEnterpriseGrain/add")
    @PostMapping("/emergencySupportesProcessEnterpriseGrain/add")
    public CommonResult<String> add(@RequestBody @Valid EsProcessEnterpriseGrainAddParam esProcessEnterpriseGrainAddParam) {
        esProcessEnterpriseGrainService.add(esProcessEnterpriseGrainAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急保障-应急加工企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/05/30 16:39
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急保障-应急加工企业管理-粮食品种")
    @CommonLog("编辑应急保障-应急加工企业管理-粮食品种")
    @SaCheckPermission("/emergencySupportesProcessEnterpriseGrain/edit")
    @PostMapping("/emergencySupportesProcessEnterpriseGrain/edit")
    public CommonResult<String> edit(@RequestBody @Valid EsProcessEnterpriseGrainEditParam esProcessEnterpriseGrainEditParam) {
        esProcessEnterpriseGrainService.edit(esProcessEnterpriseGrainEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急保障-应急加工企业管理-粮食品种
     *
     * @author ZeroLiYi
     * @date  2024/05/30 16:39
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急保障-应急加工企业管理-粮食品种")
    @CommonLog("删除应急保障-应急加工企业管理-粮食品种")
    @SaCheckPermission("/emergencySupportesProcessEnterpriseGrain/delete")
    @PostMapping("/emergencySupportesProcessEnterpriseGrain/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EsProcessEnterpriseGrainIdParam> esProcessEnterpriseGrainIdParamList) {
        esProcessEnterpriseGrainService.delete(esProcessEnterpriseGrainIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取应急保障-应急加工企业管理-粮食品种详情
     *
     * @author ZeroLiYi
     * @date  2024/05/30 16:39
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急保障-应急加工企业管理-粮食品种详情")
    @SaCheckPermission("/emergencySupportesProcessEnterpriseGrain/detail")
    @GetMapping("/emergencySupportesProcessEnterpriseGrain/detail")
    public CommonResult<EsProcessEnterpriseGrain> detail(@Valid EsProcessEnterpriseGrainIdParam esProcessEnterpriseGrainIdParam) {
        return CommonResult.data(esProcessEnterpriseGrainService.detail(esProcessEnterpriseGrainIdParam));
    }
}
