/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 应急保障-应急供应网点管理-应急网点录入表编辑参数
 *
 * @author ZeroLiYi
 * @date  2024/05/28 09:21
 **/
@Getter
@Setter
public class EsNetworkEntryEditParam {

    /** 应急网点录入唯一标识符 */
    @ApiModelProperty(value = "应急网点录入唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 企业名称 */
    @ApiModelProperty(value = "企业名称", position = 6)
    private String enterpriseName;

    /** 统一社会信用代码 */
    @ApiModelProperty(value = "统一社会信用代码", position = 7)
    private String creditCode;

    /** 成立时间 */
    @ApiModelProperty(value = "成立时间", position = 8)
    private Date establishmentTime;

    /** 所属总公司企业信用代码 */
    @ApiModelProperty(value = "所属总公司企业信用代码", position = 9)
    private String headquarterCreditCode;

    /** 法人姓名 */
    @ApiModelProperty(value = "法人姓名", position = 10)
    private String legalRepresentative;

    /** 法人联系方式 */
    @ApiModelProperty(value = "法人联系方式", position = 11)
    private String legalContact;

    /** 联系人姓名 */
    @ApiModelProperty(value = "联系人姓名", position = 12)
    private String contactPerson;

    /** 联系电话 */
    @ApiModelProperty(value = "联系电话", position = 13)
    private String contactNumber;

    /** 所属市州 */
    @ApiModelProperty(value = "所属市州", position = 14)
    private String cityState;

    /** 企业性质 */
    @ApiModelProperty(value = "企业性质", position = 15)
    private String enterpriseNature;

    /** 企业类型 */
    @ApiModelProperty(value = "企业类型", position = 16)
    private String enterpriseType;

    /** 经度 */
    @ApiModelProperty(value = "经度", position = 17)
    private BigDecimal longitude;

    /** 纬度 */
    @ApiModelProperty(value = "纬度", position = 18)
    private BigDecimal latitude;

    /** 应急分类 */
    @ApiModelProperty(value = "应急分类", position = 19)
    private String emergencyCategory;

    /** 实际经营地址（省、市、县、乡镇街道门牌号） */
    @ApiModelProperty(value = "实际经营地址（省、市、县、乡镇街道门牌号）", position = 20)
    private String actualBusinessAddress;

    /** 生产状态，0：停产；1：生产 */
    @ApiModelProperty(value = "生产状态，0：停产；1：生产", position = 21)
    private Integer productionStatus;

    /** 归口管理地区-省 */
    @ApiModelProperty(value = "归口管理地区-省", position = 22)
    private String managementAreaProvince;

    /** 归口管理地区-市 */
    @ApiModelProperty(value = "归口管理地区-市", position = 23)
    private String managementAreaCity;

    /** 归口管理地区-县 */
    @ApiModelProperty(value = "归口管理地区-县", position = 24)
    private String managementAreaCounty;

    /** 供应应急级别-是否国家级 0:否；1：是； */
    @ApiModelProperty(value = "供应应急级别-是否国家级 0:否；1：是；", position = 25)
    private Boolean isNational;

    /** 供应应急级别-是否省级  0:否；1：是； */
    @ApiModelProperty(value = "供应应急级别-是否省级  0:否；1：是；", position = 26)
    private Boolean isProvincial;

    /** 供应应急级别-是否市级 0:否；1：是； */
    @ApiModelProperty(value = "供应应急级别-是否市级 0:否；1：是；", position = 27)
    private Boolean isCity;

    /** 供应应急级别-是否县级 0:否；1：是； */
    @ApiModelProperty(value = "供应应急级别-是否县级 0:否；1：是；", position = 28)
    private Boolean isCounty;

    /** 实际经营地址-省 */
    @ApiModelProperty(value = "实际经营地址-省", position = 29)
    private String actualAddressProvince;

    /** 实际经营地址-市 */
    @ApiModelProperty(value = "实际经营地址-市", position = 30)
    private String actualAddressCity;

    /** 实际经营地址-县 */
    @ApiModelProperty(value = "实际经营地址-县", position = 31)
    private String actualAddressCounty;

    /** 状态 0：待发起；1：已发起；2：驳回；3：已完成； */
    @ApiModelProperty(value = "状态 0：待发起；1：已发起；2：驳回；3：已完成；", position = 32)
    private Integer status;

}
