/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupport.modular.es.entity.EsDeliveryEnterpriseGrain;
import com.unis.emergencySupport.modular.es.mapper.EsDeliveryEnterpriseGrainMapper;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.es.param.EsDeliveryEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.es.service.EsDeliveryEnterpriseGrainService;

import java.util.List;

/**
 * 应急保障-应急配送企业管理-粮食品种Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/06/01 11:36
 **/
@Service
public class EsDeliveryEnterpriseGrainServiceImpl extends ServiceImpl<EsDeliveryEnterpriseGrainMapper, EsDeliveryEnterpriseGrain> implements EsDeliveryEnterpriseGrainService {

    @Override
    public Page<EsDeliveryEnterpriseGrain> page(EsDeliveryEnterpriseGrainPageParam esDeliveryEnterpriseGrainPageParam) {
        QueryWrapper<EsDeliveryEnterpriseGrain> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(esDeliveryEnterpriseGrainPageParam.getSortField(), esDeliveryEnterpriseGrainPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(esDeliveryEnterpriseGrainPageParam.getSortOrder());
            queryWrapper.orderBy(true, esDeliveryEnterpriseGrainPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(esDeliveryEnterpriseGrainPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EsDeliveryEnterpriseGrain::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsDeliveryEnterpriseGrainAddParam esDeliveryEnterpriseGrainAddParam) {
        EsDeliveryEnterpriseGrain esDeliveryEnterpriseGrain = BeanUtil.toBean(esDeliveryEnterpriseGrainAddParam, EsDeliveryEnterpriseGrain.class);
        this.save(esDeliveryEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsDeliveryEnterpriseGrainEditParam esDeliveryEnterpriseGrainEditParam) {
        EsDeliveryEnterpriseGrain esDeliveryEnterpriseGrain = this.queryEntity(esDeliveryEnterpriseGrainEditParam.getId());
        BeanUtil.copyProperties(esDeliveryEnterpriseGrainEditParam, esDeliveryEnterpriseGrain);
        this.updateById(esDeliveryEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsDeliveryEnterpriseGrainIdParam> esDeliveryEnterpriseGrainIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esDeliveryEnterpriseGrainIdParamList, EsDeliveryEnterpriseGrainIdParam::getId));
    }

    @Override
    public EsDeliveryEnterpriseGrain detail(EsDeliveryEnterpriseGrainIdParam esDeliveryEnterpriseGrainIdParam) {
        return this.queryEntity(esDeliveryEnterpriseGrainIdParam.getId());
    }

    @Override
    public EsDeliveryEnterpriseGrain queryEntity(String id) {
        EsDeliveryEnterpriseGrain esDeliveryEnterpriseGrain = this.getById(id);
        if(ObjectUtil.isEmpty(esDeliveryEnterpriseGrain)) {
            throw new CommonException("应急保障-应急配送企业管理-粮食品种不存在，id值为：{}", id);
        }
        return esDeliveryEnterpriseGrain;
    }
}
