/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupport.modular.es.entity.EsNetworkEntryGrain;
import com.unis.emergencySupport.modular.es.mapper.EsNetworkEntryGrainMapper;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryGrainAddParam;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryGrainEditParam;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryGrainIdParam;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryGrainPageParam;
import com.unis.emergencySupport.modular.es.service.EsNetworkEntryGrainService;

import java.util.List;

/**
 * 应急保障-应急供应网点管理-应急网点录入-粮食品种Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/05/28 09:22
 **/
@Service
public class EsNetworkEntryGrainServiceImpl extends ServiceImpl<EsNetworkEntryGrainMapper, EsNetworkEntryGrain> implements EsNetworkEntryGrainService {

    @Override
    public Page<EsNetworkEntryGrain> page(EsNetworkEntryGrainPageParam esNetworkEntryGrainPageParam) {
        QueryWrapper<EsNetworkEntryGrain> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(esNetworkEntryGrainPageParam.getSortField(), esNetworkEntryGrainPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(esNetworkEntryGrainPageParam.getSortOrder());
            queryWrapper.orderBy(true, esNetworkEntryGrainPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(esNetworkEntryGrainPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EsNetworkEntryGrain::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsNetworkEntryGrainAddParam esNetworkEntryGrainAddParam) {
        EsNetworkEntryGrain esNetworkEntryGrain = BeanUtil.toBean(esNetworkEntryGrainAddParam, EsNetworkEntryGrain.class);
        this.save(esNetworkEntryGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsNetworkEntryGrainEditParam esNetworkEntryGrainEditParam) {
        EsNetworkEntryGrain esNetworkEntryGrain = this.queryEntity(esNetworkEntryGrainEditParam.getId());
        BeanUtil.copyProperties(esNetworkEntryGrainEditParam, esNetworkEntryGrain);
        this.updateById(esNetworkEntryGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsNetworkEntryGrainIdParam> esNetworkEntryGrainIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esNetworkEntryGrainIdParamList, EsNetworkEntryGrainIdParam::getId));
    }

    @Override
    public EsNetworkEntryGrain detail(EsNetworkEntryGrainIdParam esNetworkEntryGrainIdParam) {
        return this.queryEntity(esNetworkEntryGrainIdParam.getId());
    }

    @Override
    public EsNetworkEntryGrain queryEntity(String id) {
        EsNetworkEntryGrain esNetworkEntryGrain = this.getById(id);
        if(ObjectUtil.isEmpty(esNetworkEntryGrain)) {
            throw new CommonException("应急保障-应急供应网点管理-应急网点录入-粮食品种不存在，id值为：{}", id);
        }
        return esNetworkEntryGrain;
    }
}
