/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.es.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupport.modular.es.entity.EsProcessEnterpriseGrain;
import com.unis.emergencySupport.modular.es.mapper.EsProcessEnterpriseGrainMapper;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.es.param.EsProcessEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.es.service.EsProcessEnterpriseGrainService;

import java.util.List;

/**
 * 应急保障-应急加工企业管理-粮食品种Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/05/30 16:39
 **/
@Service
public class EsProcessEnterpriseGrainServiceImpl extends ServiceImpl<EsProcessEnterpriseGrainMapper, EsProcessEnterpriseGrain> implements EsProcessEnterpriseGrainService {

    @Override
    public Page<EsProcessEnterpriseGrain> page(EsProcessEnterpriseGrainPageParam esProcessEnterpriseGrainPageParam) {
        QueryWrapper<EsProcessEnterpriseGrain> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(esProcessEnterpriseGrainPageParam.getSortField(), esProcessEnterpriseGrainPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(esProcessEnterpriseGrainPageParam.getSortOrder());
            queryWrapper.orderBy(true, esProcessEnterpriseGrainPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(esProcessEnterpriseGrainPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EsProcessEnterpriseGrain::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsProcessEnterpriseGrainAddParam esProcessEnterpriseGrainAddParam) {
        EsProcessEnterpriseGrain esProcessEnterpriseGrain = BeanUtil.toBean(esProcessEnterpriseGrainAddParam, EsProcessEnterpriseGrain.class);
        this.save(esProcessEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsProcessEnterpriseGrainEditParam esProcessEnterpriseGrainEditParam) {
        EsProcessEnterpriseGrain esProcessEnterpriseGrain = this.queryEntity(esProcessEnterpriseGrainEditParam.getId());
        BeanUtil.copyProperties(esProcessEnterpriseGrainEditParam, esProcessEnterpriseGrain);
        this.updateById(esProcessEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsProcessEnterpriseGrainIdParam> esProcessEnterpriseGrainIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esProcessEnterpriseGrainIdParamList, EsProcessEnterpriseGrainIdParam::getId));
    }

    @Override
    public EsProcessEnterpriseGrain detail(EsProcessEnterpriseGrainIdParam esProcessEnterpriseGrainIdParam) {
        return this.queryEntity(esProcessEnterpriseGrainIdParam.getId());
    }

    @Override
    public EsProcessEnterpriseGrain queryEntity(String id) {
        EsProcessEnterpriseGrain esProcessEnterpriseGrain = this.getById(id);
        if(ObjectUtil.isEmpty(esProcessEnterpriseGrain)) {
            throw new CommonException("应急保障-应急加工企业管理-粮食品种不存在，id值为：{}", id);
        }
        return esProcessEnterpriseGrain;
    }
}
