/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.esstorageenterprisegrain.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.entity.BizEsStorageEnterpriseGrain;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.service.BizEsStorageEnterpriseGrainService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 应急保障-应急仓储企业管理表-粮食品种控制器
 *
 * @author shine
 * @date  2024/05/25 14:39
 */
@Api(tags = "应急保障-应急仓储企业管理表-粮食品种控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizEsStorageEnterpriseGrainController {

    @Resource
    private BizEsStorageEnterpriseGrainService bizEsStorageEnterpriseGrainService;

    /**
     * 获取应急保障-应急仓储企业管理表-粮食品种分页
     *
     * @author shine
     * @date  2024/05/25 14:39
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急保障-应急仓储企业管理表-粮食品种分页")
    @SaCheckPermission("/emergencySupport/esstorageenterprisegrain/page")
    @GetMapping("/emergencySupport/esstorageenterprisegrain/page")
    public CommonResult<Page<BizEsStorageEnterpriseGrain>> page(BizEsStorageEnterpriseGrainPageParam bizEsStorageEnterpriseGrainPageParam) {
        return CommonResult.data(bizEsStorageEnterpriseGrainService.page(bizEsStorageEnterpriseGrainPageParam));
    }

    /**
     * 添加应急保障-应急仓储企业管理表-粮食品种
     *
     * @author shine
     * @date  2024/05/25 14:39
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急保障-应急仓储企业管理表-粮食品种")
    @CommonLog("添加应急保障-应急仓储企业管理表-粮食品种")
    @SaCheckPermission("/emergencySupport/esstorageenterprisegrain/add")
    @PostMapping("/emergencySupport/esstorageenterprisegrain/add")
    public CommonResult<String> add(@RequestBody @Valid BizEsStorageEnterpriseGrainAddParam bizEsStorageEnterpriseGrainAddParam) {
        bizEsStorageEnterpriseGrainService.add(bizEsStorageEnterpriseGrainAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急保障-应急仓储企业管理表-粮食品种
     *
     * @author shine
     * @date  2024/05/25 14:39
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急保障-应急仓储企业管理表-粮食品种")
    @CommonLog("编辑应急保障-应急仓储企业管理表-粮食品种")
    @SaCheckPermission("/emergencySupport/esstorageenterprisegrain/edit")
    @PostMapping("/emergencySupport/esstorageenterprisegrain/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizEsStorageEnterpriseGrainEditParam bizEsStorageEnterpriseGrainEditParam) {
        bizEsStorageEnterpriseGrainService.edit(bizEsStorageEnterpriseGrainEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急保障-应急仓储企业管理表-粮食品种
     *
     * @author shine
     * @date  2024/05/25 14:39
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急保障-应急仓储企业管理表-粮食品种")
    @CommonLog("删除应急保障-应急仓储企业管理表-粮食品种")
    @SaCheckPermission("/emergencySupport/esstorageenterprisegrain/delete")
    @PostMapping("/emergencySupport/esstorageenterprisegrain/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizEsStorageEnterpriseGrainIdParam> bizEsStorageEnterpriseGrainIdParamList) {
        bizEsStorageEnterpriseGrainService.delete(bizEsStorageEnterpriseGrainIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取应急保障-应急仓储企业管理表-粮食品种详情
     *
     * @author shine
     * @date  2024/05/25 14:39
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急保障-应急仓储企业管理表-粮食品种详情")
    @SaCheckPermission("/emergencySupport/esstorageenterprisegrain/detail")
    @GetMapping("/emergencySupport/esstorageenterprisegrain/detail")
    public CommonResult<BizEsStorageEnterpriseGrain> detail(@Valid BizEsStorageEnterpriseGrainIdParam bizEsStorageEnterpriseGrainIdParam) {
        return CommonResult.data(bizEsStorageEnterpriseGrainService.detail(bizEsStorageEnterpriseGrainIdParam));
    }
}
