/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupport.modular.esstorageenterprisegrain.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.entity.BizEsStorageEnterpriseGrain;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.mapper.BizEsStorageEnterpriseGrainMapper;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainAddParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainEditParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainIdParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.param.BizEsStorageEnterpriseGrainPageParam;
import com.unis.emergencySupport.modular.esstorageenterprisegrain.service.BizEsStorageEnterpriseGrainService;

import java.util.List;

/**
 * 应急保障-应急仓储企业管理表-粮食品种Service接口实现类
 *
 * @author shine
 * @date  2024/05/25 14:39
 **/
@Service
public class BizEsStorageEnterpriseGrainServiceImpl extends ServiceImpl<BizEsStorageEnterpriseGrainMapper, BizEsStorageEnterpriseGrain> implements BizEsStorageEnterpriseGrainService {

    @Override
    public Page<BizEsStorageEnterpriseGrain> page(BizEsStorageEnterpriseGrainPageParam bizEsStorageEnterpriseGrainPageParam) {
        QueryWrapper<BizEsStorageEnterpriseGrain> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizEsStorageEnterpriseGrainPageParam.getEsStorageEnterpriseId())) {
            queryWrapper.lambda().eq(BizEsStorageEnterpriseGrain::getEsStorageEnterpriseId, bizEsStorageEnterpriseGrainPageParam.getEsStorageEnterpriseId());
        }
        if(ObjectUtil.isNotEmpty(bizEsStorageEnterpriseGrainPageParam.getType())) {
            queryWrapper.lambda().eq(BizEsStorageEnterpriseGrain::getType, bizEsStorageEnterpriseGrainPageParam.getType());
        }
        if(ObjectUtil.isNotEmpty(bizEsStorageEnterpriseGrainPageParam.getGrainVariety())) {
            queryWrapper.lambda().eq(BizEsStorageEnterpriseGrain::getGrainVariety, bizEsStorageEnterpriseGrainPageParam.getGrainVariety());
        }
        if(ObjectUtil.isAllNotEmpty(bizEsStorageEnterpriseGrainPageParam.getSortField(), bizEsStorageEnterpriseGrainPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizEsStorageEnterpriseGrainPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizEsStorageEnterpriseGrainPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizEsStorageEnterpriseGrainPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizEsStorageEnterpriseGrain::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizEsStorageEnterpriseGrainAddParam bizEsStorageEnterpriseGrainAddParam) {
        BizEsStorageEnterpriseGrain bizEsStorageEnterpriseGrain = BeanUtil.toBean(bizEsStorageEnterpriseGrainAddParam, BizEsStorageEnterpriseGrain.class);
        this.save(bizEsStorageEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizEsStorageEnterpriseGrainEditParam bizEsStorageEnterpriseGrainEditParam) {
        BizEsStorageEnterpriseGrain bizEsStorageEnterpriseGrain = this.queryEntity(bizEsStorageEnterpriseGrainEditParam.getId());
        BeanUtil.copyProperties(bizEsStorageEnterpriseGrainEditParam, bizEsStorageEnterpriseGrain);
        this.updateById(bizEsStorageEnterpriseGrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizEsStorageEnterpriseGrainIdParam> bizEsStorageEnterpriseGrainIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizEsStorageEnterpriseGrainIdParamList, BizEsStorageEnterpriseGrainIdParam::getId));
    }

    @Override
    public BizEsStorageEnterpriseGrain detail(BizEsStorageEnterpriseGrainIdParam bizEsStorageEnterpriseGrainIdParam) {
        return this.queryEntity(bizEsStorageEnterpriseGrainIdParam.getId());
    }

    @Override
    public BizEsStorageEnterpriseGrain queryEntity(String id) {
        BizEsStorageEnterpriseGrain bizEsStorageEnterpriseGrain = this.getById(id);
        if(ObjectUtil.isEmpty(bizEsStorageEnterpriseGrain)) {
            throw new CommonException("应急保障-应急仓储企业管理表-粮食品种不存在，id值为：{}", id);
        }
        return bizEsStorageEnterpriseGrain;
    }
}
