/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEdAssessment.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.emergencySupportCenter.modular.esEdAssessment.entity.VO.EsEdAssessmentVO;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.entity.EsEdProcessDesign;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.entity.VO.EsEdSceneRecordVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.esEdAssessment.entity.EsEdAssessment;
import com.unis.emergencySupportCenter.modular.esEdAssessment.mapper.EsEdAssessmentMapper;
import com.unis.emergencySupportCenter.modular.esEdAssessment.param.EsEdAssessmentAddParam;
import com.unis.emergencySupportCenter.modular.esEdAssessment.param.EsEdAssessmentEditParam;
import com.unis.emergencySupportCenter.modular.esEdAssessment.param.EsEdAssessmentIdParam;
import com.unis.emergencySupportCenter.modular.esEdAssessment.param.EsEdAssessmentPageParam;
import com.unis.emergencySupportCenter.modular.esEdAssessment.service.EsEdAssessmentService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 应急演练-评估管理Service接口实现类
 *
 * @author TS
 * @date  2024/07/01 10:10
 **/
@Service
public class EsEdAssessmentServiceImpl extends ServiceImpl<EsEdAssessmentMapper, EsEdAssessment> implements EsEdAssessmentService {
    @Resource
    private  EsEdAssessmentMapper  esEdAssessmentMapper;
    @Override
    public IPage<EsEdAssessmentVO> findPage(EsEdAssessmentPageParam pageParam) {
        //条形查询器
        QueryWrapper<EsEdAssessmentVO> queryWrapper = new QueryWrapper<>();

        //分页相关
        if(StringUtils.isNotBlank(pageParam.getDrillTheme())){
            queryWrapper.like("a.drill_theme",pageParam.getDrillTheme() );
        }
        if(StringUtils.isNotBlank(pageParam.getResponsibleDepartment())){
            queryWrapper.like("a.responsible_department",pageParam.getResponsibleDepartment() );
        }
        Page<EsEdProcessDesign> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());

        IPage<EsEdAssessmentVO> page = esEdAssessmentMapper.selectMyMapsPage(p,queryWrapper);
        return page;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsEdAssessmentAddParam esEdAssessmentAddParam) {
        EsEdAssessment esEdAssessment = BeanUtil.toBean(esEdAssessmentAddParam, EsEdAssessment.class);
        this.save(esEdAssessment);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsEdAssessmentEditParam esEdAssessmentEditParam) {
        EsEdAssessment esEdAssessment = this.queryEntity(esEdAssessmentEditParam.getId());
        BeanUtil.copyProperties(esEdAssessmentEditParam, esEdAssessment);
        this.updateById(esEdAssessment);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsEdAssessmentIdParam> esEdAssessmentIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esEdAssessmentIdParamList, EsEdAssessmentIdParam::getId));
    }

    @Override
    public EsEdAssessmentVO detail(EsEdAssessmentIdParam esEdAssessmentIdParam) {
        return esEdAssessmentMapper.getDetail(esEdAssessmentIdParam.getId());
    }

    @Override
    public EsEdAssessment queryEntity(String id) {
        EsEdAssessment esEdAssessment = this.getById(id);
        if(ObjectUtil.isEmpty(esEdAssessment)) {
            throw new CommonException("应急演练-评估管理不存在，id值为：{}", id);
        }
        return esEdAssessment;
    }
}
