/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEdExecutionProcess.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.entity.VO.EsEdExecutionProcessVO;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.entity.EsEdProcessDesign;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.entity.EsEdExecutionProcess;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.mapper.EsEdExecutionProcessMapper;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.param.EsEdExecutionProcessAddParam;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.param.EsEdExecutionProcessEditParam;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.param.EsEdExecutionProcessIdParam;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.param.EsEdExecutionProcessPageParam;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.service.EsEdExecutionProcessService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 应急演练-执行过程Service接口实现类
 *
 * @author TS
 * @date  2024/07/01 10:06
 **/
@Service
public class EsEdExecutionProcessServiceImpl extends ServiceImpl<EsEdExecutionProcessMapper, EsEdExecutionProcess> implements EsEdExecutionProcessService {
    @Resource
    private  EsEdExecutionProcessMapper esEdExecutionProcessMapper;
    @Override
    public Page<EsEdExecutionProcess> page(EsEdExecutionProcessPageParam esEdExecutionProcessPageParam) {
        QueryWrapper<EsEdExecutionProcess> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(esEdExecutionProcessPageParam.getSortField(), esEdExecutionProcessPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(esEdExecutionProcessPageParam.getSortOrder());
            queryWrapper.orderBy(true, esEdExecutionProcessPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(esEdExecutionProcessPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EsEdExecutionProcess::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsEdExecutionProcessAddParam esEdExecutionProcessAddParam) {
        EsEdExecutionProcess esEdExecutionProcess = BeanUtil.toBean(esEdExecutionProcessAddParam, EsEdExecutionProcess.class);
        this.save(esEdExecutionProcess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsEdExecutionProcessEditParam esEdExecutionProcessEditParam) {
        EsEdExecutionProcess esEdExecutionProcess = this.queryEntity(esEdExecutionProcessEditParam.getId());
        BeanUtil.copyProperties(esEdExecutionProcessEditParam, esEdExecutionProcess);
        this.updateById(esEdExecutionProcess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsEdExecutionProcessIdParam> esEdExecutionProcessIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esEdExecutionProcessIdParamList, EsEdExecutionProcessIdParam::getId));
    }

    @Override
    public EsEdExecutionProcessVO detail(EsEdExecutionProcessIdParam esEdExecutionProcessIdParam) {
        return esEdExecutionProcessMapper.getDetail(esEdExecutionProcessIdParam.getId());
    }

    @Override
    public EsEdExecutionProcess queryEntity(String id) {
        EsEdExecutionProcess esEdExecutionProcess = this.getById(id);
        if(ObjectUtil.isEmpty(esEdExecutionProcess)) {
            throw new CommonException("应急演练-执行过程不存在，id值为：{}", id);
        }
        return esEdExecutionProcess;
    }

    /**
     * 获取应急演练-执行过程分自定义页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<EsEdExecutionProcessVO> findPage(EsEdExecutionProcessPageParam pageParam) {
            //条形查询器
            QueryWrapper<EsEdExecutionProcessVO> queryWrapper = new QueryWrapper<>();

            //分页相关
            if(StringUtils.isNotBlank(pageParam.getDrillTheme())){
                queryWrapper.like("a.drill_theme",pageParam.getDrillTheme() );
            }
            if(StringUtils.isNotBlank(pageParam.getResponsibleDepartment())){
                queryWrapper.like("a.responsible_department",pageParam.getResponsibleDepartment() );
            }
            Page<EsEdProcessDesign> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());

            IPage<EsEdExecutionProcessVO> page = esEdExecutionProcessMapper.selectMyMapsPage(p,queryWrapper);
            return page;
    }
}
