/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEdProcessDesign.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.entity.VO.EsEdProcessDesignSelectVO;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.param.EsEdProcessDesignSelectParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.entity.EsEdProcessDesign;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.param.EsEdProcessDesignAddParam;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.param.EsEdProcessDesignEditParam;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.param.EsEdProcessDesignIdParam;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.param.EsEdProcessDesignPageParam;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.service.EsEdProcessDesignService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 应急演练-流程设计控制器
 *
 * @author TS
 * @date  2024/07/01 10:02
 */
@Api(tags = "应急演练-流程设计控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EsEdProcessDesignController {

    @Resource
    private EsEdProcessDesignService esEdProcessDesignService;

    /**
     * 获取应急演练-流程设计自定义分页
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急演练-流程设计自定义分页")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/page")
    @GetMapping("/emergencySupportCenter/esEdProcessDesign/findPage")
    public CommonResult<IPage<EsEdProcessDesign>> findPage(EsEdProcessDesignPageParam esEdProcessDesignPageParam) {
        return CommonResult.data(esEdProcessDesignService.findPage(esEdProcessDesignPageParam));
    }

    /**
     * 添加应急演练-流程设计
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急演练-流程设计")
    @CommonLog("添加应急演练-流程设计")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/add")
    @PostMapping("/emergencySupportCenter/esEdProcessDesign/add")
    public CommonResult<String> add(@RequestBody @Valid EsEdProcessDesignAddParam esEdProcessDesignAddParam) {
        esEdProcessDesignService.add(esEdProcessDesignAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急演练-流程设计
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急演练-流程设计")
    @CommonLog("编辑应急演练-流程设计")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/edit")
    @PostMapping("/emergencySupportCenter/esEdProcessDesign/edit")
    public CommonResult<String> edit(@RequestBody @Valid EsEdProcessDesignEditParam esEdProcessDesignEditParam) {
        esEdProcessDesignService.edit(esEdProcessDesignEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急演练-流程设计
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急演练-流程设计")
    @CommonLog("删除应急演练-流程设计")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/delete")
    @PostMapping("/emergencySupportCenter/esEdProcessDesign/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EsEdProcessDesignIdParam> esEdProcessDesignIdParamList) {
        esEdProcessDesignService.delete(esEdProcessDesignIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取应急演练-流程设计详情
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急演练-流程设计详情")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/detail")
    @GetMapping("/emergencySupportCenter/esEdProcessDesign/detail")
    public CommonResult<EsEdProcessDesign> detail(@Valid EsEdProcessDesignIdParam esEdProcessDesignIdParam) {
        return CommonResult.data(esEdProcessDesignService.detail(esEdProcessDesignIdParam));
    }
    /**
     * 获取应急演练-流程设计下拉列表
     *
     * @author TS
     * @date  2024/07/01 10:02
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取应急演练-流程设计下拉列表")
//    @SaCheckPermission("/emergencySupportCenter/esEdProcessDesign/detail")
    @GetMapping("/emergencySupportCenter/esEdProcessDesign/getEsEdProcessDesignSelect")
    public CommonResult<List<EsEdProcessDesignSelectVO>> getEsEdProcessDesignSelect(@Valid EsEdProcessDesignSelectParam edProcessDesignSelectParam) {
        return CommonResult.data(esEdProcessDesignService.getEsEdProcessDesignSelect(edProcessDesignSelectParam));
    }
}
