/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEdSceneRecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.entity.VO.EsEdSceneRecordVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.entity.EsEdSceneRecord;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordAddParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordEditParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordIdParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordPageParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.service.EsEdSceneRecordService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 应急演练-现场过程记录管理控制器
 *
 * @author TS
 * @date  2024/07/01 15:59
 */
@Api(tags = "应急演练-现场过程记录管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EsEdSceneRecordController {

    @Resource
    private EsEdSceneRecordService esEdSceneRecordService;

    /**
     * 获取应急演练-现场过程记录管理自定义分页
     *
     * @author TS
     * @date  2024/07/01 15:59
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急演练-现场过程记录管理自定义分页")
    @GetMapping("/emergencySupportCente/esEdSceneRecord/findPage")
    public CommonResult<IPage<EsEdSceneRecordVO>> findPage(EsEdSceneRecordPageParam esEdSceneRecordPageParam) {
        return CommonResult.data(esEdSceneRecordService.findPage(esEdSceneRecordPageParam));
    }

    /**
     * 添加应急演练-现场过程记录管理
     *
     * @author TS
     * @date  2024/07/01 15:59
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急演练-现场过程记录管理")
    @CommonLog("添加应急演练-现场过程记录管理")
    @PostMapping("/emergencySupportCenter/esEdSceneRecord/add")
    public CommonResult<String> add(@RequestBody @Valid EsEdSceneRecordAddParam esEdSceneRecordAddParam) {
        esEdSceneRecordService.add(esEdSceneRecordAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急演练-现场过程记录管理
     *
     * @author TS
     * @date  2024/07/01 15:59
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急演练-现场过程记录管理")
    @CommonLog("编辑应急演练-现场过程记录管理")
    @PostMapping("/emergencySupportCenter/esEdSceneRecord/edit")
    public CommonResult<String> edit(@RequestBody @Valid EsEdSceneRecordEditParam esEdSceneRecordEditParam) {
        esEdSceneRecordService.edit(esEdSceneRecordEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急演练-现场过程记录管理
     *
     * @author TS
     * @date  2024/07/01 15:59
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急演练-现场过程记录管理")
    @CommonLog("删除应急演练-现场过程记录管理")
    @GetMapping("/emergencySupportCenter/esEdSceneRecord/delete")
    public CommonResult<String> delete(@Valid EsEdSceneRecordIdParam esEdSceneRecordIdParam) {
        esEdSceneRecordService.delete(esEdSceneRecordIdParam);
        return CommonResult.ok();
    }

    /**
     * 获取应急演练-现场过程记录管理详情
     *
     * @author TS
     * @date  2024/07/01 15:59
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急演练-现场过程记录管理详情")
    @GetMapping("/emergencySupportCenter/esEdSceneRecord/detail")
    public CommonResult<EsEdSceneRecordVO> detail(@Valid EsEdSceneRecordIdParam esEdSceneRecordIdParam) {
        return CommonResult.data(esEdSceneRecordService.detail(esEdSceneRecordIdParam));
    }
}
