/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEdSceneRecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.esEdExecutionProcess.entity.VO.EsEdExecutionProcessVO;
import com.unis.emergencySupportCenter.modular.esEdProcessDesign.entity.EsEdProcessDesign;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.entity.EsEdSceneRecord;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.entity.VO.EsEdSceneRecordVO;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.mapper.EsEdSceneRecordMapper;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordAddParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordEditParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordIdParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.param.EsEdSceneRecordPageParam;
import com.unis.emergencySupportCenter.modular.esEdSceneRecord.service.EsEdSceneRecordService;
import com.unis.emergencySupportCenter.modular.esEdSceneRecordItem.entity.EsEdSceneRecordItem;
import com.unis.emergencySupportCenter.modular.esEdSceneRecordItem.service.EsEdSceneRecordItemService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 应急演练-现场过程记录管理Service接口实现类
 *
 * @author TS
 * @date  2024/07/01 15:59
 **/
@Service
public class EsEdSceneRecordServiceImpl extends ServiceImpl<EsEdSceneRecordMapper, EsEdSceneRecord> implements EsEdSceneRecordService {
    @Autowired
    private EsEdSceneRecordItemService  esEdSceneRecordItemService;
    @Resource
    private EsEdSceneRecordMapper esEdSceneRecordMapper;
    @Override
    public IPage<EsEdSceneRecordVO> findPage(EsEdSceneRecordPageParam pageParam) {
            //条形查询器
            QueryWrapper<EsEdSceneRecordVO> queryWrapper = new QueryWrapper<>();

            //分页相关
            if(StringUtils.isNotBlank(pageParam.getDrillTheme())){
                queryWrapper.like("a.drill_theme",pageParam.getDrillTheme() );
            }
            if(StringUtils.isNotBlank(pageParam.getResponsibleDepartment())){
                queryWrapper.like("a.responsible_department",pageParam.getResponsibleDepartment() );
            }
            Page<EsEdProcessDesign> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());

            IPage<EsEdSceneRecordVO> page = esEdSceneRecordMapper.selectMyMapsPage(p,queryWrapper);
            return page;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsEdSceneRecordAddParam esEdSceneRecordAddParam) {
        EsEdSceneRecord esEdSceneRecord = BeanUtil.toBean(esEdSceneRecordAddParam, EsEdSceneRecord.class);
        boolean  b  =  this.save(esEdSceneRecord);
        if (b){ //保存成功后再保存明细数据
            String id  = esEdSceneRecord.getId();
            List<EsEdSceneRecordItem> itemList  = esEdSceneRecordAddParam.getItemList();
            for (EsEdSceneRecordItem item:itemList) {
                item.setEsEdSceneRecordId(id);
            }
            esEdSceneRecordItemService.saveBatch(itemList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsEdSceneRecordEditParam esEdSceneRecordEditParam) {
        EsEdSceneRecord esEdSceneRecord = this.queryEntity(esEdSceneRecordEditParam.getId());
        BeanUtil.copyProperties(esEdSceneRecordEditParam, esEdSceneRecord);
        boolean  b  =  this.updateById(esEdSceneRecord);
        if (b){ //保存成功后再保存明细数据
            String id  = esEdSceneRecord.getId();
            //先删除再新增
            QueryWrapper<EsEdSceneRecordItem> queryWrapper  = new QueryWrapper<>();
            queryWrapper.lambda().eq(EsEdSceneRecordItem::getEsEdSceneRecordId,id);
            esEdSceneRecordItemService.remove(queryWrapper);

            List<EsEdSceneRecordItem> itemList  = esEdSceneRecordEditParam.getItemList();
            for (EsEdSceneRecordItem item:itemList) {
                item.setEsEdSceneRecordId(id);
            }
            esEdSceneRecordItemService.saveBatch(itemList);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(EsEdSceneRecordIdParam esEdSceneRecordIdParam) {
        this.queryEntity(esEdSceneRecordIdParam.getId());
        //先删除从表
        QueryWrapper<EsEdSceneRecordItem> queryWrapper  = new QueryWrapper<>();
        queryWrapper.lambda().eq(EsEdSceneRecordItem::getEsEdSceneRecordId,esEdSceneRecordIdParam.getId());
        esEdSceneRecordItemService.remove(queryWrapper);
        //删除主表
        this.removeById(esEdSceneRecordIdParam.getId());
    }

    @Override
    public EsEdSceneRecordVO detail(EsEdSceneRecordIdParam esEdSceneRecordIdParam) {
        EsEdSceneRecordVO  esEdSceneRecord  = esEdSceneRecordMapper.getDetail(esEdSceneRecordIdParam.getId());
        if(ObjectUtil.isEmpty(esEdSceneRecord)) {
            throw new CommonException("应急演练-现场过程记录管理不存在，id值为：{}", esEdSceneRecordIdParam.getId());
        }
        //得到明细
        QueryWrapper<EsEdSceneRecordItem> queryWrapper  = new QueryWrapper<>();
        queryWrapper.lambda().eq(EsEdSceneRecordItem::getEsEdSceneRecordId,esEdSceneRecordIdParam.getId());

        List<EsEdSceneRecordItem> itemList  = esEdSceneRecordItemService.list(queryWrapper);
        esEdSceneRecord.setItemList(itemList);
        return esEdSceneRecord;
    }

    @Override
    public EsEdSceneRecord queryEntity(String id) {
        EsEdSceneRecord esEdSceneRecord = this.getById(id);
        if(ObjectUtil.isEmpty(esEdSceneRecord)) {
            throw new CommonException("应急演练-现场过程记录管理不存在，id值为：{}", id);
        }
        return esEdSceneRecord;
    }
}
