/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEpPlanTemplate.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.entity.EsEpPlanTemplate;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateAddParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateEditParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateIdParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplatePageParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.service.EsEpPlanTemplateService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 应急预案模板管理控制器
 *
 * @author QSHan
 * @date  2024/06/28 09:47
 */
@Api(tags = "应急预案模板管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EsEpPlanTemplateController {

    @Resource
    private EsEpPlanTemplateService esEpPlanTemplateService;

    /**
     * 获取应急预案模板管理分页
     *
     * @author QSHan
     * @date  2024/06/28 09:47
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取应急预案模板管理分页")
//    @SaCheckPermission("/emergencySupportCenter/esEpPlanTemplate/page")
    @GetMapping("/emergencySupportCenter/esEpPlanTemplate/page")
    public CommonResult<Page<EsEpPlanTemplate>> page(EsEpPlanTemplatePageParam esEpPlanTemplatePageParam) {
        return CommonResult.data(esEpPlanTemplateService.page(esEpPlanTemplatePageParam));
    }

    /**
     * 添加应急预案模板管理
     *
     * @author QSHan
     * @date  2024/06/28 09:47
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加应急预案模板管理")
    @CommonLog("添加应急预案模板管理")
//    @SaCheckPermission("/emergencySupportCenter/esEpPlanTemplate/add")
    @PostMapping("/emergencySupportCenter/esEpPlanTemplate/add")
    public CommonResult<String> add(@RequestBody @Valid EsEpPlanTemplateAddParam esEpPlanTemplateAddParam) {
        esEpPlanTemplateService.add(esEpPlanTemplateAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑应急预案模板管理
     *
     * @author QSHan
     * @date  2024/06/28 09:47
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑应急预案模板管理")
    @CommonLog("编辑应急预案模板管理")
//    @SaCheckPermission("/emergencySupportCenter/esEpPlanTemplate/edit")
    @PostMapping("/emergencySupportCenter/esEpPlanTemplate/edit")
    public CommonResult<String> edit(@RequestBody @Valid EsEpPlanTemplateEditParam esEpPlanTemplateEditParam) {
        esEpPlanTemplateService.edit(esEpPlanTemplateEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除应急预案模板管理
     *
     * @author QSHan
     * @date  2024/06/28 09:47
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除应急预案模板管理")
    @CommonLog("删除应急预案模板管理")
//    @SaCheckPermission("/emergencySupportCenter/esEpPlanTemplate/delete")
    @PostMapping("/emergencySupportCenter/esEpPlanTemplate/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EsEpPlanTemplateIdParam> esEpPlanTemplateIdParamList) {
        esEpPlanTemplateService.delete(esEpPlanTemplateIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取应急预案模板管理详情
     *
     * @author QSHan
     * @date  2024/06/28 09:47
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取应急预案模板管理详情")
//    @SaCheckPermission("/emergencySupportCenter/esEpPlanTemplate/detail")
    @GetMapping("/emergencySupportCenter/esEpPlanTemplate/detail")
    public CommonResult<EsEpPlanTemplate> detail(@Valid EsEpPlanTemplateIdParam esEpPlanTemplateIdParam) {
        return CommonResult.data(esEpPlanTemplateService.detail(esEpPlanTemplateIdParam));
    }
}
