/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.esEpPlanTemplate.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.entity.EsEpPlanTemplate;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.mapper.EsEpPlanTemplateMapper;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateAddParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateEditParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplateIdParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.param.EsEpPlanTemplatePageParam;
import com.unis.emergencySupportCenter.modular.esEpPlanTemplate.service.EsEpPlanTemplateService;

import java.util.List;

/**
 * 应急预案模板管理Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/28 09:47
 **/
@Service
public class EsEpPlanTemplateServiceImpl extends ServiceImpl<EsEpPlanTemplateMapper, EsEpPlanTemplate> implements EsEpPlanTemplateService {

    @Override
    public Page<EsEpPlanTemplate> page(EsEpPlanTemplatePageParam esEpPlanTemplatePageParam) {
        QueryWrapper<EsEpPlanTemplate> queryWrapper = new QueryWrapper<>();
        // 检索条件
        if (StringUtils.isNotEmpty(esEpPlanTemplatePageParam.getEmergencyPlanName())) {
            queryWrapper.lambda().like(EsEpPlanTemplate::getEmergencyPlanName, esEpPlanTemplatePageParam.getEmergencyPlanName());
        }
        if (ObjectUtils.isNotEmpty(esEpPlanTemplatePageParam.getEmergencyLevel())) {
            queryWrapper.lambda().eq(EsEpPlanTemplate::getEmergencyLevel, esEpPlanTemplatePageParam.getEmergencyLevel());
        }
        // 排序条件
        if (ObjectUtil.isAllNotEmpty(esEpPlanTemplatePageParam.getSortField(), esEpPlanTemplatePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(esEpPlanTemplatePageParam.getSortOrder());
            queryWrapper.orderBy(true, esEpPlanTemplatePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(esEpPlanTemplatePageParam.getSortField()));
        } else {
            // 倒序
            queryWrapper.lambda().orderByDesc(EsEpPlanTemplate::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EsEpPlanTemplateAddParam esEpPlanTemplateAddParam) {
        EsEpPlanTemplate esEpPlanTemplate = BeanUtil.toBean(esEpPlanTemplateAddParam, EsEpPlanTemplate.class);
        this.save(esEpPlanTemplate);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EsEpPlanTemplateEditParam esEpPlanTemplateEditParam) {
        EsEpPlanTemplate esEpPlanTemplate = this.queryEntity(esEpPlanTemplateEditParam.getId());
        BeanUtil.copyProperties(esEpPlanTemplateEditParam, esEpPlanTemplate);
        this.updateById(esEpPlanTemplate);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EsEpPlanTemplateIdParam> esEpPlanTemplateIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(esEpPlanTemplateIdParamList, EsEpPlanTemplateIdParam::getId));
    }

    @Override
    public EsEpPlanTemplate detail(EsEpPlanTemplateIdParam esEpPlanTemplateIdParam) {
        return this.queryEntity(esEpPlanTemplateIdParam.getId());
    }

    @Override
    public EsEpPlanTemplate queryEntity(String id) {
        EsEpPlanTemplate esEpPlanTemplate = this.getById(id);
        if (ObjectUtil.isEmpty(esEpPlanTemplate)) {
            throw new CommonException("应急预案模板管理不存在，id值为：{}", id);
        }
        return esEpPlanTemplate;
    }
}
