/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.onlinePlanFormulation.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.emergencySupport.modular.es.entity.EsNetworkEntry;
import com.unis.emergencySupport.modular.esstorageenterprise.entity.BizEsStorageEnterprise;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.entity.OnlinePlanFormulation;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.param.OnlinePlanFormulationAddParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.param.OnlinePlanFormulationEditParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.param.OnlinePlanFormulationIdParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.param.OnlinePlanFormulationPageParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.service.OnlinePlanFormulationService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 在线方案制定控制器
 *
 * @author QSHan
 * @date  2024/06/28 14:23
 */
@Api(tags = "在线方案制定控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OnlinePlanFormulationController {

    @Resource
    private OnlinePlanFormulationService onlinePlanFormulationService;

    /**
     * 获取在线方案制定分页
     *
     * @author QSHan
     * @date  2024/06/28 14:23
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取在线方案制定分页")
//    @SaCheckPermission("/emergencySupportCenter/onlinePlanFormulation/page")
    @GetMapping("/emergencySupportCenter/onlinePlanFormulation/page")
    public CommonResult<Page<OnlinePlanFormulation>> page(OnlinePlanFormulationPageParam onlinePlanFormulationPageParam) {
        return CommonResult.data(onlinePlanFormulationService.page(onlinePlanFormulationPageParam));
    }

    /**
     * 添加在线方案制定
     *
     * @author QSHan
     * @date  2024/06/28 14:23
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加在线方案制定")
    @CommonLog("添加在线方案制定")
//    @SaCheckPermission("/emergencySupportCenter/onlinePlanFormulation/add")
    @PostMapping("/emergencySupportCenter/onlinePlanFormulation/add")
    public CommonResult<String> add(@RequestBody @Valid OnlinePlanFormulationAddParam onlinePlanFormulationAddParam) {
        onlinePlanFormulationService.add(onlinePlanFormulationAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑在线方案制定
     *
     * @author QSHan
     * @date  2024/06/28 14:23
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑在线方案制定")
    @CommonLog("编辑在线方案制定")
//    @SaCheckPermission("/emergencySupportCenter/onlinePlanFormulation/edit")
    @PostMapping("/emergencySupportCenter/onlinePlanFormulation/edit")
    public CommonResult<String> edit(@RequestBody @Valid OnlinePlanFormulationEditParam onlinePlanFormulationEditParam) {
        onlinePlanFormulationService.edit(onlinePlanFormulationEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除在线方案制定
     *
     * @author QSHan
     * @date  2024/06/28 14:23
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除在线方案制定")
    @CommonLog("删除在线方案制定")
//    @SaCheckPermission("/emergencySupportCenter/onlinePlanFormulation/delete")
    @PostMapping("/emergencySupportCenter/onlinePlanFormulation/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OnlinePlanFormulationIdParam> onlinePlanFormulationIdParamList) {
        onlinePlanFormulationService.delete(onlinePlanFormulationIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取在线方案制定详情
     *
     * @author QSHan
     * @date  2024/06/28 14:23
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取在线方案制定详情")
//    @SaCheckPermission("/emergencySupportCenter/onlinePlanFormulation/detail")
    @GetMapping("/emergencySupportCenter/onlinePlanFormulation/detail")
    public CommonResult<OnlinePlanFormulation> detail(@Valid OnlinePlanFormulationIdParam onlinePlanFormulationIdParam) {
        return CommonResult.data(onlinePlanFormulationService.detail(onlinePlanFormulationIdParam));
    }

    // 接收应急网点
    @ApiOperationSupport(order = 6)
    @ApiOperation("接收应急网点下拉")
    @GetMapping("/emergencySupportCenter/onlinePlanFormulation/getEmergencyPointList")
    public CommonResult<List<Map<String, Object>>> getEmergencyPointList() {
        return CommonResult.data(onlinePlanFormulationService.getEmergencyPointList());
    }


}
