/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.entity.OnlinePlanFormulationOrg;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.mapper.OnlinePlanFormulationOrgMapper;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.param.OnlinePlanFormulationOrgAddParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.param.OnlinePlanFormulationOrgEditParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.param.OnlinePlanFormulationOrgIdParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.param.OnlinePlanFormulationOrgPageParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulationOrg.service.OnlinePlanFormulationOrgService;

import java.util.List;

/**
 * 在线方案制定Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/28 14:29
 **/
@Service
public class OnlinePlanFormulationOrgServiceImpl extends ServiceImpl<OnlinePlanFormulationOrgMapper, OnlinePlanFormulationOrg> implements OnlinePlanFormulationOrgService {

    @Override
    public Page<OnlinePlanFormulationOrg> page(OnlinePlanFormulationOrgPageParam onlinePlanFormulationOrgPageParam) {
        QueryWrapper<OnlinePlanFormulationOrg> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(onlinePlanFormulationOrgPageParam.getSortField(), onlinePlanFormulationOrgPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(onlinePlanFormulationOrgPageParam.getSortOrder());
            queryWrapper.orderBy(true, onlinePlanFormulationOrgPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(onlinePlanFormulationOrgPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(OnlinePlanFormulationOrg::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OnlinePlanFormulationOrgAddParam onlinePlanFormulationOrgAddParam) {
        OnlinePlanFormulationOrg onlinePlanFormulationOrg = BeanUtil.toBean(onlinePlanFormulationOrgAddParam, OnlinePlanFormulationOrg.class);
        this.save(onlinePlanFormulationOrg);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OnlinePlanFormulationOrgEditParam onlinePlanFormulationOrgEditParam) {
        OnlinePlanFormulationOrg onlinePlanFormulationOrg = this.queryEntity(onlinePlanFormulationOrgEditParam.getId());
        BeanUtil.copyProperties(onlinePlanFormulationOrgEditParam, onlinePlanFormulationOrg);
        this.updateById(onlinePlanFormulationOrg);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OnlinePlanFormulationOrgIdParam> onlinePlanFormulationOrgIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(onlinePlanFormulationOrgIdParamList, OnlinePlanFormulationOrgIdParam::getId));
    }

    @Override
    public OnlinePlanFormulationOrg detail(OnlinePlanFormulationOrgIdParam onlinePlanFormulationOrgIdParam) {
        return this.queryEntity(onlinePlanFormulationOrgIdParam.getId());
    }

    @Override
    public OnlinePlanFormulationOrg queryEntity(String id) {
        OnlinePlanFormulationOrg onlinePlanFormulationOrg = this.getById(id);
        if(ObjectUtil.isEmpty(onlinePlanFormulationOrg)) {
            throw new CommonException("在线方案制定不存在，id值为：{}", id);
        }
        return onlinePlanFormulationOrg;
    }
}
