/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.planExecute.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.emergencySupport.modular.es.entity.EsNetworkEntry;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.param.OnlinePlanFormulationIdParam;
import com.unis.emergencySupportCenter.modular.onlinePlanFormulation.service.OnlinePlanFormulationService;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.entity.PlanExecuteEnterprise;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.emergencySupportCenter.modular.planExecute.entity.PlanExecute;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteAddParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteEditParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteIdParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecutePageParam;
import com.unis.emergencySupportCenter.modular.planExecute.service.PlanExecuteService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 方案执行情况控制器
 *
 * @author QSHan
 * @date  2024/06/28 17:10
 */
@Api(tags = "方案执行情况控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PlanExecuteController {
    @Resource
    private PlanExecuteService planExecuteService;
    @Resource
    private OnlinePlanFormulationService onlinePlanFormulationService;

    /**
     * 获取方案执行情况分页
     *
     * @author QSHan
     * @date  2024/06/28 17:10
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取方案执行情况分页")
    @SaCheckPermission("/emergencySupportCenter/planExecute/page")
    @GetMapping("/emergencySupportCenter/planExecute/page")
    public CommonResult<Page<PlanExecute>> page(PlanExecutePageParam planExecutePageParam) {
        return CommonResult.data(planExecuteService.page(planExecutePageParam));
    }

    /**
     * 添加方案执行情况
     *
     * @author QSHan
     * @date  2024/06/28 17:10
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加方案执行情况")
    @CommonLog("添加方案执行情况")
    @SaCheckPermission("/emergencySupportCenter/planExecute/add")
    @PostMapping("/emergencySupportCenter/planExecute/add")
    public CommonResult<String> add(@RequestBody @Valid PlanExecuteAddParam planExecuteAddParam) {
        planExecuteService.add(planExecuteAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑方案执行情况
     *
     * @author QSHan
     * @date  2024/06/28 17:10
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑方案执行情况")
    @CommonLog("编辑方案执行情况")
    @SaCheckPermission("/emergencySupportCenter/planExecute/edit")
    @PostMapping("/emergencySupportCenter/planExecute/edit")
    public CommonResult<String> edit(@RequestBody @Valid PlanExecuteEditParam planExecuteEditParam) {
        planExecuteService.edit(planExecuteEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除方案执行情况
     *
     * @author QSHan
     * @date  2024/06/28 17:10
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除方案执行情况")
    @CommonLog("删除方案执行情况")
    @SaCheckPermission("/emergencySupportCenter/planExecute/delete")
    @PostMapping("/emergencySupportCenter/planExecute/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PlanExecuteIdParam> planExecuteIdParamList) {
        planExecuteService.delete(planExecuteIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取方案执行情况详情
     *
     * @author QSHan
     * @date  2024/06/28 17:10
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取方案执行情况详情")
    @SaCheckPermission("/emergencySupportCenter/planExecute/detail")
    @GetMapping("/emergencySupportCenter/planExecute/detail")
    public CommonResult<PlanExecute> detail(@Valid PlanExecuteIdParam planExecuteIdParam) {
        return CommonResult.data(planExecuteService.detail(planExecuteIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("已下发方案名称下拉")
    @GetMapping("/emergencySupportCenter/planExecute/getPlanNameStatusOneList")
    public CommonResult<List<Map<String, Object>>> getPlanNameStatusOneList() {
        return CommonResult.data(onlinePlanFormulationService.getPlanNameStatusOneList());
    }

    @ApiOperationSupport(order = 7)
    @ApiOperation("执行情况-企业名称下拉")
    @GetMapping("/emergencySupportCenter/onlinePlanFormulation/getFourTypeList")
    public CommonResult<List<PlanExecuteEnterprise>> getFourTypeList() {
        return CommonResult.data(planExecuteService.getFourTypeList());
    }

    // 方案执行监管
    @ApiOperationSupport(order = 8)
    @ApiOperation("获取方案执行监管分页")
    @GetMapping("/emergencySupportCenter/planExecuteSupervise/pageList")
    public CommonResult<Page<PlanExecute>> pageList(PlanExecutePageParam planExecutePageParam) {
        return CommonResult.data(planExecuteService.page(planExecutePageParam));
    }

    @ApiOperationSupport(order = 9)
    @ApiOperation("获取方案执行监管详情")
    @GetMapping("/emergencySupportCenter/planExecuteSupervise/detail")
    public CommonResult<PlanExecute> planExecuteSuperviseDetail(@Valid PlanExecuteIdParam planExecuteIdParam) {
        return CommonResult.data(planExecuteService.detail(planExecuteIdParam));
    }
}
