/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.planExecute.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.auth.core.pojo.SaBaseLoginUser;
import com.unis.auth.core.util.StpLoginUserUtil;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.entity.PlanExecuteEnterprise;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.mapper.PlanExecuteEnterpriseMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.planExecute.entity.PlanExecute;
import com.unis.emergencySupportCenter.modular.planExecute.mapper.PlanExecuteMapper;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteAddParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteEditParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecuteIdParam;
import com.unis.emergencySupportCenter.modular.planExecute.param.PlanExecutePageParam;
import com.unis.emergencySupportCenter.modular.planExecute.service.PlanExecuteService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 方案执行情况Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/28 17:10
 **/
@Service
public class PlanExecuteServiceImpl extends ServiceImpl<PlanExecuteMapper, PlanExecute> implements PlanExecuteService {
    @Resource
    private PlanExecuteEnterpriseMapper planExecuteEnterpriseMapper;
    @Resource
    private PlanExecuteMapper planExecuteMapper;

    @Override
    public Page<PlanExecute> page(PlanExecutePageParam planExecutePageParam) {
        QueryWrapper<PlanExecute> queryWrapper = new QueryWrapper<>();
        // 权限范围
        List<String> loginUserDataScope = StpLoginUserUtil.getLoginUserDataScope();
        // 创建人权限
        String loginUserId = StpLoginUserUtil.getLoginUser().getId();
        if (CollectionUtils.isNotEmpty(loginUserDataScope)) {
            queryWrapper.in("t1.sys_org_id", loginUserDataScope)
                    .or().eq("t1.create_user", loginUserId);
        } else {
            queryWrapper.eq("t1.create_user", StpUtil.getLoginIdAsString());
        }
        // 自定义查询条件
        if (StringUtils.isNotEmpty(planExecutePageParam.getPlanName())) {
            queryWrapper.like("t1.planName", planExecutePageParam.getPlanName());
        }
        if (ObjectUtil.isNotEmpty(planExecutePageParam.getEmergencyLevel())) {
            queryWrapper.eq("t1.emergencyLevel", planExecutePageParam.getEmergencyLevel());
        }
        // 排序
        if (ObjectUtil.isAllNotEmpty(planExecutePageParam.getSortField(), planExecutePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(planExecutePageParam.getSortOrder());
            queryWrapper.orderBy(true, planExecutePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(planExecutePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(PlanExecute::getId);
        }
        queryWrapper.groupBy("t1.es_online_plan_formulation_id");
        return planExecuteMapper.pageList(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PlanExecuteAddParam planExecuteAddParam) {
        PlanExecute planExecute = BeanUtil.toBean(planExecuteAddParam, PlanExecute.class);
        this.save(planExecute);
        // 保存子表关联数据
        this.insertChild(planExecute);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PlanExecuteEditParam planExecuteEditParam) {
        PlanExecute planExecute = this.queryEntity(planExecuteEditParam.getId());
        BeanUtil.copyProperties(planExecuteEditParam, planExecute);
        this.updateById(planExecute);
        // 编辑子表关联数据
        this.deleteChild(planExecute.getId()); // 先删除
        this.insertChild(planExecute); // 在新增
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PlanExecuteIdParam> planExecuteIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(planExecuteIdParamList, PlanExecuteIdParam::getId));
        // 删除子表关联数据
        planExecuteIdParamList.forEach(ids -> this.deleteChild(ids.getId()));
    }

    @Override
    public PlanExecute detail(PlanExecuteIdParam planExecuteIdParam) {
        PlanExecute planExecute = this.queryEntity(planExecuteIdParam.getId());
        // 查询子表关联数据
        List<PlanExecuteEnterprise> enterprises = planExecuteEnterpriseMapper.selectDetailList(this.queryWrapperChild(planExecute.getId()));
        if (CollectionUtils.isNotEmpty(enterprises)) {
            planExecute.setItems(enterprises);
        }
        return planExecute;
    }

    @Override
    public PlanExecute queryEntity(String id) {
        PlanExecute planExecute = this.getById(id);
        if (ObjectUtil.isEmpty(planExecute)) {
            throw new CommonException("方案执行情况不存在，id值为：{}", id);
        }
        return planExecute;
    }

    @Override
    public List<PlanExecuteEnterprise> getFourTypeList() {
        return planExecuteEnterpriseMapper.getFourTypeList();
    }

    private void insertChild(PlanExecute planExecute) {
        if (CollectionUtils.isNotEmpty(planExecute.getItems())) {
            planExecute.getItems().forEach(item -> {
                item.setEsPlanExecuteId(planExecute.getId());
                planExecuteEnterpriseMapper.insert(item);
            });
        }
    }

    private void deleteChild(String planExecuteId) {
        planExecuteEnterpriseMapper.delete(this.queryWrapperChild(planExecuteId));
    }

    private QueryWrapper<PlanExecuteEnterprise> queryWrapperChild(String planExecuteId) {
        QueryWrapper<PlanExecuteEnterprise> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(PlanExecuteEnterprise::getEsPlanExecuteId, planExecuteId);
        return wrapper;
    }
}
