/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.emergencySupportCenter.modular.planExecuteEnterprise.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.entity.PlanExecuteEnterprise;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.mapper.PlanExecuteEnterpriseMapper;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.param.PlanExecuteEnterpriseAddParam;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.param.PlanExecuteEnterpriseEditParam;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.param.PlanExecuteEnterpriseIdParam;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.param.PlanExecuteEnterprisePageParam;
import com.unis.emergencySupportCenter.modular.planExecuteEnterprise.service.PlanExecuteEnterpriseService;

import java.util.List;

/**
 * 方案执行情况-企业Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/28 17:13
 **/
@Service
public class PlanExecuteEnterpriseServiceImpl extends ServiceImpl<PlanExecuteEnterpriseMapper, PlanExecuteEnterprise> implements PlanExecuteEnterpriseService {

    @Override
    public Page<PlanExecuteEnterprise> page(PlanExecuteEnterprisePageParam planExecuteEnterprisePageParam) {
        QueryWrapper<PlanExecuteEnterprise> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(planExecuteEnterprisePageParam.getSortField(), planExecuteEnterprisePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(planExecuteEnterprisePageParam.getSortOrder());
            queryWrapper.orderBy(true, planExecuteEnterprisePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(planExecuteEnterprisePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PlanExecuteEnterprise::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PlanExecuteEnterpriseAddParam planExecuteEnterpriseAddParam) {
        PlanExecuteEnterprise planExecuteEnterprise = BeanUtil.toBean(planExecuteEnterpriseAddParam, PlanExecuteEnterprise.class);
        this.save(planExecuteEnterprise);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PlanExecuteEnterpriseEditParam planExecuteEnterpriseEditParam) {
        PlanExecuteEnterprise planExecuteEnterprise = this.queryEntity(planExecuteEnterpriseEditParam.getId());
        BeanUtil.copyProperties(planExecuteEnterpriseEditParam, planExecuteEnterprise);
        this.updateById(planExecuteEnterprise);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PlanExecuteEnterpriseIdParam> planExecuteEnterpriseIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(planExecuteEnterpriseIdParamList, PlanExecuteEnterpriseIdParam::getId));
    }

    @Override
    public PlanExecuteEnterprise detail(PlanExecuteEnterpriseIdParam planExecuteEnterpriseIdParam) {
        return this.queryEntity(planExecuteEnterpriseIdParam.getId());
    }

    @Override
    public PlanExecuteEnterprise queryEntity(String id) {
        PlanExecuteEnterprise planExecuteEnterprise = this.getById(id);
        if(ObjectUtil.isEmpty(planExecuteEnterprise)) {
            throw new CommonException("方案执行情况-企业不存在，id值为：{}", id);
        }
        return planExecuteEnterprise;
    }
}
