/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.entity.EcmCreditAssess;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessAddParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessEditParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessIdParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessPageParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.service.EcmCreditAssessService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 企业信用管理-信用评价表控制器
 *
 * @author TS
 * @date  2024/05/17 17:37
 */
@Api(tags = "企业信用管理-信用评价表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EcmCreditAssessController {

    @Resource
    private EcmCreditAssessService ecmCreditAssessService;

    /**
     * 获取企业信用管理-信用评价表分页
     *
     * @author TS
     * @date  2024/05/17 17:37
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取企业信用管理-信用评价表分页")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditAssess/page")
    @GetMapping("/enterpriseCreditManagement.info/ecmCreditAssess/page")
    public CommonResult<Page<EcmCreditAssess>> page(EcmCreditAssessPageParam ecmCreditAssessPageParam) {
        return CommonResult.data(ecmCreditAssessService.page(ecmCreditAssessPageParam));
    }

    /**
     * 添加企业信用管理-信用评价表
     *
     * @author TS
     * @date  2024/05/17 17:37
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加企业信用管理-信用评价表")
    @CommonLog("添加企业信用管理-信用评价表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditAssess/add")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditAssess/add")
    public CommonResult<String> add(@RequestBody @Valid EcmCreditAssessAddParam ecmCreditAssessAddParam) {
        ecmCreditAssessService.add(ecmCreditAssessAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑企业信用管理-信用评价表
     *
     * @author TS
     * @date  2024/05/17 17:37
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑企业信用管理-信用评价表")
    @CommonLog("编辑企业信用管理-信用评价表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditAssess/edit")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditAssess/edit")
    public CommonResult<String> edit(@RequestBody @Valid EcmCreditAssessEditParam ecmCreditAssessEditParam) {
        ecmCreditAssessService.edit(ecmCreditAssessEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除企业信用管理-信用评价表
     *
     * @author TS
     * @date  2024/05/17 17:37
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除企业信用管理-信用评价表")
    @CommonLog("删除企业信用管理-信用评价表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditAssess/delete")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditAssess/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EcmCreditAssessIdParam> ecmCreditAssessIdParamList) {
        ecmCreditAssessService.delete(ecmCreditAssessIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取企业信用管理-信用评价表详情
     *
     * @author TS
     * @date  2024/05/17 17:37
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取企业信用管理-信用评价表详情")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditAssess/detail")
    @GetMapping("/enterpriseCreditManagement.info/ecmCreditAssess/detail")
    public CommonResult<EcmCreditAssess> detail(@Valid EcmCreditAssessIdParam ecmCreditAssessIdParam) {
        return CommonResult.data(ecmCreditAssessService.detail(ecmCreditAssessIdParam));
    }
}
