/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.entity.EcmCreditAssess;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.mapper.EcmCreditAssessMapper;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessAddParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessEditParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessIdParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.param.EcmCreditAssessPageParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditAssess.service.EcmCreditAssessService;

import java.util.List;

/**
 * 企业信用管理-信用评价表Service接口实现类
 *
 * @author TS
 * @date  2024/05/17 17:37
 **/
@Service
public class EcmCreditAssessServiceImpl extends ServiceImpl<EcmCreditAssessMapper, EcmCreditAssess> implements EcmCreditAssessService {

    @Override
    public Page<EcmCreditAssess> page(EcmCreditAssessPageParam ecmCreditAssessPageParam) {
        QueryWrapper<EcmCreditAssess> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(ecmCreditAssessPageParam.getCreditScore())){
            queryWrapper.lambda().eq(EcmCreditAssess::getCreditScore,ecmCreditAssessPageParam.getCreditScore());
        }
        if (StringUtils.isNotBlank(ecmCreditAssessPageParam.getAssessResult())){
            queryWrapper.lambda().eq(EcmCreditAssess::getAssessResult,ecmCreditAssessPageParam.getAssessResult());
        }
        if(ObjectUtil.isAllNotEmpty(ecmCreditAssessPageParam.getSortField(), ecmCreditAssessPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ecmCreditAssessPageParam.getSortOrder());
            queryWrapper.orderBy(true, ecmCreditAssessPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ecmCreditAssessPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EcmCreditAssess::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EcmCreditAssessAddParam ecmCreditAssessAddParam) {
        EcmCreditAssess ecmCreditAssess = BeanUtil.toBean(ecmCreditAssessAddParam, EcmCreditAssess.class);
        this.save(ecmCreditAssess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EcmCreditAssessEditParam ecmCreditAssessEditParam) {
        EcmCreditAssess ecmCreditAssess = this.queryEntity(ecmCreditAssessEditParam.getId());
        BeanUtil.copyProperties(ecmCreditAssessEditParam, ecmCreditAssess);
        this.updateById(ecmCreditAssess);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EcmCreditAssessIdParam> ecmCreditAssessIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ecmCreditAssessIdParamList, EcmCreditAssessIdParam::getId));
    }

    @Override
    public EcmCreditAssess detail(EcmCreditAssessIdParam ecmCreditAssessIdParam) {
        return this.queryEntity(ecmCreditAssessIdParam.getId());
    }

    @Override
    public EcmCreditAssess queryEntity(String id) {
        EcmCreditAssess ecmCreditAssess = this.getById(id);
        if(ObjectUtil.isEmpty(ecmCreditAssess)) {
            throw new CommonException("企业信用管理-信用评价表不存在，id值为：{}", id);
        }
        return ecmCreditAssess;
    }
}
