/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.entity.vo.EcmCreditDataVo;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.service.EcmCreditDataService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.param.EcmCreditDataAddParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.param.EcmCreditDataEditParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.param.EcmCreditDataIdParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.param.EcmCreditDataPageParam;
import com.unis.enterpriseCreditManagement.info.modular.ecmCreditData.param.EcmCreditDataShareParam;

/**
 * 企业信用管理-信用数据管理表控制器
 *
 * @author TS
 * @date  2024/05/17 17:35
 */
@Api(tags = "企业信用管理-信用数据管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EcmCreditDataController {

    @Resource
    private EcmCreditDataService ecmCreditDataService;

    /**
     * 获取企业信用管理-信用数据管理表分页
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
//    @ApiOperationSupport(order = 1)
//    @ApiOperation("获取企业信用管理-信用数据管理表分页")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/page")
//    @GetMapping("/enterpriseCreditManagement.info/ecmCreditData/page")
//    public CommonResult<Page<EcmCreditData>> page(EcmCreditDataPageParam ecmCreditDataPageParam) {
//        return CommonResult.data(ecmCreditDataService.page(ecmCreditDataPageParam));
//    }
    /**
     * 获取企业信用管理-信用数据管理表自定义分页
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取企业信用管理-信用数据管理表自定义分页")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/findPage")
    @GetMapping("/enterpriseCreditManagement.info/ecmCreditData/findPage")
    public CommonResult<IPage<EcmCreditDataVo>> findPage(EcmCreditDataPageParam ecmCreditDataPageParam) {
        return CommonResult.data(ecmCreditDataService.findPage(ecmCreditDataPageParam));
    }

    /**
     * 添加企业信用管理-信用数据管理表
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加企业信用管理-信用数据管理表")
    @CommonLog("添加企业信用管理-信用数据管理表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/add")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditData/add")
    public CommonResult<String> add(@RequestBody @Valid EcmCreditDataAddParam ecmCreditDataAddParam) {
        ecmCreditDataService.add(ecmCreditDataAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑企业信用管理-信用数据管理表
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑企业信用管理-信用数据管理表")
    @CommonLog("编辑企业信用管理-信用数据管理表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/edit")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditData/edit")
    public CommonResult<String> edit(@RequestBody @Valid EcmCreditDataEditParam ecmCreditDataEditParam) {
        ecmCreditDataService.edit(ecmCreditDataEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除企业信用管理-信用数据管理表
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除企业信用管理-信用数据管理表")
    @CommonLog("删除企业信用管理-信用数据管理表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/delete")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditData/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EcmCreditDataIdParam> ecmCreditDataIdParamList) {
        ecmCreditDataService.delete(ecmCreditDataIdParamList);
        return CommonResult.ok();
    }
    /**
     * 批量共享
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("批量共享")
    @CommonLog("批量共享")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/shares")
    @PostMapping("/enterpriseCreditManagement.info/ecmCreditData/shares")
    public CommonResult<String> shares(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EcmCreditDataShareParam> creditDataShareParamList) {
        ecmCreditDataService.shares(creditDataShareParamList);
        return CommonResult.ok();
    }

    /**
     * 获取企业信用管理-信用数据管理表详情
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取企业信用管理-信用数据管理表详情")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/detail")
    @GetMapping("/enterpriseCreditManagement.info/ecmCreditData/detail")
    public CommonResult<EcmCreditDataVo> detail(@Valid EcmCreditDataIdParam ecmCreditDataIdParam) {
        return CommonResult.data(ecmCreditDataService.detail(ecmCreditDataIdParam));
    }
    /**
     * 获取未添加企业信用管理下拉列表
     *
     * @author TS
     * @date  2024/05/17 17:35
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取未添加企业信用管理下拉列表")
//    @SaCheckPermission("/enterpriseCreditManagement.info/ecmCreditData/getUnitList")
    @GetMapping("/enterpriseCreditManagement.info/ecmCreditData/getUnitList")
    public CommonResult<List<EcmCreditDataVo>> getUnitList() {
        return CommonResult.data(ecmCreditDataService.getUnitList());
    }
}
