/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emHonorTitle.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.entity.EmPersonInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.entity.EmHonorTitle;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.mapper.EmHonorTitleMapper;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.param.EmHonorTitleAddParam;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.param.EmHonorTitleEditParam;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.param.EmHonorTitleIdParam;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.param.EmHonorTitlePageParam;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.service.EmHonorTitleService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 企业管理-荣誉称号管理Service接口实现类
 *
 * @author TS
 * @date  2024/04/26 11:04
 **/
@Service
public class EmHonorTitleServiceImpl extends ServiceImpl<EmHonorTitleMapper, EmHonorTitle> implements EmHonorTitleService {
    @Resource
    private EmHonorTitleMapper emHonorTitleMapper;
    @Override
    public Page<EmHonorTitle> page(EmHonorTitlePageParam emHonorTitlePageParam) {
        QueryWrapper<EmHonorTitle> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(emHonorTitlePageParam.getSortField(), emHonorTitlePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emHonorTitlePageParam.getSortOrder());
            queryWrapper.orderBy(true, emHonorTitlePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emHonorTitlePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmHonorTitle::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmHonorTitleAddParam emHonorTitleAddParam) {
        EmHonorTitle emHonorTitle = BeanUtil.toBean(emHonorTitleAddParam, EmHonorTitle.class);
        this.save(emHonorTitle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmHonorTitleEditParam emHonorTitleEditParam) {
        EmHonorTitle emHonorTitle = this.queryEntity(emHonorTitleEditParam.getId());
        BeanUtil.copyProperties(emHonorTitleEditParam, emHonorTitle);
        this.updateById(emHonorTitle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmHonorTitleIdParam> emHonorTitleIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emHonorTitleIdParamList, EmHonorTitleIdParam::getId));
    }

    @Override
    public EmHonorTitle detail(EmHonorTitleIdParam emHonorTitleIdParam) {
        return this.queryEntity(emHonorTitleIdParam.getId());
    }

    @Override
    public EmHonorTitle queryEntity(String id) {
        EmHonorTitle emHonorTitle = this.getById(id);
        if(ObjectUtil.isEmpty(emHonorTitle)) {
            throw new CommonException("企业管理-荣誉称号管理不存在，id值为：{}", id);
        }
        return emHonorTitle;
    }

    /**
     * 获取企业管理-荣誉称号管理自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(EmHonorTitlePageParam pageParam) {
        //条形查询器
        QueryWrapper<EmHonorTitle> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(pageParam.getName())) {
            queryWrapper.like("a.name", pageParam.getName());
        }
        Page<EmHonorTitle> p = new Page<>(pageParam.getCurrent(), pageParam.getSize());

        IPage<Map<String, Object>> page = emHonorTitleMapper.selectMyMapsPage(p, queryWrapper);
        return page;
    }
}
