/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emKnowledge.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.grainPriceCollectProvinceSum.entity.GrainPriceCollectProvinceSum;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emKnowledge.entity.EmKnowledge;
import com.unis.enterpriseManagement.info.modular.emKnowledge.mapper.EmKnowledgeMapper;
import com.unis.enterpriseManagement.info.modular.emKnowledge.param.EmKnowledgeAddParam;
import com.unis.enterpriseManagement.info.modular.emKnowledge.param.EmKnowledgeEditParam;
import com.unis.enterpriseManagement.info.modular.emKnowledge.param.EmKnowledgeIdParam;
import com.unis.enterpriseManagement.info.modular.emKnowledge.param.EmKnowledgePageParam;
import com.unis.enterpriseManagement.info.modular.emKnowledge.service.EmKnowledgeService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 企业管理-知识库建设Service接口实现类
 *
 * @author TS
 * @date  2024/04/25 11:44
 **/
@Service
public class EmKnowledgeServiceImpl extends ServiceImpl<EmKnowledgeMapper, EmKnowledge> implements EmKnowledgeService {

    @Resource
    private EmKnowledgeMapper emKnowledgeMapper;
    @Override
    public Page<EmKnowledge> page(EmKnowledgePageParam emKnowledgePageParam) {
        QueryWrapper<EmKnowledge> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(emKnowledgePageParam.getSortField(), emKnowledgePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emKnowledgePageParam.getSortOrder());
            queryWrapper.orderBy(true, emKnowledgePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emKnowledgePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmKnowledge::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmKnowledgeAddParam emKnowledgeAddParam) {
        EmKnowledge emKnowledge = BeanUtil.toBean(emKnowledgeAddParam, EmKnowledge.class);
        this.save(emKnowledge);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmKnowledgeEditParam emKnowledgeEditParam) {
        EmKnowledge emKnowledge = this.queryEntity(emKnowledgeEditParam.getId());
        BeanUtil.copyProperties(emKnowledgeEditParam, emKnowledge);
        this.updateById(emKnowledge);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmKnowledgeIdParam> emKnowledgeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emKnowledgeIdParamList, EmKnowledgeIdParam::getId));
    }

    @Override
    public EmKnowledge detail(EmKnowledgeIdParam emKnowledgeIdParam) {
        return this.queryEntity(emKnowledgeIdParam.getId());
    }

    @Override
    public EmKnowledge queryEntity(String id) {
        EmKnowledge emKnowledge = this.getById(id);
        if(ObjectUtil.isEmpty(emKnowledge)) {
            throw new CommonException("企业管理-知识库建设不存在，id值为：{}", id);
        }
        return emKnowledge;
    }

    /**
     * 获取企业管理-知识库建设自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(EmKnowledgePageParam pageParam) {
        //条形查询器
        QueryWrapper<EmKnowledge> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(pageParam.getTheme())) {
            queryWrapper.like("theme", pageParam.getTheme());
        }
        Page<EmKnowledge> p = new Page<>(pageParam.getCurrent(), pageParam.getSize());

        IPage<Map<String, Object>> page = emKnowledgeMapper.selectMyMapsPage(p, queryWrapper);
        return page;
    }
}
