/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emPersonInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.grainPriceCollectProvinceSum.entity.GrainPriceCollectProvinceSum;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.entity.EmPersonInfo;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.mapper.EmPersonInfoMapper;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.param.EmPersonInfoAddParam;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.param.EmPersonInfoEditParam;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.param.EmPersonInfoIdParam;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.param.EmPersonInfoPageParam;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.service.EmPersonInfoService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 企业管理-人员信息管理Service接口实现类
 *
 * @author TS
 * @date  2024/04/25 11:36
 **/
@Service
public class EmPersonInfoServiceImpl extends ServiceImpl<EmPersonInfoMapper, EmPersonInfo> implements EmPersonInfoService {

    @Resource
    private  EmPersonInfoMapper emPersonInfoMapper;
    @Override
    public Page<EmPersonInfo> page(EmPersonInfoPageParam emPersonInfoPageParam) {
        QueryWrapper<EmPersonInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(emPersonInfoPageParam.getSortField(), emPersonInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emPersonInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, emPersonInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emPersonInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmPersonInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmPersonInfoAddParam emPersonInfoAddParam) {
        EmPersonInfo emPersonInfo = BeanUtil.toBean(emPersonInfoAddParam, EmPersonInfo.class);
        this.save(emPersonInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmPersonInfoEditParam emPersonInfoEditParam) {
        EmPersonInfo emPersonInfo = this.queryEntity(emPersonInfoEditParam.getId());
        BeanUtil.copyProperties(emPersonInfoEditParam, emPersonInfo);
        this.updateById(emPersonInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmPersonInfoIdParam> emPersonInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emPersonInfoIdParamList, EmPersonInfoIdParam::getId));
    }

    @Override
    public EmPersonInfo detail(EmPersonInfoIdParam emPersonInfoIdParam) {
        return this.queryEntity(emPersonInfoIdParam.getId());
    }

    @Override
    public EmPersonInfo queryEntity(String id) {
        EmPersonInfo emPersonInfo = this.getById(id);
        if(ObjectUtil.isEmpty(emPersonInfo)) {
            throw new CommonException("企业管理-人员信息管理不存在，id值为：{}", id);
        }
        return emPersonInfo;
    }

    /**
     * 获取企业管理-人员信息管理自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(EmPersonInfoPageParam pageParam) {
        //条形查询器
        QueryWrapper<EmPersonInfo> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(pageParam.getName())) {
            queryWrapper.like("a.name", pageParam.getName());
        }
        Page<EmPersonInfo> p = new Page<>(pageParam.getCurrent(), pageParam.getSize());

        IPage<Map<String, Object>> page = emPersonInfoMapper.selectMyMapsPage(p, queryWrapper);
        return page;
    }

    /**
     * 获取企业管理-人员信息下拉列表
     *
     * @return
     */
    @Override
    public List<EmPersonInfo> getPersions() {
        return this.list();
    }
}
