/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emPersonPlan.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.entity.EmPersonPlan;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanAddParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanEditParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanIdParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanPageParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.service.EmPersonPlanService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.Map;

/**
 * 企业管理-人才规划控制器
 *
 * @author TS
 * @date  2024/04/26 15:33
 */
@Api(tags = "企业管理-人才规划控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EmPersonPlanController {

    @Resource
    private EmPersonPlanService emPersonPlanService;

    /**
     * 获取企业管理-人才规划分页
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
//    @ApiOperationSupport(order = 1)
//    @ApiOperation("获取企业管理-人才规划分页")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/page")
//    @GetMapping("/enterpriseManagement.info/emPersonPlan/page")
//    public CommonResult<Page<EmPersonPlan>> page(EmPersonPlanPageParam emPersonPlanPageParam) {
//        return CommonResult.data(emPersonPlanService.page(emPersonPlanPageParam));
//    }
    /**
     * 获取企业管理-人才规划或人才规则审核自定义分页
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取企业管理-人才规划或人才规则审核自定义分页")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/findPage")
    @GetMapping("/enterpriseManagement.info/emPersonPlan/findPage")
    public CommonResult<IPage<Map<String,Object>>> page(EmPersonPlanPageParam emPersonPlanPageParam) {
        return CommonResult.data(emPersonPlanService.findPage(emPersonPlanPageParam));
    }

    /**
     * 添加企业管理-人才规划
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加企业管理-人才规划")
    @CommonLog("添加企业管理-人才规划")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/add")
    @PostMapping("/enterpriseManagement.info/emPersonPlan/add")
    public CommonResult<String> add(@RequestBody @Valid EmPersonPlanAddParam emPersonPlanAddParam) {
        emPersonPlanService.add(emPersonPlanAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑企业管理-人才规划
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑企业管理-人才规划")
    @CommonLog("编辑企业管理-人才规划")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/edit")
    @PostMapping("/enterpriseManagement.info/emPersonPlan/edit")
    public CommonResult<String> edit(@RequestBody @Valid EmPersonPlanEditParam emPersonPlanEditParam) {
        emPersonPlanService.edit(emPersonPlanEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除企业管理-人才规划
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除企业管理-人才规划")
    @CommonLog("删除企业管理-人才规划")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/delete")
    @PostMapping("/enterpriseManagement.info/emPersonPlan/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EmPersonPlanIdParam> emPersonPlanIdParamList) {
        emPersonPlanService.delete(emPersonPlanIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取企业管理-人才规划详情
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取企业管理-人才规划详情")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/detail")
    @GetMapping("/enterpriseManagement.info/emPersonPlan/detail")
    public CommonResult<JSONObject> detail(@Valid EmPersonPlanIdParam emPersonPlanIdParam) {
        return CommonResult.data(emPersonPlanService.detail(emPersonPlanIdParam));
    }

    /**
     * 启动企业管理-人才规流程
     *
     * @author TS
     * @date  2024/04/26 15:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("启动企业管理-人才规流程")
//    @SaCheckPermission("/enterpriseManagement.info/emPersonPlan/startFlow")
    @GetMapping("/enterpriseManagement.info/emPersonPlan/startFlow")
    public CommonResult<String> startFlow(@Valid EmPersonPlanIdParam emPersonPlanIdParam) {
        return CommonResult.data(emPersonPlanService.startFlow(emPersonPlanIdParam));
    }
}
