/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emPersonPlan.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.enterpriseManagement.info.modular.emHonorTitle.entity.EmHonorTitle;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.entity.EmPersonInfo;
import com.unis.enterpriseManagement.info.modular.emPersonInfo.service.EmPersonInfoService;
import com.unis.policy.info.modular.alPolicyFileReport.entity.AlPolicyFileReport;
import com.unis.policy.info.modular.auditRequest.entity.AuditRequest;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.entity.EmPersonPlan;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.mapper.EmPersonPlanMapper;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanAddParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanEditParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanIdParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.param.EmPersonPlanPageParam;
import com.unis.enterpriseManagement.info.modular.emPersonPlan.service.EmPersonPlanService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 企业管理-人才规划Service接口实现类
 *
 * @author TS
 * @date  2024/04/26 15:33
 **/
@Service
public class EmPersonPlanServiceImpl extends ServiceImpl<EmPersonPlanMapper, EmPersonPlan> implements EmPersonPlanService {

    @Resource
    private  EmPersonPlanMapper emPersonPlanMapper;

    @Autowired
    private EmPersonInfoService emPersonInfoService;
    @Override
    public Page<EmPersonPlan> page(EmPersonPlanPageParam emPersonPlanPageParam) {
        QueryWrapper<EmPersonPlan> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(emPersonPlanPageParam.getSortField(), emPersonPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emPersonPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, emPersonPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emPersonPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmPersonPlan::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmPersonPlanAddParam emPersonPlanAddParam) {
        EmPersonPlan emPersonPlan = BeanUtil.toBean(emPersonPlanAddParam, EmPersonPlan.class);
        this.save(emPersonPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmPersonPlanEditParam emPersonPlanEditParam) {
        EmPersonPlan emPersonPlan = this.queryEntity(emPersonPlanEditParam.getId());
        BeanUtil.copyProperties(emPersonPlanEditParam, emPersonPlan);
        this.updateById(emPersonPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmPersonPlanIdParam> emPersonPlanIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emPersonPlanIdParamList, EmPersonPlanIdParam::getPlanId));
    }

    @Override
    public JSONObject detail(EmPersonPlanIdParam emPersonPlanIdParam) {
        JSONObject jsonObject = new JSONObject();
        EmPersonInfo emPersonInfo = emPersonInfoService.queryEntity(emPersonPlanIdParam.getPersonInfoId());
        jsonObject.put("emPersonInfo",emPersonInfo);

        if (StringUtils.isNotBlank(emPersonPlanIdParam.getPlanId())){
            EmPersonPlan emPersonPlan =  this.queryEntity(emPersonPlanIdParam.getPlanId());
            jsonObject.put("emPersonPlan",emPersonPlan);
        }
        return jsonObject;
    }

    @Override
    public EmPersonPlan queryEntity(String id) {
        EmPersonPlan emPersonPlan = this.getById(id);
        if(ObjectUtil.isEmpty(emPersonPlan)) {
            throw new CommonException("企业管理-人才规划不存在，id值为：{}", id);
        }
        return emPersonPlan;
    }

    /**
     * 获取企业管理-人才规划自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(EmPersonPlanPageParam pageParam) {
        //条形查询器
        QueryWrapper<EmPersonPlan> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(pageParam.getName())) {
            queryWrapper.like("a.name", pageParam.getName());
        }
        if (pageParam.getType() != null && pageParam.getType() == 2){
            queryWrapper.ne("c.status", 0);

        }
        Page<EmPersonPlan> p = new Page<>(pageParam.getCurrent(), pageParam.getSize());

        IPage<Map<String, Object>> page = emPersonPlanMapper.selectMyMapsPage(p, queryWrapper,pageParam.getType());
        return page;
    }

    /**
     * 启动企业管理-人才规流程
     *
     * @param emPersonPlanIdParam
     * @return
     */
    @Override
    public String startFlow(EmPersonPlanIdParam emPersonPlanIdParam) {
        EmPersonPlan emPersonPlan  = this.queryEntity(emPersonPlanIdParam.getPlanId());
        emPersonPlan.setStatus(1);
        return this.updateById(emPersonPlan)?"申请成功":"申请失败";
    }
}
