/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emPositionInfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.entity.EmPositionInfo;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoAddParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoEditParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoIdParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoPageParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.service.EmPositionInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.Map;

/**
 * 企业管理-位置信息管理控制器
 *
 * @author TS
 * @date  2024/04/25 11:31
 */
@Api(tags = "企业管理-位置信息管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EmPositionInfoController {

    @Resource
    private EmPositionInfoService emPositionInfoService;

    /**
     * 获取企业管理-位置信息管理分页
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
//    @ApiOperationSupport(order = 1)
//    @ApiOperation("获取企业管理-位置信息管理分页")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/page")
//    @GetMapping("/enterpriseManagement.info/emPositionInfo/page")
//    public CommonResult<Page<EmPositionInfo>> page(EmPositionInfoPageParam emPositionInfoPageParam) {
//        return CommonResult.data(emPositionInfoService.page(emPositionInfoPageParam));
//    }
    /**
     * 获取企业管理-位置信息管理自定义分页
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取企业管理-位置信息管理自定义分页")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/findPage")
    @GetMapping("/enterpriseManagement.info/emPositionInfo/findPage")
    public CommonResult<IPage<Map<String,Object>>> page(EmPositionInfoPageParam emPositionInfoPageParam) {
        return CommonResult.data(emPositionInfoService.findPage(emPositionInfoPageParam));
    }

    /**
     * 添加企业管理-位置信息管理
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加企业管理-位置信息管理")
    @CommonLog("添加企业管理-位置信息管理")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/add")
    @PostMapping("/enterpriseManagement.info/emPositionInfo/add")
    public CommonResult<String> add(@RequestBody @Valid EmPositionInfoAddParam emPositionInfoAddParam) {
        emPositionInfoService.add(emPositionInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑企业管理-位置信息管理
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑企业管理-位置信息管理")
    @CommonLog("编辑企业管理-位置信息管理")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/edit")
    @PostMapping("/enterpriseManagement.info/emPositionInfo/edit")
    public CommonResult<String> edit(@RequestBody @Valid EmPositionInfoEditParam emPositionInfoEditParam) {
        emPositionInfoService.edit(emPositionInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除企业管理-位置信息管理
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除企业管理-位置信息管理")
    @CommonLog("删除企业管理-位置信息管理")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/delete")
    @PostMapping("/enterpriseManagement.info/emPositionInfo/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EmPositionInfoIdParam> emPositionInfoIdParamList) {
        emPositionInfoService.delete(emPositionInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取企业管理-位置信息管理详情
     *
     * @author TS
     * @date  2024/04/25 11:31
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取企业管理-位置信息管理详情")
//    @SaCheckPermission("/enterpriseManagement.info/emPositionInfo/detail")
    @GetMapping("/enterpriseManagement.info/emPositionInfo/detail")
    public CommonResult<EmPositionInfo> detail(@Valid EmPositionInfoIdParam emPositionInfoIdParam) {
        return CommonResult.data(emPositionInfoService.detail(emPositionInfoIdParam));
    }
}
