/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emPositionInfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.biz.modular.dict.service.BizDictService;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.entity.EmPositionInfo;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.mapper.EmPositionInfoMapper;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoAddParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoEditParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoIdParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.param.EmPositionInfoPageParam;
import com.unis.enterpriseManagement.info.modular.emPositionInfo.service.EmPositionInfoService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 企业管理-位置信息管理Service接口实现类
 *
 * @author TS
 * @date  2024/04/25 11:31
 **/
@Service
public class EmPositionInfoServiceImpl extends ServiceImpl<EmPositionInfoMapper, EmPositionInfo> implements EmPositionInfoService {

    @Resource
    private EmPositionInfoMapper emPositionInfoMapper;
    @Autowired
    private BizDictService bizDictService;
    @Override
    public Page<EmPositionInfo> page(EmPositionInfoPageParam emPositionInfoPageParam) {
        QueryWrapper<EmPositionInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(emPositionInfoPageParam.getSortField(), emPositionInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emPositionInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, emPositionInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emPositionInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmPositionInfo::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmPositionInfoAddParam emPositionInfoAddParam) {
        EmPositionInfo emPositionInfo = BeanUtil.toBean(emPositionInfoAddParam, EmPositionInfo.class);
        this.save(emPositionInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmPositionInfoEditParam emPositionInfoEditParam) {
        EmPositionInfo emPositionInfo = this.queryEntity(emPositionInfoEditParam.getId());
        BeanUtil.copyProperties(emPositionInfoEditParam, emPositionInfo);
        this.updateById(emPositionInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmPositionInfoIdParam> emPositionInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emPositionInfoIdParamList, EmPositionInfoIdParam::getId));
    }

    @Override
    public EmPositionInfo detail(EmPositionInfoIdParam emPositionInfoIdParam) {
        EmPositionInfo emPositionInfo = this.queryEntity(emPositionInfoIdParam.getId());
        if (StringUtils.isNotBlank(emPositionInfo.getZcdzProvince()))
        emPositionInfo.setZcdzProvinceName(bizDictService.getById(emPositionInfo.getZcdzProvince()).getDictLabel());
        if (StringUtils.isNotBlank(emPositionInfo.getZcdzCity()))
        emPositionInfo.setZcdzCityName(bizDictService.getById(emPositionInfo.getZcdzCity()).getDictLabel());
        if (StringUtils.isNotBlank(emPositionInfo.getZcdzArea()))
        emPositionInfo.setZcdzAreaName(bizDictService.getById(emPositionInfo.getZcdzArea()).getDictLabel());
        return emPositionInfo;
    }

    @Override
    public EmPositionInfo queryEntity(String id) {
        EmPositionInfo emPositionInfo = this.getById(id);
        if(ObjectUtil.isEmpty(emPositionInfo)) {
            throw new CommonException("企业管理-位置信息管理不存在，id值为：{}", id);
        }
        return emPositionInfo;
    }

    /**
     * 获取企业管理-位置信息管理自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(EmPositionInfoPageParam pageParam) {
        //条形查询器
        QueryWrapper<EmPositionInfo> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(pageParam.getDwmc())) {
            queryWrapper.like("a.dwmc", pageParam.getDwmc());
        }
        Page<EmPositionInfo> p = new Page<>(pageParam.getCurrent(), pageParam.getSize());

        IPage<Map<String, Object>> page = emPositionInfoMapper.selectMyMapsPage(p, queryWrapper);
        return page;
    }
}
