/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emSystemBuild.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.sys.modular.user.entity.SysUser;
import com.unis.sys.modular.user.service.SysUserService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.entity.EmSystemBuild;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.mapper.EmSystemBuildMapper;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.param.EmSystemBuildAddParam;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.param.EmSystemBuildEditParam;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.param.EmSystemBuildIdParam;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.param.EmSystemBuildPageParam;
import com.unis.enterpriseManagement.info.modular.emSystemBuild.service.EmSystemBuildService;

import java.util.List;

/**
 * 企业管理-人员制度建设Service接口实现类
 *
 * @author TS
 * @date  2024/04/26 15:25
 **/
@Service
public class EmSystemBuildServiceImpl extends ServiceImpl<EmSystemBuildMapper, EmSystemBuild> implements EmSystemBuildService {

    @Autowired
    private SysUserService sysUserService;
    @Override
    public Page<EmSystemBuild> page(EmSystemBuildPageParam emSystemBuildPageParam) {
        QueryWrapper<EmSystemBuild> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(emSystemBuildPageParam.getSystemName())){
            queryWrapper.lambda().like(EmSystemBuild::getSystemName,emSystemBuildPageParam.getSystemName());
        }
        if(ObjectUtil.isAllNotEmpty(emSystemBuildPageParam.getSortField(), emSystemBuildPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emSystemBuildPageParam.getSortOrder());
            queryWrapper.orderBy(true, emSystemBuildPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emSystemBuildPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmSystemBuild::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmSystemBuildAddParam emSystemBuildAddParam) {
        EmSystemBuild emSystemBuild = BeanUtil.toBean(emSystemBuildAddParam, EmSystemBuild.class);
        this.save(emSystemBuild);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmSystemBuildEditParam emSystemBuildEditParam) {
        EmSystemBuild emSystemBuild = this.queryEntity(emSystemBuildEditParam.getId());
        BeanUtil.copyProperties(emSystemBuildEditParam, emSystemBuild);
        this.updateById(emSystemBuild);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmSystemBuildIdParam> emSystemBuildIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emSystemBuildIdParamList, EmSystemBuildIdParam::getId));
    }

    @Override
    public EmSystemBuild detail(EmSystemBuildIdParam emSystemBuildIdParam) {
        return this.queryEntity(emSystemBuildIdParam.getId());
    }

    @Override
    public EmSystemBuild queryEntity(String id) {
        EmSystemBuild emSystemBuild = this.getById(id);
        if(ObjectUtil.isEmpty(emSystemBuild)) {
            throw new CommonException("企业管理-人员制度建设不存在，id值为：{}", id);
        }
        //设置创建用户名
       SysUser sysUser = sysUserService.queryEntity(emSystemBuild.getCreateUser());
        emSystemBuild.setCreateUserName(sysUser.getName());
        return emSystemBuild;
    }
}
