/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emTrain.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.enterpriseManagement.info.modular.emTrain.entity.EmTrain;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainAddParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainEditParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainIdParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainPageParam;
import com.unis.enterpriseManagement.info.modular.emTrain.service.EmTrainService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 企业管理-人才培训管理控制器
 *
 * @author TS
 * @date  2024/04/26 15:54
 */
@Api(tags = "企业管理-人才培训管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class EmTrainController {

    @Resource
    private EmTrainService emTrainService;

    /**
     * 获取企业管理-人才培训管理自定义分页
     *
     * @author TS
     * @date  2024/04/26 15:54
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取企业管理-人才培训管理自定义分页")
//    @SaCheckPermission("/enterpriseManagement.info/emTrain/findPage")
    @GetMapping("/enterpriseManagement.info/emTrain/findPage")
    public CommonResult<Page<EmTrain>> page(EmTrainPageParam emTrainPageParam) {
        return CommonResult.data(emTrainService.page(emTrainPageParam));
    }

    /**
     * 添加企业管理-人才培训管理
     *
     * @author TS
     * @date  2024/04/26 15:54
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加企业管理-人才培训管理")
    @CommonLog("添加企业管理-人才培训管理")
//    @SaCheckPermission("/enterpriseManagement.info/emTrain/add")
    @PostMapping("/enterpriseManagement.info/emTrain/add")
    public CommonResult<String> add(@RequestBody @Valid EmTrainAddParam emTrainAddParam) {
        emTrainService.add(emTrainAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑企业管理-人才培训管理
     *
     * @author TS
     * @date  2024/04/26 15:54
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑企业管理-人才培训管理")
    @CommonLog("编辑企业管理-人才培训管理")
//    @SaCheckPermission("/enterpriseManagement.info/emTrain/edit")
    @PostMapping("/enterpriseManagement.info/emTrain/edit")
    public CommonResult<String> edit(@RequestBody @Valid EmTrainEditParam emTrainEditParam) {
        emTrainService.edit(emTrainEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除企业管理-人才培训管理
     *
     * @author TS
     * @date  2024/04/26 15:54
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除企业管理-人才培训管理")
    @CommonLog("删除企业管理-人才培训管理")
//    @SaCheckPermission("/enterpriseManagement.info/emTrain/delete")
    @PostMapping("/enterpriseManagement.info/emTrain/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<EmTrainIdParam> emTrainIdParamList) {
        emTrainService.delete(emTrainIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取企业管理-人才培训管理详情
     *
     * @author TS
     * @date  2024/04/26 15:54
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取企业管理-人才培训管理详情")
//    @SaCheckPermission("/enterpriseManagement.info/emTrain/detail")
    @GetMapping("/enterpriseManagement.info/emTrain/detail")
    public CommonResult<EmTrain> detail(@Valid EmTrainIdParam emTrainIdParam) {
        return CommonResult.data(emTrainService.detail(emTrainIdParam));
    }
}
