/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.enterpriseManagement.info.modular.emTrain.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.enterpriseManagement.info.modular.emTrain.entity.EmTrain;
import com.unis.enterpriseManagement.info.modular.emTrain.mapper.EmTrainMapper;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainAddParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainEditParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainIdParam;
import com.unis.enterpriseManagement.info.modular.emTrain.param.EmTrainPageParam;
import com.unis.enterpriseManagement.info.modular.emTrain.service.EmTrainService;

import java.util.List;

/**
 * 企业管理-人才培训管理Service接口实现类
 *
 * @author TS
 * @date  2024/04/26 15:54
 **/
@Service
public class EmTrainServiceImpl extends ServiceImpl<EmTrainMapper, EmTrain> implements EmTrainService {

    @Override
    public Page<EmTrain> page(EmTrainPageParam emTrainPageParam) {
        QueryWrapper<EmTrain> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(emTrainPageParam.getTrainingName())){
            queryWrapper.lambda().like(EmTrain::getTrainingName,emTrainPageParam.getTrainingName());
        }

        if(ObjectUtil.isAllNotEmpty(emTrainPageParam.getSortField(), emTrainPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(emTrainPageParam.getSortOrder());
            queryWrapper.orderBy(true, emTrainPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(emTrainPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(EmTrain::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(EmTrainAddParam emTrainAddParam) {
        EmTrain emTrain = BeanUtil.toBean(emTrainAddParam, EmTrain.class);
        this.save(emTrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(EmTrainEditParam emTrainEditParam) {
        EmTrain emTrain = this.queryEntity(emTrainEditParam.getId());
        BeanUtil.copyProperties(emTrainEditParam, emTrain);
        this.updateById(emTrain);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<EmTrainIdParam> emTrainIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(emTrainIdParamList, EmTrainIdParam::getId));
    }

    @Override
    public EmTrain detail(EmTrainIdParam emTrainIdParam) {
        return this.queryEntity(emTrainIdParam.getId());
    }

    @Override
    public EmTrain queryEntity(String id) {
        EmTrain emTrain = this.getById(id);
        if(ObjectUtil.isEmpty(emTrain)) {
            throw new CommonException("企业管理-人才培训管理不存在，id值为：{}", id);
        }
        return emTrain;
    }
}
