/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.utils.ParameterUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.entity.MonitorNvr;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrAddParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrEditParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrIdParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrPageParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.service.MonitorNvrService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 硬盘录像机表控制器
 *
 * @author hjc
 * @date  2024/06/21 10:10
 */
@Api(tags = "硬盘录像机表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MonitorNvrController {

    @Resource
    private MonitorNvrService monitorNvrService;

    /**
     * 获取硬盘录像机表分页
     *
     * @author hjc
     * @date  2024/06/21 10:10
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取硬盘录像机表分页")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorNvr/page")
    @GetMapping("/equipmentOnlineRateAssessment/monitorNvr/page")
    public CommonResult<Page<MonitorNvr>> page(MonitorNvrPageParam monitorNvrPageParam) {
        return CommonResult.data(monitorNvrService.page(monitorNvrPageParam));
    }

    /**
     * 添加硬盘录像机表
     *
     * @author hjc
     * @date  2024/06/21 10:10
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加硬盘录像机表")
    @CommonLog("添加硬盘录像机表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorNvr/add")
    @PostMapping("/equipmentOnlineRateAssessment/monitorNvr/add")
    public CommonResult<String> add(@RequestBody @Valid MonitorNvrAddParam monitorNvrAddParam) {
        monitorNvrService.add(monitorNvrAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑硬盘录像机表
     *
     * @author hjc
     * @date  2024/06/21 10:10
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑硬盘录像机表")
    @CommonLog("编辑硬盘录像机表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorNvr/edit")
    @PostMapping("/equipmentOnlineRateAssessment/monitorNvr/edit")
    public CommonResult<String> edit(@RequestBody @Valid MonitorNvrEditParam monitorNvrEditParam) {
        monitorNvrService.edit(monitorNvrEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除硬盘录像机表
     *
     * @author hjc
     * @date  2024/06/21 10:10
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除硬盘录像机表")
    @CommonLog("删除硬盘录像机表")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorNvr/delete")
    @PostMapping("/equipmentOnlineRateAssessment/monitorNvr/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MonitorNvrIdParam> monitorNvrIdParamList) {
        monitorNvrService.delete(monitorNvrIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取硬盘录像机表详情
     *
     * @author hjc
     * @date  2024/06/21 10:10
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取硬盘录像机表详情")
    //@SaCheckPermission("/equipmentOnlineRateAssessment/monitorNvr/detail")
    @GetMapping("/equipmentOnlineRateAssessment/monitorNvr/detail")
    public CommonResult<MonitorNvr> detail(@Valid MonitorNvrIdParam monitorNvrIdParam) {
        return CommonResult.data(monitorNvrService.detail(monitorNvrIdParam));
    }

    /**
     * shine
     * @param orgId
     * @return
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("*查找要录像的NVR信息")
    @GetMapping("/camera/getNVRVideo")
    public CommonResult<List<Map<String,Object>>> getNVRVideo(Integer orgId) {
        Map<String,Object> map = new HashMap<>();
        map.put("orgId",orgId.toString());
        List<Map<String,Object>> list = monitorNvrService.selectByNVRDates(map);
        return CommonResult.data(ParameterUtil.slashCapitals(list));
    }
}
