/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.entity.MonitorNvr;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.mapper.MonitorNvrMapper;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrAddParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrEditParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrIdParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.param.MonitorNvrPageParam;
import com.unis.equipmentOnlineRateAssessment.modular.monitorNvr.service.MonitorNvrService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 硬盘录像机表Service接口实现类
 *
 * @author hjc
 * @date  2024/06/21 10:10
 **/
@Service
public class MonitorNvrServiceImpl extends ServiceImpl<MonitorNvrMapper, MonitorNvr> implements MonitorNvrService {

    @Resource
    private MonitorNvrMapper monitorNvrMapper;
    @Override
    public Page<MonitorNvr> page(MonitorNvrPageParam monitorNvrPageParam) {
        QueryWrapper<MonitorNvr> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(monitorNvrPageParam.getSortField(), monitorNvrPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(monitorNvrPageParam.getSortOrder());
            queryWrapper.orderBy(true, monitorNvrPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(monitorNvrPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MonitorNvr::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MonitorNvrAddParam monitorNvrAddParam) {
        MonitorNvr monitorNvr = BeanUtil.toBean(monitorNvrAddParam, MonitorNvr.class);
        this.save(monitorNvr);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MonitorNvrEditParam monitorNvrEditParam) {
        MonitorNvr monitorNvr = this.queryEntity(monitorNvrEditParam.getId());
        BeanUtil.copyProperties(monitorNvrEditParam, monitorNvr);
        this.updateById(monitorNvr);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MonitorNvrIdParam> monitorNvrIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(monitorNvrIdParamList, MonitorNvrIdParam::getId));
    }

    @Override
    public MonitorNvr detail(MonitorNvrIdParam monitorNvrIdParam) {
        return this.queryEntity(monitorNvrIdParam.getId());
    }

    @Override
    public MonitorNvr queryEntity(Integer id) {
        MonitorNvr monitorNvr = this.getById(id);
        if(ObjectUtil.isEmpty(monitorNvr)) {
            throw new CommonException("硬盘录像机表不存在，id值为：{}", id);
        }
        return monitorNvr;
    }

    @Override
    public List<Map<String, Object>> selectByNVRDates(Map<String, Object> map) {
        return monitorNvrMapper.selectByNVRDates(map);
    }
}
