/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.assessmentManage.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelAddParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.examine.modular.assessmentManage.entity.AssessmentManage;
import com.unis.examine.modular.assessmentManage.param.AssessmentManageAddParam;
import com.unis.examine.modular.assessmenttarget.param.AssessmentTargetAddParam;
import com.unis.examine.modular.assessmentManage.param.AssessmentManageEditParam;
import com.unis.examine.modular.assessmentManage.param.AssessmentManageIdParam;
import com.unis.examine.modular.assessmentManage.param.AssessmentManagePageParam;
import com.unis.examine.modular.assessmentManage.service.AssessmentManageService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * 粮食安全责任制考核-考核指标管理表控制器
 *  @author shine
 * @date  2024/04/22 11:44
 */
@Api(tags = "考核指标管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class AssessmentManageController {

    @Resource
    private AssessmentManageService assessmentManageService;

    /**
     * 获取粮食安全责任制考核-考核指标管理表分页
     *
     * @author shine
     * @date  2024/04/22 11:44
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("考核指标管理表分页")
    //@SaCheckPermission("/examine/assessmentManage/page")
    @GetMapping("/examine/assessmentManage/page")
    public CommonResult<Page<AssessmentManage>> page(AssessmentManagePageParam assessmentManagePageParam) throws ParseException {
        return CommonResult.data(assessmentManageService.page(assessmentManagePageParam));
    }

    /**
     * 添加粮食安全责任制考核-考核指标管理表
     *
     * @author shine
     * @date  2024/04/22 11:44
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加-考核指标管理表")
    @CommonLog("添加粮食安全责任制考核-考核指标管理表")
    //@SaCheckPermission("/examine/assessmentManage/add")
    @PostMapping("/examine/assessmentManage/add")
    public CommonResult<String> add(@RequestBody @Valid AssessmentManageAddParam assessmentManageAddParam ) throws ParseException {
        List<AssessmentLevelAddParam> levelList = assessmentManageAddParam.getLevelList();
        List<AssessmentTargetAddParam> targetList = assessmentManageAddParam.getTargetList();
        assessmentManageService.add(assessmentManageAddParam,levelList,targetList);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食安全责任制考核-考核指标管理表
     *
     * @author shine
     * @date  2024/04/22 11:44
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑-考核指标管理表")
    @CommonLog("编辑粮食安全责任制考核-考核指标管理表")
//    @SaCheckPermission("/examine/assessmentManage/edit")
    @PostMapping("/examine/assessmentManage/edit")
    public CommonResult<String> edit(@RequestBody @Valid AssessmentManageEditParam assessmentManageEditParam) {
        assessmentManageService.edit(assessmentManageEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食安全责任制考核-考核指标管理表
     *
     * @author shine
     * @date  2024/04/22 11:44
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除-考核指标管理表")
    @CommonLog("删除粮食安全责任制考核-考核指标管理表")
//    @SaCheckPermission("/examine/assessmentManage/delete")
    @PostMapping("/examine/assessmentManage/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<AssessmentManageIdParam> assessmentManageIdParamList) {
        assessmentManageService.delete(assessmentManageIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮食安全责任制考核-考核指标管理表详情
     *
     * @author shine
     * @date  2024/04/22 11:44
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("考核指标管理表详情")
//    @SaCheckPermission("/examine/assessmentManage/detail")
    @GetMapping("/examine/assessmentManage/detail")
    public CommonResult<AssessmentManage> detail(@Valid AssessmentManageIdParam assessmentManageIdParam) {
        return CommonResult.data(assessmentManageService.detail(assessmentManageIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("获取任务名称id,assessmentName")
//    @SaCheckPermission("/examine/assessmentManage/detail")
    @GetMapping("/examine/assessmentManage/getAssessmentName")
    public CommonResult<List<Map<String, Object>>> getAssessmentName() {
        return CommonResult.data(assessmentManageService.getAssessmentName());
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("获取省级下机构:单级(省级以下参数: 1774729858638458882)")
//    @SaCheckPermission("/examine/assessmentManage/detail")
    @GetMapping("/examine/assessmentManage/getOnlyOrgInfo/{parentId}")
    public CommonResult<List<Map<String, Object>>> getOnlyOrgInfo(@PathVariable("parentId") String parentId) {
        return CommonResult.data(assessmentManageService.getOnlyOrgInfo(parentId));
    }
}
