/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.assessmentlevel.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.examine.modular.assessmentlevel.entity.AssessmentLevel;
import com.unis.examine.modular.assessmentlevel.mapper.AssessmentLevelMapper;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelAddParam;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelEditParam;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelIdParam;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelPageParam;
import com.unis.examine.modular.assessmentlevel.service.AssessmentLevelService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮食安全责任制考核-考核指标管理-考核等级Service接口实现类
 *
 * @author shine
 * @date  2024/04/22 14:04
 **/
@Service
public class AssessmentLevelServiceImpl extends ServiceImpl<AssessmentLevelMapper, AssessmentLevel> implements AssessmentLevelService {

    @Resource
    private AssessmentLevelMapper assessmentLevelMapper;

    @Override
    public Page<AssessmentLevel> page(AssessmentLevelPageParam assessmentLevelPageParam) {
        QueryWrapper<AssessmentLevel> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(assessmentLevelPageParam.getAssessmentManageId())) {
            queryWrapper.lambda().eq(AssessmentLevel::getAssessmentManageId, assessmentLevelPageParam.getAssessmentManageId());
        }
        if(ObjectUtil.isAllNotEmpty(assessmentLevelPageParam.getSortField(), assessmentLevelPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(assessmentLevelPageParam.getSortOrder());
            queryWrapper.orderBy(true, assessmentLevelPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(assessmentLevelPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(AssessmentLevel::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(AssessmentLevelAddParam assessmentLevelAddParam) {
        AssessmentLevel assessmentLevel = BeanUtil.toBean(assessmentLevelAddParam, AssessmentLevel.class);
        this.save(assessmentLevel);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AssessmentLevelEditParam assessmentLevelEditParam) {
        AssessmentLevel assessmentLevel = this.queryEntity(assessmentLevelEditParam.getId());
        BeanUtil.copyProperties(assessmentLevelEditParam, assessmentLevel);
        this.updateById(assessmentLevel);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AssessmentLevelIdParam> assessmentLevelIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(assessmentLevelIdParamList, AssessmentLevelIdParam::getId));
    }

    @Override
    public AssessmentLevel detail(AssessmentLevelIdParam assessmentLevelIdParam) {
        return this.queryEntity(assessmentLevelIdParam.getId());
    }

    @Override
    public AssessmentLevel queryEntity(String id) {
        AssessmentLevel assessmentLevel = this.getById(id);
        if(ObjectUtil.isEmpty(assessmentLevel)) {
            throw new CommonException("粮食安全责任制考核-考核指标管理-考核等级不存在，id值为：{}", id);
        }
        return assessmentLevel;
    }

    @Override
    public List<AssessmentLevel> queryList(String assessmentManageId) {
        Map<String, Object> columnMap = new HashMap<>();
        columnMap.put("assessment_manage_id",assessmentManageId);
        List<AssessmentLevel> levelList = this.listByMap(columnMap);
        if(ObjectUtil.isEmpty(levelList)) {
            throw new CommonException("粮食安全责任制考核-考核指标管理-考核等级不存在，考核指标管理id值为：{}", assessmentManageId);
        }
        return levelList;
    }

    @Override
    public AssessmentLevel  maxandMin(int score,String assessmentManageId){
        QueryWrapper<AssessmentLevel> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("assessment_manage_id",assessmentManageId);
        queryWrapper.le("min_value", score); // min_value <= 60
        queryWrapper.gt("max_value", score); // max_value > 60
        return assessmentLevelMapper.selectOne(queryWrapper);
    }
}
