/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.assessmenttarget.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.examine.modular.assessmentlevel.entity.AssessmentLevel;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.examine.modular.assessmenttarget.entity.AssessmentTarget;
import com.unis.examine.modular.assessmenttarget.mapper.AssessmentTargetMapper;
import com.unis.examine.modular.assessmenttarget.param.AssessmentTargetAddParam;
import com.unis.examine.modular.assessmenttarget.param.AssessmentTargetEditParam;
import com.unis.examine.modular.assessmenttarget.param.AssessmentTargetIdParam;
import com.unis.examine.modular.assessmenttarget.param.AssessmentTargetPageParam;
import com.unis.examine.modular.assessmenttarget.service.AssessmentTargetService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮食安全责任制考核-考核指标管理-考核指标Service接口实现类
 *
 * @author shine
 * @date  2024/04/22 14:05
 **/
@Service
public class AssessmentTargetServiceImpl extends ServiceImpl<AssessmentTargetMapper, AssessmentTarget> implements AssessmentTargetService {

    @Override
    public Page<AssessmentTarget> page(AssessmentTargetPageParam assessmentTargetPageParam) {
        QueryWrapper<AssessmentTarget> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(assessmentTargetPageParam.getAssessmentManageId())) {
            queryWrapper.lambda().eq(AssessmentTarget::getAssessmentManageId, assessmentTargetPageParam.getAssessmentManageId());
        }
        if(ObjectUtil.isAllNotEmpty(assessmentTargetPageParam.getSortField(), assessmentTargetPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(assessmentTargetPageParam.getSortOrder());
            queryWrapper.orderBy(true, assessmentTargetPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(assessmentTargetPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(AssessmentTarget::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(AssessmentTargetAddParam assessmentTargetAddParam) {
        AssessmentTarget assessmentTarget = BeanUtil.toBean(assessmentTargetAddParam, AssessmentTarget.class);
        this.save(assessmentTarget);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AssessmentTargetEditParam assessmentTargetEditParam) {
        AssessmentTarget assessmentTarget = this.queryEntity(assessmentTargetEditParam.getId());
        BeanUtil.copyProperties(assessmentTargetEditParam, assessmentTarget);
        this.updateById(assessmentTarget);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AssessmentTargetIdParam> assessmentTargetIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(assessmentTargetIdParamList, AssessmentTargetIdParam::getId));
    }

    @Override
    public AssessmentTarget detail(AssessmentTargetIdParam assessmentTargetIdParam) {
        return this.queryEntity(assessmentTargetIdParam.getId());
    }

    @Override
    public AssessmentTarget queryEntity(String id) {
        AssessmentTarget assessmentTarget = this.getById(id);
        if(ObjectUtil.isEmpty(assessmentTarget)) {
            throw new CommonException("粮食安全责任制考核-考核指标管理-考核指标不存在，id值为：{}", id);
        }
        return assessmentTarget;
    }


    @Override
    public List<AssessmentTarget> queryList(String assessmentManageId) {
        Map<String, Object> columnMap = new HashMap<>();
        columnMap.put("assessment_manage_id",assessmentManageId);
        List<AssessmentTarget> targetList = this.listByMap(columnMap);
        if(ObjectUtil.isEmpty(targetList)) {
            throw new CommonException("粮食安全责任制考核-考核指标管理-考核指标不存在，考核指标管理id值为：{}", assessmentManageId);
        }
        return targetList;
    }
}
