/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.neassessmentScore.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.examine.modular.assessmentManage.param.AssessmentManagePageParam;
import com.unis.examine.modular.assessmentManage.service.AssessmentManageService;
import com.unis.examine.modular.assessmentlevel.param.AssessmentLevelAddParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.examine.modular.neassessmentScore.entity.BizNeAssessmentScore;
import com.unis.examine.modular.neassessmentScore.param.BizNeAssessmentScoreAddParam;
import com.unis.examine.modular.neassessmentScore.param.BizNeAssessmentScoreEditParam;
import com.unis.examine.modular.neassessmentScore.param.BizNeAssessmentScoreIdParam;
import com.unis.examine.modular.neassessmentScore.param.BizNeAssessmentScorePageParam;
import com.unis.examine.modular.neassessmentScore.service.BizNeAssessmentScoreService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * 粮食安全责任制考核-考核评分表控制器
 *
 * @author ZeroLiYi
 * @date  2024/04/23 10:15
 */
@Api(tags = "粮食安全责任制考核-考核评分表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizNeAssessmentScoreController {

    @Resource
    private BizNeAssessmentScoreService bizNeAssessmentScoreService;

    @Resource
    private AssessmentManageService assessmentManageService;

    /**
     * 获取粮食安全责任制考核-考核评分表分页
     *
     * @author ZeroLiYi
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮食安全责任制考核-核评分表分页")
//    @SaCheckPermission("/biz/neassessmentScore/page")
    @GetMapping("/biz/neassessmentScore/page")
    public CommonResult<IPage<Map<String,Object>>> page(AssessmentManagePageParam assessmentManagePageParam) throws ParseException {
        return CommonResult.data(assessmentManageService.findByOrgIdPage(assessmentManagePageParam));
    }

    /**
     * 添加粮食安全责任制考核-考核评分表
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:15
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加粮食安全责任制考核-考核评分表")
    @CommonLog("添加粮食安全责任制考核-考核评分表")
    //@SaCheckPermission("/biz/neassessmentScore/add")
    @PostMapping("/biz/neassessmentScore/add")
    public CommonResult<String> add(@RequestBody @Valid BizNeAssessmentScoreAddParam bizNeAssessmentScoreAddParam) {
        bizNeAssessmentScoreService.add(bizNeAssessmentScoreAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食安全责任制考核-考核评分表
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:15
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮食安全责任制考核-考核评分表")
    @CommonLog("编辑粮食安全责任制考核-考核评分表")
    //@SaCheckPermission("/biz/neassessmentScore/edit")
    @PostMapping("/biz/neassessmentScore/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizNeAssessmentScoreEditParam bizNeAssessmentScoreEditParam) {
        bizNeAssessmentScoreService.edit(bizNeAssessmentScoreEditParam);
        return CommonResult.ok();
    }
    /**
     * 获取粮食安全责任制考核-考核评分表详情
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:15
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮食安全责任制考核-考核评分表详情")
//    @SaCheckPermission("/biz/neassessmentScore/findByDetail")
    @GetMapping("/biz/neassessmentScore/findByDetail")
    public CommonResult<IPage<BizNeAssessmentScore>> findByDetail(@Valid BizNeAssessmentScorePageParam bizNeAssessmentScorePageParam) {
        return CommonResult.data(bizNeAssessmentScoreService.findByDetail(bizNeAssessmentScorePageParam));
    }

    /**
     * 获取粮食安全责任制考核-列表上传考核评分
     *
     * @author ZeroLiYi
     * @date  2024/04/24 10:15
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取粮食安全责任制考核-列表上传考核评分")
//    @SaCheckPermission("/biz/neassessmentScore/findByDetail")
    @PostMapping("/biz/neassessmentScore/uploading")
    public CommonResult<String> uploading(@Valid BizNeAssessmentScorePageParam bizNeAssessmentScorePageParam) {

        bizNeAssessmentScoreService.uploading(bizNeAssessmentScorePageParam);
        return CommonResult.ok();
    }

}
