/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.processmanage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.examine.modular.processmanage.entity.ProcessManage;
import com.unis.examine.modular.processmanage.mapper.ProcessManageMapper;
import com.unis.examine.modular.processmanage.param.ProcessManageAddParam;
import com.unis.examine.modular.processmanage.param.ProcessManageEditParam;
import com.unis.examine.modular.processmanage.param.ProcessManageIdParam;
import com.unis.examine.modular.processmanage.param.ProcessManagePageParam;
import com.unis.examine.modular.processmanage.service.ProcessManageService;

import java.util.List;

/**
 * 粮食安全责任制考核-流程管理Service接口实现类
 *
 * @author shine
 * @date  2024/04/22 14:11
 **/
@Service
public class ProcessManageServiceImpl extends ServiceImpl<ProcessManageMapper, ProcessManage> implements ProcessManageService {

    @Override
    public Page<ProcessManage> page(ProcessManagePageParam processManagePageParam) {
        QueryWrapper<ProcessManage> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(processManagePageParam.getProcessName())) {
            queryWrapper.lambda().like(ProcessManage::getProcessName, processManagePageParam.getProcessName());
        }
        if(ObjectUtil.isNotEmpty(processManagePageParam.getUploader())) {
            queryWrapper.lambda().like(ProcessManage::getUploader, processManagePageParam.getUploader());
        }
        if(ObjectUtil.isAllNotEmpty(processManagePageParam.getSortField(), processManagePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(processManagePageParam.getSortOrder());
            queryWrapper.orderBy(true, processManagePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(processManagePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(ProcessManage::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(ProcessManageAddParam processManageAddParam) {
        ProcessManage processManage = BeanUtil.toBean(processManageAddParam, ProcessManage.class);
        this.save(processManage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(ProcessManageEditParam processManageEditParam) {
        ProcessManage processManage = this.queryEntity(processManageEditParam.getId());
        BeanUtil.copyProperties(processManageEditParam, processManage);
        this.updateById(processManage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<ProcessManageIdParam> processManageIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(processManageIdParamList, ProcessManageIdParam::getId));
    }

    @Override
    public ProcessManage detail(ProcessManageIdParam processManageIdParam) {
        return this.queryEntity(processManageIdParam.getId());
    }

    @Override
    public ProcessManage queryEntity(String id) {
        ProcessManage processManage = this.getById(id);
        if(ObjectUtil.isEmpty(processManage)) {
            throw new CommonException("粮食安全责任制考核-流程管理不存在，id值为：{}", id);
        }
        return processManage;
    }
}
