/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.entity.BizFsReserveGrainLoanInterest;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestAddParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestEditParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestIdParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestPageParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.service.BizFsReserveGrainLoanInterestService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 储备粮贷款利息管理控制器
 *
 * @author hjc
 * @date  2024/06/26 14:20
 */
@Api(tags = "储备粮贷款利息管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizFsReserveGrainLoanInterestController {

    @Resource
    private BizFsReserveGrainLoanInterestService bizFsReserveGrainLoanInterestService;

    /**
     * 获取储备粮贷款利息管理分页
     *
     * @author hjc
     * @date  2024/06/26 14:20
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取储备粮贷款利息管理分页")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterest/page")
    @GetMapping("/financialSupervision/bizFsReserveGrainLoanInterest/page")
    public CommonResult<Page<BizFsReserveGrainLoanInterest>> page(BizFsReserveGrainLoanInterestPageParam bizFsReserveGrainLoanInterestPageParam) {
        return CommonResult.data(bizFsReserveGrainLoanInterestService.page(bizFsReserveGrainLoanInterestPageParam));
    }

    /**
     * 添加储备粮贷款利息管理
     *
     * @author hjc
     * @date  2024/06/26 14:20
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加储备粮贷款利息管理")
    @CommonLog("添加储备粮贷款利息管理")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterest/add")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterest/add")
    public CommonResult<String> add(@RequestBody @Valid BizFsReserveGrainLoanInterestAddParam bizFsReserveGrainLoanInterestAddParam) {
        bizFsReserveGrainLoanInterestService.add(bizFsReserveGrainLoanInterestAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑储备粮贷款利息管理
     *
     * @author hjc
     * @date  2024/06/26 14:20
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑储备粮贷款利息管理")
    @CommonLog("编辑储备粮贷款利息管理")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterest/edit")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterest/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizFsReserveGrainLoanInterestEditParam bizFsReserveGrainLoanInterestEditParam) {
        bizFsReserveGrainLoanInterestService.edit(bizFsReserveGrainLoanInterestEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除储备粮贷款利息管理
     *
     * @author hjc
     * @date  2024/06/26 14:20
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除储备粮贷款利息管理")
    @CommonLog("删除储备粮贷款利息管理")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterest/delete")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterest/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizFsReserveGrainLoanInterestIdParam> bizFsReserveGrainLoanInterestIdParamList) {
        bizFsReserveGrainLoanInterestService.delete(bizFsReserveGrainLoanInterestIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取储备粮贷款利息管理详情
     *
     * @author hjc
     * @date  2024/06/26 14:20
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取储备粮贷款利息管理详情")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterest/detail")
    @GetMapping("/financialSupervision/bizFsReserveGrainLoanInterest/detail")
    public CommonResult<BizFsReserveGrainLoanInterest> detail(@Valid BizFsReserveGrainLoanInterestIdParam bizFsReserveGrainLoanInterestIdParam) {
        return CommonResult.data(bizFsReserveGrainLoanInterestService.detail(bizFsReserveGrainLoanInterestIdParam));
    }
}
