/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.entity.BizFsReserveGrainLoanInterestBreakdown;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.mapper.BizFsReserveGrainLoanInterestBreakdownMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.entity.BizFsReserveGrainLoanInterest;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.mapper.BizFsReserveGrainLoanInterestMapper;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestAddParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestEditParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestIdParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.param.BizFsReserveGrainLoanInterestPageParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterest.service.BizFsReserveGrainLoanInterestService;

import java.util.List;

/**
 * 储备粮贷款利息管理Service接口实现类
 *
 * @author hjc
 * @date  2024/06/26 14:20
 **/
@Service
public class BizFsReserveGrainLoanInterestServiceImpl extends ServiceImpl<BizFsReserveGrainLoanInterestMapper, BizFsReserveGrainLoanInterest> implements BizFsReserveGrainLoanInterestService {

    @Autowired
    private BizFsReserveGrainLoanInterestBreakdownMapper interestBreakdownMapper;
    @Override
    public Page<BizFsReserveGrainLoanInterest> page(BizFsReserveGrainLoanInterestPageParam bizFsReserveGrainLoanInterestPageParam) {
        QueryWrapper<BizFsReserveGrainLoanInterest> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(bizFsReserveGrainLoanInterestPageParam.getEnterpriseName())){
            queryWrapper.lambda().like(BizFsReserveGrainLoanInterest::getEnterpriseName,bizFsReserveGrainLoanInterestPageParam.getEnterpriseName());
        }
        if (StringUtils.isNotEmpty(bizFsReserveGrainLoanInterestPageParam.getLoanNumber())){
            queryWrapper.lambda().like(BizFsReserveGrainLoanInterest::getLoanNumber,bizFsReserveGrainLoanInterestPageParam.getLoanNumber());
        }
        if(ObjectUtil.isAllNotEmpty(bizFsReserveGrainLoanInterestPageParam.getSortField(), bizFsReserveGrainLoanInterestPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizFsReserveGrainLoanInterestPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizFsReserveGrainLoanInterestPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizFsReserveGrainLoanInterestPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizFsReserveGrainLoanInterest::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizFsReserveGrainLoanInterestAddParam bizFsReserveGrainLoanInterestAddParam) {
        //保存
        BizFsReserveGrainLoanInterest bizFsReserveGrainLoanInterest = BeanUtil.toBean(bizFsReserveGrainLoanInterestAddParam, BizFsReserveGrainLoanInterest.class);
        this.save(bizFsReserveGrainLoanInterest);

        List<BizFsReserveGrainLoanInterestBreakdown> breakdownList = bizFsReserveGrainLoanInterestAddParam.getBreakdownList();
        for (BizFsReserveGrainLoanInterestBreakdown breakdown : breakdownList) {
            breakdown.setFsReserveGrainLoanInterestId(bizFsReserveGrainLoanInterest.getId());
            interestBreakdownMapper.insert(breakdown);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizFsReserveGrainLoanInterestEditParam bizFsReserveGrainLoanInterestEditParam) {
        BizFsReserveGrainLoanInterest bizFsReserveGrainLoanInterest = this.queryEntity(bizFsReserveGrainLoanInterestEditParam.getId());
        BeanUtil.copyProperties(bizFsReserveGrainLoanInterestEditParam, bizFsReserveGrainLoanInterest);
        this.updateById(bizFsReserveGrainLoanInterest);

        //删除之前的数据
        List<BizFsReserveGrainLoanInterestBreakdown> breakdownList = interestBreakdownMapper.selectList(
                new LambdaQueryWrapper<BizFsReserveGrainLoanInterestBreakdown>()
                .eq(BizFsReserveGrainLoanInterestBreakdown::getFsReserveGrainLoanInterestId,bizFsReserveGrainLoanInterestEditParam.getId()));
        interestBreakdownMapper.deleteBatchIds(breakdownList);

        //新增修改的数据
        List<BizFsReserveGrainLoanInterestBreakdown> breakdownList2 = bizFsReserveGrainLoanInterestEditParam.getBreakdownList();
        for (BizFsReserveGrainLoanInterestBreakdown breakdown : breakdownList2) {
            breakdown.setFsReserveGrainLoanInterestId(bizFsReserveGrainLoanInterestEditParam.getId());
            interestBreakdownMapper.insert(breakdown);
        }

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizFsReserveGrainLoanInterestIdParam> bizFsReserveGrainLoanInterestIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizFsReserveGrainLoanInterestIdParamList, BizFsReserveGrainLoanInterestIdParam::getId));

        //删除子表数据
        List<BizFsReserveGrainLoanInterestBreakdown> breakdownList = interestBreakdownMapper.selectList(
                new LambdaQueryWrapper<BizFsReserveGrainLoanInterestBreakdown>()
                .eq(BizFsReserveGrainLoanInterestBreakdown::getFsReserveGrainLoanInterestId,bizFsReserveGrainLoanInterestIdParamList.get(0).getId()));
        interestBreakdownMapper.deleteBatchIds(breakdownList);
    }

    @Override
    public BizFsReserveGrainLoanInterest detail(BizFsReserveGrainLoanInterestIdParam bizFsReserveGrainLoanInterestIdParam) {

        BizFsReserveGrainLoanInterest bizFsReserveGrainLoanInterest = this.queryEntity(bizFsReserveGrainLoanInterestIdParam.getId());
        List<BizFsReserveGrainLoanInterestBreakdown> breakdownList = interestBreakdownMapper.selectList(
                new LambdaQueryWrapper<BizFsReserveGrainLoanInterestBreakdown>()
                .eq(BizFsReserveGrainLoanInterestBreakdown::getFsReserveGrainLoanInterestId, bizFsReserveGrainLoanInterest.getId()));
        bizFsReserveGrainLoanInterest.setBreakdownList(breakdownList);

        return bizFsReserveGrainLoanInterest;

    }

    @Override
    public BizFsReserveGrainLoanInterest queryEntity(String id) {
        BizFsReserveGrainLoanInterest bizFsReserveGrainLoanInterest = this.getById(id);
        if(ObjectUtil.isEmpty(bizFsReserveGrainLoanInterest)) {
            throw new CommonException("储备粮贷款利息管理不存在，id值为：{}", id);
        }
        return bizFsReserveGrainLoanInterest;
    }
}
