/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.entity.BizFsReserveGrainLoanInterestBreakdown;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownAddParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownEditParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownIdParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownPageParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.service.BizFsReserveGrainLoanInterestBreakdownService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 储备粮贷款利息管理-利息分解控制器
 *
 * @author hjc
 * @date  2024/06/26 14:22
 */
@Api(tags = "储备粮贷款利息管理-利息分解控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizFsReserveGrainLoanInterestBreakdownController {

    @Resource
    private BizFsReserveGrainLoanInterestBreakdownService bizFsReserveGrainLoanInterestBreakdownService;

    /**
     * 获取储备粮贷款利息管理-利息分解分页
     *
     * @author hjc
     * @date  2024/06/26 14:22
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取储备粮贷款利息管理-利息分解分页")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/page")
    @GetMapping("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/page")
    public CommonResult<Page<BizFsReserveGrainLoanInterestBreakdown>> page(BizFsReserveGrainLoanInterestBreakdownPageParam bizFsReserveGrainLoanInterestBreakdownPageParam) {
        return CommonResult.data(bizFsReserveGrainLoanInterestBreakdownService.page(bizFsReserveGrainLoanInterestBreakdownPageParam));
    }

    /**
     * 添加储备粮贷款利息管理-利息分解
     *
     * @author hjc
     * @date  2024/06/26 14:22
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加储备粮贷款利息管理-利息分解")
    @CommonLog("添加储备粮贷款利息管理-利息分解")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/add")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/add")
    public CommonResult<String> add(@RequestBody @Valid BizFsReserveGrainLoanInterestBreakdownAddParam bizFsReserveGrainLoanInterestBreakdownAddParam) {
        bizFsReserveGrainLoanInterestBreakdownService.add(bizFsReserveGrainLoanInterestBreakdownAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑储备粮贷款利息管理-利息分解
     *
     * @author hjc
     * @date  2024/06/26 14:22
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑储备粮贷款利息管理-利息分解")
    @CommonLog("编辑储备粮贷款利息管理-利息分解")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/edit")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizFsReserveGrainLoanInterestBreakdownEditParam bizFsReserveGrainLoanInterestBreakdownEditParam) {
        bizFsReserveGrainLoanInterestBreakdownService.edit(bizFsReserveGrainLoanInterestBreakdownEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除储备粮贷款利息管理-利息分解
     *
     * @author hjc
     * @date  2024/06/26 14:22
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除储备粮贷款利息管理-利息分解")
    @CommonLog("删除储备粮贷款利息管理-利息分解")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/delete")
    @PostMapping("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizFsReserveGrainLoanInterestBreakdownIdParam> bizFsReserveGrainLoanInterestBreakdownIdParamList) {
        bizFsReserveGrainLoanInterestBreakdownService.delete(bizFsReserveGrainLoanInterestBreakdownIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取储备粮贷款利息管理-利息分解详情
     *
     * @author hjc
     * @date  2024/06/26 14:22
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取储备粮贷款利息管理-利息分解详情")
    //@SaCheckPermission("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/detail")
    @GetMapping("/financialSupervision/bizFsReserveGrainLoanInterestBreakdown/detail")
    public CommonResult<BizFsReserveGrainLoanInterestBreakdown> detail(@Valid BizFsReserveGrainLoanInterestBreakdownIdParam bizFsReserveGrainLoanInterestBreakdownIdParam) {
        return CommonResult.data(bizFsReserveGrainLoanInterestBreakdownService.detail(bizFsReserveGrainLoanInterestBreakdownIdParam));
    }
}
