/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.entity.BizFsReserveGrainLoanInterestBreakdown;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.mapper.BizFsReserveGrainLoanInterestBreakdownMapper;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownAddParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownEditParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownIdParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.param.BizFsReserveGrainLoanInterestBreakdownPageParam;
import com.unis.financialSupervision.modular.bizFsReserveGrainLoanInterestBreakdown.service.BizFsReserveGrainLoanInterestBreakdownService;

import java.util.List;

/**
 * 储备粮贷款利息管理-利息分解Service接口实现类
 *
 * @author hjc
 * @date  2024/06/26 14:22
 **/
@Service
public class BizFsReserveGrainLoanInterestBreakdownServiceImpl extends ServiceImpl<BizFsReserveGrainLoanInterestBreakdownMapper, BizFsReserveGrainLoanInterestBreakdown> implements BizFsReserveGrainLoanInterestBreakdownService {

    @Override
    public Page<BizFsReserveGrainLoanInterestBreakdown> page(BizFsReserveGrainLoanInterestBreakdownPageParam bizFsReserveGrainLoanInterestBreakdownPageParam) {
        QueryWrapper<BizFsReserveGrainLoanInterestBreakdown> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(bizFsReserveGrainLoanInterestBreakdownPageParam.getSortField(), bizFsReserveGrainLoanInterestBreakdownPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizFsReserveGrainLoanInterestBreakdownPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizFsReserveGrainLoanInterestBreakdownPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizFsReserveGrainLoanInterestBreakdownPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizFsReserveGrainLoanInterestBreakdown::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizFsReserveGrainLoanInterestBreakdownAddParam bizFsReserveGrainLoanInterestBreakdownAddParam) {
        BizFsReserveGrainLoanInterestBreakdown bizFsReserveGrainLoanInterestBreakdown = BeanUtil.toBean(bizFsReserveGrainLoanInterestBreakdownAddParam, BizFsReserveGrainLoanInterestBreakdown.class);
        this.save(bizFsReserveGrainLoanInterestBreakdown);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizFsReserveGrainLoanInterestBreakdownEditParam bizFsReserveGrainLoanInterestBreakdownEditParam) {
        BizFsReserveGrainLoanInterestBreakdown bizFsReserveGrainLoanInterestBreakdown = this.queryEntity(bizFsReserveGrainLoanInterestBreakdownEditParam.getId());
        BeanUtil.copyProperties(bizFsReserveGrainLoanInterestBreakdownEditParam, bizFsReserveGrainLoanInterestBreakdown);
        this.updateById(bizFsReserveGrainLoanInterestBreakdown);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizFsReserveGrainLoanInterestBreakdownIdParam> bizFsReserveGrainLoanInterestBreakdownIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizFsReserveGrainLoanInterestBreakdownIdParamList, BizFsReserveGrainLoanInterestBreakdownIdParam::getId));
    }

    @Override
    public BizFsReserveGrainLoanInterestBreakdown detail(BizFsReserveGrainLoanInterestBreakdownIdParam bizFsReserveGrainLoanInterestBreakdownIdParam) {
        return this.queryEntity(bizFsReserveGrainLoanInterestBreakdownIdParam.getId());
    }

    @Override
    public BizFsReserveGrainLoanInterestBreakdown queryEntity(String id) {
        BizFsReserveGrainLoanInterestBreakdown bizFsReserveGrainLoanInterestBreakdown = this.getById(id);
        if(ObjectUtil.isEmpty(bizFsReserveGrainLoanInterestBreakdown)) {
            throw new CommonException("储备粮贷款利息管理-利息分解不存在，id值为：{}", id);
        }
        return bizFsReserveGrainLoanInterestBreakdown;
    }
}
