/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.fsrotatedgrainstorage.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.financialSupervision.modular.fsrotatedgrainstorage.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.fsrotatedgrainstorage.entity.BizFsRotatedGrainStorage;
import com.unis.financialSupervision.modular.fsrotatedgrainstorage.service.BizFsRotatedGrainStorageService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 财务监管-轮换分品种分库存情况表控制器
 *
 * @author shine
 * @date  2024/06/27 10:36
 */
@Api(tags = "财务监管-轮换分品种分库存情况表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizFsRotatedGrainStorageController {

    @Resource
    private BizFsRotatedGrainStorageService bizFsRotatedGrainStorageService;

    /**
     * 获取财务监管-轮换分品种分库存情况表分页
     *
     * @author shine
     * @date  2024/06/27 10:36
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取财务监管-轮换分品种分库存情况表分页")
    @GetMapping("/financialSupervision/fsrotatedgrainstorage/page")
    public CommonResult<Page<BizFsRotatedGrainStorage>> page(BizFsRotatedGrainStoragePageParam bizFsRotatedGrainStoragePageParam) {
        return CommonResult.data(bizFsRotatedGrainStorageService.page(bizFsRotatedGrainStoragePageParam));
    }

    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取财务监管-轮换分品种分库存情况表")
    @GetMapping("/financialSupervision/fsrotatedgrainstorage/getList")
    public CommonResult<List<BizFsRotatedGrainStorage>> getList(BizFsRotatedGrainStorageListParam bizFsRotatedGrainStorageListParam) {
        return CommonResult.data(bizFsRotatedGrainStorageService.getList(bizFsRotatedGrainStorageListParam));
    }

    /**
     * 添加财务监管-轮换分品种分库存情况表
     *
     * @author shine
     * @date  2024/06/27 10:36
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加财务监管-轮换分品种分库存情况表")
    @PostMapping("/financialSupervision/fsrotatedgrainstorage/add")
    public CommonResult<String> add(@RequestBody @Valid BizFsRotatedGrainStorageAddParam bizFsRotatedGrainStorageAddParam) {
        bizFsRotatedGrainStorageService.add(bizFsRotatedGrainStorageAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑财务监管-轮换分品种分库存情况表
     *
     * @author shine
     * @date  2024/06/27 10:36
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑财务监管-轮换分品种分库存情况表")
    @PostMapping("/financialSupervision/fsrotatedgrainstorage/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizFsRotatedGrainStorageEditParam bizFsRotatedGrainStorageEditParam) {
        bizFsRotatedGrainStorageService.edit(bizFsRotatedGrainStorageEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除财务监管-轮换分品种分库存情况表
     *
     * @author shine
     * @date  2024/06/27 10:36
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除财务监管-轮换分品种分库存情况表")
    @PostMapping("/financialSupervision/fsrotatedgrainstorage/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizFsRotatedGrainStorageIdParam> bizFsRotatedGrainStorageIdParamList) {
        bizFsRotatedGrainStorageService.delete(bizFsRotatedGrainStorageIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取财务监管-轮换分品种分库存情况表详情
     *
     * @author shine
     * @date  2024/06/27 10:36
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取财务监管-轮换分品种分库存情况表详情")
    @GetMapping("/financialSupervision/fsrotatedgrainstorage/detail")
    public CommonResult<BizFsRotatedGrainStorage> detail(@Valid BizFsRotatedGrainStorageIdParam bizFsRotatedGrainStorageIdParam) {
        return CommonResult.data(bizFsRotatedGrainStorageService.detail(bizFsRotatedGrainStorageIdParam));
    }


    @ApiOperationSupport(order = 6)
    @ApiOperation("*获取当年轮换的库区")
    @GetMapping("/financialSupervision/fsrotatedgrainstorage/getRpOrgInfoList")
    public CommonResult<List<OrgInfo>> getRpOrgInfoList() {
        return CommonResult.data(bizFsRotatedGrainStorageService.getRpOrgInfoList());
    }

    @ApiOperationSupport(order = 7)
    @ApiOperation("测试****")
    @GetMapping("/financialSupervision/fsrotatedgrainstorage/rotatedData")
    public void rotatedData() {
        bizFsRotatedGrainStorageService.rotatedData();
    }
}
