/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.fsstoragesubsidysettle.entity;

import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import java.math.BigDecimal;
import java.time.Year;
import java.util.Date;

/**
 * 财务监管-保管费用粮油补贴清算表实体
 *
 * @author ZeroLiYi
 * @date  2024/06/27 09:28
 **/
@Getter
@Setter
@TableName("biz_fs_storage_subsidy_settle")
public class FsStorageSubsidySettle {

    /** 唯一标识 */
    @TableId
    @ApiModelProperty(value = "唯一标识", position = 1)
    private String id;

    /** 创建时间 */
    @ApiModelProperty(value = "创建时间", position = 2)
    @TableField(fill = FieldFill.INSERT)
    private Date createTime;

    /** 创建用户 */
    @ApiModelProperty(value = "创建用户", position = 3)
    @TableField(fill = FieldFill.INSERT)
    private String createUser;

    /** 修改时间 */
    @ApiModelProperty(value = "修改时间", position = 4)
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    /** 修改用户 */
    @ApiModelProperty(value = "修改用户", position = 5)
    @TableField(fill = FieldFill.UPDATE)
    private String updateUser;

    /** 库区；外库depot_qh.org_info的id； */
    @ApiModelProperty(value = "库区；外库depot_qh.org_info的id；", position = 6)
    private Integer orgId;

    /** 计划年度 */
    @ApiModelProperty(value = "计划年度", position = 7)
    private Year planYear;

    /** 储备粮平均库存数量 */
    @ApiModelProperty(value = "储备粮平均库存数量", position = 8)
    private BigDecimal averageInventory;

    /** 储备粮-原粮平均库存数量-小计 */
    @ApiModelProperty(value = "储备粮-原粮平均库存数量-小计", position = 9)
    private BigDecimal averageRawGrainInventory;

    /** 储备粮-原粮平均库存数量-平均月末实物库存 */
    @ApiModelProperty(value = "储备粮-原粮平均库存数量-平均月末实物库存", position = 10)
    private BigDecimal averageRawGrainInventoryPhysical;

    /** 储备粮-原粮平均库存数量-平均正常轮空期内轮空数量 */
    @ApiModelProperty(value = "储备粮-原粮平均库存数量-平均正常轮空期内轮空数量", position = 11)
    private BigDecimal averageRawGrainInventoryEmpty;

    /** 储备粮-成品粮平均库存数量-小计 */
    @ApiModelProperty(value = "储备粮-成品粮平均库存数量-小计", position = 12)
    private BigDecimal averageProcessedGrainInventory;

    /** 储备粮-成品粮平均库存数量-平均月末实物库存 */
    @ApiModelProperty(value = "储备粮-成品粮平均库存数量-平均月末实物库存", position = 13)
    private BigDecimal averageProcessedGrainInventoryPhysical;

    /** 储备粮-成品粮平均库存数量-平均正常轮空期内轮空数量 */
    @ApiModelProperty(value = "储备粮-成品粮平均库存数量-平均正常轮空期内轮空数量", position = 14)
    private BigDecimal averageProcessedGrainInventoryEmpty;

    /** 储备粮-原粮保管费用补贴应拨数 */
    @ApiModelProperty(value = "储备粮-原粮保管费用补贴应拨数", position = 15)
    private BigDecimal storageSubsidyRawGrain;

    /** 储备粮-原粮保管费用补贴（标准：0.12元/公斤）应拨数 */
    @ApiModelProperty(value = "储备粮-原粮保管费用补贴（标准：0.12元/公斤）应拨数", position = 16)
    private BigDecimal storageSubsidyStandardRawGrain;

    /** 储备粮-成品粮保管费用补贴（标准：0.20元/公斤）应拨数 */
    @ApiModelProperty(value = "储备粮-成品粮保管费用补贴（标准：0.20元/公斤）应拨数", position = 17)
    private BigDecimal storageSubsidyProcessedGrain;

    /** 储备油-储油平均库存数量-小计 */
    @ApiModelProperty(value = "储备油-储油平均库存数量-小计", position = 18)
    private BigDecimal averageOilInventory;

    /** 储备油-储油平均库存数量-平均月末实物库存 */
    @ApiModelProperty(value = "储备油-储油平均库存数量-平均月末实物库存", position = 19)
    private BigDecimal averageOilInventoryPhysical;

    /** 储备油-储油平均库存数量-平均正常轮空期内轮空数量 */
    @ApiModelProperty(value = "储备油-储油平均库存数量-平均正常轮空期内轮空数量", position = 20)
    private BigDecimal averageOilInventoryEmpty;

    /** 储备油-油料保管费用补贴（标准：0.40元/公斤）应拨数 */
    @ApiModelProperty(value = "储备油-油料保管费用补贴（标准：0.40元/公斤）应拨数", position = 21)
    private BigDecimal storageSubsidyOil;

    /** 其他 */
    @ApiModelProperty(value = "其他", position = 22)
    private String other;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 23)
    private String remarks;
}
