/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.rotationCostSubsidySettle.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 轮换费用补贴清算添加参数
 *
 * @author QSHan
 * @date  2024/06/26 20:00
 **/
@Getter
@Setter
public class RotationCostSubsidySettleAddParam {

    /** 库区；外库depot_qh.org_info的id； */
    @ApiModelProperty(value = "库区；外库depot_qh.org_info的id；", position = 6)
    private Integer orgId;

    /** 计划年度 */
    @ApiModelProperty(value = "计划年度", position = 7)
    private Date planYear;

    /** 原粮静态轮换-计划数量 */
    @ApiModelProperty(value = "原粮静态轮换-计划数量", position = 8)
    private BigDecimal staticRawGrainPlanQuantity;

    /** 原粮静态轮换-完成率 */
    @ApiModelProperty(value = "原粮静态轮换-完成率", position = 9)
    private BigDecimal staticRawGrainCompletionRate;

    /** 原粮静态轮换费用标准 */
    @ApiModelProperty(value = "原粮静态轮换费用标准", position = 10)
    private BigDecimal staticRawGrainCostStandard;

    /** 原粮静态轮换费用补贴应拨数 */
    @ApiModelProperty(value = "原粮静态轮换费用补贴应拨数", position = 11)
    private BigDecimal staticRawGrainSubsidy;

    /** 原粮动态轮换-计划数量 */
    @ApiModelProperty(value = "原粮动态轮换-计划数量", position = 12)
    private BigDecimal dynamicRawGrainPlanQuantity;

    /** 原粮动态轮换-完成率 */
    @ApiModelProperty(value = "原粮动态轮换-完成率", position = 13)
    private BigDecimal dynamicRawGrainCompletionRate;

    /** 原粮动态轮换费用标准 */
    @ApiModelProperty(value = "原粮动态轮换费用标准", position = 14)
    private BigDecimal dynamicRawGrainCostStandard;

    /** 原粮动态轮换费用补贴应拨数 */
    @ApiModelProperty(value = "原粮动态轮换费用补贴应拨数", position = 15)
    private BigDecimal dynamicRawGrainSubsidy;

    /** 成品粮轮换-计划数量 */
    @ApiModelProperty(value = "成品粮轮换-计划数量", position = 16)
    private BigDecimal processedGrainPlanQuantity;

    /** 成品粮轮换-完成率 */
    @ApiModelProperty(value = "成品粮轮换-完成率", position = 17)
    private BigDecimal processedGrainCompletionRate;

    /** 成品粮轮换费用标准 */
    @ApiModelProperty(value = "成品粮轮换费用标准", position = 18)
    private BigDecimal processedGrainCostStandard;

    /** 成品粮动态轮换费用补贴应拨数 */
    @ApiModelProperty(value = "成品粮动态轮换费用补贴应拨数", position = 19)
    private BigDecimal processedGrainSubsidy;

    /** 应拨其他费用补贴，默认0 */
    @ApiModelProperty(value = "应拨其他费用补贴，默认0", position = 20)
    private BigDecimal otherSubsidy;

    /** 应拨数小计 */
    @ApiModelProperty(value = "应拨数小计", position = 21)
    private BigDecimal subsidySubtotal;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 22)
    private String remark;

}
