/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.rotationCostSubsidySettle.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.entity.RotationCostSubsidySettle;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.mapper.RotationCostSubsidySettleMapper;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.param.RotationCostSubsidySettleAddParam;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.param.RotationCostSubsidySettleEditParam;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.param.RotationCostSubsidySettleIdParam;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.param.RotationCostSubsidySettlePageParam;
import com.unis.financialSupervision.modular.rotationCostSubsidySettle.service.RotationCostSubsidySettleService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 轮换费用补贴清算Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/26 20:00
 **/
@Service
public class RotationCostSubsidySettleServiceImpl extends ServiceImpl<RotationCostSubsidySettleMapper, RotationCostSubsidySettle> implements RotationCostSubsidySettleService {
    @Resource
    private RotationCostSubsidySettleMapper rotationCostSubsidySettleMapper;

    @Override
    public Page<RotationCostSubsidySettle> page(RotationCostSubsidySettlePageParam rotationCostSubsidySettlePageParam) {
        QueryWrapper<RotationCostSubsidySettle> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isAllNotEmpty(rotationCostSubsidySettlePageParam.getSortField(), rotationCostSubsidySettlePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(rotationCostSubsidySettlePageParam.getSortOrder());
            queryWrapper.orderBy(true, rotationCostSubsidySettlePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(rotationCostSubsidySettlePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(RotationCostSubsidySettle::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RotationCostSubsidySettleAddParam rotationCostSubsidySettleAddParam) {
        RotationCostSubsidySettle rotationCostSubsidySettle = BeanUtil.toBean(rotationCostSubsidySettleAddParam, RotationCostSubsidySettle.class);
        this.save(rotationCostSubsidySettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RotationCostSubsidySettleEditParam rotationCostSubsidySettleEditParam) {
        RotationCostSubsidySettle rotationCostSubsidySettle = this.queryEntity(rotationCostSubsidySettleEditParam.getId());
        BeanUtil.copyProperties(rotationCostSubsidySettleEditParam, rotationCostSubsidySettle);
        this.updateById(rotationCostSubsidySettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RotationCostSubsidySettleIdParam> rotationCostSubsidySettleIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(rotationCostSubsidySettleIdParamList, RotationCostSubsidySettleIdParam::getId));
    }

    @Override
    public RotationCostSubsidySettle detail(RotationCostSubsidySettleIdParam rotationCostSubsidySettleIdParam) {
        return this.queryEntity(rotationCostSubsidySettleIdParam.getId());
    }

    @Override
    public RotationCostSubsidySettle queryEntity(String id) {
        RotationCostSubsidySettle rotationCostSubsidySettle = this.getById(id);
        if (ObjectUtil.isEmpty(rotationCostSubsidySettle)) {
            throw new CommonException("轮换费用补贴清算不存在，id值为：{}", id);
        }
        return rotationCostSubsidySettle;
    }

    @Override
    public List<RotationCostSubsidySettle> getList(Integer planYear) {
        QueryWrapper<RotationCostSubsidySettle> wrapper = new QueryWrapper<>();
        // 计划年度
        if (ObjectUtils.isNotEmpty(planYear)) {
            wrapper.lambda().eq(RotationCostSubsidySettle::getPlanYear, planYear);
        }
        return rotationCostSubsidySettleMapper.getList(wrapper);
    }

    @Override
    public void taskAction() {
        List<RotationCostSubsidySettle> chaosData = rotationCostSubsidySettleMapper.selectChaosData();
        if (CollectionUtils.isNotEmpty(chaosData)) {
            // 先删除本年度
            QueryWrapper<RotationCostSubsidySettle> wrapper = new QueryWrapper<>();
            wrapper.lambda().eq(RotationCostSubsidySettle::getPlanYear, chaosData.get(0).getPlanYear());
            rotationCostSubsidySettleMapper.delete(wrapper);
            chaosData.forEach(item -> rotationCostSubsidySettleMapper.insert(item));
        }
    }
}
