/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.basicWarehouse.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.grainReserves.modular.basicWarehouse.entity.BasicWarehouse;
import com.unis.grainReserves.modular.basicWarehouse.param.BasicWarehouseAddParam;
import com.unis.grainReserves.modular.basicWarehouse.param.BasicWarehouseEditParam;
import com.unis.grainReserves.modular.basicWarehouse.param.BasicWarehouseIdParam;
import com.unis.grainReserves.modular.basicWarehouse.param.BasicWarehousePageParam;
import com.unis.grainReserves.modular.basicWarehouse.service.BasicWarehouseService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 库中仓房下的货位信息控制器
 *
 * @author hjc
 * @date  2024/05/19 21:52
 */
@Api(tags = "库中仓房下的货位信息控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BasicWarehouseController {

    @Resource
    private BasicWarehouseService basicWarehouseService;

    /**
     * 获取库中仓房下的货位信息分页
     *
     * @author hjc
     * @date  2024/05/19 21:52
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取库中仓房下的货位信息分页")
    @SaCheckPermission("/grainReserves/basicWarehouse/page")
    @GetMapping("/grainReserves/basicWarehouse/page")
    public CommonResult<Page<BasicWarehouse>> page(BasicWarehousePageParam basicWarehousePageParam) {
        return CommonResult.data(basicWarehouseService.page(basicWarehousePageParam));
    }

    /**
     * 添加库中仓房下的货位信息
     *
     * @author hjc
     * @date  2024/05/19 21:52
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加库中仓房下的货位信息")
    @CommonLog("添加库中仓房下的货位信息")
    @SaCheckPermission("/grainReserves/basicWarehouse/add")
    @PostMapping("/grainReserves/basicWarehouse/add")
    public CommonResult<String> add(@RequestBody @Valid BasicWarehouseAddParam basicWarehouseAddParam) {
        basicWarehouseService.add(basicWarehouseAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑库中仓房下的货位信息
     *
     * @author hjc
     * @date  2024/05/19 21:52
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑库中仓房下的货位信息")
    @CommonLog("编辑库中仓房下的货位信息")
    @SaCheckPermission("/grainReserves/basicWarehouse/edit")
    @PostMapping("/grainReserves/basicWarehouse/edit")
    public CommonResult<String> edit(@RequestBody @Valid BasicWarehouseEditParam basicWarehouseEditParam) {
        basicWarehouseService.edit(basicWarehouseEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除库中仓房下的货位信息
     *
     * @author hjc
     * @date  2024/05/19 21:52
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除库中仓房下的货位信息")
    @CommonLog("删除库中仓房下的货位信息")
    @SaCheckPermission("/grainReserves/basicWarehouse/delete")
    @PostMapping("/grainReserves/basicWarehouse/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BasicWarehouseIdParam> basicWarehouseIdParamList) {
        basicWarehouseService.delete(basicWarehouseIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取库中仓房下的货位信息详情
     *
     * @author hjc
     * @date  2024/05/19 21:52
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取库中仓房下的货位信息详情")
    @SaCheckPermission("/grainReserves/basicWarehouse/detail")
    @GetMapping("/grainReserves/basicWarehouse/detail")
    public CommonResult<BasicWarehouse> detail(@Valid BasicWarehouseIdParam basicWarehouseIdParam) {
        return CommonResult.data(basicWarehouseService.detail(basicWarehouseIdParam));
    }
}
