/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.businessGslrLossCollect.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 粮食储备-节粮损益-损溢损失信息采集编辑参数
 *
 * @author hjc
 * @date  2024/05/17 15:22
 **/
@Getter
@Setter
public class BusinessGslrLossCollectEditParam {

    /** 主键ID */
    @ApiModelProperty(value = "主键ID", required = true, position = 1)
    @NotNull(message = "id不能为空")
    private String id;

    /** 创建日期 */
    @ApiModelProperty(value = "创建日期", position = 2)
    private Date createdate;

    /** 更新人 */
    @ApiModelProperty(value = "更新人", position = 3)
    private String updatename;

    /** 更新日期 */
    @ApiModelProperty(value = "更新日期", position = 4)
    private Date updatedate;

    /** 损益单号 */
    @ApiModelProperty(value = "损益单号", position = 5)
    private String sydh;

    /** 业务日期 */
    @ApiModelProperty(value = "业务日期", position = 6)
    private Date businessDate;

    /** 库区id；org_info的id； */
    @ApiModelProperty(value = "库区id；org_info的id；", position = 7)
    private Integer orgId;

    /** basic_storehouse的id；仓房id */
    @ApiModelProperty(value = "basic_storehouse的id；仓房id", position = 8)
    private Integer basicStorehouseId;

    /** basic_warehouse的id；货位id */
    @ApiModelProperty(value = "basic_warehouse的id；货位id", position = 9)
    private Integer warehouseId;

    /** 粮食品种；basic_enum的id； */
    @ApiModelProperty(value = "粮食品种；basic_enum的id；", position = 10)
    private Integer grainVarietyId;

    /** 粮食性质；basic_enum的id； */
    @ApiModelProperty(value = "粮食性质；basic_enum的id；", position = 11)
    private Integer grainNatureId;

    /** 粮食等级；basic_enum的id； */
    @ApiModelProperty(value = "粮食等级；basic_enum的id；", position = 12)
    private Integer grainGradeId;

    /** 入库时间 */
    @ApiModelProperty(value = "入库时间", position = 13)
    private Date storageTime;

    /** 入库净重 */
    @ApiModelProperty(value = "入库净重", position = 14)
    private BigDecimal netWeightIn;

    /** 出库时间 */
    @ApiModelProperty(value = "出库时间", position = 15)
    private Date outboundTime;

    /** 出库净重 */
    @ApiModelProperty(value = "出库净重", position = 16)
    private BigDecimal netWeightOut;

    /** 存储年限 */
    @ApiModelProperty(value = "存储年限", position = 17)
    private Integer storageYears;

    /** 损溢是否正常 1：正常；2:不正常； */
    @ApiModelProperty(value = "损溢是否正常 1：正常；2:不正常；", position = 18)
    private Integer isNormalLoss;

    /** 存储数量 */
    @ApiModelProperty(value = "存储数量", position = 19)
    private Integer storageQuantity;

    /** 入库水分 */
    @ApiModelProperty(value = "入库水分", position = 20)
    private BigDecimal moistureIn;

    /** 入库杂质 */
    @ApiModelProperty(value = "入库杂质", position = 21)
    private BigDecimal impurityIn;

    /** 质检水分（实测水分） */
    @ApiModelProperty(value = "质检水分（实测水分）", position = 22)
    private BigDecimal moistureQuality;

    /** 出库水分 */
    @ApiModelProperty(value = "出库水分", position = 23)
    private BigDecimal moistureOut;

    /** 出库杂质 */
    @ApiModelProperty(value = "出库杂质", position = 24)
    private BigDecimal impurityOut;

    /** 水分减量 */
    @ApiModelProperty(value = "水分减量", position = 25)
    private BigDecimal moistureLoss;

    /** 保管自然损耗 */
    @ApiModelProperty(value = "保管自然损耗", position = 26)
    private BigDecimal naturalLoss;

    /** 存储损耗 */
    @ApiModelProperty(value = "存储损耗", position = 27)
    private BigDecimal storageLoss;

    /** 超耗数量 */
    @ApiModelProperty(value = "超耗数量", position = 28)
    private BigDecimal excessLossQuantity;

    /** 检查计算数 */
    @ApiModelProperty(value = "检查计算数", position = 29)
    private BigDecimal checkCalculateNumber;

    /** 水杂减量 */
    @ApiModelProperty(value = "水杂减量", position = 30)
    private BigDecimal moistureImpurityLoss;

    /** 损益原因 */
    @ApiModelProperty(value = "损益原因", position = 31)
    private String lossProfitReason;

    /** 仓储审核人 */
    @ApiModelProperty(value = "仓储审核人", position = 32)
    private String warehouseAuditor;

    /** 质检审核人 */
    @ApiModelProperty(value = "质检审核人", position = 33)
    private String qualityAuditor;

    /** 统计审核人 */
    @ApiModelProperty(value = "统计审核人", position = 34)
    private String statisticsAuditor;

    /** 会计审核人 */
    @ApiModelProperty(value = "会计审核人", position = 35)
    private String accountingAuditor;

    /** 领导审核人 */
    @ApiModelProperty(value = "领导审核人", position = 36)
    private String leadershipAuditor;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 37)
    private String remark;

    /** 状态 0：保存；1：上报； */
    @ApiModelProperty(value = "状态 0：保存；1：上报；", position = 38)
    private Integer status;

}
