/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.gopsPlanBuy.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.grainReserves.modular.gopsPlanBuy.entity.GopsPlanBuy;
import com.unis.grainReserves.modular.gopsPlanBuy.mapper.GopsPlanBuyMapper;
import com.unis.grainReserves.modular.gopsPlanBuy.param.GopsPlanBuyAddParam;
import com.unis.grainReserves.modular.gopsPlanBuy.param.GopsPlanBuyEditParam;
import com.unis.grainReserves.modular.gopsPlanBuy.param.GopsPlanBuyIdParam;
import com.unis.grainReserves.modular.gopsPlanBuy.param.GopsPlanBuyPageParam;
import com.unis.grainReserves.modular.gopsPlanBuy.service.GopsPlanBuyService;

import java.util.List;

/**
 * 购销计划-销售Service接口实现类
 *
 * @author QSHan
 * @date  2024/05/21 15:48
 **/
@Service
public class GopsPlanBuyServiceImpl extends ServiceImpl<GopsPlanBuyMapper, GopsPlanBuy> implements GopsPlanBuyService {

    @Override
    public Page<GopsPlanBuy> page(GopsPlanBuyPageParam gopsPlanBuyPageParam) {
        QueryWrapper<GopsPlanBuy> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(gopsPlanBuyPageParam.getSortField(), gopsPlanBuyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(gopsPlanBuyPageParam.getSortOrder());
            queryWrapper.orderBy(true, gopsPlanBuyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(gopsPlanBuyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GopsPlanBuy::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GopsPlanBuyAddParam gopsPlanBuyAddParam) {
        GopsPlanBuy gopsPlanBuy = BeanUtil.toBean(gopsPlanBuyAddParam, GopsPlanBuy.class);
        this.save(gopsPlanBuy);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GopsPlanBuyEditParam gopsPlanBuyEditParam) {
        GopsPlanBuy gopsPlanBuy = this.queryEntity(gopsPlanBuyEditParam.getId());
        BeanUtil.copyProperties(gopsPlanBuyEditParam, gopsPlanBuy);
        this.updateById(gopsPlanBuy);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GopsPlanBuyIdParam> gopsPlanBuyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(gopsPlanBuyIdParamList, GopsPlanBuyIdParam::getId));
    }

    @Override
    public GopsPlanBuy detail(GopsPlanBuyIdParam gopsPlanBuyIdParam) {
        return this.queryEntity(gopsPlanBuyIdParam.getId());
    }

    @Override
    public GopsPlanBuy queryEntity(String id) {
        GopsPlanBuy gopsPlanBuy = this.getById(id);
        if(ObjectUtil.isEmpty(gopsPlanBuy)) {
            throw new CommonException("购销计划-销售不存在，id值为：{}", id);
        }
        return gopsPlanBuy;
    }
}
