/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.gopsPlanSale.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.grainReserves.modular.gopsPlanSale.entity.GopsPlanSale;
import com.unis.grainReserves.modular.gopsPlanSale.mapper.GopsPlanSaleMapper;
import com.unis.grainReserves.modular.gopsPlanSale.param.GopsPlanSaleAddParam;
import com.unis.grainReserves.modular.gopsPlanSale.param.GopsPlanSaleEditParam;
import com.unis.grainReserves.modular.gopsPlanSale.param.GopsPlanSaleIdParam;
import com.unis.grainReserves.modular.gopsPlanSale.param.GopsPlanSalePageParam;
import com.unis.grainReserves.modular.gopsPlanSale.service.GopsPlanSaleService;

import java.util.List;

/**
 * 购销计划-销售Service接口实现类
 *
 * @author QSHan
 * @date  2024/05/18 17:31
 **/
@Service
public class GopsPlanSaleServiceImpl extends ServiceImpl<GopsPlanSaleMapper, GopsPlanSale> implements GopsPlanSaleService {

    @Override
    public Page<GopsPlanSale> page(GopsPlanSalePageParam gopsPlanSalePageParam) {
        QueryWrapper<GopsPlanSale> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(gopsPlanSalePageParam.getSortField(), gopsPlanSalePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(gopsPlanSalePageParam.getSortOrder());
            queryWrapper.orderBy(true, gopsPlanSalePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(gopsPlanSalePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GopsPlanSale::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GopsPlanSaleAddParam gopsPlanSaleAddParam) {
        GopsPlanSale gopsPlanSale = BeanUtil.toBean(gopsPlanSaleAddParam, GopsPlanSale.class);
        this.save(gopsPlanSale);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GopsPlanSaleEditParam gopsPlanSaleEditParam) {
        GopsPlanSale gopsPlanSale = this.queryEntity(gopsPlanSaleEditParam.getId());
        BeanUtil.copyProperties(gopsPlanSaleEditParam, gopsPlanSale);
        this.updateById(gopsPlanSale);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GopsPlanSaleIdParam> gopsPlanSaleIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(gopsPlanSaleIdParamList, GopsPlanSaleIdParam::getId));
    }

    @Override
    public GopsPlanSale detail(GopsPlanSaleIdParam gopsPlanSaleIdParam) {
        return this.queryEntity(gopsPlanSaleIdParam.getId());
    }

    @Override
    public GopsPlanSale queryEntity(String id) {
        GopsPlanSale gopsPlanSale = this.getById(id);
        if(ObjectUtil.isEmpty(gopsPlanSale)) {
            throw new CommonException("购销计划-销售不存在，id值为：{}", id);
        }
        return gopsPlanSale;
    }
}
