/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.grReserveScale.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.unitInfo.entity.BasicEnum;
import com.unis.basic.info.modular.unitInfo.entity.UnitInfo;
import com.unis.basic.info.modular.unitInfo.vo.UnitInfoVO;
import com.unis.grainReserves.modular.grReserveScale.param.*;
import com.unis.grainReserves.modular.grReserveScale.vo.GrReserveScaleVO;
import com.unis.grainReserves.modular.grReserveScale.vo.LspzInfoVO;

import com.unis.grainReserves.modular.grReserveScale.vo.LsxzInfoVO;
import com.unis.grainReserves.modular.grReserveScale.vo.OrgInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Param;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.grainReserves.modular.grReserveScale.entity.GrReserveScale;
import com.unis.grainReserves.modular.grReserveScale.service.GrReserveScaleService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 粮食储备-储备规模控制器
 *
 * @author hjc
 * @date 2024/05/14 17:28
 */
@Api(tags = "粮食储备-储备规模控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrReserveScaleController {

    @Resource
    private GrReserveScaleService grReserveScaleService;

    /**
     * 获取粮食储备-储备规模分页
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮食储备-储备规模分页")
    // @SaCheckPermission("/grainReserves/grReserveScale/page")
    @GetMapping("/grainReserves/grReserveScale/page")
    public CommonResult<Page<GrReserveScaleVO>> page(GrReserveScalePageParam grReserveScalePageParam) {
        return CommonResult.data(grReserveScaleService.page(grReserveScalePageParam));
    }

    /**
     * 添加粮食储备-储备规模
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加粮食储备-储备规模")
    @CommonLog("添加粮食储备-储备规模")
    //@SaCheckPermission("/grainReserves/grReserveScale/add")
    @PostMapping("/grainReserves/grReserveScale/add")
    public CommonResult<String> add(@RequestBody @Valid GrReserveScaleAddParam grReserveScaleAddParam) {
        grReserveScaleService.add(grReserveScaleAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食储备-储备规模
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮食储备-储备规模")
    @CommonLog("编辑粮食储备-储备规模")
    // @SaCheckPermission("/grainReserves/grReserveScale/edit")
    @PostMapping("/grainReserves/grReserveScale/edit")
    public CommonResult<String> edit(@RequestBody @Valid GrReserveScaleEditParam grReserveScaleEditParam) {
        grReserveScaleService.edit(grReserveScaleEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食储备-储备规模
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除粮食储备-储备规模")
    @CommonLog("删除粮食储备-储备规模")
    // @SaCheckPermission("/grainReserves/grReserveScale/delete")
    @PostMapping("/grainReserves/grReserveScale/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<GrReserveScaleIdParam> grReserveScaleIdParamList) {
        grReserveScaleService.delete(grReserveScaleIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮食储备-储备规模详情
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮食储备-储备规模详情")
    // @SaCheckPermission("/grainReserves/grReserveScale/detail")
    @GetMapping("/grainReserves/grReserveScale/detail")
    public CommonResult<GrReserveScaleVO> detail(@Valid GrReserveScaleIdParam grReserveScaleIdParam) {
        return CommonResult.data(grReserveScaleService.detail(grReserveScaleIdParam));
    }

    /**
     * 获取粮食储备-企业单位
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取粮食储备-企业单位")
    // @SaCheckPermission("/grainReserves/grReserveScale/getUnitInfo")
    @GetMapping("/grainReserves/grReserveScale/getUnitInfo")
    public CommonResult<List<UnitInfo>> getUnitInfo() {
        return CommonResult.data(grReserveScaleService.getUnitInfo());
    }

    /**
     * 获取粮食储备-根据企业信息查出库区名称
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取粮食储备-库区名称")
    // @SaCheckPermission("/grainReserves/grReserveScale/getOrgInfo")
    @GetMapping("/grainReserves/grReserveScale/getOrgInfo")
    public CommonResult<List<OrgInfoVO>> getOrgInfo(@Valid OrgInfoParam orgInfoParam) {
        return CommonResult.data(grReserveScaleService.getOrgInfo(orgInfoParam));
    }

    /**
     * 获取粮食储备-粮食品种
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("获取粮食储备-粮食品种")
    // @SaCheckPermission("/grainReserves/grReserveScale/getLspz")
    @GetMapping("/grainReserves/grReserveScale/getLspzInfo")
    public CommonResult<List<LspzInfoVO>> getLspzInfo() {
        return CommonResult.data(grReserveScaleService.getLspzInfo());
    }


    /**
     * 获取粮食储备-粮食性质
     *
     * @author hjc
     * @date 2024/05/14 17:28
     */
    @ApiOperationSupport(order = 9)
    @ApiOperation("获取粮食储备-粮食性质")
    // @SaCheckPermission("/grainReserves/grReserveScale/getLspz")
    @GetMapping("/grainReserves/grReserveScale/getLsxzInfo")
    public CommonResult<List<LsxzInfoVO>> getLsxzInfo(String parentId) {
        return CommonResult.data(grReserveScaleService.getLsxzInfo(parentId));
    }



    /* *
     * 获取粮食储备-下发
     *
     * @author hjc
     * @date  2024/05/14 17:28
     * */

    @ApiOperationSupport(order = 9)
    @ApiOperation("获取粮食储备-下发")
    // @SaCheckPermission("/grainReserves/grReserveScale/getLspz")
    @PostMapping("/grainReserves/grReserveScale/issued")
    public CommonResult<String> issued(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                           CommonValidList<GrReserveScaleIdAndStatusParam> paramCommonValidList) {
        grReserveScaleService.issued(paramCommonValidList);
        return CommonResult.ok();
    }

}
