/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.grainReserves.modular.grReserveScale.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 粮食储备-储备规模编辑参数
 *
 * @author hjc
 * @date  2024/05/14 17:28
 **/
@Getter
@Setter
public class GrReserveScaleEditParam {

    /** 唯一标识 */
    @ApiModelProperty(value = "唯一标识", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 企业单位；biz_unit_info的id； */
    @ApiModelProperty(value = "企业单位；biz_unit_info的id；", position = 7)
    @NotBlank(message = "企业单位不能为空")
    private String unitInfoId;

    /** 库区名称；外库的表，depot_qh.org_info的id； */
    @ApiModelProperty(value = "库区名称；外库的表，depot_qh.org_info的id；", position = 8)
    @NotNull(message = "库区名称不能为空")
    private Integer orgInfoId;

    /** 粮食品种；外库的表，depot_qh.basic_enum的id； */
    @ApiModelProperty(value = "粮食品种；外库的表，depot_qh.basic_enum的id；", position = 9)
    @NotNull(message = "粮食品种不能为空")
    private Integer grainVarietyId;

    /** 粮食性质；外库的表，depot_qh.basic_enum的id； */
    @ApiModelProperty(value = "粮食性质；外库的表，depot_qh.basic_enum的id；", position = 10)
    @NotNull(message = "粮食性质不能为空")
    private Integer grainNatureId;

    /** 储备规模计划量（吨） */
    @ApiModelProperty(value = "储备规模计划量（吨）", position = 11)
    @NotNull(message = "储备规划计划量不能为空")
    private BigDecimal reservePlanQuantity;

    /** 状态 1：保存；2：下发； */
    @ApiModelProperty(value = "状态 1：保存；2：下发；", position = 12)
    @NotNull(message = "状态不能为空")
    private Integer status;

    /** 下发时间 */
    @ApiModelProperty(value = "下发时间", position = 13)
    private Date distributeTime;

    /** 计划文号 */
    @ApiModelProperty(value = "计划文号", position = 14)
    private String planNo;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 15)
    private String remark;

    /** 日期-年 */
    @ApiModelProperty(value = "日期-年", position = 16)
    private Integer scaleYear;

    /** 日期-月 */
    @ApiModelProperty(value = "日期-月", position = 17)
    private Integer scaleMonth;
}
