/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.common.pojo.CommonValidList;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.entity.DataCrkywCkrmdjDefault;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultAddParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultEditParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultIdParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultPageParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.service.DataCrkywCkrmdjDefaultService;
import com.unis.intelligentManagement.modular.tLqData.param.OrgInfoByIdParam;
import com.unis.intelligentManagement.modular.tLqData.vo.CrkywVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;


import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 汽车出库-入门登记控制器
 *
 * @author hjc
 * @date  2024/06/07 17:55
 */
@Api(tags = "汽车出库-入门登记控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DataCrkywCkrmdjDefaultController {

    @Resource
    private DataCrkywCkrmdjDefaultService dataCrkywCkrmdjDefaultService;

    /**
     * 获取汽车出库-入门登记分页
     *
     * @author hjc
     * @date  2024/06/07 17:55
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取汽车出库-入门登记分页")
    @SaCheckPermission("/auth/dataCrkywCkrmdjDefault/page")
    @GetMapping("/auth/dataCrkywCkrmdjDefault/page")
    public CommonResult<Page<DataCrkywCkrmdjDefault>> page(DataCrkywCkrmdjDefaultPageParam dataCrkywCkrmdjDefaultPageParam) {
        return CommonResult.data(dataCrkywCkrmdjDefaultService.page(dataCrkywCkrmdjDefaultPageParam));
    }

    /**
     * 添加汽车出库-入门登记
     *
     * @author hjc
     * @date  2024/06/07 17:55
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加汽车出库-入门登记")
    @CommonLog("添加汽车出库-入门登记")
    @SaCheckPermission("/auth/dataCrkywCkrmdjDefault/add")
    @PostMapping("/auth/dataCrkywCkrmdjDefault/add")
    public CommonResult<String> add(@RequestBody @Valid DataCrkywCkrmdjDefaultAddParam dataCrkywCkrmdjDefaultAddParam) {
        dataCrkywCkrmdjDefaultService.add(dataCrkywCkrmdjDefaultAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑汽车出库-入门登记
     *
     * @author hjc
     * @date  2024/06/07 17:55
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑汽车出库-入门登记")
    @CommonLog("编辑汽车出库-入门登记")
    @SaCheckPermission("/auth/dataCrkywCkrmdjDefault/edit")
    @PostMapping("/auth/dataCrkywCkrmdjDefault/edit")
    public CommonResult<String> edit(@RequestBody @Valid DataCrkywCkrmdjDefaultEditParam dataCrkywCkrmdjDefaultEditParam) {
        dataCrkywCkrmdjDefaultService.edit(dataCrkywCkrmdjDefaultEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除汽车出库-入门登记
     *
     * @author hjc
     * @date  2024/06/07 17:55
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除汽车出库-入门登记")
    @CommonLog("删除汽车出库-入门登记")
    @SaCheckPermission("/auth/dataCrkywCkrmdjDefault/delete")
    @PostMapping("/auth/dataCrkywCkrmdjDefault/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<DataCrkywCkrmdjDefaultIdParam> dataCrkywCkrmdjDefaultIdParamList) {
        dataCrkywCkrmdjDefaultService.delete(dataCrkywCkrmdjDefaultIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取汽车出库-入门登记详情
     *
     * @author hjc
     * @date  2024/06/07 17:55
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取汽车出库-入门登记详情")
    @SaCheckPermission("/auth/dataCrkywCkrmdjDefault/detail")
    @GetMapping("/auth/dataCrkywCkrmdjDefault/detail")
    public CommonResult<DataCrkywCkrmdjDefault> detail(@Valid DataCrkywCkrmdjDefaultIdParam dataCrkywCkrmdjDefaultIdParam) {
        return CommonResult.data(dataCrkywCkrmdjDefaultService.detail(dataCrkywCkrmdjDefaultIdParam));
    }


    /**
     * 获取首页
     *
     * @author hjc
     * @date  2024/06/07 10:18
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取首页")
    //@SaCheckPermission("/intelligentManagement/tLqData/detail")
    @GetMapping("/intelligentManagement/tLqData/getHome")
    public CommonResult<CrkywVO> getHome(@Valid OrgInfoByIdParam orgInfoByIdParam) {
        return CommonResult.data(dataCrkywCkrmdjDefaultService.getHome(orgInfoByIdParam));
    }

}
