/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.mapper.DataCrkywRmdjDefaultMapper;
import com.unis.intelligentManagement.modular.tLqData.param.OrgInfoByIdParam;
import com.unis.intelligentManagement.modular.tLqData.vo.CrkywVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.entity.DataCrkywCkrmdjDefault;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.mapper.DataCrkywCkrmdjDefaultMapper;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultAddParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultEditParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultIdParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.param.DataCrkywCkrmdjDefaultPageParam;
import com.unis.intelligentManagement.modular.dataCrkywCkrmdjDefault.service.DataCrkywCkrmdjDefaultService;

import java.util.List;

/**
 * 汽车出库-入门登记Service接口实现类
 *
 * @author hjc
 * @date 2024/06/07 17:55
 **/
@Service
public class DataCrkywCkrmdjDefaultServiceImpl extends ServiceImpl<DataCrkywCkrmdjDefaultMapper, DataCrkywCkrmdjDefault> implements DataCrkywCkrmdjDefaultService {

    @Autowired
    private DataCrkywCkrmdjDefaultMapper dataCrkywCkrmdjDefaultMapper;

    @Autowired
    private DataCrkywRmdjDefaultMapper dataCrkywRmdjDefaultMapper;


    @Override
    public Page<DataCrkywCkrmdjDefault> page(DataCrkywCkrmdjDefaultPageParam dataCrkywCkrmdjDefaultPageParam) {
        QueryWrapper<DataCrkywCkrmdjDefault> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isAllNotEmpty(dataCrkywCkrmdjDefaultPageParam.getSortField(), dataCrkywCkrmdjDefaultPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(dataCrkywCkrmdjDefaultPageParam.getSortOrder());
            queryWrapper.orderBy(true, dataCrkywCkrmdjDefaultPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(dataCrkywCkrmdjDefaultPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(DataCrkywCkrmdjDefault::getBuilddate);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(DataCrkywCkrmdjDefaultAddParam dataCrkywCkrmdjDefaultAddParam) {
        DataCrkywCkrmdjDefault dataCrkywCkrmdjDefault = BeanUtil.toBean(dataCrkywCkrmdjDefaultAddParam, DataCrkywCkrmdjDefault.class);
        this.save(dataCrkywCkrmdjDefault);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(DataCrkywCkrmdjDefaultEditParam dataCrkywCkrmdjDefaultEditParam) {
        DataCrkywCkrmdjDefault dataCrkywCkrmdjDefault = new DataCrkywCkrmdjDefault();
        BeanUtil.copyProperties(dataCrkywCkrmdjDefaultEditParam, dataCrkywCkrmdjDefault);
        this.updateById(dataCrkywCkrmdjDefault);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<DataCrkywCkrmdjDefaultIdParam> dataCrkywCkrmdjDefaultIdParamList) {
        // 执行删除
    }

    @Override
    public DataCrkywCkrmdjDefault detail(DataCrkywCkrmdjDefaultIdParam dataCrkywCkrmdjDefaultIdParam) {
        return this.queryEntity(dataCrkywCkrmdjDefaultIdParam.getId());
    }

    @Override
    public DataCrkywCkrmdjDefault queryEntity(String id) {
        DataCrkywCkrmdjDefault dataCrkywCkrmdjDefault = this.getById(id);
        if (ObjectUtil.isEmpty(dataCrkywCkrmdjDefault)) {
            throw new CommonException("汽车出库-入门登记不存在，id值为：{}", id);
        }
        return dataCrkywCkrmdjDefault;
    }


    /**
     * 获取首页
     *
     * @author hjc
     * @date 2024/06/07 10:18
     */
    @Override
    public CrkywVO getHome(OrgInfoByIdParam orgInfoByIdParam) {

        //统计今日出库数量
        Integer ckrmdjNum = dataCrkywCkrmdjDefaultMapper.selectTodayCrkywCkrmdj(orgInfoByIdParam.getOrgId());
        //统计今日入库数量
        Integer rmdjNum = dataCrkywRmdjDefaultMapper.selectTodayCrkywRmdj(orgInfoByIdParam.getOrgId());

       return CrkywVO.builder().ckrmdjNum(ckrmdjNum).rmdjNum(rmdjNum).build();


    }


}
