/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.entity.DataCrkywRmdjDefault;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;

import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.param.DataCrkywRmdjDefaultAddParam;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.param.DataCrkywRmdjDefaultEditParam;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.param.DataCrkywRmdjDefaultIdParam;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.param.DataCrkywRmdjDefaultPageParam;
import com.unis.intelligentManagement.modular.dataCrkywRmdjDefault.service.DataCrkywRmdjDefaultService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 出入库登记控制器
 *
 * @author hjc
 * @date  2024/06/07 17:58
 */
@Api(tags = "出入库登记控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DataCrkywRmdjDefaultController {

    @Resource
    private DataCrkywRmdjDefaultService dataCrkywRmdjDefaultService;

    /**
     * 获取出入库登记分页
     *
     * @author hjc
     * @date  2024/06/07 17:58
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取出入库登记分页")
    //@SaCheckPermission("/auth/dataCrkywRmdjDefault/page")
    @GetMapping("/auth/dataCrkywRmdjDefault/page")
    public CommonResult<Page<DataCrkywRmdjDefault>> page(DataCrkywRmdjDefaultPageParam dataCrkywRmdjDefaultPageParam) {
        return CommonResult.data(dataCrkywRmdjDefaultService.page(dataCrkywRmdjDefaultPageParam));
    }

    /**
     * 添加出入库登记
     *
     * @author hjc
     * @date  2024/06/07 17:58
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加出入库登记")
    @CommonLog("添加出入库登记")
    //@SaCheckPermission("/auth/dataCrkywRmdjDefault/add")
    @PostMapping("/auth/dataCrkywRmdjDefault/add")
    public CommonResult<String> add(@RequestBody @Valid DataCrkywRmdjDefaultAddParam dataCrkywRmdjDefaultAddParam) {
        dataCrkywRmdjDefaultService.add(dataCrkywRmdjDefaultAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑出入库登记
     *
     * @author hjc
     * @date  2024/06/07 17:58
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑出入库登记")
    @CommonLog("编辑出入库登记")
    //@SaCheckPermission("/auth/dataCrkywRmdjDefault/edit")
    @PostMapping("/auth/dataCrkywRmdjDefault/edit")
    public CommonResult<String> edit(@RequestBody @Valid DataCrkywRmdjDefaultEditParam dataCrkywRmdjDefaultEditParam) {
        dataCrkywRmdjDefaultService.edit(dataCrkywRmdjDefaultEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除出入库登记
     *
     * @author hjc
     * @date  2024/06/07 17:58
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除出入库登记")
    @CommonLog("删除出入库登记")
    //@SaCheckPermission("/auth/dataCrkywRmdjDefault/delete")
    @PostMapping("/auth/dataCrkywRmdjDefault/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<DataCrkywRmdjDefaultIdParam> dataCrkywRmdjDefaultIdParamList) {
        dataCrkywRmdjDefaultService.delete(dataCrkywRmdjDefaultIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取出入库登记详情
     *
     * @author hjc
     * @date  2024/06/07 17:58
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取出入库登记详情")
    //@SaCheckPermission("/auth/dataCrkywRmdjDefault/detail")
    @GetMapping("/auth/dataCrkywRmdjDefault/detail")
    public CommonResult<DataCrkywRmdjDefault> detail(@Valid DataCrkywRmdjDefaultIdParam dataCrkywRmdjDefaultIdParam) {
        return CommonResult.data(dataCrkywRmdjDefaultService.detail(dataCrkywRmdjDefaultIdParam));
    }
}
