/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.lqdatalayer.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.intelligentManagement.modular.tLqData.param.TLqDataIdParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.intelligentManagement.modular.lqdatalayer.entity.TLqDataLayer;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerAddParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerEditParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerIdParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerPageParam;
import com.unis.intelligentManagement.modular.lqdatalayer.service.TLqDataLayerService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 多功能粮情-子表控制器
 *
 * @author shine
 * @date  2024/06/11 20:27
 */
@Api(tags = "多功能粮情-子表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class TLqDataLayerController {

    @Resource
    private TLqDataLayerService tLqDataLayerService;

    /**
     * 获取多功能粮情-子表分页
     *
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取多功能粮情-子表分页")
    @SaCheckPermission("/intelligentManagement/lqdatalayer/page")
    @GetMapping("/intelligentManagement/lqdatalayer/page")
    public CommonResult<Page<TLqDataLayer>> page(TLqDataLayerPageParam tLqDataLayerPageParam) {
        return CommonResult.data(tLqDataLayerService.page(tLqDataLayerPageParam));
    }

    /**
     * 添加多功能粮情-子表
     *
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加多功能粮情-子表")
    @CommonLog("添加多功能粮情-子表")
    @SaCheckPermission("/intelligentManagement/lqdatalayer/add")
    @PostMapping("/intelligentManagement/lqdatalayer/add")
    public CommonResult<String> add(@RequestBody @Valid TLqDataLayerAddParam tLqDataLayerAddParam) {
        tLqDataLayerService.add(tLqDataLayerAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑多功能粮情-子表
     *
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑多功能粮情-子表")
    @CommonLog("编辑多功能粮情-子表")
    @SaCheckPermission("/intelligentManagement/lqdatalayer/edit")
    @PostMapping("/intelligentManagement/lqdatalayer/edit")
    public CommonResult<String> edit(@RequestBody @Valid TLqDataLayerEditParam tLqDataLayerEditParam) {
        tLqDataLayerService.edit(tLqDataLayerEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除多功能粮情-子表
     *
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除多功能粮情-子表")
    @CommonLog("删除多功能粮情-子表")
    @SaCheckPermission("/intelligentManagement/lqdatalayer/delete")
    @PostMapping("/intelligentManagement/lqdatalayer/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<TLqDataLayerIdParam> tLqDataLayerIdParamList) {
        tLqDataLayerService.delete(tLqDataLayerIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取多功能粮情-子表详情
     *
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取多功能粮情-子表详情")
    @GetMapping("/intelligentManagement/lqdatalayer/detail")
    public CommonResult<TLqDataLayer> detail(@Valid TLqDataLayerIdParam tLqDataLayerIdParam) {
        return CommonResult.data(tLqDataLayerService.detail(tLqDataLayerIdParam));
    }


































    /**
     * 根据主表id获取子表
     * @author shine
     * @date  2024/06/11 20:27
     */
    @ApiOperationSupport(order = 6 )
    @ApiOperation("*根据主表id获取子表")
    @GetMapping("/intelligentManagement/lqdatalayer/detailByZid")
    public CommonResult<List<TLqDataLayer>> detailByZid(@Valid TLqDataIdParam tLqDataIdParam) {
        return CommonResult.data(tLqDataLayerService.detailByZid(tLqDataIdParam));
    }


































}
