/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.lqdatalayer.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.intelligentManagement.modular.tLqData.param.TLqDataIdParam;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.intelligentManagement.modular.lqdatalayer.entity.TLqDataLayer;
import com.unis.intelligentManagement.modular.lqdatalayer.mapper.TLqDataLayerMapper;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerAddParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerEditParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerIdParam;
import com.unis.intelligentManagement.modular.lqdatalayer.param.TLqDataLayerPageParam;
import com.unis.intelligentManagement.modular.lqdatalayer.service.TLqDataLayerService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 多功能粮情-子表Service接口实现类
 *
 * @author shine
 * @date 2024/06/11 20:27
 **/
@Service
public class TLqDataLayerServiceImpl extends ServiceImpl<TLqDataLayerMapper, TLqDataLayer> implements TLqDataLayerService {
    @Resource
    private TLqDataLayerMapper tLqDataLayerMapper;

    @Override
    public Page<TLqDataLayer> page(TLqDataLayerPageParam tLqDataLayerPageParam) {
        QueryWrapper<TLqDataLayer> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotEmpty(tLqDataLayerPageParam.getOrgId())) {
            queryWrapper.lambda().eq(TLqDataLayer::getOrgId, tLqDataLayerPageParam.getOrgId());
        }
        if (ObjectUtil.isNotEmpty(tLqDataLayerPageParam.getLqId())) {
            queryWrapper.lambda().eq(TLqDataLayer::getLqId, tLqDataLayerPageParam.getLqId());
        }
        if (ObjectUtil.isAllNotEmpty(tLqDataLayerPageParam.getSortField(), tLqDataLayerPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(tLqDataLayerPageParam.getSortOrder());
            queryWrapper.orderBy(true, tLqDataLayerPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(tLqDataLayerPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(TLqDataLayer::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(TLqDataLayerAddParam tLqDataLayerAddParam) {
        TLqDataLayer tLqDataLayer = BeanUtil.toBean(tLqDataLayerAddParam, TLqDataLayer.class);
        this.save(tLqDataLayer);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(TLqDataLayerEditParam tLqDataLayerEditParam) {
        TLqDataLayer tLqDataLayer = this.queryEntity(tLqDataLayerEditParam.getId());
        BeanUtil.copyProperties(tLqDataLayerEditParam, tLqDataLayer);
        this.updateById(tLqDataLayer);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<TLqDataLayerIdParam> tLqDataLayerIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(tLqDataLayerIdParamList, TLqDataLayerIdParam::getId));
    }

    @Override
    public TLqDataLayer detail(TLqDataLayerIdParam tLqDataLayerIdParam) {
        return this.queryEntity(tLqDataLayerIdParam.getId());
    }







































































    @Override
    public TLqDataLayer queryEntity(String id) {
        TLqDataLayer tLqDataLayer = this.getById(id);
        if (ObjectUtil.isEmpty(tLqDataLayer)) {
            throw new CommonException("多功能粮情-子表不存在，id值为：{}", id);
        }
        return tLqDataLayer;
    }

























    /**
     * 购销监管-粮情监管-查看
     *
     * @author hjc
     * @date 2024/06/07 10:18
     */
    @Override
    public List<TLqDataLayer> getTLqDataLayerDetail(String lqId) {

        QueryWrapper<TLqDataLayer> wrapper = new QueryWrapper<>();
        wrapper.eq("lq_id", lqId);
        return tLqDataLayerMapper.selectList(wrapper);

    }

    @Override
    public List<TLqDataLayer> detailByZid(TLqDataIdParam tLqDataIdParam) {
        QueryWrapper<TLqDataLayer> wrapper = new QueryWrapper<>();
        wrapper.eq("lq_id", tLqDataIdParam.getId());
        return this.list(wrapper);
    }


}