package com.unis.intelligentManagement.modular.rgb.service;

import com.alibaba.fastjson.JSONArray;

import com.unis.intelligentManagement.modular.rgb.entity.ResultTempMap;
import com.unis.intelligentManagement.modular.rgb.entity.TPoints;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author qingsong.han
 * @description:
 * @create 2022-01-24 14:39
 */
@Slf4j
@Service
public class RGBTransformerService {

    // 1.温度json数据,已山西云南数据为例
    //private static final String data = "[{\"temp\":11.8,\"x\":\"1\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":3.1,\"x\":\"2\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":9.4,\"x\":\"3\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":9.2,\"x\":\"4\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":13.5,\"x\":\"5\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":5.1,\"x\":\"6\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":10.8,\"x\":\"7\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":10.1,\"x\":\"8\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":9.2,\"x\":\"9\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":9.8,\"x\":\"10\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":13.0,\"x\":\"11\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":7.7,\"x\":\"12\",\"y\":\"1\",\"z\":\"1\"},{\"temp\":13.2,\"x\":\"1\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":11.4,\"x\":\"2\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":13.6,\"x\":\"3\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":11.1,\"x\":\"4\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":2.8,\"x\":\"5\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"6\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":12.7,\"x\":\"7\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":12.9,\"x\":\"8\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":11.1,\"x\":\"9\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":12.3,\"x\":\"10\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":9.1,\"x\":\"11\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":8.5,\"x\":\"12\",\"y\":\"2\",\"z\":\"1\"},{\"temp\":11.3,\"x\":\"1\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"2\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":8.5,\"x\":\"3\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":3.7,\"x\":\"4\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":13.5,\"x\":\"5\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":12.4,\"x\":\"6\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":11.1,\"x\":\"7\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":11.3,\"x\":\"8\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":3.7,\"x\":\"9\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":10.3,\"x\":\"10\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"11\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":12.7,\"x\":\"12\",\"y\":\"3\",\"z\":\"1\"},{\"temp\":10.1,\"x\":\"1\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":1.9,\"x\":\"2\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":2.0,\"x\":\"3\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":10.3,\"x\":\"4\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":11.5,\"x\":\"5\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"6\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":8.9,\"x\":\"7\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":12.5,\"x\":\"8\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":12.7,\"x\":\"9\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":2.9,\"x\":\"10\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":8.1,\"x\":\"11\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":9.6,\"x\":\"12\",\"y\":\"4\",\"z\":\"1\"},{\"temp\":13.2,\"x\":\"1\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":13.3,\"x\":\"2\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":12.6,\"x\":\"3\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":12.8,\"x\":\"4\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":9.7,\"x\":\"5\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":12.8,\"x\":\"6\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"7\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":13.0,\"x\":\"8\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":13.0,\"x\":\"9\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":12.5,\"x\":\"10\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":13.3,\"x\":\"11\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":11.6,\"x\":\"12\",\"y\":\"5\",\"z\":\"1\"},{\"temp\":12.8,\"x\":\"1\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":13.7,\"x\":\"2\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":13.5,\"x\":\"3\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":4.8,\"x\":\"4\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":13.2,\"x\":\"5\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":4.5,\"x\":\"6\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":10.6,\"x\":\"7\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":9.2,\"x\":\"8\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":6.7,\"x\":\"9\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":12.2,\"x\":\"10\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":13.1,\"x\":\"11\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":12.6,\"x\":\"12\",\"y\":\"6\",\"z\":\"1\"},{\"temp\":4.9,\"x\":\"1\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":4.5,\"x\":\"2\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":6.4,\"x\":\"3\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":6.8,\"x\":\"4\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":6.1,\"x\":\"5\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":6.7,\"x\":\"6\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":8.6,\"x\":\"7\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":11.0,\"x\":\"8\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":6.8,\"x\":\"9\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":9.6,\"x\":\"10\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":9.3,\"x\":\"11\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":8.1,\"x\":\"12\",\"y\":\"1\",\"z\":\"2\"},{\"temp\":7.1,\"x\":\"1\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":9.1,\"x\":\"2\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":3.5,\"x\":\"3\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":8.1,\"x\":\"4\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":5.9,\"x\":\"5\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":6.4,\"x\":\"6\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":9.7,\"x\":\"7\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":13.1,\"x\":\"8\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":8.1,\"x\":\"9\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":10.1,\"x\":\"10\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":10.7,\"x\":\"11\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":9.5,\"x\":\"12\",\"y\":\"2\",\"z\":\"2\"},{\"temp\":6.0,\"x\":\"1\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":9.0,\"x\":\"2\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":2.6,\"x\":\"3\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":5.0,\"x\":\"4\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":5.1,\"x\":\"5\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":6.1,\"x\":\"6\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":12.9,\"x\":\"7\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":9.3,\"x\":\"8\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":5.0,\"x\":\"9\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":10.1,\"x\":\"10\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":10.2,\"x\":\"11\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":8.6,\"x\":\"12\",\"y\":\"3\",\"z\":\"2\"},{\"temp\":4.8,\"x\":\"1\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":3.9,\"x\":\"2\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":5.8,\"x\":\"3\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":6.5,\"x\":\"4\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":8.5,\"x\":\"5\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":9.5,\"x\":\"6\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":12.2,\"x\":\"7\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":8.2,\"x\":\"8\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":6.0,\"x\":\"9\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":9.4,\"x\":\"10\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":8.4,\"x\":\"11\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":7.9,\"x\":\"12\",\"y\":\"4\",\"z\":\"2\"},{\"temp\":7.5,\"x\":\"1\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":4.5,\"x\":\"2\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":5.7,\"x\":\"3\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":5.1,\"x\":\"4\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":4.6,\"x\":\"5\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":7.8,\"x\":\"6\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":8.6,\"x\":\"7\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":10.1,\"x\":\"8\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":8.1,\"x\":\"9\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":12.6,\"x\":\"10\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":9.0,\"x\":\"11\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":8.1,\"x\":\"12\",\"y\":\"5\",\"z\":\"2\"},{\"temp\":5.3,\"x\":\"1\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":4.1,\"x\":\"2\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":4.9,\"x\":\"3\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":7.1,\"x\":\"4\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":5.7,\"x\":\"5\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":5.8,\"x\":\"6\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":8.0,\"x\":\"7\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":5.2,\"x\":\"8\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":8.6,\"x\":\"9\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":9.6,\"x\":\"10\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":8.4,\"x\":\"11\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":7.7,\"x\":\"12\",\"y\":\"6\",\"z\":\"2\"},{\"temp\":-0.1,\"x\":\"1\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-0.9,\"x\":\"2\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-1.3,\"x\":\"3\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":1.1,\"x\":\"4\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-1.2,\"x\":\"5\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-1.1,\"x\":\"6\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-0.1,\"x\":\"7\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":0.9,\"x\":\"8\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":1.1,\"x\":\"9\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":1.5,\"x\":\"10\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":0.2,\"x\":\"11\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":1.8,\"x\":\"12\",\"y\":\"1\",\"z\":\"3\"},{\"temp\":-1.9,\"x\":\"1\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-1.7,\"x\":\"2\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-2.1,\"x\":\"3\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-2.4,\"x\":\"4\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-0.9,\"x\":\"5\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-0.3,\"x\":\"6\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-0.3,\"x\":\"7\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":0.1,\"x\":\"8\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":-2.4,\"x\":\"9\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":0.3,\"x\":\"10\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":0.3,\"x\":\"11\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":0.3,\"x\":\"12\",\"y\":\"2\",\"z\":\"3\"},{\"temp\":0.6,\"x\":\"1\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-1.6,\"x\":\"2\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-2.6,\"x\":\"3\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-2.2,\"x\":\"4\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.0,\"x\":\"5\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.4,\"x\":\"6\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.3,\"x\":\"7\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-0.3,\"x\":\"8\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-2.2,\"x\":\"9\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.6,\"x\":\"10\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.6,\"x\":\"11\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":0.0,\"x\":\"12\",\"y\":\"3\",\"z\":\"3\"},{\"temp\":-2.0,\"x\":\"1\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-0.7,\"x\":\"2\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-1.4,\"x\":\"3\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-2.2,\"x\":\"4\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-0.5,\"x\":\"5\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":0.2,\"x\":\"6\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-0.1,\"x\":\"7\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-0.2,\"x\":\"8\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":4.3,\"x\":\"9\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":0.4,\"x\":\"10\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":0.8,\"x\":\"11\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":0.5,\"x\":\"12\",\"y\":\"4\",\"z\":\"3\"},{\"temp\":-1.5,\"x\":\"1\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-0.6,\"x\":\"2\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-2.3,\"x\":\"3\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-2.3,\"x\":\"4\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-0.5,\"x\":\"5\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-0.4,\"x\":\"6\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-0.8,\"x\":\"7\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-0.6,\"x\":\"8\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":0.0,\"x\":\"9\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":1.2,\"x\":\"10\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":1.2,\"x\":\"11\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":0.2,\"x\":\"12\",\"y\":\"5\",\"z\":\"3\"},{\"temp\":-2.2,\"x\":\"1\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-1.1,\"x\":\"2\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-2.3,\"x\":\"3\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-1.5,\"x\":\"4\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-0.4,\"x\":\"5\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-0.3,\"x\":\"6\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-0.7,\"x\":\"7\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":-0.3,\"x\":\"8\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":1.2,\"x\":\"9\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":1.4,\"x\":\"10\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":0.6,\"x\":\"11\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":0.5,\"x\":\"12\",\"y\":\"6\",\"z\":\"3\"},{\"temp\":2.5,\"x\":\"1\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":3.3,\"x\":\"2\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":1.0,\"x\":\"3\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":3.1,\"x\":\"4\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":2.9,\"x\":\"5\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":2.4,\"x\":\"6\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":1.5,\"x\":\"7\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":1.3,\"x\":\"8\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":3.1,\"x\":\"9\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":2.7,\"x\":\"10\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":2.6,\"x\":\"11\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":2.8,\"x\":\"12\",\"y\":\"1\",\"z\":\"4\"},{\"temp\":0.8,\"x\":\"1\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":2.5,\"x\":\"2\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":-0.4,\"x\":\"3\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":1.5,\"x\":\"4\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":3.9,\"x\":\"5\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":4.2,\"x\":\"6\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":3.0,\"x\":\"7\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":0.1,\"x\":\"8\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":1.5,\"x\":\"9\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":1.6,\"x\":\"10\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":4.1,\"x\":\"11\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":1.6,\"x\":\"12\",\"y\":\"2\",\"z\":\"4\"},{\"temp\":-1.1,\"x\":\"1\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":2.3,\"x\":\"2\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":0.7,\"x\":\"3\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":2.2,\"x\":\"4\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":4.9,\"x\":\"5\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":4.4,\"x\":\"6\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":2.2,\"x\":\"7\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":1.2,\"x\":\"8\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":2.2,\"x\":\"9\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":2.1,\"x\":\"10\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":3.9,\"x\":\"11\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":1.5,\"x\":\"12\",\"y\":\"3\",\"z\":\"4\"},{\"temp\":1.4,\"x\":\"1\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":3.1,\"x\":\"2\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":1.4,\"x\":\"3\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":1.9,\"x\":\"4\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":3.5,\"x\":\"5\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":3.2,\"x\":\"6\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":2.7,\"x\":\"7\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":2.5,\"x\":\"8\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":0.2,\"x\":\"9\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":2.4,\"x\":\"10\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":4.5,\"x\":\"11\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":3.7,\"x\":\"12\",\"y\":\"4\",\"z\":\"4\"},{\"temp\":1.2,\"x\":\"1\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":4.7,\"x\":\"2\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":2.2,\"x\":\"3\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":2.4,\"x\":\"4\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":4.5,\"x\":\"5\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":3.3,\"x\":\"6\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":1.6,\"x\":\"7\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":1.8,\"x\":\"8\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":2.4,\"x\":\"9\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":2.9,\"x\":\"10\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":4.8,\"x\":\"11\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":1.7,\"x\":\"12\",\"y\":\"5\",\"z\":\"4\"},{\"temp\":1.9,\"x\":\"1\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":4.5,\"x\":\"2\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":2.7,\"x\":\"3\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":1.8,\"x\":\"4\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":2.6,\"x\":\"5\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":3.1,\"x\":\"6\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":1.6,\"x\":\"7\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":2.8,\"x\":\"8\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":1.9,\"x\":\"9\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":2.2,\"x\":\"10\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":3.2,\"x\":\"11\",\"y\":\"6\",\"z\":\"4\"},{\"temp\":1.1,\"x\":\"12\",\"y\":\"6\",\"z\":\"4\"}]";
    // lqData = data
    public ResultTempMap tempOrderly(int z,String lqData) {

        // 1.将字符串json转换成对象
        List<TPoints> tPoints = JSONArray.parseArray(lqData, TPoints.class);
        Map<Integer, List<TPoints>> collectZ = tPoints.stream().collect(Collectors.groupingBy(TPoints::getZ));
//        log.info("collect-z: {}", JSON.toJSONString(collectZ));
        if (z > 0) {
            List<TPoints> tPoints1 = collectZ.get(z);
            Map<Integer, List<TPoints>> collect = tPoints1.stream()
                    .collect(Collectors.groupingBy(TPoints::getX));
            // 测温点长(y)
            int ySize = tPoints1.stream().collect(Collectors.groupingBy(TPoints::getY)).size();
//            log.info("y.length: {}", ySize);
            // 测温点宽(x)
            int xSize = collect.size();
//            log.info("x.length: {}", xSize);
            Map<String, Double> xOrderlyTemp = new LinkedHashMap<>();
            collect.forEach((k, v) -> {
                v.forEach(point -> {
                    log.info(point.getX() + "-" + point.getY());
                    xOrderlyTemp.put(point.getX() + "-" + point.getY(), point.getTemp());
                });
            });
            // 封装返回数据对象
            ResultTempMap resultTempMap = new ResultTempMap();
            resultTempMap.setYSize(ySize); // 测温点长(y)
            resultTempMap.setXSize(xSize); // 测温点宽(x)
            resultTempMap.setXOrderlyTemp(xOrderlyTemp);
            return resultTempMap;
        }
        return new ResultTempMap();
    }


    /**
     * 温度转为rgb的值
     * temperature 温度
     * <p>
     * 颜色渐变解析
     * R        G        B
     * 255  |  0-255 |    0      //红-黄769-1024
     * 255-0 |   255  |    0      //黄-绿513-768
     * 0   |   255  |  0-255    //绿-浅蓝257-512
     * 0   |  255-0 |   255     //浅蓝-深蓝  1-256
     */
    public String Temperature_RGB(double temperature, double highest, double lowest) {

        //temperature = -20 ;
        //double highest = 45; // 零上40度
        //double lowest = -35; // 零下30度
        double interval = 0; //温度的区间
        int colorInterval = 256 * 4;    //颜色取值区间，见上方的注释


        double intervalTemp = 0; //在温度区间中 该温度所处的位置
        double originalRatio = 0; //在该温度区间中所占的比
        int actualColor = 0; //在颜色区间中的值

        int rgb = 0;
        String rgbS = "";

        if(temperature >= highest){
        	actualColor = 1024;
        }else if(temperature <= lowest){
        	actualColor = 1;
        }else{
        	interval = highest - lowest; //70
            intervalTemp = temperature - lowest; //50
            originalRatio = intervalTemp / interval;
            actualColor = (int) Math.round(originalRatio * colorInterval);
        }
        


        
        if (actualColor >= 1 && actualColor <= 256) {
            actualColor = actualColor - 1;
            rgbS = 0 + "," + actualColor + "," + 255;

        } else if (actualColor >= 257 && actualColor <= 512) {
            actualColor = actualColor - 257;
            actualColor = 255 - actualColor;    //镜象翻转处理
            rgbS = 0 + "," + 255 + "," + actualColor;

        } else if (actualColor >= 513 && actualColor <= 768) {
            actualColor = actualColor - 513;
            rgbS = actualColor + "," + 255 + "," + 000;
        } else if (actualColor >= 769 && actualColor <= 1024) {
            actualColor = actualColor - 769;
            actualColor = 255 - actualColor;    //镜象翻转处理
            rgbS = 255 + "," + actualColor + "," + 0;
        } else {
            System.out.println("actualColor"+actualColor);
            rgbS = "000,000,000";
            System.out.println("temperature是"+temperature);
        }

        return rgbS;

    }

    /**
     * rgb转温度
     *
     * @param rgb
     */
    public double RGB_Temperature(String rgb, double highest, double lowest, Integer i, Integer j) {
        //int highest = 45;	//最高值，暂定零上40度
        //int lowest = -35;	//最低值，暂定零下30度
        double interval;    //温度取值区间
        int colorInterval = 256 * 4;    //颜色取值区间，见最上方的注释
        double originalRatio;    //温度取值比率，保留1位小数四舍五入
        int actualColor;    //对应颜色的值
        double temperature;    //温度返回值
        int r = 0;
        int g = 0;
        int b = 0;
        String[] rgbArray = rgb.split(",");
        //System.out.println(rgb+"*************"+rgbArray);
        r = Integer.parseInt(rgbArray[0]);
        g = Integer.parseInt(rgbArray[1]);
        b = Integer.parseInt(rgbArray[2]);
		/*String rgbS = rgb+"";
		//判断这个的个数 是不是3的倍数 不是的话 前面 补0
		if(rgbS.length()%3 != 0){
			int a = 3-rgbS.length()%3;
			for (int i = 0; i < a; i++) {
				rgbS = "0"+rgbS;
			}
		}
		for (int i = 0; i < rgbS.length(); i++) {
			System.out.println("i的值是"+i);
			rgbS.substring(i,i+3);
			if(i==0){
				r = Integer.parseInt(rgbS.substring(0,3));
			}
			if(i==3){
				g = Integer.parseInt(rgbS.substring(3,6));
			}
			if(i==6){
				b = Integer.parseInt(rgbS.substring(6,9));
			}
			//System.out.println("分割的值是："+rgbS.substring(i,i+3));
			i = i+2;
		}*/

        if (r == 0 && g >= 0 && g <= 255 && b == 255)        //r:0	    g:255-0    b:255	 //浅蓝-深蓝    	1-256
        {
            actualColor = g + 1;

        } else if (r == 0 && g == 255 && b >= 0 && b <= 255)    //r:0	    g:255      b:0-255	 //绿-浅蓝   		257-512
        {
            actualColor = 255 - b;                        //镜象翻转处理
            actualColor += 257;

        } else if (r >= 0 && r <= 255 && g == 255 && b == 0)    //r:255-0	g:255      b:0	 //黄-绿				513-768
        {
            actualColor = r + 513;

        } else if (r == 255 && g >= 0 && g <= 255 && b == 0)    //r:255     g:0-255    b:0	 //红-黄				769-1024
        {
            actualColor = 255 - g;                        //镜象翻转处理
            actualColor += 769;
        } else {
            System.out.println("r是"+r+"g是"+g+"b是"+b);
        	 System.out.println("2222222222222222");
            return 0;
        }

        interval = highest - lowest;    //求温度取值区间
		/*originalRatio = actualColor/colorInterval;		//温度取值比率，保留1位小数四舍五入

		temperature = originalRatio*interval;			//温度取值，保留整数四舍五入
		temperature += lowest;*/
        BigDecimal actualColorBig = new BigDecimal(actualColor);
        BigDecimal colorIntervalBig = new BigDecimal(colorInterval);
        originalRatio = actualColorBig.divide(colorIntervalBig).setScale(2, BigDecimal.ROUND_HALF_UP).doubleValue();
        temperature = originalRatio * interval;            //温度取值，保留整数四舍五入
        temperature = temperature + lowest;

        return temperature;
    }


}
