/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.station.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.intelligentManagement.modular.station.entity.TStation;
import com.unis.intelligentManagement.modular.station.mapper.TStationMapper;
import com.unis.intelligentManagement.modular.station.param.TStationAddParam;
import com.unis.intelligentManagement.modular.station.param.TStationEditParam;
import com.unis.intelligentManagement.modular.station.param.TStationIdParam;
import com.unis.intelligentManagement.modular.station.param.TStationPageParam;
import com.unis.intelligentManagement.modular.station.service.TStationService;

import java.util.List;

/**
 * 通信设置Service接口实现类
 *
 * @author shine
 * @date  2024/06/11 20:53
 **/
@Service
public class TStationServiceImpl extends ServiceImpl<TStationMapper, TStation> implements TStationService {

    @Override
    public Page<TStation> page(TStationPageParam tStationPageParam) {
        QueryWrapper<TStation> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(tStationPageParam.getOrgId())) {
            queryWrapper.lambda().eq(TStation::getOrgId, tStationPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(tStationPageParam.getSitecode())) {
            queryWrapper.lambda().eq(TStation::getSitecode, tStationPageParam.getSitecode());
        }
        if(ObjectUtil.isAllNotEmpty(tStationPageParam.getSortField(), tStationPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(tStationPageParam.getSortOrder());
            queryWrapper.orderBy(true, tStationPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(tStationPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(TStation::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(TStationAddParam tStationAddParam) {
        TStation tStation = BeanUtil.toBean(tStationAddParam, TStation.class);
        this.save(tStation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(TStationEditParam tStationEditParam) {
        TStation tStation = this.queryEntity(tStationEditParam.getId());
        BeanUtil.copyProperties(tStationEditParam, tStation);
        this.updateById(tStation);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<TStationIdParam> tStationIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(tStationIdParamList, TStationIdParam::getId));
    }

    @Override
    public TStation detail(TStationIdParam tStationIdParam) {
        return this.queryEntity(tStationIdParam.getId());
    }

    @Override
    public TStation queryEntity(String id) {
        TStation tStation = this.getById(id);
        if(ObjectUtil.isEmpty(tStation)) {
            throw new CommonException("通信设置不存在，id值为：{}", id);
        }
        return tStation;
    }
}
