/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.intelligentManagement.modular.tLqData.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 多功能粮情-主表编辑参数
 *
 * @author hjc
 * @date  2024/06/07 10:18
 **/
@Getter
@Setter
public class TLqDataEditParam {

    /** 32位主键id */
    @ApiModelProperty(value = "32位主键id", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 机构id */
    @ApiModelProperty(value = "机构id", position = 2)
    private String orgId;

    /** 机构编码 */
    @ApiModelProperty(value = "机构编码", position = 3)
    private String orgCode;

    /** 机构名称 */
    @ApiModelProperty(value = "机构名称", position = 4)
    private String orgName;

    /** 仓房国标编码 */
    @ApiModelProperty(value = "仓房国标编码", position = 5)
    private String storehouseCode;

    /** 仓房名称 */
    @ApiModelProperty(value = "仓房名称", position = 6)
    private String storehouseName;

    /** 仓厫编码 */
    @ApiModelProperty(value = "仓厫编码", position = 7)
    private String house;

    /** 库存数量 */
    @ApiModelProperty(value = "库存数量", position = 8)
    private String kcsl;

    /** 粮食品种名称 */
    @ApiModelProperty(value = "粮食品种名称", position = 9)
    private String foodVarietyName;

    /** 粮食性质 */
    @ApiModelProperty(value = "粮食性质", position = 10)
    private String foodNature;

    /** 采集时间 */
    @ApiModelProperty(value = "采集时间", position = 11)
    private Date gatherTime;

    /** 仓内温 单位：摄氏度，精确到小数点后1位； */
    @ApiModelProperty(value = "仓内温 单位：摄氏度，精确到小数点后1位；", position = 12)
    private BigDecimal inTemp;

    /** 仓内湿 单位：%，精确到小数点后1位； */
    @ApiModelProperty(value = "仓内湿 单位：%，精确到小数点后1位；", position = 13)
    private BigDecimal inH;

    /** 仓外温 单位：摄氏度，精确到小数点后1位； */
    @ApiModelProperty(value = "仓外温 单位：摄氏度，精确到小数点后1位；", position = 14)
    private BigDecimal outTemp;

    /** 仓外湿 单位：%，精确到小数点后1位； */
    @ApiModelProperty(value = "仓外湿 单位：%，精确到小数点后1位；", position = 15)
    private BigDecimal outH;

    /** 最高粮温 */
    @ApiModelProperty(value = "最高粮温", position = 16)
    private BigDecimal tempMax;

    /** 最低粮温 */
    @ApiModelProperty(value = "最低粮温", position = 17)
    private BigDecimal tempMin;

    /** 平均粮温 */
    @ApiModelProperty(value = "平均粮温", position = 18)
    private BigDecimal tempAvg;

    /** 数据来源 */
    @ApiModelProperty(value = "数据来源", position = 19)
    private String dataSource;

    /** 0：粮情；1：油情；2：水分 */
    @ApiModelProperty(value = "0：粮情；1：油情；2：水分", position = 20)
    private String ilqYq;

    /** temp:温度值 单位：摄氏度；坏点值以250表示；精确到小数点后1位;测温点在仓内的X坐标代表长度 代表列;测温点在仓内的Y坐标宽度方向 代表行;测温点在仓内的Z坐标高度 */
    @ApiModelProperty(value = "temp:温度值 单位：摄氏度；坏点值以250表示；精确到小数点后1位;测温点在仓内的X坐标代表长度 代表列;测温点在仓内的Y坐标宽度方向 代表行;测温点在仓内的Z坐标高度", position = 21)
    private String tempPoints;

    /** 国家局格式化数据 */
    @ApiModelProperty(value = "国家局格式化数据", position = 22)
    private String strPoints;

    /** 同上次相比平均粮温 1：相同；2：上升；3：下降； */
    @ApiModelProperty(value = "同上次相比平均粮温 1：相同；2：上升；3：下降；", position = 23)
    private Integer compareLastTempAvg;

}
