/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesCase.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.lawEnforcementSupervision.modular.lesCase.entity.LesCaseCount;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesCase.entity.LesCase;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseAddParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseEditParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseIdParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCasePageParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.service.LesCaseService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 案件管理控制器
 *
 * @author QSHan
 * @date  2024/06/22 14:27
 */
@Api(tags = "案件管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class LesCaseController {

    @Resource
    private LesCaseService lesCaseService;

    /**
     * 获取案件管理分页
     *
     * @author QSHan
     * @date  2024/06/22 14:27
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取案件管理分页")
//    @SaCheckPermission("/lawEnforcementSupervision/lesCase/page")
    @GetMapping("/lawEnforcementSupervision/lesCase/page")
    public CommonResult<Page<LesCase>> page(LesCasePageParam lesCasePageParam) {
        return CommonResult.data(lesCaseService.page(lesCasePageParam));
    }

    /**
     * 添加案件管理
     *
     * @author QSHan
     * @date  2024/06/22 14:27
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加案件管理")
    @CommonLog("添加案件管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesCase/add")
    @PostMapping("/lawEnforcementSupervision/lesCase/add")
    public CommonResult<String> add(@RequestBody @Valid LesCaseAddParam lesCaseAddParam) {
        lesCaseService.add(lesCaseAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑案件管理
     *
     * @author QSHan
     * @date  2024/06/22 14:27
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑案件管理")
    @CommonLog("编辑案件管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesCase/edit")
    @PostMapping("/lawEnforcementSupervision/lesCase/edit")
    public CommonResult<String> edit(@RequestBody @Valid LesCaseEditParam lesCaseEditParam) {
        lesCaseService.edit(lesCaseEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除案件管理
     *
     * @author QSHan
     * @date  2024/06/22 14:27
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除案件管理")
    @CommonLog("删除案件管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesCase/delete")
    @PostMapping("/lawEnforcementSupervision/lesCase/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<LesCaseIdParam> lesCaseIdParamList) {
        lesCaseService.delete(lesCaseIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取案件管理详情
     *
     * @author QSHan
     * @date  2024/06/22 14:27
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取案件管理详情")
//    @SaCheckPermission("/lawEnforcementSupervision/lesCase/detail")
    @GetMapping("/lawEnforcementSupervision/lesCase/detail")
    public CommonResult<LesCase> detail(@Valid LesCaseIdParam lesCaseIdParam) {
        return CommonResult.data(lesCaseService.detail(lesCaseIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("获取承办人员")
    @GetMapping("/lawEnforcementSupervision/lesCase/getCaseHandler")
    public CommonResult<List<Map<String, Object>>> getCaseHandler() {
        return CommonResult.data(lesCaseService.getCaseHandler());
    }

    @ApiOperationSupport(order = 7)
    @ApiOperation("案件查询-统计")
    @GetMapping("/lawEnforcementSupervision/lesCase/getCaseCount")
    public CommonResult<LesCaseCount> getCaseCount() {
        return CommonResult.data(lesCaseService.getCaseCount());
    }
}
