/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesCase.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 案件管理编辑参数
 *
 * @author QSHan
 * @date  2024/06/22 14:27
 **/
@Getter
@Setter
public class LesCaseEditParam {

    /** 唯一标识 */
    @ApiModelProperty(value = "唯一标识", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 案件编号 */
    @ApiModelProperty(value = "案件编号", position = 6)
    private String caseNumber;

    /** 案件名称 */
    @ApiModelProperty(value = "案件名称", position = 7)
    private String caseName;

    /** 案件来源 1:12325热线转办 2:举报 3:检查发现 4:线索转移 5:其他 */
    @ApiModelProperty(value = "案件来源 1:12325热线转办 2:举报 3:检查发现 4:线索转移 5:其他", position = 8)
    private Integer caseSource;

    /** 涉案对象类型 1:企业 2:个人 */
    @ApiModelProperty(value = "涉案对象类型 1:企业 2:个人", position = 9)
    private Integer caseSubjectType;

    /** 涉案对象，可填多人，逗号分割 */
    @ApiModelProperty(value = "涉案对象，可填多人，逗号分割", position = 10)
    private String caseSubjects;

    /** 身份证号，可填多人，逗号分割 */
    @ApiModelProperty(value = "身份证号，可填多人，逗号分割", position = 11)
    private String idCardNumbers;

    /** 统一社会信用代码 */
    @ApiModelProperty(value = "统一社会信用代码", position = 12)
    private String uniformSocialCreditCode;

    /** 涉案粮食性质 1:省级储备粮 2:市级储备粮 3:县级储备粮 4:商品粮 */
    @ApiModelProperty(value = "涉案粮食性质 1:省级储备粮 2:市级储备粮 3:县级储备粮 4:商品粮", position = 13)
    private Integer caseGrainNature;

    /** 涉案粮食种类；外库depot_qh.basic_enum的id； */
    @ApiModelProperty(value = "涉案粮食种类；外库depot_qh.basic_enum的id；", position = 14)
    private Integer grainVarietyId;

    /** 承办人员；biz_les_person的ID； */
    @ApiModelProperty(value = "承办人员；biz_les_person的ID；", position = 15)
    private String caseHandlerId;

    /** 案件日期 */
    @ApiModelProperty(value = "案件日期", position = 16)
    private Date caseDate;

    /** 核查进展情况 1:查处中 2:已完成 */
    @ApiModelProperty(value = "核查进展情况 1:查处中 2:已完成", position = 17)
    private Integer verificationProgress;

    /** 案情描述 */
    @ApiModelProperty(value = "案情描述", position = 18)
    private String caseDescription;

    /** 处罚依据 */
    @ApiModelProperty(value = "处罚依据", position = 19)
    private String punishmentBasis;

    /** 处罚内容 */
    @ApiModelProperty(value = "处罚内容", position = 20)
    private String punishmentContent;

    /** 现场证据采集，图片URL，多个用“,”分隔； */
    @ApiModelProperty(value = "现场证据采集，图片URL，多个用“,”分隔；", position = 21)
    private String evidenceCollection;

    /** 状态 1:保存 2:结案 */
    @ApiModelProperty(value = "状态 1:保存 2:结案", position = 22)
    private Integer status;

}
