/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesCase.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.util.DateUtil;
import com.unis.common.util.OrderNumberUtil;
import com.unis.lawEnforcementSupervision.modular.lesCase.entity.LesCaseCount;
import com.unis.lawEnforcementSupervision.modular.lesCase.entity.OverCurrentYearMonth;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesCase.entity.LesCase;
import com.unis.lawEnforcementSupervision.modular.lesCase.mapper.LesCaseMapper;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseAddParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseEditParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCaseIdParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.param.LesCasePageParam;
import com.unis.lawEnforcementSupervision.modular.lesCase.service.LesCaseService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 案件管理Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/22 14:27
 **/
@Service
public class LesCaseServiceImpl extends ServiceImpl<LesCaseMapper, LesCase> implements LesCaseService {
    @Resource
    private LesCaseMapper lesCaseMapper;

    @Override
    public Page<LesCase> page(LesCasePageParam lesCasePageParam) {
        QueryWrapper<LesCase> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(lesCasePageParam.getCaseName())) {
            queryWrapper.lambda().like(LesCase::getCaseName, lesCasePageParam.getCaseName());
        }
        if (ObjectUtils.isNotEmpty(lesCasePageParam.getCaseSource())) {
            queryWrapper.lambda().like(LesCase::getCaseSource, lesCasePageParam.getCaseSource());
        }
        if (StringUtils.isNotEmpty(lesCasePageParam.getStartCaseDate()) && StringUtils.isNotEmpty(lesCasePageParam.getEndCaseDate())) {
            queryWrapper.lambda().between(LesCase::getCaseDate, lesCasePageParam.getStartCaseDate() + DateUtil.startTime, lesCasePageParam.getEndCaseDate() + DateUtil.endTime);
        }
        if (ObjectUtil.isAllNotEmpty(lesCasePageParam.getSortField(), lesCasePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesCasePageParam.getSortOrder());
            queryWrapper.orderBy(true, lesCasePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesCasePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(LesCase::getId);
        }
        return lesCaseMapper.pageList(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesCaseAddParam lesCaseAddParam) {
        LesCase lesCase = BeanUtil.toBean(lesCaseAddParam, LesCase.class);
        // 查询案件编号
        String caseNumber = lesCaseMapper.selectNumber();
        // 生成需要 AJXXSJG + 20230306 + 002
        lesCase.setCaseNumber(OrderNumberUtil.initNum("AJXXSJG", 3, caseNumber));
        this.save(lesCase);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesCaseEditParam lesCaseEditParam) {
        LesCase lesCase = this.queryEntity(lesCaseEditParam.getId());
        BeanUtil.copyProperties(lesCaseEditParam, lesCase);
        this.updateById(lesCase);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesCaseIdParam> lesCaseIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesCaseIdParamList, LesCaseIdParam::getId));
    }

    @Override
    public LesCase detail(LesCaseIdParam lesCaseIdParam) {
        return lesCaseMapper.queryEntity(lesCaseIdParam.getId());
    }

    @Override
    public LesCase queryEntity(String id) {
        LesCase lesCase = this.getById(id);
        if (ObjectUtil.isEmpty(lesCase)) {
            throw new CommonException("案件管理不存在，id值为：{}", id);
        }
        return lesCase;
    }

    @Override
    public List<Map<String, Object>> getCaseHandler() {
        return lesCaseMapper.getCaseHandler();
    }

    @Override
    public LesCaseCount getCaseCount() {
        LesCaseCount lesCaseCount = lesCaseMapper.getCaseCount();
        List<OverCurrentYearMonth> overList_1 = lesCaseMapper.selectCurrentYearMonth_1();
        if (CollectionUtils.isNotEmpty(overList_1)) {
            lesCaseCount.setOverList_1(overList_1);
        }
        List<OverCurrentYearMonth> overList_2 = lesCaseMapper.selectCurrentYearMonth_2();
        if (CollectionUtils.isNotEmpty(overList_2)) {
            lesCaseCount.setOverList_2(overList_2);
        }
        return lesCaseCount;
    }
}
