/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionContent.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.util.DateUtil;
import com.unis.common.util.OrderNumberUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.entity.LesInspectionContent;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.mapper.LesInspectionContentMapper;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.param.LesInspectionContentAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.param.LesInspectionContentEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.param.LesInspectionContentIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.param.LesInspectionContentPageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionContent.service.LesInspectionContentService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 专项检查-检查内容Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/25 10:49
 **/
@Service
public class LesInspectionContentServiceImpl extends ServiceImpl<LesInspectionContentMapper, LesInspectionContent> implements LesInspectionContentService {
    @Resource
    private LesInspectionContentMapper lesInspectionContentMapper;

    @Override
    public Page<LesInspectionContent> page(LesInspectionContentPageParam lesInspectionContentPageParam) {
        QueryWrapper<LesInspectionContent> queryWrapper = new QueryWrapper<>();
        // 检查名称(内容名称)
        String contentName = lesInspectionContentPageParam.getContentName();
        if (StringUtils.isNotEmpty(contentName)) {
            queryWrapper.lambda().like(LesInspectionContent::getContentName, contentName);
        }
        // 查询创建时间范围
        String startCreateTime = lesInspectionContentPageParam.getStartCreateTime();
        String endCreateTime = lesInspectionContentPageParam.getEndCreateTime();
        if (StringUtils.isNotEmpty(startCreateTime) && StringUtils.isNotEmpty(endCreateTime)) {
            queryWrapper.lambda().between(LesInspectionContent::getCreateTime, startCreateTime + DateUtil.startTime, endCreateTime + DateUtil.endTime);
        }
        if (ObjectUtil.isAllNotEmpty(lesInspectionContentPageParam.getSortField(), lesInspectionContentPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesInspectionContentPageParam.getSortOrder());
            queryWrapper.orderBy(true, lesInspectionContentPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesInspectionContentPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(LesInspectionContent::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesInspectionContentAddParam lesInspectionContentAddParam) {
        LesInspectionContent lesInspectionContent = BeanUtil.toBean(lesInspectionContentAddParam, LesInspectionContent.class);
        // 查询内容编号
        String contentNumber = lesInspectionContentMapper.selectLastContentNumber();
        // 内容编号:JCNR+年月日+3位顺序号
        lesInspectionContent.setContentNumber(OrderNumberUtil.initNum("JCNR", 3, contentNumber));
        this.save(lesInspectionContent);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesInspectionContentEditParam lesInspectionContentEditParam) {
        LesInspectionContent lesInspectionContent = this.queryEntity(lesInspectionContentEditParam.getId());
        BeanUtil.copyProperties(lesInspectionContentEditParam, lesInspectionContent);
        this.updateById(lesInspectionContent);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesInspectionContentIdParam> lesInspectionContentIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesInspectionContentIdParamList, LesInspectionContentIdParam::getId));
    }

    @Override
    public LesInspectionContent detail(LesInspectionContentIdParam lesInspectionContentIdParam) {
        return this.queryEntity(lesInspectionContentIdParam.getId());
    }

    @Override
    public LesInspectionContent queryEntity(String id) {
        LesInspectionContent lesInspectionContent = this.getById(id);
        if (ObjectUtil.isEmpty(lesInspectionContent)) {
            throw new CommonException("专项检查-检查内容不存在，id值为：{}", id);
        }
        return lesInspectionContent;
    }
}
