/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.entity.LesInspectionResultCollect;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.param.LesInspectionResultCollectAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.param.LesInspectionResultCollectEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.param.LesInspectionResultCollectIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.param.LesInspectionResultCollectPageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollect.service.LesInspectionResultCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 专项检查-检查结果采集汇总控制器
 *
 * @author QSHan
 * @date  2024/06/25 14:29
 */
@Api(tags = "专项检查-检查结果采集汇总控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class LesInspectionResultCollectController {

    @Resource
    private LesInspectionResultCollectService lesInspectionResultCollectService;

    /**
     * 获取专项检查-检查结果采集汇总分页
     *
     * @author QSHan
     * @date  2024/06/25 14:29
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取专项检查-检查结果采集汇总分页")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionResultCollect/page")
    @GetMapping("/lawEnforcementSupervision/lesInspectionResultCollect/page")
    public CommonResult<Page<LesInspectionResultCollect>> page(LesInspectionResultCollectPageParam lesInspectionResultCollectPageParam) {
        return CommonResult.data(lesInspectionResultCollectService.page(lesInspectionResultCollectPageParam));
    }

    /**
     * 添加专项检查-检查结果采集汇总
     *
     * @author QSHan
     * @date  2024/06/25 14:29
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加专项检查-检查结果采集汇总")
    @CommonLog("添加专项检查-检查结果采集汇总")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionResultCollect/add")
    @PostMapping("/lawEnforcementSupervision/lesInspectionResultCollect/add")
    public CommonResult<String> add(@RequestBody @Valid LesInspectionResultCollectAddParam lesInspectionResultCollectAddParam) {
        lesInspectionResultCollectService.add(lesInspectionResultCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑专项检查-检查结果采集汇总
     *
     * @author QSHan
     * @date  2024/06/25 14:29
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑专项检查-检查结果采集汇总")
    @CommonLog("编辑专项检查-检查结果采集汇总")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionResultCollect/edit")
    @PostMapping("/lawEnforcementSupervision/lesInspectionResultCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid LesInspectionResultCollectEditParam lesInspectionResultCollectEditParam) {
        lesInspectionResultCollectService.edit(lesInspectionResultCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除专项检查-检查结果采集汇总
     *
     * @author QSHan
     * @date  2024/06/25 14:29
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除专项检查-检查结果采集汇总")
    @CommonLog("删除专项检查-检查结果采集汇总")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionResultCollect/delete")
    @PostMapping("/lawEnforcementSupervision/lesInspectionResultCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<LesInspectionResultCollectIdParam> lesInspectionResultCollectIdParamList) {
        lesInspectionResultCollectService.delete(lesInspectionResultCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取专项检查-检查结果采集汇总详情
     *
     * @author QSHan
     * @date  2024/06/25 14:29
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取专项检查-检查结果采集汇总详情")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionResultCollect/detail")
    @GetMapping("/lawEnforcementSupervision/lesInspectionResultCollect/detail")
    public CommonResult<LesInspectionResultCollect> detail(@Valid LesInspectionResultCollectIdParam lesInspectionResultCollectIdParam) {
        return CommonResult.data(lesInspectionResultCollectService.detail(lesInspectionResultCollectIdParam));
    }
}
