/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.entity.LesInspectionResultCollectItem;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.mapper.LesInspectionResultCollectItemMapper;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.param.LesInspectionResultCollectItemAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.param.LesInspectionResultCollectItemEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.param.LesInspectionResultCollectItemIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.param.LesInspectionResultCollectItemPageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionResultCollectItem.service.LesInspectionResultCollectItemService;

import java.util.List;

/**
 * 专项检查-检查结果采集汇总-检查清单Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/25 14:39
 **/
@Service
public class LesInspectionResultCollectItemServiceImpl extends ServiceImpl<LesInspectionResultCollectItemMapper, LesInspectionResultCollectItem> implements LesInspectionResultCollectItemService {

    @Override
    public Page<LesInspectionResultCollectItem> page(LesInspectionResultCollectItemPageParam lesInspectionResultCollectItemPageParam) {
        QueryWrapper<LesInspectionResultCollectItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(lesInspectionResultCollectItemPageParam.getSortField(), lesInspectionResultCollectItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesInspectionResultCollectItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, lesInspectionResultCollectItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesInspectionResultCollectItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(LesInspectionResultCollectItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesInspectionResultCollectItemAddParam lesInspectionResultCollectItemAddParam) {
        LesInspectionResultCollectItem lesInspectionResultCollectItem = BeanUtil.toBean(lesInspectionResultCollectItemAddParam, LesInspectionResultCollectItem.class);
        this.save(lesInspectionResultCollectItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesInspectionResultCollectItemEditParam lesInspectionResultCollectItemEditParam) {
        LesInspectionResultCollectItem lesInspectionResultCollectItem = this.queryEntity(lesInspectionResultCollectItemEditParam.getId());
        BeanUtil.copyProperties(lesInspectionResultCollectItemEditParam, lesInspectionResultCollectItem);
        this.updateById(lesInspectionResultCollectItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesInspectionResultCollectItemIdParam> lesInspectionResultCollectItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesInspectionResultCollectItemIdParamList, LesInspectionResultCollectItemIdParam::getId));
    }

    @Override
    public LesInspectionResultCollectItem detail(LesInspectionResultCollectItemIdParam lesInspectionResultCollectItemIdParam) {
        return this.queryEntity(lesInspectionResultCollectItemIdParam.getId());
    }

    @Override
    public LesInspectionResultCollectItem queryEntity(String id) {
        LesInspectionResultCollectItem lesInspectionResultCollectItem = this.getById(id);
        if(ObjectUtil.isEmpty(lesInspectionResultCollectItem)) {
            throw new CommonException("专项检查-检查结果采集汇总-检查清单不存在，id值为：{}", id);
        }
        return lesInspectionResultCollectItem;
    }
}
