/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.entity.LesInspectionTemplate;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplatePageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.service.LesInspectionTemplateService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 联合检查-检查模版管理控制器
 *
 * @author QSHan
 * @date  2024/06/25 17:06
 */
@Api(tags = "联合检查-检查模版管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class LesInspectionTemplateController {

    @Resource
    private LesInspectionTemplateService lesInspectionTemplateService;

    /**
     * 获取联合检查-检查模版管理分页
     *
     * @author QSHan
     * @date  2024/06/25 17:06
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取联合检查-检查模版管理分页")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionTemplate/page")
    @GetMapping("/lawEnforcementSupervision/lesInspectionTemplate/page")
    public CommonResult<Page<LesInspectionTemplate>> page(LesInspectionTemplatePageParam lesInspectionTemplatePageParam) {
        return CommonResult.data(lesInspectionTemplateService.page(lesInspectionTemplatePageParam));
    }

    /**
     * 添加联合检查-检查模版管理
     *
     * @author QSHan
     * @date  2024/06/25 17:06
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加联合检查-检查模版管理")
    @CommonLog("添加联合检查-检查模版管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionTemplate/add")
    @PostMapping("/lawEnforcementSupervision/lesInspectionTemplate/add")
    public CommonResult<String> add(@RequestBody @Valid LesInspectionTemplateAddParam lesInspectionTemplateAddParam) {
        lesInspectionTemplateService.add(lesInspectionTemplateAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑联合检查-检查模版管理
     *
     * @author QSHan
     * @date  2024/06/25 17:06
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑联合检查-检查模版管理")
    @CommonLog("编辑联合检查-检查模版管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionTemplate/edit")
    @PostMapping("/lawEnforcementSupervision/lesInspectionTemplate/edit")
    public CommonResult<String> edit(@RequestBody @Valid LesInspectionTemplateEditParam lesInspectionTemplateEditParam) {
        lesInspectionTemplateService.edit(lesInspectionTemplateEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除联合检查-检查模版管理
     *
     * @author QSHan
     * @date  2024/06/25 17:06
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除联合检查-检查模版管理")
    @CommonLog("删除联合检查-检查模版管理")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionTemplate/delete")
    @PostMapping("/lawEnforcementSupervision/lesInspectionTemplate/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<LesInspectionTemplateIdParam> lesInspectionTemplateIdParamList) {
        lesInspectionTemplateService.delete(lesInspectionTemplateIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取联合检查-检查模版管理详情
     *
     * @author QSHan
     * @date  2024/06/25 17:06
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取联合检查-检查模版管理详情")
//    @SaCheckPermission("/lawEnforcementSupervision/lesInspectionTemplate/detail")
    @GetMapping("/lawEnforcementSupervision/lesInspectionTemplate/detail")
    public CommonResult<LesInspectionTemplate> detail(@Valid LesInspectionTemplateIdParam lesInspectionTemplateIdParam) {
        return CommonResult.data(lesInspectionTemplateService.detail(lesInspectionTemplateIdParam));
    }
}
