/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.ObjectUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.entity.LesInspectionTemplateItem;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.mapper.LesInspectionTemplateItemMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.entity.LesInspectionTemplate;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.mapper.LesInspectionTemplateMapper;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplateIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.param.LesInspectionTemplatePageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplate.service.LesInspectionTemplateService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 联合检查-检查模版管理Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/25 17:06
 **/
@Service
public class LesInspectionTemplateServiceImpl extends ServiceImpl<LesInspectionTemplateMapper, LesInspectionTemplate> implements LesInspectionTemplateService {
    @Resource
    private LesInspectionTemplateItemMapper lesInspectionTemplateItemMapper;

    @Override
    public Page<LesInspectionTemplate> page(LesInspectionTemplatePageParam lesInspectionTemplatePageParam) {
        QueryWrapper<LesInspectionTemplate> queryWrapper = new QueryWrapper<>();
        // 检查名称
        String inspectionName = lesInspectionTemplatePageParam.getInspectionName();
        if (StringUtils.isNotEmpty(inspectionName))
            queryWrapper.lambda().like(LesInspectionTemplate::getInspectionName, inspectionName);
        // 生效状态
        Integer effectiveStatus = lesInspectionTemplatePageParam.getEffectiveStatus();
        if (ObjectUtils.isNotEmpty(effectiveStatus))
            queryWrapper.lambda().eq(LesInspectionTemplate::getEffectiveStatus, effectiveStatus);
        if (ObjectUtil.isAllNotEmpty(lesInspectionTemplatePageParam.getSortField(), lesInspectionTemplatePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesInspectionTemplatePageParam.getSortOrder());
            queryWrapper.orderBy(true, lesInspectionTemplatePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesInspectionTemplatePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(LesInspectionTemplate::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesInspectionTemplateAddParam lesInspectionTemplateAddParam) {
        LesInspectionTemplate lesInspectionTemplate = BeanUtil.toBean(lesInspectionTemplateAddParam, LesInspectionTemplate.class);
        this.save(lesInspectionTemplate);
        // 保存子表数据
        this.insertChild(lesInspectionTemplate);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesInspectionTemplateEditParam lesInspectionTemplateEditParam) {
        LesInspectionTemplate lesInspectionTemplate = this.queryEntity(lesInspectionTemplateEditParam.getId());
        BeanUtil.copyProperties(lesInspectionTemplateEditParam, lesInspectionTemplate);
        this.updateById(lesInspectionTemplate);
        // 子表
        if (CollectionUtils.isNotEmpty(lesInspectionTemplate.getItems())) {
            // 先删除
            this.deleteChild(lesInspectionTemplate.getId());
            // 在新增
            this.insertChild(lesInspectionTemplate);
        }
    }

    // 保存子表关联数据
    private void insertChild(LesInspectionTemplate lesInspectionTemplate) {
        if (CollectionUtils.isNotEmpty(lesInspectionTemplate.getItems())) {
            lesInspectionTemplate.getItems().forEach(item -> {
                item.setLesInspectionTemplateId(lesInspectionTemplate.getId());
                lesInspectionTemplateItemMapper.insert(item);
            });
        }
    }

    // 删除子表关联数据
    private void deleteChild(String lesInspectionTemplateId) {
        QueryWrapper<LesInspectionTemplateItem> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(LesInspectionTemplateItem::getLesInspectionTemplateId, lesInspectionTemplateId);
        lesInspectionTemplateItemMapper.delete(wrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesInspectionTemplateIdParam> lesInspectionTemplateIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesInspectionTemplateIdParamList, LesInspectionTemplateIdParam::getId));
        // 删除子表关联数据
        lesInspectionTemplateIdParamList.forEach(ids -> this.deleteChild(ids.getId()));
    }

    @Override
    public LesInspectionTemplate detail(LesInspectionTemplateIdParam lesInspectionTemplateIdParam) {
        LesInspectionTemplate lesInspectionTemplate = this.queryEntity(lesInspectionTemplateIdParam.getId());
        // 查询子表数据集
        QueryWrapper<LesInspectionTemplateItem> wrapper = new QueryWrapper<>();
        wrapper.lambda().eq(LesInspectionTemplateItem::getLesInspectionTemplateId, lesInspectionTemplate.getId());
        List<LesInspectionTemplateItem> items = lesInspectionTemplateItemMapper.selectList(wrapper);
        if (CollectionUtils.isNotEmpty(items)) {
            lesInspectionTemplate.setItems(items);
        }
        return lesInspectionTemplate;
    }

    @Override
    public LesInspectionTemplate queryEntity(String id) {
        LesInspectionTemplate lesInspectionTemplate = this.getById(id);
        if (ObjectUtil.isEmpty(lesInspectionTemplate)) {
            throw new CommonException("联合检查-检查模版管理不存在，id值为：{}", id);
        }
        return lesInspectionTemplate;
    }
}
