/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.entity.LesInspectionTemplateItem;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.mapper.LesInspectionTemplateItemMapper;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.param.LesInspectionTemplateItemAddParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.param.LesInspectionTemplateItemEditParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.param.LesInspectionTemplateItemIdParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.param.LesInspectionTemplateItemPageParam;
import com.unis.lawEnforcementSupervision.modular.lesInspectionTemplateItem.service.LesInspectionTemplateItemService;

import java.util.List;

/**
 * 联合检查-检查模版管理-检查任务Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/25 17:09
 **/
@Service
public class LesInspectionTemplateItemServiceImpl extends ServiceImpl<LesInspectionTemplateItemMapper, LesInspectionTemplateItem> implements LesInspectionTemplateItemService {

    @Override
    public Page<LesInspectionTemplateItem> page(LesInspectionTemplateItemPageParam lesInspectionTemplateItemPageParam) {
        QueryWrapper<LesInspectionTemplateItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(lesInspectionTemplateItemPageParam.getSortField(), lesInspectionTemplateItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesInspectionTemplateItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, lesInspectionTemplateItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesInspectionTemplateItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(LesInspectionTemplateItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesInspectionTemplateItemAddParam lesInspectionTemplateItemAddParam) {
        LesInspectionTemplateItem lesInspectionTemplateItem = BeanUtil.toBean(lesInspectionTemplateItemAddParam, LesInspectionTemplateItem.class);
        this.save(lesInspectionTemplateItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesInspectionTemplateItemEditParam lesInspectionTemplateItemEditParam) {
        LesInspectionTemplateItem lesInspectionTemplateItem = this.queryEntity(lesInspectionTemplateItemEditParam.getId());
        BeanUtil.copyProperties(lesInspectionTemplateItemEditParam, lesInspectionTemplateItem);
        this.updateById(lesInspectionTemplateItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesInspectionTemplateItemIdParam> lesInspectionTemplateItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesInspectionTemplateItemIdParamList, LesInspectionTemplateItemIdParam::getId));
    }

    @Override
    public LesInspectionTemplateItem detail(LesInspectionTemplateItemIdParam lesInspectionTemplateItemIdParam) {
        return this.queryEntity(lesInspectionTemplateItemIdParam.getId());
    }

    @Override
    public LesInspectionTemplateItem queryEntity(String id) {
        LesInspectionTemplateItem lesInspectionTemplateItem = this.getById(id);
        if(ObjectUtil.isEmpty(lesInspectionTemplateItem)) {
            throw new CommonException("联合检查-检查模版管理-检查任务不存在，id值为：{}", id);
        }
        return lesInspectionTemplateItem;
    }
}
