/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.entity.LesJointInspectionTask;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.param.LesJointInspectionTaskAddParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.param.LesJointInspectionTaskEditParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.param.LesJointInspectionTaskIdParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.param.LesJointInspectionTaskPageParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTask.service.LesJointInspectionTaskService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 联合检查-联合检查任务控制器
 *
 * @author QSHan
 * @date  2024/06/25 17:13
 */
@Api(tags = "联合检查-联合检查任务控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class LesJointInspectionTaskController {

    @Resource
    private LesJointInspectionTaskService lesJointInspectionTaskService;

    /**
     * 获取联合检查-联合检查任务分页
     *
     * @author QSHan
     * @date  2024/06/25 17:13
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取联合检查-联合检查任务分页")
//    @SaCheckPermission("/lawEnforcementSupervision/lesJointInspectionTask/page")
    @GetMapping("/lawEnforcementSupervision/lesJointInspectionTask/page")
    public CommonResult<Page<LesJointInspectionTask>> page(LesJointInspectionTaskPageParam lesJointInspectionTaskPageParam) {
        return CommonResult.data(lesJointInspectionTaskService.page(lesJointInspectionTaskPageParam));
    }

    /**
     * 添加联合检查-联合检查任务
     *
     * @author QSHan
     * @date  2024/06/25 17:13
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加联合检查-联合检查任务")
    @CommonLog("添加联合检查-联合检查任务")
//    @SaCheckPermission("/lawEnforcementSupervision/lesJointInspectionTask/add")
    @PostMapping("/lawEnforcementSupervision/lesJointInspectionTask/add")
    public CommonResult<String> add(@RequestBody @Valid LesJointInspectionTaskAddParam lesJointInspectionTaskAddParam) {
        lesJointInspectionTaskService.add(lesJointInspectionTaskAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑联合检查-联合检查任务
     *
     * @author QSHan
     * @date  2024/06/25 17:13
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑联合检查-联合检查任务")
    @CommonLog("编辑联合检查-联合检查任务")
//    @SaCheckPermission("/lawEnforcementSupervision/lesJointInspectionTask/edit")
    @PostMapping("/lawEnforcementSupervision/lesJointInspectionTask/edit")
    public CommonResult<String> edit(@RequestBody @Valid LesJointInspectionTaskEditParam lesJointInspectionTaskEditParam) {
        lesJointInspectionTaskService.edit(lesJointInspectionTaskEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除联合检查-联合检查任务
     *
     * @author QSHan
     * @date  2024/06/25 17:13
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除联合检查-联合检查任务")
    @CommonLog("删除联合检查-联合检查任务")
//    @SaCheckPermission("/lawEnforcementSupervision/lesJointInspectionTask/delete")
    @PostMapping("/lawEnforcementSupervision/lesJointInspectionTask/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<LesJointInspectionTaskIdParam> lesJointInspectionTaskIdParamList) {
        lesJointInspectionTaskService.delete(lesJointInspectionTaskIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取联合检查-联合检查任务详情
     *
     * @author QSHan
     * @date  2024/06/25 17:13
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取联合检查-联合检查任务详情")
//    @SaCheckPermission("/lawEnforcementSupervision/lesJointInspectionTask/detail")
    @GetMapping("/lawEnforcementSupervision/lesJointInspectionTask/detail")
    public CommonResult<LesJointInspectionTask> detail(@Valid LesJointInspectionTaskIdParam lesJointInspectionTaskIdParam) {
        return CommonResult.data(lesJointInspectionTaskService.detail(lesJointInspectionTaskIdParam));
    }
}
