/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.entity.LesJointInspectionTaskItem;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.mapper.LesJointInspectionTaskItemMapper;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.param.LesJointInspectionTaskItemAddParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.param.LesJointInspectionTaskItemEditParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.param.LesJointInspectionTaskItemIdParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.param.LesJointInspectionTaskItemPageParam;
import com.unis.lawEnforcementSupervision.modular.lesJointInspectionTaskItem.service.LesJointInspectionTaskItemService;

import java.util.List;

/**
 * 联合检查任务-检查项Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/25 17:15
 **/
@Service
public class LesJointInspectionTaskItemServiceImpl extends ServiceImpl<LesJointInspectionTaskItemMapper, LesJointInspectionTaskItem> implements LesJointInspectionTaskItemService {

    @Override
    public Page<LesJointInspectionTaskItem> page(LesJointInspectionTaskItemPageParam lesJointInspectionTaskItemPageParam) {
        QueryWrapper<LesJointInspectionTaskItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(lesJointInspectionTaskItemPageParam.getSortField(), lesJointInspectionTaskItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(lesJointInspectionTaskItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, lesJointInspectionTaskItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(lesJointInspectionTaskItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(LesJointInspectionTaskItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(LesJointInspectionTaskItemAddParam lesJointInspectionTaskItemAddParam) {
        LesJointInspectionTaskItem lesJointInspectionTaskItem = BeanUtil.toBean(lesJointInspectionTaskItemAddParam, LesJointInspectionTaskItem.class);
        this.save(lesJointInspectionTaskItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(LesJointInspectionTaskItemEditParam lesJointInspectionTaskItemEditParam) {
        LesJointInspectionTaskItem lesJointInspectionTaskItem = this.queryEntity(lesJointInspectionTaskItemEditParam.getId());
        BeanUtil.copyProperties(lesJointInspectionTaskItemEditParam, lesJointInspectionTaskItem);
        this.updateById(lesJointInspectionTaskItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<LesJointInspectionTaskItemIdParam> lesJointInspectionTaskItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(lesJointInspectionTaskItemIdParamList, LesJointInspectionTaskItemIdParam::getId));
    }

    @Override
    public LesJointInspectionTaskItem detail(LesJointInspectionTaskItemIdParam lesJointInspectionTaskItemIdParam) {
        return this.queryEntity(lesJointInspectionTaskItemIdParam.getId());
    }

    @Override
    public LesJointInspectionTaskItem queryEntity(String id) {
        LesJointInspectionTaskItem lesJointInspectionTaskItem = this.getById(id);
        if(ObjectUtil.isEmpty(lesJointInspectionTaskItem)) {
            throw new CommonException("联合检查任务-检查项不存在，id值为：{}", id);
        }
        return lesJointInspectionTaskItem;
    }
}
