/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesagency.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesagency.entity.BizLesAgency;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyAddParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyEditParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyIdParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyPageParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.service.BizLesAgencyService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 执法监督-监督执法机构表控制器
 *
 * @author shine
 * @date  2024/06/22 11:56
 */
@Api(tags = "执法监督-监督执法机构表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesAgencyController {

    @Resource
    private BizLesAgencyService bizLesAgencyService;

    /**
     * 获取执法监督-监督执法机构表分页
     *
     * @author shine
     * @date  2024/06/22 11:56
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取执法监督-监督执法机构表分页")
    //@SaCheckPermission("/lawEnforcementSupervision/lesagency/page")
    @GetMapping("/lawEnforcementSupervision/lesagency/page")
    public CommonResult<Page<BizLesAgency>> page(BizLesAgencyPageParam bizLesAgencyPageParam) {
        return CommonResult.data(bizLesAgencyService.page(bizLesAgencyPageParam));
    }

    /**
     * 添加执法监督-监督执法机构表
     *
     * @author shine
     * @date  2024/06/22 11:56
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加执法监督-监督执法机构表")
    @CommonLog("添加执法监督-监督执法机构表")
    //@SaCheckPermission("/lawEnforcementSupervision/lesagency/add")
    @PostMapping("/lawEnforcementSupervision/lesagency/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesAgencyAddParam bizLesAgencyAddParam) {
        bizLesAgencyService.add(bizLesAgencyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-监督执法机构表
     *
     * @author shine
     * @date  2024/06/22 11:56
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑执法监督-监督执法机构表")
    @CommonLog("编辑执法监督-监督执法机构表")
   //@SaCheckPermission("/lawEnforcementSupervision/lesagency/edit")
    @PostMapping("/lawEnforcementSupervision/lesagency/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesAgencyEditParam bizLesAgencyEditParam) {
        bizLesAgencyService.edit(bizLesAgencyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-监督执法机构表
     *
     * @author shine
     * @date  2024/06/22 11:56
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除执法监督-监督执法机构表")
    @CommonLog("删除执法监督-监督执法机构表")
    //@SaCheckPermission("/lawEnforcementSupervision/lesagency/delete")
    @PostMapping("/lawEnforcementSupervision/lesagency/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesAgencyIdParam> bizLesAgencyIdParamList) {
        bizLesAgencyService.delete(bizLesAgencyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取执法监督-监督执法机构表详情
     *
     * @author shine
     * @date  2024/06/22 11:56
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取执法监督-监督执法机构表详情")
    //@SaCheckPermission("/lawEnforcementSupervision/lesagency/detail")
    @GetMapping("/lawEnforcementSupervision/lesagency/detail")
    public CommonResult<BizLesAgency> detail(@Valid BizLesAgencyIdParam bizLesAgencyIdParam) {
        return CommonResult.data(bizLesAgencyService.detail(bizLesAgencyIdParam));
    }


    /**
     * 所有监督执法机构数据
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("*获取执法监督-监督执法机构列表")
    @GetMapping("/lawEnforcementSupervision/lesagency/getList")
    public CommonResult<List<BizLesAgency>> getList() {
        return CommonResult.data(bizLesAgencyService.getList());
    }
}
