/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesagency.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesagency.entity.BizLesAgency;
import com.unis.lawEnforcementSupervision.modular.lesagency.mapper.BizLesAgencyMapper;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyAddParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyEditParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyIdParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.param.BizLesAgencyPageParam;
import com.unis.lawEnforcementSupervision.modular.lesagency.service.BizLesAgencyService;

import java.util.List;

/**
 * 执法监督-监督执法机构表Service接口实现类
 *
 * @author shine
 * @date  2024/06/22 11:56
 **/
@Service
public class BizLesAgencyServiceImpl extends ServiceImpl<BizLesAgencyMapper, BizLesAgency> implements BizLesAgencyService {

    @Override
    public Page<BizLesAgency> page(BizLesAgencyPageParam bizLesAgencyPageParam) {
        QueryWrapper<BizLesAgency> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesAgencyPageParam.getAgencyName())) {
            queryWrapper.lambda().like(BizLesAgency::getAgencyName, bizLesAgencyPageParam.getAgencyName());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesAgencyPageParam.getSortField(), bizLesAgencyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesAgencyPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesAgencyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesAgencyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesAgency::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesAgencyAddParam bizLesAgencyAddParam) {
        BizLesAgency bizLesAgency = BeanUtil.toBean(bizLesAgencyAddParam, BizLesAgency.class);
        this.save(bizLesAgency);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesAgencyEditParam bizLesAgencyEditParam) {
        BizLesAgency bizLesAgency = this.queryEntity(bizLesAgencyEditParam.getId());
        BeanUtil.copyProperties(bizLesAgencyEditParam, bizLesAgency);
        this.updateById(bizLesAgency);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesAgencyIdParam> bizLesAgencyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesAgencyIdParamList, BizLesAgencyIdParam::getId));
    }

    @Override
    public BizLesAgency detail(BizLesAgencyIdParam bizLesAgencyIdParam) {
        return this.queryEntity(bizLesAgencyIdParam.getId());
    }

    @Override
    public BizLesAgency queryEntity(String id) {
        BizLesAgency bizLesAgency = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesAgency)) {
            throw new CommonException("执法监督-监督执法机构表不存在，id值为：{}", id);
        }
        return bizLesAgency;
    }

    @Override
    public List<BizLesAgency> getList() {
        return this.list();
    }
}
