/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesbasis.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesbasis.entity.BizLesBasis;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisAddParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisEditParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisIdParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisPageParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.service.BizLesBasisService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 执法监督-执法依据控制器
 * @author shine
 * @date  2024/06/22 14:38
 */
@Api(tags = "执法监督-执法依据控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesBasisController {

    @Resource
    private BizLesBasisService bizLesBasisService;

    /**
     * 获取执法监督-执法依据分页
     *
     * @author shine
     * @date  2024/06/22 14:38
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取执法监督-执法依据分页")
    //@SaCheckPermission("/lawEnforcementSupervision/lesbasis/page")
    @GetMapping("/lawEnforcementSupervision/lesbasis/page")
    public CommonResult<Page<BizLesBasis>> page(BizLesBasisPageParam bizLesBasisPageParam) {
        return CommonResult.data(bizLesBasisService.page(bizLesBasisPageParam));
    }

    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取执法监督-执法依据分页")
    @GetMapping("/lawEnforcementSupervision/lesbasis/getPage")
    public CommonResult<IPage<List<Map<String,Object>>>> getPage(BizLesBasisPageParam bizLesBasisPageParam) {
        return CommonResult.data(bizLesBasisService.getPage(bizLesBasisPageParam));
    }

    /**
     * 添加执法监督-执法依据
     *
     * @author shine
     * @date  2024/06/22 14:38
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加执法监督-执法依据")
    /*@CommonLog("添加执法监督-执法依据")
    @SaCheckPermission("/lawEnforcementSupervision/lesbasis/add")*/
    @PostMapping("/lawEnforcementSupervision/lesbasis/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesBasisAddParam bizLesBasisAddParam) {
        bizLesBasisService.add(bizLesBasisAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-执法依据
     *
     * @author shine
     * @date  2024/06/22 14:38
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑执法监督-执法依据")
    /*@CommonLog("编辑执法监督-执法依据")
    @SaCheckPermission("/lawEnforcementSupervision/lesbasis/edit")*/
    @PostMapping("/lawEnforcementSupervision/lesbasis/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesBasisEditParam bizLesBasisEditParam) {
        bizLesBasisService.edit(bizLesBasisEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-执法依据
     *
     * @author shine
     * @date  2024/06/22 14:38
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除执法监督-执法依据")
    /*@CommonLog("删除执法监督-执法依据")
    @SaCheckPermission("/lawEnforcementSupervision/lesbasis/delete")*/
    @PostMapping("/lawEnforcementSupervision/lesbasis/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesBasisIdParam> bizLesBasisIdParamList) {
        bizLesBasisService.delete(bizLesBasisIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取执法监督-执法依据详情
     *
     * @author shine
     * @date  2024/06/22 14:38
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取执法监督-执法依据详情")
    //@SaCheckPermission("/lawEnforcementSupervision/lesbasis/detail")
    @GetMapping("/lawEnforcementSupervision/lesbasis/detail")
    public CommonResult<BizLesBasis> detail(@Valid BizLesBasisIdParam bizLesBasisIdParam) {
        return CommonResult.data(bizLesBasisService.detail(bizLesBasisIdParam));
    }
}
