/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesbasis.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesbasis.entity.BizLesBasis;
import com.unis.lawEnforcementSupervision.modular.lesbasis.mapper.BizLesBasisMapper;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisAddParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisEditParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisIdParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.param.BizLesBasisPageParam;
import com.unis.lawEnforcementSupervision.modular.lesbasis.service.BizLesBasisService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 执法监督-执法依据Service接口实现类
 *
 * @author shine
 * @date  2024/06/22 14:38
 **/
@Service
public class BizLesBasisServiceImpl extends ServiceImpl<BizLesBasisMapper, BizLesBasis> implements BizLesBasisService {

    @Resource
    private BizLesBasisMapper bizLesBasisMapper;

    @Override
    public Page<BizLesBasis> page(BizLesBasisPageParam bizLesBasisPageParam) {
        QueryWrapper<BizLesBasis> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesBasisPageParam.getBasisName())) {
            queryWrapper.lambda().like(BizLesBasis::getBasisName, bizLesBasisPageParam.getBasisName());
        }
        if(ObjectUtil.isNotEmpty(bizLesBasisPageParam.getRegulationType())) {
            queryWrapper.lambda().eq(BizLesBasis::getRegulationType, bizLesBasisPageParam.getRegulationType());
        }
        if(ObjectUtil.isNotEmpty(bizLesBasisPageParam.getDocument())) {
            queryWrapper.lambda().like(BizLesBasis::getDocument, bizLesBasisPageParam.getDocument());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesBasisPageParam.getSortField(), bizLesBasisPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesBasisPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesBasisPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesBasisPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesBasis::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesBasisAddParam bizLesBasisAddParam) {
        BizLesBasis bizLesBasis = BeanUtil.toBean(bizLesBasisAddParam, BizLesBasis.class);
        this.save(bizLesBasis);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesBasisEditParam bizLesBasisEditParam) {
        BizLesBasis bizLesBasis = this.queryEntity(bizLesBasisEditParam.getId());
        BeanUtil.copyProperties(bizLesBasisEditParam, bizLesBasis);
        this.updateById(bizLesBasis);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesBasisIdParam> bizLesBasisIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesBasisIdParamList, BizLesBasisIdParam::getId));
    }

    @Override
    public BizLesBasis detail(BizLesBasisIdParam bizLesBasisIdParam) {
        return this.queryEntity(bizLesBasisIdParam.getId());
    }

    @Override
    public BizLesBasis queryEntity(String id) {
        BizLesBasis bizLesBasis = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesBasis)) {
            throw new CommonException("执法监督-执法依据不存在，id值为：{}", id);
        }
        return bizLesBasis;
    }

    @Override
    public IPage<List<Map<String,Object>>> getPage(BizLesBasisPageParam bizLesBasisPageParam) {
        return bizLesBasisMapper.getPage(new Page<>(bizLesBasisPageParam.getCurrent(), bizLesBasisPageParam.getSize()), bizLesBasisPageParam);

    }
}
