/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesflow.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.entity.BizLesFlowLink;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.param.BizLesFlowLinkIdParam;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.service.BizLesFlowLinkService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesflow.entity.BizLesFlow;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowAddParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowEditParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowIdParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowPageParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.service.BizLesFlowService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.ArrayList;
import java.util.List;

/**
 * 执法监督-执法流程管理-流程管理控制器
 *
 * @author shine
 * @date  2024/06/22 17:26
 */
@Api(tags = "执法监督-执法流程管理-流程管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesFlowController {

    @Resource
    private BizLesFlowLinkService bizLesFlowLinkService;

    @Resource
    private BizLesFlowService bizLesFlowService;

    /**
     * 获取执法监督-执法流程管理-流程管理分页
     * @author shine
     * @date  2024/06/22 17:26
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取执法监督-执法流程管理-流程管理分页")
    //@SaCheckPermission("/lawEnforcementSupervision/lesflow/page")
    @GetMapping("/lawEnforcementSupervision/lesflow/page")
    public CommonResult<Page<BizLesFlow>> page(BizLesFlowPageParam bizLesFlowPageParam) {
        return CommonResult.data(bizLesFlowService.page(bizLesFlowPageParam));
    }

    /**
     * 添加执法监督-执法流程管理-流程管理
     *
     * @author shine
     * @date  2024/06/22 17:26
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加执法监督-执法流程管理-流程管理")
    @PostMapping("/lawEnforcementSupervision/lesflow/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesFlowAddParam bizLesFlowAddParam) {
        bizLesFlowService.add(bizLesFlowAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-执法流程管理-流程管理
     *
     * @author shine
     * @date  2024/06/22 17:26
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑执法监督-执法流程管理-流程管理")
    @PostMapping("/lawEnforcementSupervision/lesflow/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesFlowEditParam bizLesFlowEditParam) {
        bizLesFlowService.edit(bizLesFlowEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-执法流程管理-流程管理
     *
     * @author shine
     * @date  2024/06/22 17:26
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除执法监督-执法流程管理-流程管理")
    @PostMapping("/lawEnforcementSupervision/lesflow/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesFlowIdParam> bizLesFlowIdParamList) {
        bizLesFlowService.delete(bizLesFlowIdParamList);
        /**
         * 删除子表
         */
        List<BizLesFlowLinkIdParam> BizLesFlowLinkIdParamList = new ArrayList<BizLesFlowLinkIdParam>();
        QueryWrapper<BizLesFlowLink> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("les_flow_id",bizLesFlowIdParamList.get(0).getId());
        List<BizLesFlowLink> zlist = bizLesFlowLinkService.list(queryWrapper);
        for(BizLesFlowLink bizLesFlowLink:zlist){
            BizLesFlowLinkIdParam bizLesFlowLinkIdParam = new BizLesFlowLinkIdParam();
            bizLesFlowLinkIdParam.setId(bizLesFlowLink.getId());
            BizLesFlowLinkIdParamList.add(bizLesFlowLinkIdParam);
            bizLesFlowLinkService.delete(BizLesFlowLinkIdParamList);
        }

        return CommonResult.ok();
    }

    /**
     * 获取执法监督-执法流程管理-流程管理详情
     *
     * @author shine
     * @date  2024/06/22 17:26
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取执法监督-执法流程管理-流程管理详情")
    @GetMapping("/lawEnforcementSupervision/lesflow/detail")
    public CommonResult<BizLesFlow> detail(@Valid BizLesFlowIdParam bizLesFlowIdParam) {
        BizLesFlow bizLesFlow = bizLesFlowService.detail(bizLesFlowIdParam);

        List<BizLesFlowLink> bizLesFlowLinkList = new ArrayList<BizLesFlowLink>();
        QueryWrapper<BizLesFlowLink> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("les_flow_id",bizLesFlowIdParam.getId());
        List<BizLesFlowLink> zlist = bizLesFlowLinkService.list(queryWrapper);
        bizLesFlow.setFlowLinkList(zlist);
        return CommonResult.data(bizLesFlow);
    }
}
