/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesflow.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.entity.BizLesFlowLink;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.service.impl.BizLesFlowLinkServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesflow.entity.BizLesFlow;
import com.unis.lawEnforcementSupervision.modular.lesflow.mapper.BizLesFlowMapper;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowAddParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowEditParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowIdParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.param.BizLesFlowPageParam;
import com.unis.lawEnforcementSupervision.modular.lesflow.service.BizLesFlowService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 执法监督-执法流程管理-流程管理Service接口实现类
 *
 * @author shine
 * @date  2024/06/22 17:26
 **/
@Service
public class BizLesFlowServiceImpl extends ServiceImpl<BizLesFlowMapper, BizLesFlow> implements BizLesFlowService {

    @Resource
    private BizLesFlowLinkServiceImpl bizLesFlowLinkServiceImpl;
    @Override
    public Page<BizLesFlow> page(BizLesFlowPageParam bizLesFlowPageParam) {
        QueryWrapper<BizLesFlow> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesFlowPageParam.getProcessName())) {
            queryWrapper.lambda().like(BizLesFlow::getProcessName, bizLesFlowPageParam.getProcessName());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesFlowPageParam.getSortField(), bizLesFlowPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesFlowPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesFlowPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesFlowPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesFlow::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesFlowAddParam bizLesFlowAddParam) {
        BizLesFlow bizLesFlow = BeanUtil.toBean(bizLesFlowAddParam, BizLesFlow.class);
        this.save(bizLesFlow);
        for(BizLesFlowLink bizLesFlowLink:bizLesFlow.getFlowLinkList()){
            bizLesFlowLink.setLesFlowId(bizLesFlow.getId());
            bizLesFlowLinkServiceImpl.save(bizLesFlowLink);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesFlowEditParam bizLesFlowEditParam) {
        BizLesFlow bizLesFlow = this.queryEntity(bizLesFlowEditParam.getId());
        BeanUtil.copyProperties(bizLesFlowEditParam, bizLesFlow);
        this.updateById(bizLesFlow);
        for(BizLesFlowLink bizLesFlowLink:bizLesFlow.getFlowLinkList()){
            bizLesFlowLinkServiceImpl.updateById(bizLesFlowLink);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesFlowIdParam> bizLesFlowIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesFlowIdParamList, BizLesFlowIdParam::getId));
    }

    @Override
    public BizLesFlow detail(BizLesFlowIdParam bizLesFlowIdParam) {
        return this.queryEntity(bizLesFlowIdParam.getId());
    }

    @Override
    public BizLesFlow queryEntity(String id) {
        BizLesFlow bizLesFlow = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesFlow)) {
            throw new CommonException("执法监督-执法流程管理-流程管理不存在，id值为：{}", id);
        }
        return bizLesFlow;
    }
}
