/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesflowlink.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.entity.BizLesFlowLink;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.mapper.BizLesFlowLinkMapper;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.param.BizLesFlowLinkAddParam;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.param.BizLesFlowLinkEditParam;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.param.BizLesFlowLinkIdParam;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.param.BizLesFlowLinkPageParam;
import com.unis.lawEnforcementSupervision.modular.lesflowlink.service.BizLesFlowLinkService;

import java.util.List;

/**
 * 执法监督-执法流程管理-流程管理-审批环节Service接口实现类
 *
 * @author shine
 * @date  2024/06/22 17:30
 **/
@Service
public class BizLesFlowLinkServiceImpl extends ServiceImpl<BizLesFlowLinkMapper, BizLesFlowLink> implements BizLesFlowLinkService {

    @Override
    public Page<BizLesFlowLink> page(BizLesFlowLinkPageParam bizLesFlowLinkPageParam) {
        QueryWrapper<BizLesFlowLink> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesFlowLinkPageParam.getLesFlowId())) {
            queryWrapper.lambda().eq(BizLesFlowLink::getLesFlowId, bizLesFlowLinkPageParam.getLesFlowId());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesFlowLinkPageParam.getSortField(), bizLesFlowLinkPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesFlowLinkPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesFlowLinkPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesFlowLinkPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesFlowLink::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesFlowLinkAddParam bizLesFlowLinkAddParam) {
        BizLesFlowLink bizLesFlowLink = BeanUtil.toBean(bizLesFlowLinkAddParam, BizLesFlowLink.class);
        this.save(bizLesFlowLink);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesFlowLinkEditParam bizLesFlowLinkEditParam) {
        BizLesFlowLink bizLesFlowLink = this.queryEntity(bizLesFlowLinkEditParam.getId());
        BeanUtil.copyProperties(bizLesFlowLinkEditParam, bizLesFlowLink);
        this.updateById(bizLesFlowLink);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesFlowLinkIdParam> bizLesFlowLinkIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesFlowLinkIdParamList, BizLesFlowLinkIdParam::getId));
    }

    @Override
    public BizLesFlowLink detail(BizLesFlowLinkIdParam bizLesFlowLinkIdParam) {
        return this.queryEntity(bizLesFlowLinkIdParam.getId());
    }

    @Override
    public BizLesFlowLink queryEntity(String id) {
        BizLesFlowLink bizLesFlowLink = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesFlowLink)) {
            throw new CommonException("执法监督-执法流程管理-流程管理-审批环节不存在，id值为：{}", id);
        }
        return bizLesFlowLink;
    }
}
