/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesperson.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesperson.entity.BizLesPerson;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonAddParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonEditParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonIdParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonPageParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.service.BizLesPersonService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 执法监督-监督执法人员表控制器
 *
 * @author shine
 * @date  2024/06/22 11:59
 */
@Api(tags = "执法监督-监督执法人员表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesPersonController {

    @Resource
    private BizLesPersonService bizLesPersonService;

    /**
     * 获取执法监督-监督执法人员表分页
     *
     * @author shine
     * @date  2024/06/22 11:59
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取执法监督-监督执法人员表分页")
    //@SaCheckPermission("/lawEnforcementSupervision/lesperson/page")
    @GetMapping("/lawEnforcementSupervision/lesperson/page")
    public CommonResult<Page<BizLesPerson>> page(BizLesPersonPageParam bizLesPersonPageParam) {
        return CommonResult.data(bizLesPersonService.page(bizLesPersonPageParam));
    }

    /**
     * 添加执法监督-监督执法人员表
     *
     * @author shine
     * @date  2024/06/22 11:59
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加执法监督-监督执法人员表")
    //@CommonLog("添加执法监督-监督执法人员表")
    //@SaCheckPermission("/lawEnforcementSupervision/lesperson/add")
    @PostMapping("/lawEnforcementSupervision/lesperson/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesPersonAddParam bizLesPersonAddParam) {
        bizLesPersonService.add(bizLesPersonAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-监督执法人员表
     *
     * @author shine
     * @date  2024/06/22 11:59
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑执法监督-监督执法人员表")
    //@CommonLog("编辑执法监督-监督执法人员表")
    //@SaCheckPermission("/lawEnforcementSupervision/lesperson/edit")
    @PostMapping("/lawEnforcementSupervision/lesperson/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesPersonEditParam bizLesPersonEditParam) {
        bizLesPersonService.edit(bizLesPersonEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-监督执法人员表
     *
     * @author shine
     * @date  2024/06/22 11:59
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除执法监督-监督执法人员表")
    //@CommonLog("删除执法监督-监督执法人员表")
    //@SaCheckPermission("/lawEnforcementSupervision/lesperson/delete")
    @PostMapping("/lawEnforcementSupervision/lesperson/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesPersonIdParam> bizLesPersonIdParamList) {
        bizLesPersonService.delete(bizLesPersonIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取执法监督-监督执法人员表详情
     *
     * @author shine
     * @date  2024/06/22 11:59
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取执法监督-监督执法人员表详情")
    @GetMapping("/lawEnforcementSupervision/lesperson/detail")
    public CommonResult<BizLesPerson> detail(@Valid BizLesPersonIdParam bizLesPersonIdParam) {
        return CommonResult.data(bizLesPersonService.detail(bizLesPersonIdParam));
    }
}
