/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesperson.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 执法监督-监督执法人员表编辑参数
 *
 * @author shine
 * @date  2024/06/22 11:59
 **/
@Getter
@Setter
public class BizLesPersonEditParam {

    /** 执法人员记录唯一标识符 */
    @ApiModelProperty(value = "执法人员记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 人员所属机构；biz_les_agency的ID； */
    @ApiModelProperty(value = "人员所属机构；biz_les_agency的ID；", position = 6)
    private String lesAgencyId;

    /** 姓名 */
    @ApiModelProperty(value = "姓名", position = 7)
    private String name;

    /** 性别 1：男；2：女；3：保密； */
    @ApiModelProperty(value = "性别 1：男；2：女；3：保密；", position = 8)
    private Integer gender;

    /** 联系方式 */
    @ApiModelProperty(value = "联系方式", position = 9)
    private String contactInformation;

    /** 身份证号 */
    @ApiModelProperty(value = "身份证号", position = 10)
    private String identityCardNumber;

    /** 民族；dev_dict的ID； */
    @ApiModelProperty(value = "民族；dev_dict的ID；", position = 11)
    private String ethnicity;

    /** 籍贯-省；dev_dict的ID； */
    @ApiModelProperty(value = "籍贯-省；dev_dict的ID；", position = 12)
    private String nativePlaceProvince;

    /** 电子邮箱 */
    @ApiModelProperty(value = "电子邮箱", position = 13)
    private String email;

    /** 执法证号 */
    @ApiModelProperty(value = "执法证号", position = 14)
    private String enforcementCertificateNumber;

    /** 执法岗位 */
    @ApiModelProperty(value = "执法岗位", position = 15)
    private String enforcementPost;

    /** 参加执法活动 */
    @ApiModelProperty(value = "参加执法活动", position = 16)
    private String participateInEnforcementActivities;

    /** 参加执法培训 */
    @ApiModelProperty(value = "参加执法培训", position = 17)
    private String participateInEnforcementTraining;

    /** 法规学习课时合计 */
    @ApiModelProperty(value = "法规学习课时合计", position = 18)
    private Integer legalStudyHoursTotal;

    /** 行政执法人员在线培训课时 */
    @ApiModelProperty(value = "行政执法人员在线培训课时", position = 19)
    private Integer administrativeLawEnforcementOnlineTrainingHours;

    /** 法宣在线课时 */
    @ApiModelProperty(value = "法宣在线课时", position = 20)
    private Integer lawPropagandaOnlineHours;

    /** 其他学习课时 */
    @ApiModelProperty(value = "其他学习课时", position = 21)
    private Integer otherStudyHours;

    /** 发证单位 */
    @ApiModelProperty(value = "发证单位", position = 22)
    private String issuingAuthority;

    /** 执法证书照片，图片URL */
    @ApiModelProperty(value = "执法证书照片，图片URL", position = 23)
    private String enforcementCertificatePhoto;

}
