/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesperson.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.lawEnforcementSupervision.modular.lesagency.entity.BizLesAgency;
import com.unis.lawEnforcementSupervision.modular.lesagency.service.impl.BizLesAgencyServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesperson.entity.BizLesPerson;
import com.unis.lawEnforcementSupervision.modular.lesperson.mapper.BizLesPersonMapper;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonAddParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonEditParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonIdParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.param.BizLesPersonPageParam;
import com.unis.lawEnforcementSupervision.modular.lesperson.service.BizLesPersonService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 执法监督-监督执法人员表Service接口实现类
 *
 * @author shine
 * @date  2024/06/22 11:59
 **/
@Service
public class BizLesPersonServiceImpl extends ServiceImpl<BizLesPersonMapper, BizLesPerson> implements BizLesPersonService {

    @Resource
    private BizLesAgencyServiceImpl bizLesAgencyServiceImpl;
    @Override
    public Page<BizLesPerson> page(BizLesPersonPageParam bizLesPersonPageParam) {
        QueryWrapper<BizLesPerson> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesPersonPageParam.getLesAgencyId())) {
            queryWrapper.lambda().like(BizLesPerson::getLesAgencyId, bizLesPersonPageParam.getLesAgencyId());
        }
        if(ObjectUtil.isNotEmpty(bizLesPersonPageParam.getName())) {
            queryWrapper.lambda().like(BizLesPerson::getName, bizLesPersonPageParam.getName());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesPersonPageParam.getSortField(), bizLesPersonPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesPersonPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesPersonPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesPersonPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesPerson::getId);
        }

        Page<BizLesPerson> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizLesPerson bizLesPerson:pageList.getRecords()){
            BizLesAgency bizLesAgency = bizLesAgencyServiceImpl.getById(bizLesPerson.getLesAgencyId());
            if(ObjectUtil.isNotNull(bizLesAgency)){
                bizLesPerson.setAgencyName(bizLesAgency.getAgencyName());
            }
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesPersonAddParam bizLesPersonAddParam) {
        BizLesPerson bizLesPerson = BeanUtil.toBean(bizLesPersonAddParam, BizLesPerson.class);
        this.save(bizLesPerson);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesPersonEditParam bizLesPersonEditParam) {
        BizLesPerson bizLesPerson = this.queryEntity(bizLesPersonEditParam.getId());
        BeanUtil.copyProperties(bizLesPersonEditParam, bizLesPerson);
        this.updateById(bizLesPerson);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesPersonIdParam> bizLesPersonIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesPersonIdParamList, BizLesPersonIdParam::getId));
    }

    @Override
    public BizLesPerson detail(BizLesPersonIdParam bizLesPersonIdParam) {
        return this.queryEntity(bizLesPersonIdParam.getId());
    }

    @Override
    public BizLesPerson queryEntity(String id) {
        BizLesPerson bizLesPerson = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesPerson)) {
            throw new CommonException("执法监督-监督执法人员表不存在，id值为：{}", id);
        }
        return bizLesPerson;
    }
}
