/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesprocess.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.entity.BizLesProcessLink;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkIdParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.service.BizLesProcessLinkService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesprocess.entity.BizLesProcess;
import com.unis.lawEnforcementSupervision.modular.lesprocess.param.BizLesProcessAddParam;
import com.unis.lawEnforcementSupervision.modular.lesprocess.param.BizLesProcessEditParam;
import com.unis.lawEnforcementSupervision.modular.lesprocess.param.BizLesProcessIdParam;
import com.unis.lawEnforcementSupervision.modular.lesprocess.param.BizLesProcessPageParam;
import com.unis.lawEnforcementSupervision.modular.lesprocess.service.BizLesProcessService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.ArrayList;
import java.util.List;

/**
 * 执法监督-执法流程管理-执法过程控制器
 *
 * @author shine
 * @date  2024/06/22 17:25
 */
@Api(tags = "执法监督-执法流程管理-执法过程控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesProcessController {

    @Resource
    private BizLesProcessService bizLesProcessService;

    @Resource
    private BizLesProcessLinkService bizLesProcessLinkService;

    /**
     * 获取执法监督-执法流程管理-执法过程分页
     *
     * @author shine
     * @date  2024/06/22 17:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取执法监督-执法流程管理-执法过程分页")
    //@SaCheckPermission("/lawEnforcementSupervision/lesprocess/page")
    @GetMapping("/lawEnforcementSupervision/lesprocess/page")
    public CommonResult<Page<BizLesProcess>> page(BizLesProcessPageParam bizLesProcessPageParam) {
        return CommonResult.data(bizLesProcessService.page(bizLesProcessPageParam));
    }

    /**
     * 添加执法监督-执法流程管理-执法过程
     *
     * @author shine
     * @date  2024/06/22 17:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加执法监督-执法流程管理-执法过程")
    @PostMapping("/lawEnforcementSupervision/lesprocess/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesProcessAddParam bizLesProcessAddParam) {
        bizLesProcessService.add(bizLesProcessAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-执法流程管理-执法过程
     *
     * @author shine
     * @date  2024/06/22 17:25
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑执法监督-执法流程管理-执法过程")
    @PostMapping("/lawEnforcementSupervision/lesprocess/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesProcessEditParam bizLesProcessEditParam) {
        bizLesProcessService.edit(bizLesProcessEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-执法流程管理-执法过程
     *
     * @author shine
     * @date  2024/06/22 17:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除执法监督-执法流程管理-执法过程")
    @PostMapping("/lawEnforcementSupervision/lesprocess/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesProcessIdParam> bizLesProcessIdParamList) {
        bizLesProcessService.delete(bizLesProcessIdParamList);

        /**
         * 删除子表
         */
        List<BizLesProcessLinkIdParam> bizLesProcessLinkIdParamList = new ArrayList<BizLesProcessLinkIdParam>();
        QueryWrapper<BizLesProcessLink> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("les_process_id",bizLesProcessIdParamList.get(0).getId());
        List<BizLesProcessLink> zlist = bizLesProcessLinkService.list(queryWrapper);
        for(BizLesProcessLink bizLesProcessLink:zlist){
            BizLesProcessLinkIdParam bizLesProcessLinkIdParam = new BizLesProcessLinkIdParam();
            bizLesProcessLinkIdParam.setId(bizLesProcessLink.getId());
            bizLesProcessLinkIdParamList.add(bizLesProcessLinkIdParam);
            bizLesProcessLinkService.delete(bizLesProcessLinkIdParamList);
        }
        return CommonResult.ok();
    }

    /**
     * 获取执法监督-执法流程管理-执法过程详情
     *
     * @author shine
     * @date  2024/06/22 17:25
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取执法监督-执法流程管理-执法过程详情")
    @GetMapping("/lawEnforcementSupervision/lesprocess/detail")
    public CommonResult<BizLesProcess> detail(@Valid BizLesProcessIdParam bizLesProcessIdParam) {
        BizLesProcess bizLesProcess = bizLesProcessService.detail(bizLesProcessIdParam);

        List<BizLesProcessLink> bizLesProcessLink = new ArrayList<BizLesProcessLink>();
        QueryWrapper<BizLesProcessLink> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("les_process_id",bizLesProcessIdParam.getId());
        List<BizLesProcessLink> zlist = bizLesProcessLinkService.list(queryWrapper);
        bizLesProcess.setProcessLinkList(zlist);
        return CommonResult.data(bizLesProcess);
    }
}
