/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesprocesslink.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.entity.BizLesProcessLink;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkAddParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkEditParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkIdParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkPageParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.service.BizLesProcessLinkService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 执法监督-执法流程管理-执法环节控制器
 *
 * @author shine
 * @date  2024/06/24 10:52
 */
@Api(tags = "执法监督-执法流程管理-执法环节控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizLesProcessLinkController {

    @Resource
    private BizLesProcessLinkService bizLesProcessLinkService;

    /**
     * 获取执法监督-执法流程管理-执法环节分页
     *
     * @author shine
     * @date  2024/06/24 10:52
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取执法监督-执法流程管理-执法环节分页")
    @SaCheckPermission("/lawEnforcementSupervision/lesprocesslink/page")
    @GetMapping("/lawEnforcementSupervision/lesprocesslink/page")
    public CommonResult<Page<BizLesProcessLink>> page(BizLesProcessLinkPageParam bizLesProcessLinkPageParam) {
        return CommonResult.data(bizLesProcessLinkService.page(bizLesProcessLinkPageParam));
    }

    /**
     * 添加执法监督-执法流程管理-执法环节
     *
     * @author shine
     * @date  2024/06/24 10:52
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加执法监督-执法流程管理-执法环节")
    @CommonLog("添加执法监督-执法流程管理-执法环节")
    @SaCheckPermission("/lawEnforcementSupervision/lesprocesslink/add")
    @PostMapping("/lawEnforcementSupervision/lesprocesslink/add")
    public CommonResult<String> add(@RequestBody @Valid BizLesProcessLinkAddParam bizLesProcessLinkAddParam) {
        bizLesProcessLinkService.add(bizLesProcessLinkAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑执法监督-执法流程管理-执法环节
     *
     * @author shine
     * @date  2024/06/24 10:52
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑执法监督-执法流程管理-执法环节")
    @CommonLog("编辑执法监督-执法流程管理-执法环节")
    @SaCheckPermission("/lawEnforcementSupervision/lesprocesslink/edit")
    @PostMapping("/lawEnforcementSupervision/lesprocesslink/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizLesProcessLinkEditParam bizLesProcessLinkEditParam) {
        bizLesProcessLinkService.edit(bizLesProcessLinkEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除执法监督-执法流程管理-执法环节
     *
     * @author shine
     * @date  2024/06/24 10:52
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除执法监督-执法流程管理-执法环节")
    @CommonLog("删除执法监督-执法流程管理-执法环节")
    @SaCheckPermission("/lawEnforcementSupervision/lesprocesslink/delete")
    @PostMapping("/lawEnforcementSupervision/lesprocesslink/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizLesProcessLinkIdParam> bizLesProcessLinkIdParamList) {
        bizLesProcessLinkService.delete(bizLesProcessLinkIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取执法监督-执法流程管理-执法环节详情
     *
     * @author shine
     * @date  2024/06/24 10:52
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取执法监督-执法流程管理-执法环节详情")
    @SaCheckPermission("/lawEnforcementSupervision/lesprocesslink/detail")
    @GetMapping("/lawEnforcementSupervision/lesprocesslink/detail")
    public CommonResult<BizLesProcessLink> detail(@Valid BizLesProcessLinkIdParam bizLesProcessLinkIdParam) {
        return CommonResult.data(bizLesProcessLinkService.detail(bizLesProcessLinkIdParam));
    }
}
