/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.lesprocesslink.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.entity.BizLesProcessLink;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.mapper.BizLesProcessLinkMapper;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkAddParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkEditParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkIdParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.param.BizLesProcessLinkPageParam;
import com.unis.lawEnforcementSupervision.modular.lesprocesslink.service.BizLesProcessLinkService;

import java.util.List;

/**
 * 执法监督-执法流程管理-执法环节Service接口实现类
 *
 * @author shine
 * @date  2024/06/24 10:52
 **/
@Service
public class BizLesProcessLinkServiceImpl extends ServiceImpl<BizLesProcessLinkMapper, BizLesProcessLink> implements BizLesProcessLinkService {

    @Override
    public Page<BizLesProcessLink> page(BizLesProcessLinkPageParam bizLesProcessLinkPageParam) {
        QueryWrapper<BizLesProcessLink> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizLesProcessLinkPageParam.getLesProcessId())) {
            queryWrapper.lambda().eq(BizLesProcessLink::getLesProcessId, bizLesProcessLinkPageParam.getLesProcessId());
        }
        if(ObjectUtil.isAllNotEmpty(bizLesProcessLinkPageParam.getSortField(), bizLesProcessLinkPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizLesProcessLinkPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizLesProcessLinkPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizLesProcessLinkPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizLesProcessLink::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizLesProcessLinkAddParam bizLesProcessLinkAddParam) {
        BizLesProcessLink bizLesProcessLink = BeanUtil.toBean(bizLesProcessLinkAddParam, BizLesProcessLink.class);
        this.save(bizLesProcessLink);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizLesProcessLinkEditParam bizLesProcessLinkEditParam) {
        BizLesProcessLink bizLesProcessLink = this.queryEntity(bizLesProcessLinkEditParam.getId());
        BeanUtil.copyProperties(bizLesProcessLinkEditParam, bizLesProcessLink);
        this.updateById(bizLesProcessLink);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizLesProcessLinkIdParam> bizLesProcessLinkIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizLesProcessLinkIdParamList, BizLesProcessLinkIdParam::getId));
    }

    @Override
    public BizLesProcessLink detail(BizLesProcessLinkIdParam bizLesProcessLinkIdParam) {
        return this.queryEntity(bizLesProcessLinkIdParam.getId());
    }

    @Override
    public BizLesProcessLink queryEntity(String id) {
        BizLesProcessLink bizLesProcessLink = this.getById(id);
        if(ObjectUtil.isEmpty(bizLesProcessLink)) {
            throw new CommonException("执法监督-执法流程管理-执法环节不存在，id值为：{}", id);
        }
        return bizLesProcessLink;
    }
}
