/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.entity.BizPgmsGrainCollectStrategy;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyAddParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyEditParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyIdParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyPageParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.service.BizPgmsGrainCollectStrategyService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 省级粮情监控系统-粮情采集策略配置控制器
 *
 * @author shine
 * @date  2024/06/24 15:13
 */
@Api(tags = "省级粮情监控系统-粮情采集策略配置控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizPgmsGrainCollectStrategyController {

    @Resource
    private BizPgmsGrainCollectStrategyService bizPgmsGrainCollectStrategyService;

    /**
     * 获取省级粮情监控系统-粮情采集策略配置分页
     *
     * @author shine
     * @date  2024/06/24 15:13
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取省级粮情监控系统-粮情采集策略配置分页")
    @GetMapping("/lawEnforcementSupervision/pgmsgraincollectstrategy/page")
    public CommonResult<Page<BizPgmsGrainCollectStrategy>> page(BizPgmsGrainCollectStrategyPageParam bizPgmsGrainCollectStrategyPageParam) {
        return CommonResult.data(bizPgmsGrainCollectStrategyService.page(bizPgmsGrainCollectStrategyPageParam));
    }

    /**
     * 添加省级粮情监控系统-粮情采集策略配置
     *
     * @author shine
     * @date  2024/06/24 15:13
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加省级粮情监控系统-粮情采集策略配置")
    @PostMapping("/lawEnforcementSupervision/pgmsgraincollectstrategy/add")
    public CommonResult<String> add(@RequestBody @Valid BizPgmsGrainCollectStrategyAddParam bizPgmsGrainCollectStrategyAddParam) {
        bizPgmsGrainCollectStrategyService.add(bizPgmsGrainCollectStrategyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑省级粮情监控系统-粮情采集策略配置
     * @author shine
     * @date  2024/06/24 15:13
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑省级粮情监控系统-粮情采集策略配置")
    @PostMapping("/lawEnforcementSupervision/pgmsgraincollectstrategy/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPgmsGrainCollectStrategyEditParam bizPgmsGrainCollectStrategyEditParam) {
        bizPgmsGrainCollectStrategyService.edit(bizPgmsGrainCollectStrategyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除省级粮情监控系统-粮情采集策略配置
     *
     * @author shine
     * @date  2024/06/24 15:13
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除省级粮情监控系统-粮情采集策略配置")
    @PostMapping("/lawEnforcementSupervision/pgmsgraincollectstrategy/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizPgmsGrainCollectStrategyIdParam> bizPgmsGrainCollectStrategyIdParamList) {
        bizPgmsGrainCollectStrategyService.delete(bizPgmsGrainCollectStrategyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取省级粮情监控系统-粮情采集策略配置详情
     *
     * @author shine
     * @date  2024/06/24 15:13
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取省级粮情监控系统-粮情采集策略配置详情")
    @GetMapping("/lawEnforcementSupervision/pgmsgraincollectstrategy/detail")
    public CommonResult<BizPgmsGrainCollectStrategy> detail(@Valid BizPgmsGrainCollectStrategyIdParam bizPgmsGrainCollectStrategyIdParam) {
        return CommonResult.data(bizPgmsGrainCollectStrategyService.detail(bizPgmsGrainCollectStrategyIdParam));
    }
}
