/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.entity.BizPgmsGrainCollectStrategy;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.mapper.BizPgmsGrainCollectStrategyMapper;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyAddParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyEditParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyIdParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.param.BizPgmsGrainCollectStrategyPageParam;
import com.unis.lawEnforcementSupervision.modular.pgmsgraincollectstrategy.service.BizPgmsGrainCollectStrategyService;

import java.util.List;

/**
 * 省级粮情监控系统-粮情采集策略配置Service接口实现类
 *
 * @author shine
 * @date  2024/06/24 15:13
 **/
@Service
public class BizPgmsGrainCollectStrategyServiceImpl extends ServiceImpl<BizPgmsGrainCollectStrategyMapper, BizPgmsGrainCollectStrategy> implements BizPgmsGrainCollectStrategyService {

    @Override
    public Page<BizPgmsGrainCollectStrategy> page(BizPgmsGrainCollectStrategyPageParam bizPgmsGrainCollectStrategyPageParam) {
        QueryWrapper<BizPgmsGrainCollectStrategy> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizPgmsGrainCollectStrategyPageParam.getWarehouseName())) {
            queryWrapper.lambda().like(BizPgmsGrainCollectStrategy::getWarehouseName, bizPgmsGrainCollectStrategyPageParam.getWarehouseName());
        }
        if(ObjectUtil.isAllNotEmpty(bizPgmsGrainCollectStrategyPageParam.getSortField(), bizPgmsGrainCollectStrategyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizPgmsGrainCollectStrategyPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizPgmsGrainCollectStrategyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizPgmsGrainCollectStrategyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizPgmsGrainCollectStrategy::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizPgmsGrainCollectStrategyAddParam bizPgmsGrainCollectStrategyAddParam) {
        BizPgmsGrainCollectStrategy bizPgmsGrainCollectStrategy = BeanUtil.toBean(bizPgmsGrainCollectStrategyAddParam, BizPgmsGrainCollectStrategy.class);
        this.save(bizPgmsGrainCollectStrategy);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizPgmsGrainCollectStrategyEditParam bizPgmsGrainCollectStrategyEditParam) {
        BizPgmsGrainCollectStrategy bizPgmsGrainCollectStrategy = this.queryEntity(bizPgmsGrainCollectStrategyEditParam.getId());
        BeanUtil.copyProperties(bizPgmsGrainCollectStrategyEditParam, bizPgmsGrainCollectStrategy);
        this.updateById(bizPgmsGrainCollectStrategy);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizPgmsGrainCollectStrategyIdParam> bizPgmsGrainCollectStrategyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizPgmsGrainCollectStrategyIdParamList, BizPgmsGrainCollectStrategyIdParam::getId));
    }

    @Override
    public BizPgmsGrainCollectStrategy detail(BizPgmsGrainCollectStrategyIdParam bizPgmsGrainCollectStrategyIdParam) {
        return this.queryEntity(bizPgmsGrainCollectStrategyIdParam.getId());
    }

    @Override
    public BizPgmsGrainCollectStrategy queryEntity(String id) {
        BizPgmsGrainCollectStrategy bizPgmsGrainCollectStrategy = this.getById(id);
        if(ObjectUtil.isEmpty(bizPgmsGrainCollectStrategy)) {
            throw new CommonException("省级粮情监控系统-粮情采集策略配置不存在，id值为：{}", id);
        }
        return bizPgmsGrainCollectStrategy;
    }
}
