/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.gsqCarQueue.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.mobileInfo.modular.gsqCarQueue.param.*;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterIdParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.mobileInfo.modular.gsqCarQueue.entity.GsqCarQueue;
import com.unis.mobileInfo.modular.gsqCarQueue.service.GsqCarQueueService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 售粮排队监测预警-车辆排队控制器
 *
 * @author QSHan
 * @date  2024/04/28 20:05
 */
@Api(tags = "售粮排队监测预警-车辆排队控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GsqCarQueueController {

    @Resource
    private GsqCarQueueService gsqCarQueueService;

    @ApiOperationSupport(order = 1)
    @ApiOperation("车辆动态监测,远程调度列表")
    @GetMapping("/client/c/mobileInfo/gsqCarQueue/getCarDynamicCheck")
    public CommonResult<GsqCarQueueParams> getCarDynamicCheck(GsqCarQueuePageParam param) {
        return CommonResult.data(gsqCarQueueService.getCarDynamicCheck(param));
    }
    // GsqReservationRegisterIdParam
    @ApiOperationSupport(order = 2)
    @ApiOperation("删除-车辆排队(入场)")
    @CommonLog("删除售粮排队监测预警-车辆排队(入场)")
    @PostMapping("/client/c/mobileInfo/gsqCarQueue/delete")
    public CommonResult<String> deleteAll(GsqReservationRegisterIdParam param) {
        gsqCarQueueService.deleteAll(param);
        return CommonResult.ok();
    }

    @ApiOperationSupport(order = 3)
    @ApiOperation("远程调度-更新-车辆排队(根据reservationRegisterId(主表id)改变排序)")
    @CommonLog("远程调度-更新-车辆排队")
    @PostMapping("/client/c/mobileInfo/gsqCarQueue/updateSort")
    public CommonResult<String> updateSort(@RequestBody List<GsqCarQueueEditParam> params) {
        gsqCarQueueService.updateSort(params);
        return CommonResult.ok();
    }
    /**
     * 获取售粮排队监测预警-车辆排队分页
     *
     * @author QSHan
     * @date  2024/04/28 20:05
     */
    /*@ApiOperationSupport(order = 1)
    @ApiOperation("获取售粮排队监测预警-车辆排队分页")
//    @SaCheckPermission("/mobileInfo/gsqCarQueue/page")
    @GetMapping("/mobileInfo/gsqCarQueue/page")
    public CommonResult<Page<GsqCarQueue>> page(GsqCarQueuePageParam gsqCarQueuePageParam) {
        return CommonResult.data(gsqCarQueueService.page(gsqCarQueuePageParam));
    }*/

    /**
     * 添加售粮排队监测预警-车辆排队
     *
     * @author QSHan
     * @date  2024/04/28 20:05
     */
    /*@ApiOperationSupport(order = 2)
    @ApiOperation("添加售粮排队监测预警-车辆排队")
    @CommonLog("添加售粮排队监测预警-车辆排队")
//    @SaCheckPermission("/mobileInfo/gsqCarQueue/add")
    @PostMapping("/mobileInfo/gsqCarQueue/add")
    public CommonResult<String> add(@RequestBody @Valid GsqCarQueueAddParam gsqCarQueueAddParam) {
        gsqCarQueueService.add(gsqCarQueueAddParam);
        return CommonResult.ok();
    }*/

    /**
     * 编辑售粮排队监测预警-车辆排队
     *
     * @author QSHan
     * @date  2024/04/28 20:05
     */
    /*@ApiOperationSupport(order = 3)
    @ApiOperation("编辑售粮排队监测预警-车辆排队")
    @CommonLog("编辑售粮排队监测预警-车辆排队")
//    @SaCheckPermission("/mobileInfo/gsqCarQueue/edit")
    @PostMapping("/mobileInfo/gsqCarQueue/edit")
    public CommonResult<String> edit(@RequestBody @Valid GsqCarQueueEditParam gsqCarQueueEditParam) {
        gsqCarQueueService.edit(gsqCarQueueEditParam);
        return CommonResult.ok();
    }*/

    /**
     * 删除售粮排队监测预警-车辆排队
     *
     * @author QSHan
     * @date  2024/04/28 20:05
     */
    /*@ApiOperationSupport(order = 4)
    @ApiOperation("删除售粮排队监测预警-车辆排队")
    @CommonLog("删除售粮排队监测预警-车辆排队")
//    @SaCheckPermission("/mobileInfo/gsqCarQueue/delete")
    @PostMapping("/mobileInfo/gsqCarQueue/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<GsqCarQueueIdParam> gsqCarQueueIdParamList) {
        gsqCarQueueService.delete(gsqCarQueueIdParamList);
        return CommonResult.ok();
    }*/

    /**
     * 获取售粮排队监测预警-车辆排队详情
     *
     * @author QSHan
     * @date  2024/04/28 20:05
     */
    /*@ApiOperationSupport(order = 5)
    @ApiOperation("获取售粮排队监测预警-车辆排队详情")
//    @SaCheckPermission("/mobileInfo/gsqCarQueue/detail")
    @GetMapping("/mobileInfo/gsqCarQueue/detail")
    public CommonResult<GsqCarQueue> detail(@Valid GsqCarQueueIdParam gsqCarQueueIdParam) {
        return CommonResult.data(gsqCarQueueService.detail(gsqCarQueueIdParam));
    }*/
}
