/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.gsqCarQueue.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.mobileInfo.modular.gsqCarQueue.param.*;
import com.unis.mobileInfo.modular.gsqReservationRegister.entity.GsqReservationRegister;
import com.unis.mobileInfo.modular.gsqReservationRegister.mapper.GsqReservationRegisterMapper;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterIdParam;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.exception.CommonException;
import com.unis.mobileInfo.modular.gsqCarQueue.entity.GsqCarQueue;
import com.unis.mobileInfo.modular.gsqCarQueue.mapper.GsqCarQueueMapper;
import com.unis.mobileInfo.modular.gsqCarQueue.service.GsqCarQueueService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 售粮排队监测预警-车辆排队Service接口实现类
 *
 * @author QSHan
 * @date 2024/04/28 20:05
 **/
@Service
public class GsqCarQueueServiceImpl extends ServiceImpl<GsqCarQueueMapper, GsqCarQueue> implements GsqCarQueueService {
    @Resource
    private GsqCarQueueMapper gsqCarQueueMapper;
    @Resource
    private GsqReservationRegisterMapper gsqReservationRegisterMapper;

    /*@Override
    public Page<GsqCarQueue> page(GsqCarQueuePageParam gsqCarQueuePageParam) {
        QueryWrapper<GsqCarQueue> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(gsqCarQueuePageParam.getSortField(), gsqCarQueuePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(gsqCarQueuePageParam.getSortOrder());
            queryWrapper.orderBy(true, gsqCarQueuePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(gsqCarQueuePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GsqCarQueue::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }*/
    @Override
    public Page<GsqCarQueue> page(GsqCarQueuePageParam gsqCarQueuePageParam) {
        return null;
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GsqCarQueueAddParam gsqCarQueueAddParam) {
        GsqCarQueue gsqCarQueue = BeanUtil.toBean(gsqCarQueueAddParam, GsqCarQueue.class);
        this.save(gsqCarQueue);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GsqCarQueueEditParam gsqCarQueueEditParam) {
        GsqCarQueue gsqCarQueue = this.queryEntity(gsqCarQueueEditParam.getId());
        BeanUtil.copyProperties(gsqCarQueueEditParam, gsqCarQueue);
        this.updateById(gsqCarQueue);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GsqCarQueueIdParam> gsqCarQueueIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(gsqCarQueueIdParamList, GsqCarQueueIdParam::getId));
    }

    @Override
    public GsqCarQueue detail(GsqCarQueueIdParam gsqCarQueueIdParam) {
        return this.queryEntity(gsqCarQueueIdParam.getId());
    }

    @Override
    public GsqCarQueue queryEntity(String id) {
        GsqCarQueue gsqCarQueue = this.getById(id);
        if (ObjectUtil.isEmpty(gsqCarQueue)) {
            throw new CommonException("售粮排队监测预警-车辆排队不存在，id值为：{}", id);
        }
        return gsqCarQueue;
    }

    @Override
    public List<GsqCarQueueEditParam> getSortList(Integer orgId) {
        return gsqCarQueueMapper.getSortList(orgId);
    }

    @Override
    public GsqCarQueueParams getCarDynamicCheck(GsqCarQueuePageParam param) {
        List<GsqReservationRegister> carDynamicCheck = gsqCarQueueMapper.getCarDynamicCheck(param.getOrgId());
        Integer carCount = carDynamicCheck.size();
        GsqCarQueueParams params = new GsqCarQueueParams();
        params.setCarCount(carCount);
        params.setListParam(carDynamicCheck);
        return params;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteAll(GsqReservationRegisterIdParam param) {
        // 入场删除
        gsqReservationRegisterMapper.deleteById(param.getId());
        QueryWrapper<GsqCarQueue> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("reservation_register_id", param.getId());
        gsqCarQueueMapper.delete(queryWrapper);
    }

    @Override
    public void updateSort(List<GsqCarQueueEditParam> params) {
        params.forEach(p -> {
            GsqCarQueue gsqCarQueue = BeanUtil.copyProperties(p, GsqCarQueue.class);
            QueryWrapper<GsqCarQueue> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("reservation_register_id", gsqCarQueue.getReservationRegisterId());
            gsqCarQueueMapper.update(gsqCarQueue, queryWrapper);
        });
    }
}
