/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.gsqReservationRegister.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.mobileInfo.modular.gsqCarQueue.param.GsqCarQueueAddParam;
import com.unis.mobileInfo.modular.gsqCarQueue.param.GsqCarQueueEditParam;
import com.unis.mobileInfo.modular.gsqCarQueue.service.GsqCarQueueService;
import com.unis.mobileInfo.utils.SortRegroupUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.mobileInfo.modular.gsqReservationRegister.entity.GsqReservationRegister;
import com.unis.mobileInfo.modular.gsqReservationRegister.mapper.GsqReservationRegisterMapper;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterAddParam;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterEditParam;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterIdParam;
import com.unis.mobileInfo.modular.gsqReservationRegister.param.GsqReservationRegisterPageParam;
import com.unis.mobileInfo.modular.gsqReservationRegister.service.GsqReservationRegisterService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 售粮排队监测预警-预约登记Service接口实现类
 *
 * @author QSHan
 * @date 2024/04/28 20:08
 **/
@Slf4j
@Service
public class GsqReservationRegisterServiceImpl extends ServiceImpl<GsqReservationRegisterMapper, GsqReservationRegister> implements GsqReservationRegisterService {
    @Resource
    private GsqCarQueueService gsqCarQueueService;

    @Override
    public Page<GsqReservationRegister> page(GsqReservationRegisterPageParam gsqReservationRegisterPageParam) {
        QueryWrapper<GsqReservationRegister> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isAllNotEmpty(gsqReservationRegisterPageParam.getSortField(), gsqReservationRegisterPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(gsqReservationRegisterPageParam.getSortOrder());
            queryWrapper.orderBy(true, gsqReservationRegisterPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(gsqReservationRegisterPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GsqReservationRegister::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GsqReservationRegisterAddParam gsqReservationRegisterAddParam) {
        // 保存预约登记
        GsqReservationRegister gsqReservationRegister = BeanUtil.toBean(gsqReservationRegisterAddParam, GsqReservationRegister.class);
        this.save(gsqReservationRegister);
        // 保存动态监测,远程调度
        log.info("biz_gsq_reservation_register的id: {}", gsqReservationRegister.getId());
        GsqCarQueueAddParam gsqCarQueueAddParam = new GsqCarQueueAddParam();
        gsqCarQueueAddParam.setReservationRegisterId(gsqReservationRegister.getId());
        // 每保存一次根据机构编码查询排序重组一次
        List<GsqCarQueueEditParam> params = gsqCarQueueService.getSortList(gsqReservationRegisterAddParam.getOrgId());
        if (params.size() > 0) {
            // 先重组
            gsqCarQueueService.updateSort(SortRegroupUtil.getRegroup(params));
            // 查询重组后的排序数据
            List<GsqCarQueueEditParam> afterParams = gsqCarQueueService.getSortList(gsqReservationRegisterAddParam.getOrgId());
            // 放入最新排序值
            gsqCarQueueAddParam.setSortNo(SortRegroupUtil.getInitSort(afterParams));
        } else {
            // 本单位没有排队,直接初始化
            gsqCarQueueAddParam.setSortNo(SortRegroupUtil.getInitSort(params));
        }
        // 查询排队序号
        gsqCarQueueService.add(gsqCarQueueAddParam);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GsqReservationRegisterEditParam gsqReservationRegisterEditParam) {
        GsqReservationRegister gsqReservationRegister = this.queryEntity(gsqReservationRegisterEditParam.getId());
        BeanUtil.copyProperties(gsqReservationRegisterEditParam, gsqReservationRegister);
        this.updateById(gsqReservationRegister);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GsqReservationRegisterIdParam> gsqReservationRegisterIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(gsqReservationRegisterIdParamList, GsqReservationRegisterIdParam::getId));
    }

    @Override
    public GsqReservationRegister detail(GsqReservationRegisterIdParam gsqReservationRegisterIdParam) {
        return this.queryEntity(gsqReservationRegisterIdParam.getId());
    }

    @Override
    public GsqReservationRegister queryEntity(String id) {
        GsqReservationRegister gsqReservationRegister = this.getById(id);
        if (ObjectUtil.isEmpty(gsqReservationRegister)) {
            throw new CommonException("售粮排队监测预警-预约登记不存在，id值为：{}", id);
        }
        return gsqReservationRegister;
    }
}
