/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.qcqualityinspection.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.mobileInfo.modular.qcqualityinspection.param.*;
import com.unis.mobileInfo.modular.qcqualityinspection.vo.ReserveQualityCityPageVO;
import com.unis.mobileInfo.modular.qcqualityinspection.vo.ReserveQualityOrgPageVO;
import com.unis.mobileInfo.modular.qcqualityinspection.vo.ReserveQualityStoreHousePageVO;
import com.unis.statisticalAnalysis.modular.kczl.service.KczlService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.mobileInfo.modular.qcqualityinspection.entity.BusinessQcQualityInspection;
import com.unis.mobileInfo.modular.qcqualityinspection.service.BusinessQcQualityInspectionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 质量管理-验收质检表控制器--库平台
 *
 * @author shine
 * @date  2024/06/06 11:25
 */
@Api(tags = "质量管理-验收质检表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BusinessQcQualityInspectionController {

    @Resource
    private BusinessQcQualityInspectionService businessQcQualityInspectionService;

    @Resource
    private KczlService kczlService;

    /**
     * 获取质量管理-验收质检表分页
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取质量管理-验收质检数据通过条件")
    @GetMapping("/client/c/mobileInfo/qcqualityinspection/getData")
    public CommonResult<List<BusinessQcQualityInspection>> getData(BusinessQcQualityInspectionPageParam businessQcQualityInspectionPageParam) {
        return CommonResult.data(businessQcQualityInspectionService.getData(businessQcQualityInspectionPageParam));
    }


    /**
     * 根据id获取详情
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*获取质量管理-验收质检表详情")
    @GetMapping("/client/c/mobileInfo/qcqualityinspection/getDetail")
    public CommonResult<com.unis.statisticalAnalysis.modular.kczl.entity.BusinessQcQualityInspection> getByMasterId(String id) {
        return CommonResult.data(kczlService.getByMasterId(id));
    }

    /**
     * 获取质量管理-验收质检表分页
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取质量管理-验收质检表分页")
    @SaCheckPermission("/mobileInfo/qcqualityinspection/page")
    @GetMapping("/mobileInfo/qcqualityinspection/page")
    public CommonResult<Page<BusinessQcQualityInspection>> page(BusinessQcQualityInspectionPageParam businessQcQualityInspectionPageParam) {
        return CommonResult.data(businessQcQualityInspectionService.page(businessQcQualityInspectionPageParam));
    }

    /**
     * 添加质量管理-验收质检表
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加质量管理-验收质检表")
    @CommonLog("添加质量管理-验收质检表")
    @SaCheckPermission("/mobileInfo/qcqualityinspection/add")
    @PostMapping("/mobileInfo/qcqualityinspection/add")
    public CommonResult<String> add(@RequestBody @Valid BusinessQcQualityInspectionAddParam businessQcQualityInspectionAddParam) {
        businessQcQualityInspectionService.add(businessQcQualityInspectionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑质量管理-验收质检表
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑质量管理-验收质检表")
    @CommonLog("编辑质量管理-验收质检表")
    @SaCheckPermission("/mobileInfo/qcqualityinspection/edit")
    @PostMapping("/mobileInfo/qcqualityinspection/edit")
    public CommonResult<String> edit(@RequestBody @Valid BusinessQcQualityInspectionEditParam businessQcQualityInspectionEditParam) {
        businessQcQualityInspectionService.edit(businessQcQualityInspectionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除质量管理-验收质检表
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除质量管理-验收质检表")
    @CommonLog("删除质量管理-验收质检表")
    @SaCheckPermission("/mobileInfo/qcqualityinspection/delete")
    @PostMapping("/mobileInfo/qcqualityinspection/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BusinessQcQualityInspectionIdParam> businessQcQualityInspectionIdParamList) {
        businessQcQualityInspectionService.delete(businessQcQualityInspectionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取质量管理-验收质检表详情
     *
     * @author shine
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取质量管理-验收质检表详情")
    @SaCheckPermission("/mobileInfo/qcqualityinspection/detail")
    @GetMapping("/mobileInfo/qcqualityinspection/detail")
    public CommonResult<BusinessQcQualityInspection> detail(@Valid BusinessQcQualityInspectionIdParam businessQcQualityInspectionIdParam) {
        return CommonResult.data(businessQcQualityInspectionService.detail(businessQcQualityInspectionIdParam));
    }


   /**
     * 粮食储备-储备质量(市州)-分页
     *
     * @author hjc
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("粮食储备-储备质量(市州)-分页")
    @GetMapping("/mobileInfo/qcqualityinspection/reserveQualityCityPage")
    public CommonResult<Page<ReserveQualityCityPageVO>> reserveQualityCityPage(ReserveQualityCityPageParam pageParam) {
        return CommonResult.data(businessQcQualityInspectionService.reserveQualityCityPage(pageParam));
    }

    /**
     * 粮食储备-储备质量(库区)-分页
     *
     * @author hjc
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("粮食储备-储备质量(库区)-分页")
    @GetMapping("/mobileInfo/qcqualityinspection/reserveQualityOrgPage")
    public CommonResult<Page<ReserveQualityOrgPageVO>> reserveQualityOrgPage(ReserveQualityOrgPageParam reserveQualityOrgPageParam) {
        return CommonResult.data(businessQcQualityInspectionService.reserveQualityOrgPage(reserveQualityOrgPageParam));
    }

    /**
     * 粮食储备-储备质量(仓房)-分页
     *
     * @author hjc
     * @date  2024/06/06 11:25
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("粮食储备-储备质量(仓房)-分页")
    @GetMapping("/mobileInfo/qcqualityinspection/reserveQualityStoreHousePage")
    public CommonResult<Page<ReserveQualityStoreHousePageVO>> reserveQualityStoreHousePage(ReserveQualityStoreHousePageParam pageParam) {
        return CommonResult.data(businessQcQualityInspectionService.reserveQualityStoreHousePage(pageParam));
    }


}
