/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.qcqualityinspectionitem.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.entity.BusinessQcQualityInspectionItem;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemAddParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemEditParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemIdParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemPageParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.service.BusinessQcQualityInspectionItemService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 质量管理-验收质检-检验项目及依据控制器
 *
 * @author shine
 * @date  2024/06/06 11:26
 */
@Api(tags = "质量管理-验收质检-检验项目及依据控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BusinessQcQualityInspectionItemController {

    @Resource
    private BusinessQcQualityInspectionItemService businessQcQualityInspectionItemService;

    /**
     * 获取质量管理-验收质检-检验项目及依据分页
     *
     * @author shine
     * @date  2024/06/06 11:26
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取质量管理-验收质检-检验项目及依据分页")
    @SaCheckPermission("/mobileInfo/qcqualityinspectionitem/page")
    @GetMapping("/mobileInfo/qcqualityinspectionitem/page")
    public CommonResult<Page<BusinessQcQualityInspectionItem>> page(BusinessQcQualityInspectionItemPageParam businessQcQualityInspectionItemPageParam) {
        return CommonResult.data(businessQcQualityInspectionItemService.page(businessQcQualityInspectionItemPageParam));
    }

    /**
     * 添加质量管理-验收质检-检验项目及依据
     *
     * @author shine
     * @date  2024/06/06 11:26
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加质量管理-验收质检-检验项目及依据")
    @CommonLog("添加质量管理-验收质检-检验项目及依据")
    @SaCheckPermission("/mobileInfo/qcqualityinspectionitem/add")
    @PostMapping("/mobileInfo/qcqualityinspectionitem/add")
    public CommonResult<String> add(@RequestBody @Valid BusinessQcQualityInspectionItemAddParam businessQcQualityInspectionItemAddParam) {
        businessQcQualityInspectionItemService.add(businessQcQualityInspectionItemAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑质量管理-验收质检-检验项目及依据
     *
     * @author shine
     * @date  2024/06/06 11:26
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑质量管理-验收质检-检验项目及依据")
    @CommonLog("编辑质量管理-验收质检-检验项目及依据")
    @SaCheckPermission("/mobileInfo/qcqualityinspectionitem/edit")
    @PostMapping("/mobileInfo/qcqualityinspectionitem/edit")
    public CommonResult<String> edit(@RequestBody @Valid BusinessQcQualityInspectionItemEditParam businessQcQualityInspectionItemEditParam) {
        businessQcQualityInspectionItemService.edit(businessQcQualityInspectionItemEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除质量管理-验收质检-检验项目及依据
     *
     * @author shine
     * @date  2024/06/06 11:26
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除质量管理-验收质检-检验项目及依据")
    @CommonLog("删除质量管理-验收质检-检验项目及依据")
    @SaCheckPermission("/mobileInfo/qcqualityinspectionitem/delete")
    @PostMapping("/mobileInfo/qcqualityinspectionitem/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BusinessQcQualityInspectionItemIdParam> businessQcQualityInspectionItemIdParamList) {
        businessQcQualityInspectionItemService.delete(businessQcQualityInspectionItemIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取质量管理-验收质检-检验项目及依据详情
     *
     * @author shine
     * @date  2024/06/06 11:26
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取质量管理-验收质检-检验项目及依据详情")
    @SaCheckPermission("/mobileInfo/qcqualityinspectionitem/detail")
    @GetMapping("/mobileInfo/qcqualityinspectionitem/detail")
    public CommonResult<BusinessQcQualityInspectionItem> detail(@Valid BusinessQcQualityInspectionItemIdParam businessQcQualityInspectionItemIdParam) {
        return CommonResult.data(businessQcQualityInspectionItemService.detail(businessQcQualityInspectionItemIdParam));
    }
}
