/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.mobileInfo.modular.qcqualityinspectionitem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.entity.BusinessQcQualityInspectionItem;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.mapper.BusinessQcQualityInspectionItemMapper;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemAddParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemEditParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemIdParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.param.BusinessQcQualityInspectionItemPageParam;
import com.unis.mobileInfo.modular.qcqualityinspectionitem.service.BusinessQcQualityInspectionItemService;

import java.util.List;

/**
 * 质量管理-验收质检-检验项目及依据Service接口实现类
 *
 * @author shine
 * @date  2024/06/06 11:26
 **/
@Service
public class BusinessQcQualityInspectionItemServiceImpl extends ServiceImpl<BusinessQcQualityInspectionItemMapper, BusinessQcQualityInspectionItem> implements BusinessQcQualityInspectionItemService {

    @Override
    public Page<BusinessQcQualityInspectionItem> page(BusinessQcQualityInspectionItemPageParam businessQcQualityInspectionItemPageParam) {
        QueryWrapper<BusinessQcQualityInspectionItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(businessQcQualityInspectionItemPageParam.getQcQualityInspectionId())) {
            queryWrapper.lambda().eq(BusinessQcQualityInspectionItem::getQcQualityInspectionId, businessQcQualityInspectionItemPageParam.getQcQualityInspectionId());
        }
        if(ObjectUtil.isNotEmpty(businessQcQualityInspectionItemPageParam.getParentInspectionItemId())) {
            queryWrapper.lambda().eq(BusinessQcQualityInspectionItem::getParentInspectionItemId, businessQcQualityInspectionItemPageParam.getParentInspectionItemId());
        }
        if(ObjectUtil.isNotEmpty(businessQcQualityInspectionItemPageParam.getInspectionItemId())) {
            queryWrapper.lambda().eq(BusinessQcQualityInspectionItem::getInspectionItemId, businessQcQualityInspectionItemPageParam.getInspectionItemId());
        }
        if(ObjectUtil.isAllNotEmpty(businessQcQualityInspectionItemPageParam.getSortField(), businessQcQualityInspectionItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(businessQcQualityInspectionItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, businessQcQualityInspectionItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(businessQcQualityInspectionItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BusinessQcQualityInspectionItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BusinessQcQualityInspectionItemAddParam businessQcQualityInspectionItemAddParam) {
        BusinessQcQualityInspectionItem businessQcQualityInspectionItem = BeanUtil.toBean(businessQcQualityInspectionItemAddParam, BusinessQcQualityInspectionItem.class);
        this.save(businessQcQualityInspectionItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BusinessQcQualityInspectionItemEditParam businessQcQualityInspectionItemEditParam) {
        BusinessQcQualityInspectionItem businessQcQualityInspectionItem = this.queryEntity(businessQcQualityInspectionItemEditParam.getId().toString());
        BeanUtil.copyProperties(businessQcQualityInspectionItemEditParam, businessQcQualityInspectionItem);
        this.updateById(businessQcQualityInspectionItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BusinessQcQualityInspectionItemIdParam> businessQcQualityInspectionItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(businessQcQualityInspectionItemIdParamList, BusinessQcQualityInspectionItemIdParam::getId));
    }

    @Override
    public BusinessQcQualityInspectionItem detail(BusinessQcQualityInspectionItemIdParam businessQcQualityInspectionItemIdParam) {
        return this.queryEntity(businessQcQualityInspectionItemIdParam.getId().toString());
    }

    @Override
    public BusinessQcQualityInspectionItem queryEntity(String id) {
        BusinessQcQualityInspectionItem businessQcQualityInspectionItem = this.getById(id);
        if(ObjectUtil.isEmpty(businessQcQualityInspectionItem)) {
            throw new CommonException("质量管理-验收质检-检验项目及依据不存在，id值为：{}", id);
        }
        return businessQcQualityInspectionItem;
    }
}
