/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.alPolicyFileReportManage.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.alPolicyFileReportManage.entity.AlPolicyFileReportManage;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageAddParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageEditParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageIdParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManagePageParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.service.AlPolicyFileReportManageService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 政策法规文件管理控制器
 *
 * @author TS
 * @date  2024/04/18 15:03
 */
@Api(tags = "政策法规文件管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class AlPolicyFileReportManageController {

    @Resource
    private AlPolicyFileReportManageService alPolicyFileReportManageService;

    /**
     * 获取政策法规文件管理自定义分页
     *
     * @author TS
     * @date  2024/04/18 15:03
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取政策法规文件管理自定义分页")
//    @SaCheckPermission("/policy.info/alPolicyFileReportManage/findPage")
    @GetMapping("/policy.info/alPolicyFileReportManage/findPage")
    public CommonResult<Page<AlPolicyFileReportManage>> findPage(AlPolicyFileReportManagePageParam alPolicyFileReportManagePageParam) {
        return CommonResult.data(alPolicyFileReportManageService.page(alPolicyFileReportManagePageParam));
    }

    /**
     * 添加政策法规文件管理
     *
     * @author TS
     * @date  2024/04/18 15:03
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加政策法规文件管理")
    @CommonLog("添加政策法规文件管理")
//    @SaCheckPermission("/policy.info/alPolicyFileReportManage/add")
    @PostMapping("/policy.info/alPolicyFileReportManage/add")
    public CommonResult<String> add(@RequestBody @Valid AlPolicyFileReportManageAddParam alPolicyFileReportManageAddParam) {
        alPolicyFileReportManageService.add(alPolicyFileReportManageAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑政策法规文件管理
     *
     * @author TS
     * @date  2024/04/18 15:03
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑政策法规文件管理")
    @CommonLog("编辑政策法规文件管理")
//    @SaCheckPermission("/policy.info/alPolicyFileReportManage/edit")
    @PostMapping("/policy.info/alPolicyFileReportManage/edit")
    public CommonResult<String> edit(@RequestBody @Valid AlPolicyFileReportManageEditParam alPolicyFileReportManageEditParam) {
        alPolicyFileReportManageService.edit(alPolicyFileReportManageEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除政策法规文件管理
     *
     * @author TS
     * @date  2024/04/18 15:03
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除政策法规文件管理")
    @CommonLog("删除政策法规文件管理")
//    @SaCheckPermission("/policy.info/alPolicyFileReportManage/delete")
    @PostMapping("/policy.info/alPolicyFileReportManage/delete")
    public CommonResult<String> delete(@RequestBody @Valid AlPolicyFileReportManageIdParam alPolicyFileReportManageIdParam) {
        alPolicyFileReportManageService.delete(alPolicyFileReportManageIdParam);
        return CommonResult.ok();
    }

    /**
     * 获取政策法规文件管理详情
     *
     * @author TS
     * @date  2024/04/18 15:03
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取政策法规文件管理详情")
//    @SaCheckPermission("/policy.info/alPolicyFileReportManage/detail")
    @GetMapping("/policy.info/alPolicyFileReportManage/detail")
    public CommonResult<AlPolicyFileReportManage> detail(@Valid AlPolicyFileReportManageIdParam alPolicyFileReportManageIdParam) {
        return CommonResult.data(alPolicyFileReportManageService.detail(alPolicyFileReportManageIdParam));
    }
}
