/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.alPolicyFileReportManage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.policy.info.modular.alPolicyFileReport.entity.AlPolicyFileReport;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.alPolicyFileReportManage.entity.AlPolicyFileReportManage;
import com.unis.policy.info.modular.alPolicyFileReportManage.mapper.AlPolicyFileReportManageMapper;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageAddParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageEditParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManageIdParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.param.AlPolicyFileReportManagePageParam;
import com.unis.policy.info.modular.alPolicyFileReportManage.service.AlPolicyFileReportManageService;

import java.util.List;

/**
 * 政策法规文件管理Service接口实现类
 *
 * @author TS
 * @date  2024/04/18 15:03
 **/
@Service
public class AlPolicyFileReportManageServiceImpl extends ServiceImpl<AlPolicyFileReportManageMapper, AlPolicyFileReportManage> implements AlPolicyFileReportManageService {

    @Override
    public Page<AlPolicyFileReportManage> page(AlPolicyFileReportManagePageParam alPolicyFileReportManagePageParam) {
        QueryWrapper<AlPolicyFileReportManage> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotBlank(alPolicyFileReportManagePageParam.getFileName()))
        queryWrapper.lambda().like(AlPolicyFileReportManage::getFileName,alPolicyFileReportManagePageParam.getFileName());

        if (StringUtils.isNotBlank(alPolicyFileReportManagePageParam.getUploader()))
        queryWrapper.lambda().like(AlPolicyFileReportManage::getUploader,alPolicyFileReportManagePageParam.getUploader());

        if(ObjectUtil.isAllNotEmpty(alPolicyFileReportManagePageParam.getSortField(), alPolicyFileReportManagePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(alPolicyFileReportManagePageParam.getSortOrder());
            queryWrapper.orderBy(true, alPolicyFileReportManagePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(alPolicyFileReportManagePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(AlPolicyFileReportManage::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(AlPolicyFileReportManageAddParam alPolicyFileReportManageAddParam) {
        AlPolicyFileReportManage alPolicyFileReportManage = BeanUtil.toBean(alPolicyFileReportManageAddParam, AlPolicyFileReportManage.class);
        this.save(alPolicyFileReportManage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AlPolicyFileReportManageEditParam alPolicyFileReportManageEditParam) {
        AlPolicyFileReportManage alPolicyFileReportManage = this.queryEntity(alPolicyFileReportManageEditParam.getId());
        BeanUtil.copyProperties(alPolicyFileReportManageEditParam, alPolicyFileReportManage);
        this.updateById(alPolicyFileReportManage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(AlPolicyFileReportManageIdParam alPolicyFileReportManageIdParam) {
        AlPolicyFileReportManage alPolicyFileReportManage = this.getById(alPolicyFileReportManageIdParam.getId());
        if (ObjectUtil.isEmpty(alPolicyFileReportManage)){
            throw new CommonException("政策法规文件不存在，id值为：{}", alPolicyFileReportManage.getId());
        }
        // 执行删除
        this.removeById(alPolicyFileReportManageIdParam.getId());
    }

    @Override
    public AlPolicyFileReportManage detail(AlPolicyFileReportManageIdParam alPolicyFileReportManageIdParam) {
        return this.queryEntity(alPolicyFileReportManageIdParam.getId());
    }

    @Override
    public AlPolicyFileReportManage queryEntity(String id) {
        AlPolicyFileReportManage alPolicyFileReportManage = this.getById(id);
        if(ObjectUtil.isEmpty(alPolicyFileReportManage)) {
            throw new CommonException("政策法规文件管理不存在，id值为：{}", id);
        }
        return alPolicyFileReportManage;
    }
}
