/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.auditRecord.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.auditRecord.entity.AuditRecord;
import com.unis.policy.info.modular.auditRecord.mapper.AuditRecordMapper;
import com.unis.policy.info.modular.auditRecord.param.AuditRecordAddParam;
import com.unis.policy.info.modular.auditRecord.param.AuditRecordEditParam;
import com.unis.policy.info.modular.auditRecord.param.AuditRecordIdParam;
import com.unis.policy.info.modular.auditRecord.param.AuditRecordPageParam;
import com.unis.policy.info.modular.auditRecord.service.AuditRecordService;

import java.util.List;

/**
 * 审核记录Service接口实现类
 *
 * @author TS
 * @date  2024/04/18 14:40
 **/
@Service
public class AuditRecordServiceImpl extends ServiceImpl<AuditRecordMapper, AuditRecord> implements AuditRecordService {

    @Override
    public Page<AuditRecord> page(AuditRecordPageParam auditRecordPageParam) {
        QueryWrapper<AuditRecord> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(auditRecordPageParam.getSortField(), auditRecordPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(auditRecordPageParam.getSortOrder());
            queryWrapper.orderBy(true, auditRecordPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(auditRecordPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(AuditRecord::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(AuditRecordAddParam auditRecordAddParam) {
        AuditRecord auditRecord = BeanUtil.toBean(auditRecordAddParam, AuditRecord.class);
        this.save(auditRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(AuditRecordEditParam auditRecordEditParam) {
        AuditRecord auditRecord = this.queryEntity(auditRecordEditParam.getId());
        BeanUtil.copyProperties(auditRecordEditParam, auditRecord);
        this.updateById(auditRecord);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<AuditRecordIdParam> auditRecordIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(auditRecordIdParamList, AuditRecordIdParam::getId));
    }

    @Override
    public AuditRecord detail(AuditRecordIdParam auditRecordIdParam) {
        return this.queryEntity(auditRecordIdParam.getId());
    }

    @Override
    public AuditRecord queryEntity(String id) {
        AuditRecord auditRecord = this.getById(id);
        if(ObjectUtil.isEmpty(auditRecord)) {
            throw new CommonException("审核记录不存在，id值为：{}", id);
        }
        return auditRecord;
    }
}
