/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.auditRequest.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unis.emergencySupport.modular.es.entity.EsNetworkEntry;
import com.unis.emergencySupport.modular.es.entity.vo.EsNetworkEntryVO;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryIdParam;
import com.unis.emergencySupport.modular.es.param.EsNetworkEntryPageParam;
import com.unis.policy.info.modular.auditRequest.entity.AuditRequest;
import com.unis.policy.info.modular.auditRequest.vo.AuditRequestVO;
import com.unis.policy.info.modular.auditRequest.vo.PmApplicationVO;
import com.unis.policy.info.modular.auditRequest.vo.UnitInfoVO;
import com.unis.projectManagement.modular.pmApplication.entity.PmApplication;
import com.unis.projectManagement.modular.pmStorageConstruction.entity.PmStorageConstruction;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 审核请求Mapper接口
 *
 * @author TS
 * @date  2024/04/18 14:51
 **/
@Mapper
public interface AuditRequestMapper extends BaseMapper<AuditRequest> {
    /**
     * 展示审核记录
     * @param reporttId
     * @return
     */
    List<Map<String,Object>> queryReconds(@Param("reporttId") String reporttId);

    /**
     * 承储资格审批--分页展示列表数据
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    Page<AuditRequestVO> selectMyPage(Page<AuditRequestVO> page, String dwmc);


    /**
     * 承储资格企业--分页展示列表数据
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    Page<AuditRequestVO> enterprisePage(Page<AuditRequestVO> page, String dwmc);
    /**
     * 承储资格延续申请--分页查询
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    Page<AuditRequestVO> continuationPage(Page<AuditRequestVO> page, String dwmc);

    /**
     * 补发证书--分页查询
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    Page<AuditRequestVO> reissuePage(Page<AuditRequestVO> page, String dwmc);

    /**
     * 补发证书--查看详情
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    UnitInfoVO selectReissueInfo(String id);

    /**
     * 信息变更审批--分页
     *
     * @author hjc
     * @date 2024/04/18 14:51
     */
    Page<AuditRequestVO> infoChangesPage(Page<AuditRequestVO> page, String dwmc);

    Page<EsNetworkEntry> esNetworkEntryPage(Page<EsNetworkEntry> page,@Param("esNetworkEntryPageParam") EsNetworkEntryPageParam esNetworkEntryPageParam);


    /**
     * 获取项目审批分页
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    Page<PmApplicationVO> selectApprovalPage(@Param("page") Page<PmApplicationVO> page,
                                             @Param("projectName") String projectName,
                                             @Param("auditStatus") Integer auditStatus);


    /**
     * 获取仓储设施投资-仓储设施建设审批分页
     *
     * @author hjc
     * @date 2024/05/30 15:58
     */
    Page<PmStorageConstruction> selectPmStorageConstructionPage(@Param("page") Page<PmStorageConstruction> page,
                                                                @Param("projectName") String projectName);
}
