/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.auditRequest.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;

/**
 * 审核请求添加参数
 *
 * @author TS
 * @date  2024/04/18 14:51
 **/
@Getter
@Setter
public class AuditRequestAddParam {

    /** 业务类型  1：政策规范性文件申报；2：人才规划；3：承储资格 */
    @ApiModelProperty(value = "业务类型  1：政策规范性文件申报；2：人才规划；3：承储资格", position = 7)
    @NotBlank(message = "业务类型不能为空")
//    @Pattern(regexp = "\\{1\\}",message = "业务类型 1：政策规范性文件申报")
    private String type;

    /** 步骤   type=1，1：合法性审核；2：过会审核； type=2，1：规划审批；type=3，1：承储资格审批； */
    @ApiModelProperty(value = "步骤   type=1，1：合法性审核；2：过会审核； type=2，1：规划审批；type=3，1：承储资格审批；", position = 8)
    @NotBlank(message = "步骤不能为空")
    private String step;

    /** 申请id   type=1，biz_al_policy_file的id；type=2，biz_em_person_plan的id；type=3，biz_sqr_enterprise_apply的id； */
    @ApiModelProperty(value = "申请id   type=1，biz_al_policy_file的id；type=2，biz_em_person_plan的id；type=3，biz_sqr_enterprise_apply的id；", position = 9)
    @NotBlank(message = "申请Id不能为空")
    private String requestId;

    /** 状态 0：待审核；1：已审核；2：驳回； */
    @ApiModelProperty(value = "状态 0：待审核；1：已审核；2：驳回；", position = 10)
    @NotNull(message = "业务类型不能为空")
    private Integer auditStatus;

    /** 审核意见； */
    @ApiModelProperty(value = "审核意见；", position = 11)
    @NotBlank(message = "审核意见不能为空")
    private String auditAdvice;

    /** 审核人；sys_user的id； */
    @ApiModelProperty(value = "审核人；sys_user的id；", position = 12)
    @NotBlank(message = "审核人不能为空")
    private String auditUserId;

    /** 审核时间 */
    @ApiModelProperty(value = "审核时间", position = 13)
    @NotNull(message = "审核时间不能为空")
    private Date auditTime;

    /** 附件；多个附件，‘,’分割; */
    @ApiModelProperty(value = "附件；多个附件，‘,’分割;", position = 14)
//    @NotBlank(message = "附件不能为空")
    private String attachment;

}