/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpAdviceCollectFeedback.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.policy.info.modular.mlpAdviceCollect.entity.MlpAdviceCollect;
import com.unis.policy.info.modular.mlpAdviceCollect.service.MlpAdviceCollectService;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.vo.MlpAdviceCollectOrgFeedbackVO;
import com.unis.policy.info.modular.mlpFirstDraftCollect.entity.MlpFirstDraftCollect;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.entity.MlpAdviceCollectOrgFeedback;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackAddParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackEditParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackIdParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackPageParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.service.MlpAdviceCollectOrgFeedbackService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 中长期规划管理-规划编制（意见收集）-意见反馈控制器
 *
 * @author hujinachun
 * @date 2024/04/19 16:31
 */
@Api(tags = "中长期规划管理-规划编制（意见收集）-意见反馈控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpAdviceCollectOrgFeedbackController {

    @Resource
    private MlpAdviceCollectOrgFeedbackService mlpAdviceCollectOrgFeedbackService;

    @Autowired
    private MlpAdviceCollectService mlpAdviceCollectService;

    /**
     * 获取中长期规划管理-规划编制（意见收集）-意见反馈分页
     *
     * @author hujinachun
     * @date 2024/04/19 16:31
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取中长期规划管理-规划编制（意见收集）-意见反馈分页")
    @SaCheckPermission("/policy.info/mlpAdviceCollectFeedback/page")
    @GetMapping("/policy.info/mlpAdviceCollectFeedback/page")
    public CommonResult<Page<MlpAdviceCollectOrgFeedbackVO>> page(MlpAdviceCollectOrgFeedbackPageParam mlpAdviceCollectOrgFeedbackPageParam) {
        return CommonResult.data(mlpAdviceCollectOrgFeedbackService.page(mlpAdviceCollectOrgFeedbackPageParam));
    }

    /**
     * 添加中长期规划管理-规划编制（意见收集）-意见反馈
     *
     * @author hujinachun
     * @date 2024/04/19 16:31
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加中长期规划管理-规划编制（意见收集）-意见反馈")
    @CommonLog("添加中长期规划管理-规划编制（意见收集）-意见反馈")
    // @SaCheckPermission("/policy.info/mlpAdviceCollectFeedback/add")
    @PostMapping("/policy.info/mlpAdviceCollectFeedback/add")
    public CommonResult<String> add(@RequestBody @Valid MlpAdviceCollectOrgFeedbackAddParam mlpAdviceCollectOrgFeedbackAddParam) {
        mlpAdviceCollectOrgFeedbackService.add(mlpAdviceCollectOrgFeedbackAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-规划编制（意见收集）-意见反馈
     *
     * @author hujinachun
     * @date 2024/04/19 16:31
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑中长期规划管理-规划编制（意见收集）-意见反馈")
    @CommonLog("编辑中长期规划管理-规划编制（意见收集）-意见反馈")
    // @SaCheckPermission("/policy.info/mlpAdviceCollectFeedback/edit")
    @PostMapping("/policy.info/mlpAdviceCollectFeedback/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpAdviceCollectOrgFeedbackEditParam mlpAdviceCollectOrgFeedbackEditParam) {
        mlpAdviceCollectOrgFeedbackService.edit(mlpAdviceCollectOrgFeedbackEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-规划编制（意见收集）-意见反馈
     *
     * @author hujinachun
     * @date 2024/04/19 16:31
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除中长期规划管理-规划编制（意见收集）-意见反馈")
    @CommonLog("删除中长期规划管理-规划编制（意见收集）-意见反馈")
    // @SaCheckPermission("/policy.info/mlpAdviceCollectFeedback/delete")
    @PostMapping("/policy.info/mlpAdviceCollectFeedback/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<MlpAdviceCollectOrgFeedbackIdParam> mlpAdviceCollectOrgFeedbackIdParamList) {
        mlpAdviceCollectOrgFeedbackService.delete(mlpAdviceCollectOrgFeedbackIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-规划编制（意见收集）-意见反馈详情
     *
     * @author hujinachun
     * @date 2024/04/19 16:31
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-规划编制（意见收集）-意见反馈详情")
    // @SaCheckPermission("/policy.info/mlpAdviceCollectFeedback/detail")
    @GetMapping("/policy.info/mlpAdviceCollectFeedback/detail")
    public CommonResult<MlpAdviceCollectOrgFeedback> detail(@Valid MlpAdviceCollectOrgFeedbackIdParam mlpAdviceCollectOrgFeedbackIdParam) {
        return CommonResult.data(mlpAdviceCollectOrgFeedbackService.detail(mlpAdviceCollectOrgFeedbackIdParam));
    }


    @ApiOperationSupport(order = 6)
    @ApiOperation(value = "带出意见反馈新增参数", notes = "firstAdviceCollectId")
    @GetMapping("/policy.info/mlpAdviceCollectFeedback/selectParams")
    public CommonResult<MlpAdviceCollect> selectParams(String firstAdviceCollectId) {
        return CommonResult.data(mlpAdviceCollectService.getById(firstAdviceCollectId));
    }


}
