/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpAdviceCollectFeedback.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.auth.core.pojo.SaBaseLoginUser;
import com.unis.auth.core.util.StpClientUtil;
import com.unis.auth.core.util.StpLoginUserUtil;
import com.unis.policy.info.modular.mlpAdviceCollect.entity.MlpAdviceCollect;
import com.unis.policy.info.modular.mlpAdviceCollect.entity.MlpAdviceCollectOrg;
import com.unis.policy.info.modular.mlpAdviceCollect.mapper.MlpAdviceCollectMapper;
import com.unis.policy.info.modular.mlpAdviceCollect.mapper.MlpAdviceCollectOrgMapper;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.vo.MlpAdviceCollectOrgFeedbackVO;
import com.unis.sys.modular.user.entity.SysUser;
import com.unis.sys.modular.user.mapper.SysUserMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.entity.MlpAdviceCollectOrgFeedback;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.mapper.MlpAdviceCollectOrgFeedbackMapper;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackAddParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackEditParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackIdParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackPageParam;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.service.MlpAdviceCollectOrgFeedbackService;

import java.util.Date;
import java.util.List;

/**
 * 中长期规划管理-规划编制（意见收集）-意见反馈Service接口实现类
 *
 * @author hujinachun
 * @date 2024/04/19 16:31
 **/
@Service
public class MlpAdviceCollectOrgFeedbackServiceImpl extends ServiceImpl<MlpAdviceCollectOrgFeedbackMapper, MlpAdviceCollectOrgFeedback> implements MlpAdviceCollectOrgFeedbackService {

    @Autowired
    private MlpAdviceCollectOrgFeedbackMapper mlpAdviceCollectOrgFeedbackMapper;

    @Autowired
    private MlpAdviceCollectMapper mlpAdviceCollectMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Override
    public Page<MlpAdviceCollectOrgFeedbackVO> page(MlpAdviceCollectOrgFeedbackPageParam pageParam) {
      /*  QueryWrapper<MlpAdviceCollectOrgFeedback> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(mlpAdviceCollectOrgFeedbackPageParam.getSortField(), mlpAdviceCollectOrgFeedbackPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(mlpAdviceCollectOrgFeedbackPageParam.getSortOrder());
            queryWrapper.orderBy(true, mlpAdviceCollectOrgFeedbackPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(mlpAdviceCollectOrgFeedbackPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MlpAdviceCollectOrgFeedback::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);*/

        //数据范围
        SaBaseLoginUser saBaseLoginUser = StpLoginUserUtil.getLoginUser();
        if (ObjectUtil.isEmpty(saBaseLoginUser)) {
            throw new CommonException("无法获取到用户信息");
        }
        String orgId = saBaseLoginUser.getOrgId();
        List<String> loginUserDataScope = StpLoginUserUtil.getLoginUserDataScope();
        if (ObjectUtil.isEmpty(loginUserDataScope)) {
            throw new CommonException("您没有权限操作意见收集");
        }
        if (!loginUserDataScope.contains(saBaseLoginUser.getOrgId())) {
            throw new CommonException("您没有权限进行操作意见收集，机构id：", saBaseLoginUser.getOrgId());
        }

        Page<MlpAdviceCollectOrgFeedbackVO> page = new Page<>(pageParam.getCurrent(), pageParam.getSize());
        return mlpAdviceCollectOrgFeedbackMapper.selectMyPage(page, pageParam.getPlanName(),
                DateUtil.format(pageParam.getCollectionDeadline(), "yyyy-MM-dd"),orgId);

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MlpAdviceCollectOrgFeedbackAddParam mlpAdviceCollectOrgFeedbackAddParam) {
        MlpAdviceCollectOrgFeedback feedback = BeanUtil.toBean(mlpAdviceCollectOrgFeedbackAddParam, MlpAdviceCollectOrgFeedback.class);
        feedback.setCreateTime(new Date());
        this.save(feedback);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MlpAdviceCollectOrgFeedbackEditParam mlpAdviceCollectOrgFeedbackEditParam) {
        MlpAdviceCollectOrgFeedback mlpAdviceCollectOrgFeedback = this.queryEntity(mlpAdviceCollectOrgFeedbackEditParam.getId());
        BeanUtil.copyProperties(mlpAdviceCollectOrgFeedbackEditParam, mlpAdviceCollectOrgFeedback);
        this.updateById(mlpAdviceCollectOrgFeedback);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MlpAdviceCollectOrgFeedbackIdParam> mlpAdviceCollectOrgFeedbackIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(mlpAdviceCollectOrgFeedbackIdParamList, MlpAdviceCollectOrgFeedbackIdParam::getId));
    }

    @Override
    public MlpAdviceCollectOrgFeedback detail(MlpAdviceCollectOrgFeedbackIdParam mlpAdviceCollectOrgFeedbackIdParam) {
        //  return this.queryEntity(mlpAdviceCollectOrgFeedbackIdParam.getId());

        //数据范围
        SaBaseLoginUser saBaseLoginUser = StpLoginUserUtil.getLoginUser();
        if (ObjectUtil.isEmpty(saBaseLoginUser)) {
            throw new CommonException("无法获取到用户信息");
        }
        String id = saBaseLoginUser.getId();

        QueryWrapper<MlpAdviceCollectOrgFeedback> wrapper = new QueryWrapper<>();
        wrapper.eq("advice_collect_id", mlpAdviceCollectOrgFeedbackIdParam.getId());
        wrapper.eq("sys_user_id",id);
        return mlpAdviceCollectOrgFeedbackMapper.selectOne(wrapper);
    }

    @Override
    public MlpAdviceCollectOrgFeedback queryEntity(String id) {
        MlpAdviceCollectOrgFeedback mlpAdviceCollectOrgFeedback = this.getById(id);
        if (ObjectUtil.isEmpty(mlpAdviceCollectOrgFeedback)) {
            throw new CommonException("中长期规划管理-规划编制（意见收集）-意见反馈不存在，id值为：{}", id);
        }
        return mlpAdviceCollectOrgFeedback;
    }
}
