/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpDraftModify.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpDraftModify.entity.MlpDraftModify;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyAddParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyEditParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyIdParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyPageParam;
import com.unis.policy.info.modular.mlpDraftModify.service.MlpDraftModifyService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 中长期规划管理-规划修改控制器
 *
 * @author hujinachun
 * @date  2024/04/23 11:40
 */
@Api(tags = "中长期规划管理-规划修改控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpDraftModifyController {

    @Resource
    private MlpDraftModifyService mlpDraftModifyService;

    /**
     * 获取中长期规划管理-规划修改分页
     *
     * @author hujinachun
     * @date  2024/04/23 11:40
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取中长期规划管理-规划修改分页")
//    @SaCheckPermission("/policy.info/mlpDraftModify/page")
    @GetMapping("/policy.info/mlpDraftModify/page")
    public CommonResult<Page<MlpDraftModify>> page(MlpDraftModifyPageParam mlpDraftModifyPageParam) {
        return CommonResult.data(mlpDraftModifyService.page(mlpDraftModifyPageParam));
    }

    /**
     * 添加中长期规划管理-规划修改
     *
     * @author hujinachun
     * @date  2024/04/23 11:40
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加中长期规划管理-规划修改")
    @CommonLog("添加中长期规划管理-规划修改")
//    @SaCheckPermission("/policy.info/mlpDraftModify/add")
    @PostMapping("/policy.info/mlpDraftModify/add")
    public CommonResult<String> add(@RequestBody @Valid MlpDraftModifyAddParam mlpDraftModifyAddParam) {
        mlpDraftModifyService.add(mlpDraftModifyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-规划修改
     *
     * @author hujinachun
     * @date  2024/04/23 11:40
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑中长期规划管理-规划修改")
    @CommonLog("编辑中长期规划管理-规划修改")
//    @SaCheckPermission("/policy.info/mlpDraftModify/edit")
    @PostMapping("/policy.info/mlpDraftModify/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpDraftModifyEditParam mlpDraftModifyEditParam) {
        mlpDraftModifyService.edit(mlpDraftModifyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-规划修改
     *
     * @author hujinachun
     * @date  2024/04/23 11:40
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除中长期规划管理-规划修改")
    @CommonLog("删除中长期规划管理-规划修改")
//    @SaCheckPermission("/policy.info/mlpDraftModify/delete")
    @PostMapping("/policy.info/mlpDraftModify/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MlpDraftModifyIdParam> mlpDraftModifyIdParamList) {
        mlpDraftModifyService.delete(mlpDraftModifyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-规划修改详情
     *
     * @author hujinachun
     * @date  2024/04/23 11:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-规划修改详情")
//    @SaCheckPermission("/policy.info/mlpDraftModify/detail")
    @GetMapping("/policy.info/mlpDraftModify/detail")
    public CommonResult<MlpDraftModify> detail(@Valid MlpDraftModifyIdParam mlpDraftModifyIdParam) {
        return CommonResult.data(mlpDraftModifyService.detail(mlpDraftModifyIdParam));
    }
}
