/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpDraftModify.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.mlpDraftModify.entity.MlpDraftModify;
import com.unis.policy.info.modular.mlpDraftModify.mapper.MlpDraftModifyMapper;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyAddParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyEditParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyIdParam;
import com.unis.policy.info.modular.mlpDraftModify.param.MlpDraftModifyPageParam;
import com.unis.policy.info.modular.mlpDraftModify.service.MlpDraftModifyService;

import java.util.Date;
import java.util.List;

/**
 * 中长期规划管理-规划修改Service接口实现类
 *
 * @author hujinachun
 * @date 2024/04/23 11:40
 **/
@Service
public class MlpDraftModifyServiceImpl extends ServiceImpl<MlpDraftModifyMapper, MlpDraftModify> implements MlpDraftModifyService {

    @Override
    public Page<MlpDraftModify> page(MlpDraftModifyPageParam mlpDraftModifyPageParam) {
        QueryWrapper<MlpDraftModify> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(mlpDraftModifyPageParam.getPlanName())) {
            queryWrapper.like("plan_name", mlpDraftModifyPageParam.getPlanName());
        }
        if (ObjectUtil.isAllNotEmpty(mlpDraftModifyPageParam.getSortField(), mlpDraftModifyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(mlpDraftModifyPageParam.getSortOrder());
            queryWrapper.orderBy(true, mlpDraftModifyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(mlpDraftModifyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MlpDraftModify::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MlpDraftModifyAddParam mlpDraftModifyAddParam) {
        //需要前端调用规划初稿里面的数据，回显出来进行修改
        MlpDraftModify mlpDraftModify = BeanUtil.toBean(mlpDraftModifyAddParam, MlpDraftModify.class);
        mlpDraftModify.setCreateTime(new Date());
        this.save(mlpDraftModify);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MlpDraftModifyEditParam mlpDraftModifyEditParam) {
        MlpDraftModify mlpDraftModify = this.queryEntity(mlpDraftModifyEditParam.getId());
        BeanUtil.copyProperties(mlpDraftModifyEditParam, mlpDraftModify);
        mlpDraftModify.setUpdateTime(new Date());
        this.updateById(mlpDraftModify);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MlpDraftModifyIdParam> mlpDraftModifyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(mlpDraftModifyIdParamList, MlpDraftModifyIdParam::getId));
    }

    @Override
    public MlpDraftModify detail(MlpDraftModifyIdParam mlpDraftModifyIdParam) {
        return this.queryEntity(mlpDraftModifyIdParam.getId());
    }

    @Override
    public MlpDraftModify queryEntity(String id) {
        MlpDraftModify mlpDraftModify = this.getById(id);
        if (ObjectUtil.isEmpty(mlpDraftModify)) {
            throw new CommonException("中长期规划管理-规划修改不存在，id值为：{}", id);
        }
        return mlpDraftModify;
    }
}
