/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpFirstDraft.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.policy.info.modular.mlpFirstDraft.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpFirstDraft.entity.MlpFirstDraft;
import com.unis.policy.info.modular.mlpFirstDraft.service.MlpFirstDraftService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 中长期规划管理-规划初稿(规划拟稿)控制器
 *
 * @author QSHan
 * @date  2024/04/18 16:52
 */
@Api(tags = "中长期规划管理-规划初稿(规划拟稿)控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpFirstDraftController {

    @Resource
    private MlpFirstDraftService mlpFirstDraftService;

    /**
     * 获取中长期规划管理-规划初稿(规划拟稿)分页
     *
     * @author QSHan
     * @date  2024/04/18 16:52
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取-规划初稿(规划拟稿)分页")
    @SaCheckPermission("/policy.info/mlpFirstDraft/page")
    @GetMapping("/policy.info/mlpFirstDraft/page")
    public CommonResult<Page<MlpFirstDraft>> page(MlpFirstDraftPageParam mlpFirstDraftPageParam, MlpFirstDraftQueryParam param) {
        return CommonResult.data(mlpFirstDraftService.page(mlpFirstDraftPageParam, param));
    }

    /**
     * 添加中长期规划管理-规划初稿(规划拟稿)
     *
     * @author QSHan
     * @date  2024/04/18 16:52
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加-规划初稿(规划拟稿)")
    @CommonLog("添加中长期规划管理-规划初稿(规划拟稿)")
//    @SaCheckPermission("/policy.info/mlpFirstDraft/add")
    @PostMapping("/policy.info/mlpFirstDraft/add")
    public CommonResult<String> add(@RequestBody @Valid MlpFirstDraftAddParam mlpFirstDraftAddParam) {
        mlpFirstDraftService.add(mlpFirstDraftAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-规划初稿(规划拟稿)
     *
     * @author QSHan
     * @date  2024/04/18 16:52
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑-规划初稿(规划拟稿)")
    @CommonLog("编辑中长期规划管理-规划初稿(规划拟稿)")
//    @SaCheckPermission("/policy.info/mlpFirstDraft/edit")
    @PostMapping("/policy.info/mlpFirstDraft/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpFirstDraftEditParam mlpFirstDraftEditParam) {
        mlpFirstDraftService.edit(mlpFirstDraftEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-规划初稿(规划拟稿)
     *
     * @author QSHan
     * @date  2024/04/18 16:52
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除-规划初稿(规划拟稿)")
    @CommonLog("删除中长期规划管理-规划初稿(规划拟稿)")
//    @SaCheckPermission("/policy.info/mlpFirstDraft/delete")
    @PostMapping("/policy.info/mlpFirstDraft/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MlpFirstDraftIdParam> mlpFirstDraftIdParamList) {
        mlpFirstDraftService.delete(mlpFirstDraftIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-规划初稿(规划拟稿)详情
     *
     * @author QSHan
     * @date  2024/04/18 16:52
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("规划初稿(规划拟稿)详情")
//    @SaCheckPermission("/policy.info/mlpFirstDraft/detail")
    @GetMapping("/policy.info/mlpFirstDraft/detail")
    public CommonResult<MlpFirstDraft> detail(@Valid MlpFirstDraftIdParam mlpFirstDraftIdParam) {
        return CommonResult.data(mlpFirstDraftService.detail(mlpFirstDraftIdParam));
    }


    /**
     * 获取中长期规划管理-初稿意见征集详情
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("意见征集-获取规划名称(mapNow:完成日期内,mapAll:所有)")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/detail")
    @GetMapping("/policy.info/mlpFirstDraftCollect/getPlanName")
    public CommonResult<Map<String, Object>> getPlanName() {
        return CommonResult.data(mlpFirstDraftService.getPlanName());
    }

}
