/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.sqrEnterprise.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.sqrEnterprise.entity.SqrEnterprise;
import com.unis.policy.info.modular.sqrEnterprise.mapper.SqrEnterpriseMapper;
import com.unis.policy.info.modular.sqrEnterprise.param.SqrEnterpriseAddParam;
import com.unis.policy.info.modular.sqrEnterprise.param.SqrEnterpriseEditParam;
import com.unis.policy.info.modular.sqrEnterprise.param.SqrEnterpriseIdParam;
import com.unis.policy.info.modular.sqrEnterprise.param.SqrEnterprisePageParam;
import com.unis.policy.info.modular.sqrEnterprise.service.SqrEnterpriseService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 承储资格认定-承储企业Service接口实现类
 *
 * @author hjc
 * @date  2024/04/28 16:46
 **/
@Service
public class SqrEnterpriseServiceImpl extends ServiceImpl<SqrEnterpriseMapper, SqrEnterprise> implements SqrEnterpriseService {

    @Resource
    private SqrEnterpriseMapper sqrEnterpriseMapper;

    @Override
    public List<SqrEnterprise> page() {

        return sqrEnterpriseMapper.page();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SqrEnterpriseAddParam sqrEnterpriseAddParam) {
        SqrEnterprise sqrEnterprise = BeanUtil.toBean(sqrEnterpriseAddParam, SqrEnterprise.class);
        this.save(sqrEnterprise);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SqrEnterpriseEditParam sqrEnterpriseEditParam) {
        SqrEnterprise sqrEnterprise = this.queryEntity(sqrEnterpriseEditParam.getId());
        BeanUtil.copyProperties(sqrEnterpriseEditParam, sqrEnterprise);
        this.updateById(sqrEnterprise);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SqrEnterpriseIdParam> sqrEnterpriseIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(sqrEnterpriseIdParamList, SqrEnterpriseIdParam::getId));
    }

    @Override
    public SqrEnterprise detail(SqrEnterpriseIdParam sqrEnterpriseIdParam) {
        return this.queryEntity(sqrEnterpriseIdParam.getId());
    }

    @Override
    public SqrEnterprise queryEntity(String id) {
        SqrEnterprise sqrEnterprise = this.getById(id);
        if(ObjectUtil.isEmpty(sqrEnterprise)) {
            throw new CommonException("承储资格认定-承储企业不存在，id值为：{}", id);
        }
        return sqrEnterprise;
    }
}
