/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.sqrEnterpriseApply.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.sqrEnterpriseApply.entity.SqrEnterpriseApply;
import com.unis.policy.info.modular.sqrEnterpriseApply.param.SqrEnterpriseApplyAddParam;
import com.unis.policy.info.modular.sqrEnterpriseApply.param.SqrEnterpriseApplyEditParam;
import com.unis.policy.info.modular.sqrEnterpriseApply.param.SqrEnterpriseApplyIdParam;
import com.unis.policy.info.modular.sqrEnterpriseApply.param.SqrEnterpriseApplyPageParam;
import com.unis.policy.info.modular.sqrEnterpriseApply.service.SqrEnterpriseApplyService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.Map;

/**
 * 承储资格认定-承储资格申请控制器
 *
 * @author hjc
 * @date  2024/04/28 15:45
 */
@Api(tags = "承储资格认定-承储资格申请控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SqrEnterpriseApplyController {

    @Resource
    private SqrEnterpriseApplyService sqrEnterpriseApplyService;

    /**
     * 获取承储资格认定-承储资格申请分页
     *
     * @author hjc
     * @date  2024/04/28 15:45
     */
//    @ApiOperationSupport(order = 1)
//    @ApiOperation("获取承储资格认定-承储资格申请分页")
//    @SaCheckPermission("/policy.info/sqrEnterpriseApply/page")
//    @GetMapping("/policy.info/sqrEnterpriseApply/page")
//    public CommonResult<Page<SqrEnterpriseApply>> page(SqrEnterpriseApplyPageParam sqrEnterpriseApplyPageParam) {
//        return CommonResult.data(sqrEnterpriseApplyService.page(sqrEnterpriseApplyPageParam));
//    }

    /**
     * 添加承储资格认定-承储资格申请
     *
     * @author hjc
     * @date  2024/04/28 15:45
     */
//    @ApiOperationSupport(order = 2)
//    @ApiOperation("添加承储资格认定-承储资格申请")
//    @CommonLog("添加承储资格认定-承储资格申请")
//    @SaCheckPermission("/policy.info/sqrEnterpriseApply/add")
//    @PostMapping("/policy.info/sqrEnterpriseApply/add")
//    public CommonResult<String> add(@RequestBody @Valid SqrEnterpriseApplyAddParam sqrEnterpriseApplyAddParam) {
//        sqrEnterpriseApplyService.add(sqrEnterpriseApplyAddParam);
//        return CommonResult.ok();
//    }

    /**
     * 编辑承储资格认定-承储资格申请
     *
     * @author hjc
     * @date  2024/04/28 15:45
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("承储资格证书补发申请保存和提交")
    @CommonLog("承储资格证书补发申请保存和提交")
    @PostMapping("/policy.info/sqrEnterpriseApply/edit")
    public CommonResult<String> edit(@RequestBody @Valid SqrEnterpriseApplyEditParam sqrEnterpriseApplyEditParam) {
        sqrEnterpriseApplyService.edit(sqrEnterpriseApplyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除承储资格认定-承储资格申请
     *
     * @author hjc
     * @date  2024/04/28 15:45
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除承储资格认定-承储资格申请")
    @CommonLog("删除承储资格认定-承储资格申请")
    @PostMapping("/policy.info/sqrEnterpriseApply/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<SqrEnterpriseApplyIdParam> sqrEnterpriseApplyIdParamList) {
        sqrEnterpriseApplyService.delete(sqrEnterpriseApplyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取承储资格认定-承储资格申请详情
     *
     * @author hjc
     * @date  2024/04/28 15:45
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取承储资格认定-承储资格申请详情")
    @GetMapping("/policy.info/sqrEnterpriseApply/detail")
    public CommonResult<SqrEnterpriseApply> detail(@Valid SqrEnterpriseApplyIdParam sqrEnterpriseApplyIdParam) {
        return CommonResult.data(sqrEnterpriseApplyService.detail(sqrEnterpriseApplyIdParam));
    }


    /**
     * 承储资格证书补发申请分页
     *
     * @author ZeroLiYi
     * @date  2024/05/06 15:45
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("承储资格证书补发申请分页")
    @GetMapping("/policy.info/sqrEnterpriseApply/page")
    public CommonResult<IPage<Map<String,Object>>> findBypage(SqrEnterpriseApplyPageParam sqrEnterpriseApplyPageParam) {
        return CommonResult.data(sqrEnterpriseApplyService.findByPage(sqrEnterpriseApplyPageParam));
    }

    /**
     * 承储企业资格失效
     *
     * @author ZeroLiYi
     * @date  2024/05/06 15:45
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("承储企业资格失效")
    @CommonLog("承储企业资格失效")
    @PostMapping("/policy.info/sqrEnterpriseApply/updateStatus")
    public CommonResult<String> updateStatus() {
        sqrEnterpriseApplyService.updateStatus();
        return CommonResult.ok();
    }


}
