/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmApplication.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.projectManagement.modular.pmApplication.vo.ConstructionLocationVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.projectManagement.modular.pmApplication.entity.PmApplication;
import com.unis.projectManagement.modular.pmApplication.param.PmApplicationAddParam;
import com.unis.projectManagement.modular.pmApplication.param.PmApplicationEditParam;
import com.unis.projectManagement.modular.pmApplication.param.PmApplicationIdParam;
import com.unis.projectManagement.modular.pmApplication.param.PmApplicationPageParam;
import com.unis.projectManagement.modular.pmApplication.service.PmApplicationService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 项目申报管理表控制器
 *
 * @author hjc
 * @date 2024/05/27 17:26
 */
@Api(tags = "项目申报管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PmApplicationController {

    @Resource
    private PmApplicationService pmApplicationService;

    /**
     * 获取项目申报管理表分页
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取项目申报管理表分页")
    //@SaCheckPermission("/projectManagement/pmApplication/page")
    @GetMapping("/projectManagement/pmApplication/page")
    public CommonResult<Page<PmApplication>> page(PmApplicationPageParam pmApplicationPageParam) {
        return CommonResult.data(pmApplicationService.page(pmApplicationPageParam));
    }

    /**
     * 添加项目申报管理表
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加项目申报管理表")
    @CommonLog("添加项目申报管理表")
    //@SaCheckPermission("/projectManagement/pmApplication/add")
    @PostMapping("/projectManagement/pmApplication/add")
    public CommonResult<String> add(@RequestBody @Valid PmApplicationAddParam pmApplicationAddParam) {
        pmApplicationService.add(pmApplicationAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑项目申报管理表
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑项目申报管理表")
    @CommonLog("编辑项目申报管理表")
    //@SaCheckPermission("/projectManagement/pmApplication/edit")
    @PostMapping("/projectManagement/pmApplication/edit")
    public CommonResult<String> edit(@RequestBody @Valid PmApplicationEditParam pmApplicationEditParam) {
        pmApplicationService.edit(pmApplicationEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除项目申报管理表
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除项目申报管理表")
    @CommonLog("删除项目申报管理表")
    //@SaCheckPermission("/projectManagement/pmApplication/delete")
    @PostMapping("/projectManagement/pmApplication/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<PmApplicationIdParam> pmApplicationIdParamList) {
        pmApplicationService.delete(pmApplicationIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取项目申报管理表详情
     *
     * @author hjc
     * @date 2024/05/27 17:26
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取项目申报管理表详情")
    // @SaCheckPermission("/projectManagement/pmApplication/detail")
    @GetMapping("/projectManagement/pmApplication/detail")
    public CommonResult<PmApplication> detail(@Valid PmApplicationIdParam pmApplicationIdParam) {
        return CommonResult.data(pmApplicationService.detail(pmApplicationIdParam));
    }

}
