/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmApplication.entity;

import com.baomidou.mybatisplus.annotation.*;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 项目申报管理表实体
 *
 * @author hjc
 * @date  2024/05/27 17:26
 **/
@Getter
@Setter
@TableName("biz_pm_application")
public class PmApplication {

    /** 项目申报记录唯一标识符 */
    @TableId
    @ApiModelProperty(value = "项目申报记录唯一标识符", position = 1)
    private String id;

    /** 创建时间 */
    @ApiModelProperty(value = "创建时间", position = 2)
    @TableField(fill = FieldFill.INSERT)
    private Date createTime;

    /** 创建用户 */
    @ApiModelProperty(value = "创建用户", position = 3)
    @TableField(fill = FieldFill.INSERT)
    private String createUser;

    /** 修改时间 */
    @ApiModelProperty(value = "修改时间", position = 4)
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    /** 修改用户 */
    @ApiModelProperty(value = "修改用户", position = 5)
    @TableField(fill = FieldFill.UPDATE)
    private String updateUser;

    /** 项目编号 */
    @ApiModelProperty(value = "项目编号", position = 6)
    private String projectCode;

    /** 项目名称 */
    @ApiModelProperty(value = "项目名称", position = 7)
    private String projectName;

    /** 行政区划 */
    @ApiModelProperty(value = "行政区划", position = 8)
    private String administrativeDivision;

    /** 年份 */
    @ApiModelProperty(value = "年份", position = 9)
    private Integer year;

    /** 项目类型 1:财政预算内资金项目；2：专项资金项目；3：财政预算外资金项目；4：银行贷款项目；5：债券项目；6：外商投资项目；7：企业自筹资金项目；8：其他资金项目； */
    @ApiModelProperty(value = "项目类型 1:财政预算内资金项目；2：专项资金项目；3：财政预算外资金项目；4：银行贷款项目；5：债券项目；6：外商投资项目；7：企业自筹资金项目；8：其他资金项目；", position = 10)
    private Integer projectType;

    /** 拟开工时间 */
    @ApiModelProperty(value = "拟开工时间", position = 11)
    private Date plannedStartTime;

    /** 拟建成时间 */
    @ApiModelProperty(value = "拟建成时间", position = 12)
    private Date plannedCompletionTime;

    /** 建设状态 1：已立项未开工；2：建设中；3：已验收；4：已取消； */
    @ApiModelProperty(value = "建设状态 1：已立项未开工；2：建设中；3：已验收；4：已取消；", position = 13)
    private Integer constructionStatus;

    /** 申报日期 */
    @ApiModelProperty(value = "申报日期", position = 14)
    private Date declarationDate;

    /** 审批文号 */
    @ApiModelProperty(value = "审批文号", position = 15)
    private String approvalDocumentNumber;

    /** 项目（法人）单位 */
    @ApiModelProperty(value = "项目（法人）单位", position = 16)
    private String projectLegalUnit;

    /** 法定代表人证照类型 1：居民身份证；2：港澳居民来往内地通行证；3：台湾居民来往大陆通行证；4：护照；5：外国人永久居留身份证；6：港澳台居民居住证； */
    @ApiModelProperty(value = "法定代表人证照类型 1：居民身份证；2：港澳居民来往内地通行证；3：台湾居民来往大陆通行证；4：护照；5：外国人永久居留身份证；6：港澳台居民居住证；", position = 17)
    private Integer legalRepresentativeIdType;

    /** 法定代表人证照号码 */
    @ApiModelProperty(value = "法定代表人证照号码", position = 18)
    private String legalRepresentativeIdNumber;

    /** 联系人 */
    @ApiModelProperty(value = "联系人", position = 19)
    private String contactPerson;

    /** 联系方式 */
    @ApiModelProperty(value = "联系方式", position = 20)
    private String contactInformation;

    /** 电子邮箱 */
    @ApiModelProperty(value = "电子邮箱", position = 21)
    private String email;

    /** 建设地点-省 */
    @ApiModelProperty(value = "建设地点-省", position = 22)
    private String constructionLocationProvince;

    /** 建设地点-市州 */
    @ApiModelProperty(value = "建设地点-市州", position = 23)
    private String constructionLocationCity;

    /** 建设地点-区县 */
    @ApiModelProperty(value = "建设地点-区县", position = 24)
    private String constructionLocationDistrict;

    /** 建设地点-详细地址 */
    @ApiModelProperty(value = "建设地点-详细地址", position = 25)
    private String constructionLocationAddress;

    /** 总投资 */
    @ApiModelProperty(value = "总投资", position = 26)
    private BigDecimal totalInvestment;

    /** 固定资产投资 */
    @ApiModelProperty(value = "固定资产投资", position = 27)
    private BigDecimal fixedAssetInvestment;

    /** 中央财政资金 */
    @ApiModelProperty(value = "中央财政资金", position = 28)
    private BigDecimal centralFinancialFunds;

    /** 省财政资金 */
    @ApiModelProperty(value = "省财政资金", position = 29)
    private BigDecimal provincialFinancialFunds;

    /** 市财政资金 */
    @ApiModelProperty(value = "市财政资金", position = 30)
    private BigDecimal municipalFinancialFunds;

    /** 银行贷款 */
    @ApiModelProperty(value = "银行贷款", position = 31)
    private BigDecimal bankLoans;

    /** 股票债券 */
    @ApiModelProperty(value = "股票债券", position = 32)
    private BigDecimal stocksBonds;

    /** 其他资金 */
    @ApiModelProperty(value = "其他资金", position = 33)
    private BigDecimal otherFunds;

    /** 项目地址经度 */
    @ApiModelProperty(value = "项目地址经度", position = 34)
    private BigDecimal projectAddressLongitude;

    /** 项目地址纬度 */
    @ApiModelProperty(value = "项目地址纬度", position = 35)
    private BigDecimal projectAddressLatitude;

    /** 建设内容及规模 */
    @ApiModelProperty(value = "建设内容及规模", position = 36)
    private String constructionContentScale;

    /** 状态 0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复； */
    @ApiModelProperty(value = "状态 0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复；", position = 37)
    private Integer status;
}
