/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmBudget.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.unis.projectManagement.modular.projectInfoPlan.entity.ProjectInfoPlan;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 项目预算资金实体
 *
 * @author QSHan
 * @date  2024/05/28 16:04
 **/
@Getter
@Setter
@TableName("biz_pm_budget")
public class PmBudget {

    /** 项目预算资金唯一标识符 */
    @TableId
    @ApiModelProperty(value = "项目预算资金唯一标识符", position = 1)
    private String id;

    /** 创建时间 */
    @ApiModelProperty(value = "创建时间", position = 2)
    @TableField(fill = FieldFill.INSERT)
    private Date createTime;

    /** 创建用户 */
    @ApiModelProperty(value = "创建用户", position = 3)
    @TableField(fill = FieldFill.INSERT)
    private String createUser;

    /** 修改时间 */
    @ApiModelProperty(value = "修改时间", position = 4)
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    /** 修改用户 */
    @ApiModelProperty(value = "修改用户", position = 5)
    @TableField(fill = FieldFill.UPDATE)
    private String updateUser;

    /** biz_pm_project_info的id */
    @ApiModelProperty(value = "biz_pm_project_info的id", position = 6)
    private String pmProjectInfoId;

    /** biz_pm_application的id */
    @ApiModelProperty(value = "biz_pm_application的id", position = 7)
    private String pmApplicationId;

    /** 申报时间 */
    @ApiModelProperty(value = "申报时间", position = 8)
    private Date declarationTime;

    /** 项目建设牵头处室 */
    @ApiModelProperty(value = "项目建设牵头处室", position = 9)
    private String leadingDepartment;

    /** 申请人 */
    @ApiModelProperty(value = "申请人", position = 10)
    private String applicant;

    /** 牵头处室审核人 */
    @ApiModelProperty(value = "牵头处室审核人", position = 11)
    private String reviewer;

    /** 建设周期 */
    @ApiModelProperty(value = "建设周期", position = 12)
    private String constructionPeriod;

    /** 资金规模 */
    @ApiModelProperty(value = "资金规模", position = 13)
    private BigDecimal fundsScale;

    /** 资金来源，1：固定资产投资；2：中央财政资金；...；7：其他资金 */
    @ApiModelProperty(value = "资金来源(1:固定资产投资;2:中央财政资金;3.省财政资金;4.市财政资金;5.银行贷款;6.股票债券;7:其他资金)", position = 14)
    private Integer fundsSource;

    /** 绩效标准 */
    @ApiModelProperty(value = "绩效标准", position = 15)
    private String performanceStandard;

    /** 建设计划 */
    @ApiModelProperty(value = "建设计划", position = 16)
    private String constructionPlan;

    /** 建设内容概要 */
    @ApiModelProperty(value = "建设内容概要", position = 17)
    private String constructionContentSummary;

    /** 建议书或设计/建设方案 */
    @ApiModelProperty(value = "建议书或设计/建设方案", position = 18)
    private String proposalDesignOrConstructionScheme;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 19)
    private String remark;

    /** 状态 0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复； */
    @ApiModelProperty(value = "状态 0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复；", position = 20)
    private Integer status;

    @ApiModelProperty(value = "项目编号", position = 20)
    @TableField(exist = false)
    private String projectCode;

    @ApiModelProperty(value = "项目名称", position = 21)
    @TableField(exist = false)
    private String projectName;

    @ApiModelProperty(value = "项目进度计划", position = 22)
    @TableField(exist = false)
    private List<ProjectInfoPlan> projectInfoPlan;

    @ApiModelProperty(value = "审核意见", position = 23)
    @TableField(exist = false)
    private String auditAdvice;

    // 附件上传
    @ApiModelProperty(value = "附件上传-文件名称", position = 24)
    @TableField(exist = false)
    private String fileName;

    @ApiModelProperty(value = "附件上传-版本(不需要传值)", position = 25)
    @TableField(exist = false)
    private String version;

    /*@ApiModelProperty(value = "附件上传-备注(同主表备注相同不需要传值)", position = 26)
    @TableField(exist = false)
    private String upRemark;*/

    @ApiModelProperty(value = "附件上传-附件(url)", position = 27)
    @TableField(exist = false)
    private String attachment;

}
