/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmProjectInfo.controller;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.projectManagement.modular.pmApplication.entity.PmApplication;
import com.unis.projectManagement.modular.pmProjectInfo.vo.PmProjectInfoPageVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.alibaba.fastjson.JSONObject;
import com.unis.projectManagement.modular.pmProjectInfo.param.PmProjectInfoAddParam;
import com.unis.projectManagement.modular.pmProjectInfo.param.PmProjectInfoEditParam;
import com.unis.projectManagement.modular.pmProjectInfo.param.PmProjectInfoIdParam;
import com.unis.projectManagement.modular.pmProjectInfo.param.PmProjectInfoPageParam;
import com.unis.projectManagement.modular.pmProjectInfo.service.PmProjectInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 项目信息管理表控制器
 *
 * @author hjc
 * @date  2024/05/28 11:33
 */
@Api(tags = "项目信息管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PmProjectInfoController {

    @Resource
    private PmProjectInfoService pmProjectInfoService;

    /**
     * 获取项目信息管理表分页和项目进度管理分页
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取项目信息管理表分页")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/page")
    @GetMapping("/projectManagement/pmProjectInfo/page")
    public CommonResult<Page<PmProjectInfoPageVO>> page(PmProjectInfoPageParam pmProjectInfoPageParam) {
        return CommonResult.data(pmProjectInfoService.page(pmProjectInfoPageParam));
    }

    /**
     * 新增时下拉-获取项目申报信息   //带出后面数据接口  /projectManagement/pmApplication/detail
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("新增时下拉-获取项目申报信息")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/detail")
    @GetMapping("/projectManagement/pmProjectInfo/getPmApplication")
    public CommonResult<List<PmApplication>> getPmApplication() {
        return CommonResult.data(pmProjectInfoService.getPmApplication());
    }
    /**
     * 添加项目信息管理表
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加项目信息管理表")
    @CommonLog("添加项目信息管理表")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/add")
    @PostMapping("/projectManagement/pmProjectInfo/add")
    public CommonResult<String> add(@RequestBody @Valid PmProjectInfoAddParam pmProjectInfoAddParam) {
        pmProjectInfoService.add(pmProjectInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑项目信息管理表
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑项目信息管理表")
    @CommonLog("编辑项目信息管理表")
   // @SaCheckPermission("/projectManagement/pmProjectInfo/edit")
    @PostMapping("/projectManagement/pmProjectInfo/edit")
    public CommonResult<String> edit(@RequestBody @Valid PmProjectInfoEditParam pmProjectInfoEditParam) {
        pmProjectInfoService.edit(pmProjectInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除项目信息管理表
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除项目信息管理表")
    @CommonLog("删除项目信息管理表")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/delete")
    @PostMapping("/projectManagement/pmProjectInfo/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PmProjectInfoIdParam> pmProjectInfoIdParamList) {
        pmProjectInfoService.delete(pmProjectInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取项目信息管理表详情
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取项目信息管理表详情")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/detail")
    @GetMapping("/projectManagement/pmProjectInfo/detail")
    public CommonResult<JSONObject> detail(@Valid PmProjectInfoIdParam pmProjectInfoIdParam) {
        return CommonResult.data(pmProjectInfoService.detail(pmProjectInfoIdParam));
    }
    /**
     * 获取项目监督管理详情
     *
     * @author hjc
     * @date  2024/05/28 11:33
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取项目监督管理详情")
    //@SaCheckPermission("/projectManagement/pmProjectInfo/detail")
    @GetMapping("/projectManagement/pmProjectInfo/getSuperviseDetail")
    public CommonResult<JSONObject> getSuperviseDetail(@Valid PmProjectInfoIdParam pmProjectInfoIdParam) {
        return CommonResult.data(pmProjectInfoService.getSuperviseDetail(pmProjectInfoIdParam));
    }

}
