/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmProjectInfoFile.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.pmProjectInfoFile.entity.PmProjectInfoFile;
import com.unis.projectManagement.modular.pmProjectInfoFile.mapper.PmProjectInfoFileMapper;
import com.unis.projectManagement.modular.pmProjectInfoFile.param.PmProjectInfoFileAddParam;
import com.unis.projectManagement.modular.pmProjectInfoFile.param.PmProjectInfoFileEditParam;
import com.unis.projectManagement.modular.pmProjectInfoFile.param.PmProjectInfoFileIdParam;
import com.unis.projectManagement.modular.pmProjectInfoFile.param.PmProjectInfoFilePageParam;
import com.unis.projectManagement.modular.pmProjectInfoFile.service.PmProjectInfoFileService;

import java.util.List;

/**
 * 项目信息管理-项目文件表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/28 19:22
 **/
@Service
public class PmProjectInfoFileServiceImpl extends ServiceImpl<PmProjectInfoFileMapper, PmProjectInfoFile> implements PmProjectInfoFileService {

    @Override
    public Page<PmProjectInfoFile> page(PmProjectInfoFilePageParam pmProjectInfoFilePageParam) {
        QueryWrapper<PmProjectInfoFile> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(pmProjectInfoFilePageParam.getSortField(), pmProjectInfoFilePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pmProjectInfoFilePageParam.getSortOrder());
            queryWrapper.orderBy(true, pmProjectInfoFilePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pmProjectInfoFilePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PmProjectInfoFile::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PmProjectInfoFileAddParam pmProjectInfoFileAddParam) {
        PmProjectInfoFile pmProjectInfoFile = BeanUtil.toBean(pmProjectInfoFileAddParam, PmProjectInfoFile.class);
        this.save(pmProjectInfoFile);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PmProjectInfoFileEditParam pmProjectInfoFileEditParam) {
        PmProjectInfoFile pmProjectInfoFile = this.queryEntity(pmProjectInfoFileEditParam.getId());
        BeanUtil.copyProperties(pmProjectInfoFileEditParam, pmProjectInfoFile);
        this.updateById(pmProjectInfoFile);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PmProjectInfoFileIdParam> pmProjectInfoFileIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pmProjectInfoFileIdParamList, PmProjectInfoFileIdParam::getId));
    }

    @Override
    public PmProjectInfoFile detail(PmProjectInfoFileIdParam pmProjectInfoFileIdParam) {
        return this.queryEntity(pmProjectInfoFileIdParam.getId());
    }

    @Override
    public PmProjectInfoFile queryEntity(String id) {
        PmProjectInfoFile pmProjectInfoFile = this.getById(id);
        if(ObjectUtil.isEmpty(pmProjectInfoFile)) {
            throw new CommonException("项目信息管理-项目文件表不存在，id值为：{}", id);
        }
        return pmProjectInfoFile;
    }
}
