/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageConstruction.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.projectManagement.modular.pmStorageConstruction.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.projectManagement.modular.pmStorageConstruction.entity.PmStorageConstruction;
import com.unis.projectManagement.modular.pmStorageConstruction.service.PmStorageConstructionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 仓储设施投资-仓储设施建设表控制器
 *
 * @author hjc
 * @date  2024/05/30 15:58
 */
@Api(tags = "仓储设施建设表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PmStorageConstructionController {

    @Resource
    private PmStorageConstructionService pmStorageConstructionService;

    /**
     * 获取仓储设施投资-仓储设施建设表分页
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取仓储设施投资-仓储设施建设表分页")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/page")
    @GetMapping("/projectManagement/pmStorageConstruction/page")
    public CommonResult<Page<PmStorageConstruction>> page(PmStorageConstructionPageParam pmStorageConstructionPageParam) {
        return CommonResult.data(pmStorageConstructionService.page(pmStorageConstructionPageParam));
    }

    /**
     * 添加仓储设施投资-仓储设施建设表
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加仓储设施投资-仓储设施建设表")
    @CommonLog("添加仓储设施投资-仓储设施建设表")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/add")
    @PostMapping("/projectManagement/pmStorageConstruction/add")
    public CommonResult<String> add(@RequestBody @Valid PmStorageConstructionAddParam pmStorageConstructionAddParam) {
        pmStorageConstructionService.add(pmStorageConstructionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑仓储设施投资-仓储设施建设表
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑仓储设施投资-仓储设施建设表")
    @CommonLog("编辑仓储设施投资-仓储设施建设表")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/edit")
    @PostMapping("/projectManagement/pmStorageConstruction/edit")
    public CommonResult<String> edit(@RequestBody @Valid PmStorageConstructionEditParam pmStorageConstructionEditParam) {
        pmStorageConstructionService.edit(pmStorageConstructionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除仓储设施投资-仓储设施建设表
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除仓储设施投资-仓储设施建设表")
    @CommonLog("删除仓储设施投资-仓储设施建设表")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/delete")
    @PostMapping("/projectManagement/pmStorageConstruction/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PmStorageConstructionIdParam> pmStorageConstructionIdParamList) {
        pmStorageConstructionService.delete(pmStorageConstructionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取仓储设施投资-仓储设施建设表详情
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取仓储设施投资-仓储设施建设表详情")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/detail")
    @GetMapping("/projectManagement/pmStorageConstruction/detail")
    public CommonResult<JSONObject> detail(@Valid PmStorageConstructionIdParam pmStorageConstructionIdParam) {
        return CommonResult.data(pmStorageConstructionService.detail(pmStorageConstructionIdParam));
    }

    /**
     * 获取仓储设施投资-申报
     *
     * @author hjc
     * @date  2024/05/30 15:58
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取仓储设施投资-申报")
    //@SaCheckPermission("/projectManagement/pmStorageConstruction/detail")
    @GetMapping("/projectManagement/pmStorageConstruction/declare")
    public CommonResult<String> declare(@Valid PmStorageConstructionDeclareParam declareParam) {
        pmStorageConstructionService.declare(declareParam);
        return CommonResult.ok();
    }
}
