/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageConstruction.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.projectManagement.modular.pmStorageConstructionFile.entity.PmStorageConstructionFile;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.entity.PmStorageConstructionPlan;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 仓储设施投资-仓储设施建设表编辑参数
 *
 * @author hjc
 * @date  2024/05/30 15:58
 **/
@Getter
@Setter
public class PmStorageConstructionEditParam {

    /** 仓储设施建设记录唯一标识符 */
    @ApiModelProperty(value = "仓储设施建设记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 项目名称 */
    @ApiModelProperty(value = "项目名称", position = 6)
    private String projectName;

    /** 项目编号 */
    @ApiModelProperty(value = "项目编号", position = 7)
    private String projectCode;

    /** 项目单位 */
    @ApiModelProperty(value = "项目单位", position = 8)
    private String projectUnit;

    /** 资金投入（元） */
    @ApiModelProperty(value = "资金投入（元）", position = 9)
    private BigDecimal fundsInvested;

    /** 项目经理 */
    @ApiModelProperty(value = "项目经理", position = 10)
    private String projectManager;

    /** 联系方式 */
    @ApiModelProperty(value = "联系方式", position = 11)
    private String contactInformation;

    /** 项目审批或备案文号 */
    @ApiModelProperty(value = "项目审批或备案文号", position = 12)
    private String approvalOrRecordNumber;

    /** 立项日期 */
    @ApiModelProperty(value = "立项日期", position = 13)
    @JsonFormat(pattern="yyyy-MM-dd")
    private Date establishmentDate;

    /** 项目开始时间 */
    @ApiModelProperty(value = "项目开始时间", position = 14)
    private Date projectStartTime;

    /** 项目结束时间 */
    @ApiModelProperty(value = "项目结束时间", position = 15)
    private Date projectEndTime;

    /** 主要建设内容及规模 */
    @ApiModelProperty(value = "主要建设内容及规模", position = 16)
    private String constructionContentScale;

    /** 状态，0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复 */
    @ApiModelProperty(value = "状态，0：保存（待申报）；1：提交（待批复）；2：驳回；3：已批复", position = 17)
    private Integer status;


    /** 项目申报资料集合 */
    @ApiModelProperty(value = "项目申报资料集合", position = 18)
    private List<PmStorageConstructionFile> pmStorageConstructionFileList;

    /** 项目进度计划集合 */
    @ApiModelProperty(value = "项目进度计划集合", position = 19)
    private List<PmStorageConstructionPlan> pmStorageConstructionPlanList;

}
