/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageConstructionFile.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.pmStorageConstructionFile.entity.PmStorageConstructionFile;
import com.unis.projectManagement.modular.pmStorageConstructionFile.mapper.PmStorageConstructionFileMapper;
import com.unis.projectManagement.modular.pmStorageConstructionFile.param.PmStorageConstructionFileAddParam;
import com.unis.projectManagement.modular.pmStorageConstructionFile.param.PmStorageConstructionFileEditParam;
import com.unis.projectManagement.modular.pmStorageConstructionFile.param.PmStorageConstructionFileIdParam;
import com.unis.projectManagement.modular.pmStorageConstructionFile.param.PmStorageConstructionFilePageParam;
import com.unis.projectManagement.modular.pmStorageConstructionFile.service.PmStorageConstructionFileService;

import java.util.List;

/**
 * 仓储设施建设-项目文件表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/30 16:39
 **/
@Service
public class PmStorageConstructionFileServiceImpl extends ServiceImpl<PmStorageConstructionFileMapper, PmStorageConstructionFile> implements PmStorageConstructionFileService {

    @Override
    public Page<PmStorageConstructionFile> page(PmStorageConstructionFilePageParam pmStorageConstructionFilePageParam) {
        QueryWrapper<PmStorageConstructionFile> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(pmStorageConstructionFilePageParam.getSortField(), pmStorageConstructionFilePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pmStorageConstructionFilePageParam.getSortOrder());
            queryWrapper.orderBy(true, pmStorageConstructionFilePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pmStorageConstructionFilePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PmStorageConstructionFile::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PmStorageConstructionFileAddParam pmStorageConstructionFileAddParam) {
        PmStorageConstructionFile pmStorageConstructionFile = BeanUtil.toBean(pmStorageConstructionFileAddParam, PmStorageConstructionFile.class);
        this.save(pmStorageConstructionFile);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PmStorageConstructionFileEditParam pmStorageConstructionFileEditParam) {
        PmStorageConstructionFile pmStorageConstructionFile = this.queryEntity(pmStorageConstructionFileEditParam.getId());
        BeanUtil.copyProperties(pmStorageConstructionFileEditParam, pmStorageConstructionFile);
        this.updateById(pmStorageConstructionFile);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PmStorageConstructionFileIdParam> pmStorageConstructionFileIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pmStorageConstructionFileIdParamList, PmStorageConstructionFileIdParam::getId));
    }

    @Override
    public PmStorageConstructionFile detail(PmStorageConstructionFileIdParam pmStorageConstructionFileIdParam) {
        return this.queryEntity(pmStorageConstructionFileIdParam.getId());
    }

    @Override
    public PmStorageConstructionFile queryEntity(String id) {
        PmStorageConstructionFile pmStorageConstructionFile = this.getById(id);
        if(ObjectUtil.isEmpty(pmStorageConstructionFile)) {
            throw new CommonException("仓储设施建设-项目文件表不存在，id值为：{}", id);
        }
        return pmStorageConstructionFile;
    }
}
