/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageConstructionPlan.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.entity.PmStorageConstructionPlan;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.mapper.PmStorageConstructionPlanMapper;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.param.PmStorageConstructionPlanAddParam;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.param.PmStorageConstructionPlanEditParam;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.param.PmStorageConstructionPlanIdParam;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.param.PmStorageConstructionPlanPageParam;
import com.unis.projectManagement.modular.pmStorageConstructionPlan.service.PmStorageConstructionPlanService;

import java.util.List;

/**
 * 仓储设施建设-计划进度表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/30 16:40
 **/
@Service
public class PmStorageConstructionPlanServiceImpl extends ServiceImpl<PmStorageConstructionPlanMapper, PmStorageConstructionPlan> implements PmStorageConstructionPlanService {

    @Override
    public Page<PmStorageConstructionPlan> page(PmStorageConstructionPlanPageParam pmStorageConstructionPlanPageParam) {
        QueryWrapper<PmStorageConstructionPlan> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(pmStorageConstructionPlanPageParam.getSortField(), pmStorageConstructionPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pmStorageConstructionPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, pmStorageConstructionPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pmStorageConstructionPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PmStorageConstructionPlan::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PmStorageConstructionPlanAddParam pmStorageConstructionPlanAddParam) {
        PmStorageConstructionPlan pmStorageConstructionPlan = BeanUtil.toBean(pmStorageConstructionPlanAddParam, PmStorageConstructionPlan.class);
        this.save(pmStorageConstructionPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PmStorageConstructionPlanEditParam pmStorageConstructionPlanEditParam) {
        PmStorageConstructionPlan pmStorageConstructionPlan = this.queryEntity(pmStorageConstructionPlanEditParam.getId());
        BeanUtil.copyProperties(pmStorageConstructionPlanEditParam, pmStorageConstructionPlan);
        this.updateById(pmStorageConstructionPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PmStorageConstructionPlanIdParam> pmStorageConstructionPlanIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pmStorageConstructionPlanIdParamList, PmStorageConstructionPlanIdParam::getId));
    }

    @Override
    public PmStorageConstructionPlan detail(PmStorageConstructionPlanIdParam pmStorageConstructionPlanIdParam) {
        return this.queryEntity(pmStorageConstructionPlanIdParam.getId());
    }

    @Override
    public PmStorageConstructionPlan queryEntity(String id) {
        PmStorageConstructionPlan pmStorageConstructionPlan = this.getById(id);
        if(ObjectUtil.isEmpty(pmStorageConstructionPlan)) {
            throw new CommonException("仓储设施建设-计划进度表不存在，id值为：{}", id);
        }
        return pmStorageConstructionPlan;
    }
}
