/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageInvest.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.projectManagement.modular.pmStorageInvestAsset.entity.PmStorageInvestAsset;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.entity.PmStorageInvestDistribution;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 仓储设施投资表编辑参数
 *
 * @author hjc
 * @date  2024/05/29 19:17
 **/
@Getter
@Setter
public class PmStorageInvestEditParam {

    /** 项目记录唯一标识符 */
    @ApiModelProperty(value = "项目记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 项目名称 */
    @ApiModelProperty(value = "项目名称", position = 6)
    @NotBlank(message = "项目名称不能为空")
    private String projectName;

    /** 项目编号 */
    @ApiModelProperty(value = "项目编号", position = 7)
    private String projectCode;

    /** 项目单位 */
    @ApiModelProperty(value = "项目单位", position = 8)
    private String projectUnit;

    /** 资金投入(元)*/
    @ApiModelProperty(value = "资金投入(元)", position = 9)
    private BigDecimal moneyInvest;

    /** 项目经理 */
    @ApiModelProperty(value = "项目经理", position = 9)
    private String projectManager;

    /** 联系方式 */
    @ApiModelProperty(value = "联系方式", position = 10)
    private String contactInformation;

    /** 项目审批或备案文号 */
    @ApiModelProperty(value = "项目审批或备案文号", position = 11)
    private String approvalOrRecordNumber;

    /** 立项日期 */
    @ApiModelProperty(value = "立项日期", position = 12)
    @JsonFormat(pattern="yyyy-MM-dd")
    private Date establishmentDate;

    /** 项目开始时间 */
    @ApiModelProperty(value = "项目开始时间", position = 13)
    private Date projectStartTime;

    /** 项目结束时间 */
    @ApiModelProperty(value = "项目结束时间", position = 14)
    private Date projectEndTime;

    /** 储设施资产情况 */
    @ApiModelProperty(value = "储设施资产情况集合", position = 15)
    private List<PmStorageInvestAsset> pmStorageInvestAssetList;

    /** 投资分布情况集合 */
    @ApiModelProperty(value = "投资分布情况集合", position = 16)
    private List<PmStorageInvestDistribution> pmStorageInvestDistributionList;

}
