/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageInvestAsset.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.pmStorageInvestAsset.entity.PmStorageInvestAsset;
import com.unis.projectManagement.modular.pmStorageInvestAsset.mapper.PmStorageInvestAssetMapper;
import com.unis.projectManagement.modular.pmStorageInvestAsset.param.PmStorageInvestAssetAddParam;
import com.unis.projectManagement.modular.pmStorageInvestAsset.param.PmStorageInvestAssetEditParam;
import com.unis.projectManagement.modular.pmStorageInvestAsset.param.PmStorageInvestAssetIdParam;
import com.unis.projectManagement.modular.pmStorageInvestAsset.param.PmStorageInvestAssetPageParam;
import com.unis.projectManagement.modular.pmStorageInvestAsset.service.PmStorageInvestAssetService;

import java.util.List;

/**
 * 仓储设施投资-仓储设施资产情况表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/29 19:19
 **/
@Service
public class PmStorageInvestAssetServiceImpl extends ServiceImpl<PmStorageInvestAssetMapper, PmStorageInvestAsset> implements PmStorageInvestAssetService {

    @Override
    public Page<PmStorageInvestAsset> page(PmStorageInvestAssetPageParam pmStorageInvestAssetPageParam) {
        QueryWrapper<PmStorageInvestAsset> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(pmStorageInvestAssetPageParam.getSortField(), pmStorageInvestAssetPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pmStorageInvestAssetPageParam.getSortOrder());
            queryWrapper.orderBy(true, pmStorageInvestAssetPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pmStorageInvestAssetPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PmStorageInvestAsset::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PmStorageInvestAssetAddParam pmStorageInvestAssetAddParam) {
        PmStorageInvestAsset pmStorageInvestAsset = BeanUtil.toBean(pmStorageInvestAssetAddParam, PmStorageInvestAsset.class);
        this.save(pmStorageInvestAsset);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PmStorageInvestAssetEditParam pmStorageInvestAssetEditParam) {
        PmStorageInvestAsset pmStorageInvestAsset = this.queryEntity(pmStorageInvestAssetEditParam.getId());
        BeanUtil.copyProperties(pmStorageInvestAssetEditParam, pmStorageInvestAsset);
        this.updateById(pmStorageInvestAsset);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PmStorageInvestAssetIdParam> pmStorageInvestAssetIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pmStorageInvestAssetIdParamList, PmStorageInvestAssetIdParam::getId));
    }

    @Override
    public PmStorageInvestAsset detail(PmStorageInvestAssetIdParam pmStorageInvestAssetIdParam) {
        return this.queryEntity(pmStorageInvestAssetIdParam.getId());
    }

    @Override
    public PmStorageInvestAsset queryEntity(String id) {
        PmStorageInvestAsset pmStorageInvestAsset = this.getById(id);
        if(ObjectUtil.isEmpty(pmStorageInvestAsset)) {
            throw new CommonException("仓储设施投资-仓储设施资产情况表不存在，id值为：{}", id);
        }
        return pmStorageInvestAsset;
    }
}
