/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageInvestDistribution.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.entity.PmStorageInvestDistribution;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionAddParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionEditParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionIdParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionPageParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.service.PmStorageInvestDistributionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 仓储设施投资-投资分布表控制器
 *
 * @author hjc
 * @date  2024/05/29 19:21
 */
@Api(tags = "仓储设施投资-投资分布表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PmStorageInvestDistributionController {

    @Resource
    private PmStorageInvestDistributionService pmStorageInvestDistributionService;

    /**
     * 获取仓储设施投资-投资分布表分页
     *
     * @author hjc
     * @date  2024/05/29 19:21
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取仓储设施投资-投资分布表分页")
    //@SaCheckPermission("/projectManagement/pmStorageInvestDistribution/page")
    @GetMapping("/projectManagement/pmStorageInvestDistribution/page")
    public CommonResult<Page<PmStorageInvestDistribution>> page(PmStorageInvestDistributionPageParam pmStorageInvestDistributionPageParam) {
        return CommonResult.data(pmStorageInvestDistributionService.page(pmStorageInvestDistributionPageParam));
    }

    /**
     * 添加仓储设施投资-投资分布表
     *
     * @author hjc
     * @date  2024/05/29 19:21
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加仓储设施投资-投资分布表")
    @CommonLog("添加仓储设施投资-投资分布表")
    //@SaCheckPermission("/projectManagement/pmStorageInvestDistribution/add")
    @PostMapping("/projectManagement/pmStorageInvestDistribution/add")
    public CommonResult<String> add(@RequestBody @Valid PmStorageInvestDistributionAddParam pmStorageInvestDistributionAddParam) {
        pmStorageInvestDistributionService.add(pmStorageInvestDistributionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑仓储设施投资-投资分布表
     *
     * @author hjc
     * @date  2024/05/29 19:21
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑仓储设施投资-投资分布表")
    @CommonLog("编辑仓储设施投资-投资分布表")
    //@SaCheckPermission("/projectManagement/pmStorageInvestDistribution/edit")
    @PostMapping("/projectManagement/pmStorageInvestDistribution/edit")
    public CommonResult<String> edit(@RequestBody @Valid PmStorageInvestDistributionEditParam pmStorageInvestDistributionEditParam) {
        pmStorageInvestDistributionService.edit(pmStorageInvestDistributionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除仓储设施投资-投资分布表
     *
     * @author hjc
     * @date  2024/05/29 19:21
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除仓储设施投资-投资分布表")
    @CommonLog("删除仓储设施投资-投资分布表")
    //@SaCheckPermission("/projectManagement/pmStorageInvestDistribution/delete")
    @PostMapping("/projectManagement/pmStorageInvestDistribution/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PmStorageInvestDistributionIdParam> pmStorageInvestDistributionIdParamList) {
        pmStorageInvestDistributionService.delete(pmStorageInvestDistributionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取仓储设施投资-投资分布表详情
     *
     * @author hjc
     * @date  2024/05/29 19:21
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取仓储设施投资-投资分布表详情")
    //@SaCheckPermission("/projectManagement/pmStorageInvestDistribution/detail")
    @GetMapping("/projectManagement/pmStorageInvestDistribution/detail")
    public CommonResult<PmStorageInvestDistribution> detail(@Valid PmStorageInvestDistributionIdParam pmStorageInvestDistributionIdParam) {
        return CommonResult.data(pmStorageInvestDistributionService.detail(pmStorageInvestDistributionIdParam));
    }
}
