/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.pmStorageInvestDistribution.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.entity.PmStorageInvestDistribution;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.mapper.PmStorageInvestDistributionMapper;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionAddParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionEditParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionIdParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.param.PmStorageInvestDistributionPageParam;
import com.unis.projectManagement.modular.pmStorageInvestDistribution.service.PmStorageInvestDistributionService;

import java.util.List;

/**
 * 仓储设施投资-投资分布表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/29 19:21
 **/
@Service
public class PmStorageInvestDistributionServiceImpl extends ServiceImpl<PmStorageInvestDistributionMapper, PmStorageInvestDistribution> implements PmStorageInvestDistributionService {

    @Override
    public Page<PmStorageInvestDistribution> page(PmStorageInvestDistributionPageParam pmStorageInvestDistributionPageParam) {
        QueryWrapper<PmStorageInvestDistribution> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(pmStorageInvestDistributionPageParam.getSortField(), pmStorageInvestDistributionPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(pmStorageInvestDistributionPageParam.getSortOrder());
            queryWrapper.orderBy(true, pmStorageInvestDistributionPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(pmStorageInvestDistributionPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PmStorageInvestDistribution::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PmStorageInvestDistributionAddParam pmStorageInvestDistributionAddParam) {
        PmStorageInvestDistribution pmStorageInvestDistribution = BeanUtil.toBean(pmStorageInvestDistributionAddParam, PmStorageInvestDistribution.class);
        this.save(pmStorageInvestDistribution);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PmStorageInvestDistributionEditParam pmStorageInvestDistributionEditParam) {
        PmStorageInvestDistribution pmStorageInvestDistribution = this.queryEntity(pmStorageInvestDistributionEditParam.getId());
        BeanUtil.copyProperties(pmStorageInvestDistributionEditParam, pmStorageInvestDistribution);
        this.updateById(pmStorageInvestDistribution);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PmStorageInvestDistributionIdParam> pmStorageInvestDistributionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pmStorageInvestDistributionIdParamList, PmStorageInvestDistributionIdParam::getId));
    }

    @Override
    public PmStorageInvestDistribution detail(PmStorageInvestDistributionIdParam pmStorageInvestDistributionIdParam) {
        return this.queryEntity(pmStorageInvestDistributionIdParam.getId());
    }

    @Override
    public PmStorageInvestDistribution queryEntity(String id) {
        PmStorageInvestDistribution pmStorageInvestDistribution = this.getById(id);
        if(ObjectUtil.isEmpty(pmStorageInvestDistribution)) {
            throw new CommonException("仓储设施投资-投资分布表不存在，id值为：{}", id);
        }
        return pmStorageInvestDistribution;
    }
}
