/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.projectInfoPlan.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.projectManagement.modular.projectInfoPlan.entity.ProjectInfoPlan;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanAddParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanEditParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanIdParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanPageParam;
import com.unis.projectManagement.modular.projectInfoPlan.service.ProjectInfoPlanService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 进度监督控制器
 *
 * @author QSHan
 * @date  2024/05/28 11:54
 */
@Api(tags = "项目信息管理-计划进度表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class ProjectInfoPlanController {

    @Resource
    private ProjectInfoPlanService projectInfoPlanService;

    /**
     * 获取进度监督分页
     *
     * @author QSHan
     * @date  2024/05/28 11:54
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("项目信息管理分页")
//    @SaCheckPermission("/projectManagement/projectInfoPlan/page")
    @GetMapping("/projectManagement/projectInfoPlan/page")
    public CommonResult<Page<ProjectInfoPlan>> page(ProjectInfoPlanPageParam projectInfoPlanPageParam) {
        return CommonResult.data(projectInfoPlanService.page(projectInfoPlanPageParam));
    }

    /**
     * 添加进度监督
     *
     * @author QSHan
     * @date  2024/05/28 11:54
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加项目信息管理")
    @CommonLog("添加项目信息管理")
//    @SaCheckPermission("/projectManagement/projectInfoPlan/add")
    @PostMapping("/projectManagement/projectInfoPlan/add")
    public CommonResult<String> add(@RequestBody @Valid ProjectInfoPlanAddParam projectInfoPlanAddParam) {
        projectInfoPlanService.add(projectInfoPlanAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑进度监督
     *
     * @author QSHan
     * @date  2024/05/28 11:54
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑项目信息管理")
    @CommonLog("编辑项目信息管理")
//    @SaCheckPermission("/projectManagement/projectInfoPlan/edit")
    @PostMapping("/projectManagement/projectInfoPlan/edit")
    public CommonResult<String> edit(@RequestBody @Valid ProjectInfoPlanEditParam projectInfoPlanEditParam) {
        projectInfoPlanService.edit(projectInfoPlanEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除进度监督
     *
     * @author QSHan
     * @date  2024/05/28 11:54
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除项目信息管理")
    @CommonLog("删除项目信息管理")
//    @SaCheckPermission("/projectManagement/projectInfoPlan/delete")
    @PostMapping("/projectManagement/projectInfoPlan/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<ProjectInfoPlanIdParam> projectInfoPlanIdParamList) {
        projectInfoPlanService.delete(projectInfoPlanIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取进度监督详情
     *
     * @author QSHan
     * @date  2024/05/28 11:54
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取项目信息管理详情")
//    @SaCheckPermission("/projectManagement/projectInfoPlan/detail")
    @GetMapping("/projectManagement/projectInfoPlan/detail")
    public CommonResult<ProjectInfoPlan> detail(@Valid ProjectInfoPlanIdParam projectInfoPlanIdParam) {
        return CommonResult.data(projectInfoPlanService.detail(projectInfoPlanIdParam));
    }
}
