/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.projectManagement.modular.projectInfoPlan.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.projectManagement.modular.projectInfoPlan.entity.ProjectInfoPlan;
import com.unis.projectManagement.modular.projectInfoPlan.mapper.ProjectInfoPlanMapper;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanAddParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanEditParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanIdParam;
import com.unis.projectManagement.modular.projectInfoPlan.param.ProjectInfoPlanPageParam;
import com.unis.projectManagement.modular.projectInfoPlan.service.ProjectInfoPlanService;

import java.util.List;

/**
 * 进度监督Service接口实现类
 *
 * @author QSHan
 * @date  2024/05/28 11:54
 **/
@Service
public class ProjectInfoPlanServiceImpl extends ServiceImpl<ProjectInfoPlanMapper, ProjectInfoPlan> implements ProjectInfoPlanService {

    @Override
    public Page<ProjectInfoPlan> page(ProjectInfoPlanPageParam projectInfoPlanPageParam) {
        QueryWrapper<ProjectInfoPlan> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(projectInfoPlanPageParam.getSortField(), projectInfoPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(projectInfoPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, projectInfoPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(projectInfoPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(ProjectInfoPlan::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(ProjectInfoPlanAddParam projectInfoPlanAddParam) {
        ProjectInfoPlan projectInfoPlan = BeanUtil.toBean(projectInfoPlanAddParam, ProjectInfoPlan.class);
        this.save(projectInfoPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(ProjectInfoPlanEditParam projectInfoPlanEditParam) {
        ProjectInfoPlan projectInfoPlan = this.queryEntity(projectInfoPlanEditParam.getId());
        BeanUtil.copyProperties(projectInfoPlanEditParam, projectInfoPlan);
        this.updateById(projectInfoPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<ProjectInfoPlanIdParam> projectInfoPlanIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(projectInfoPlanIdParamList, ProjectInfoPlanIdParam::getId));
    }

    @Override
    public ProjectInfoPlan detail(ProjectInfoPlanIdParam projectInfoPlanIdParam) {
        return this.queryEntity(projectInfoPlanIdParam.getId());
    }

    @Override
    public ProjectInfoPlan queryEntity(String id) {
        ProjectInfoPlan projectInfoPlan = this.getById(id);
        if(ObjectUtil.isEmpty(projectInfoPlan)) {
            throw new CommonException("进度监督不存在，id值为：{}", id);
        }
        return projectInfoPlan;
    }
}
