/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.entity.BizPssFundDockCollect;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectAddParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectEditParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectIdParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectPageParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.service.BizPssFundDockCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 财务类业务监管-资金信息对接采集表控制器
 *
 * @author hjc
 * @date  2024/06/13 14:39
 */
@Api(tags = "财务类业务监管-资金信息对接采集表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizPssFundDockCollectController {

    @Resource
    private BizPssFundDockCollectService bizPssFundDockCollectService;

    /**
     * 获取财务类业务监管-资金信息对接采集表分页
     *
     * @author hjc
     * @date  2024/06/13 14:39
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取财务类业务监管-资金信息对接采集表分页")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssFundDockCollect/page")
    @GetMapping("/purchaseAndSalesSupervision/bizPssFundDockCollect/page")
    public CommonResult<Page<BizPssFundDockCollect>> page(BizPssFundDockCollectPageParam bizPssFundDockCollectPageParam) {
        return CommonResult.data(bizPssFundDockCollectService.page(bizPssFundDockCollectPageParam));
    }

    /**
     * 添加财务类业务监管-资金信息对接采集表
     *
     * @author hjc
     * @date  2024/06/13 14:39
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加财务类业务监管-资金信息对接采集表")
    @CommonLog("添加财务类业务监管-资金信息对接采集表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssFundDockCollect/add")
    @PostMapping("/purchaseAndSalesSupervision/bizPssFundDockCollect/add")
    public CommonResult<String> add(@RequestBody @Valid BizPssFundDockCollectAddParam bizPssFundDockCollectAddParam) {
        bizPssFundDockCollectService.add(bizPssFundDockCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑财务类业务监管-资金信息对接采集表
     *
     * @author hjc
     * @date  2024/06/13 14:39
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑财务类业务监管-资金信息对接采集表")
    @CommonLog("编辑财务类业务监管-资金信息对接采集表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssFundDockCollect/edit")
    @PostMapping("/purchaseAndSalesSupervision/bizPssFundDockCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPssFundDockCollectEditParam bizPssFundDockCollectEditParam) {
        bizPssFundDockCollectService.edit(bizPssFundDockCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除财务类业务监管-资金信息对接采集表
     *
     * @author hjc
     * @date  2024/06/13 14:39
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除财务类业务监管-资金信息对接采集表")
    @CommonLog("删除财务类业务监管-资金信息对接采集表")
   // @SaCheckPermission("/purchaseAndSalesSupervision/bizPssFundDockCollect/delete")
    @PostMapping("/purchaseAndSalesSupervision/bizPssFundDockCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizPssFundDockCollectIdParam> bizPssFundDockCollectIdParamList) {
        bizPssFundDockCollectService.delete(bizPssFundDockCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取财务类业务监管-资金信息对接采集表详情
     *
     * @author hjc
     * @date  2024/06/13 14:39
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取财务类业务监管-资金信息对接采集表详情")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssFundDockCollect/detail")
    @GetMapping("/purchaseAndSalesSupervision/bizPssFundDockCollect/detail")
    public CommonResult<BizPssFundDockCollect> detail(@Valid BizPssFundDockCollectIdParam bizPssFundDockCollectIdParam) {
        return CommonResult.data(bizPssFundDockCollectService.detail(bizPssFundDockCollectIdParam));
    }
}
