/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 财务类业务监管-资金信息对接采集表编辑参数
 *
 * @author hjc
 * @date  2024/06/13 14:39
 **/
@Getter
@Setter
public class BizPssFundDockCollectEditParam {

    /** 资金信息对接采集记录唯一标识符 */
    @ApiModelProperty(value = "资金信息对接采集记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 贷款单号 */
    @ApiModelProperty(value = "贷款单号", position = 6)
    @NotBlank(message = "贷款单号不能为空")
    private String loanNumber;

    /** 借款单位 */
    @ApiModelProperty(value = "借款单位", position = 7)
    @NotBlank(message = "借款单位不能为空")
    private String borrowingUnit;

    /** 利息单号 */
    @ApiModelProperty(value = "利息单号", position = 8)
    @NotBlank(message = "利息单号不能为空")
    private String interestNumber;

    /** 计息账户 */
    @ApiModelProperty(value = "计息账户", position = 9)
    @NotBlank(message = "计息账号不能为空")
    private String interestBearingAccount;

    /** 计息开始日 */
    @ApiModelProperty(value = "计息开始日", position = 10)
    @NotNull(message = "计息开始日不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date interestStartDate;

    /** 计息结束日 */
    @ApiModelProperty(value = "计息结束日", position = 11)
    @NotNull(message = "计息结束日不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date interestEndDate;

    /** 计息天数 */
    @ApiModelProperty(value = "计息天数", position = 12)
    @NotNull(message = "计息天数不能为空")
    private Integer interestDays;

    /** 计息本金 */
    @ApiModelProperty(value = "计息本金", position = 13)
    @NotNull(message = "计息本金不能为空")
    private BigDecimal principalAmount;

    /** 利率 */
    @ApiModelProperty(value = "利率", position = 14)
    @NotNull(message = "利率不能为空")
    private BigDecimal interestRate;

    /** 应计利息 */
    @ApiModelProperty(value = "应计利息", position = 15)
    @NotNull(message = "应计利息不能为空")
    private BigDecimal accruedInterest;

    /** 实计利息 */
    @ApiModelProperty(value = "实计利息", position = 16)
    @NotNull(message = "实计利息不能为空")
    private BigDecimal actualInterest;

    /** 罚息率 */
    @ApiModelProperty(value = "罚息率", position = 17)
    @NotNull(message = "罚息率不能为空")
    private BigDecimal penaltyRate;

    /** 应计罚息 */
    @ApiModelProperty(value = "应计罚息", position = 18)
    @NotNull(message = "应计罚息不能为空")
    private BigDecimal accruedPenalty;

    /** 实计罚息 */
    @ApiModelProperty(value = "实计罚息", position = 19)
    @NotNull(message = "实计罚息不能为空")
    private BigDecimal actualPenalty;

    /** 逾期天数 */
    @ApiModelProperty(value = "逾期天数", position = 20)
    @NotNull(message = "逾期天数不能为空")
    private Integer overdueDays;

    /** 币种 */
    @ApiModelProperty(value = "币种", position = 21)
    @NotBlank(message = "币种不能为空")
    private String currency;
}
