/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.entity.BizPssFundDockCollect;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.mapper.BizPssFundDockCollectMapper;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectAddParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectEditParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectIdParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.param.BizPssFundDockCollectPageParam;
import com.unis.purchaseAndSalesSupervision.modular.bizPssFundDockCollect.service.BizPssFundDockCollectService;

import java.util.List;

/**
 * 财务类业务监管-资金信息对接采集表Service接口实现类
 *
 * @author hjc
 * @date  2024/06/13 14:39
 **/
@Service
public class BizPssFundDockCollectServiceImpl extends ServiceImpl<BizPssFundDockCollectMapper, BizPssFundDockCollect> implements BizPssFundDockCollectService {

    @Override
    public Page<BizPssFundDockCollect> page(BizPssFundDockCollectPageParam bizPssFundDockCollectPageParam) {
        QueryWrapper<BizPssFundDockCollect> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(bizPssFundDockCollectPageParam.getBorrowingUnit())){
            queryWrapper.lambda().like(BizPssFundDockCollect::getBorrowingUnit,bizPssFundDockCollectPageParam.getBorrowingUnit());
        }
        if (StringUtils.isNotEmpty(bizPssFundDockCollectPageParam.getInterestNumber())){
            queryWrapper.lambda().like(BizPssFundDockCollect::getInterestNumber,bizPssFundDockCollectPageParam.getInterestNumber());
        }
        if(ObjectUtil.isAllNotEmpty(bizPssFundDockCollectPageParam.getSortField(), bizPssFundDockCollectPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizPssFundDockCollectPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizPssFundDockCollectPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizPssFundDockCollectPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizPssFundDockCollect::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizPssFundDockCollectAddParam bizPssFundDockCollectAddParam) {
        BizPssFundDockCollect bizPssFundDockCollect = BeanUtil.toBean(bizPssFundDockCollectAddParam, BizPssFundDockCollect.class);
        this.save(bizPssFundDockCollect);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizPssFundDockCollectEditParam bizPssFundDockCollectEditParam) {
        BizPssFundDockCollect bizPssFundDockCollect = this.queryEntity(bizPssFundDockCollectEditParam.getId());
        BeanUtil.copyProperties(bizPssFundDockCollectEditParam, bizPssFundDockCollect);
        this.updateById(bizPssFundDockCollect);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizPssFundDockCollectIdParam> bizPssFundDockCollectIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizPssFundDockCollectIdParamList, BizPssFundDockCollectIdParam::getId));
    }

    @Override
    public BizPssFundDockCollect detail(BizPssFundDockCollectIdParam bizPssFundDockCollectIdParam) {
        return this.queryEntity(bizPssFundDockCollectIdParam.getId());
    }

    @Override
    public BizPssFundDockCollect queryEntity(String id) {
        BizPssFundDockCollect bizPssFundDockCollect = this.getById(id);
        if(ObjectUtil.isEmpty(bizPssFundDockCollect)) {
            throw new CommonException("财务类业务监管-资金信息对接采集表不存在，id值为：{}", id);
        }
        return bizPssFundDockCollect;
    }
}
