/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssMoRotationEmptyPeriod.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.purchaseAndSalesSupervision.modular.bizPssMoRotationEmptyPeriod.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.purchaseAndSalesSupervision.modular.bizPssMoRotationEmptyPeriod.entity.BizPssMoRotationEmptyPeriod;
import com.unis.purchaseAndSalesSupervision.modular.bizPssMoRotationEmptyPeriod.service.BizPssMoRotationEmptyPeriodService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 模型优化-轮空期模型优化表控制器
 *
 * @author hjc
 * @date  2024/06/12 20:03
 */
@Api(tags = "模型优化-轮空期模型优化表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizPssMoRotationEmptyPeriodController {

    @Resource
    private BizPssMoRotationEmptyPeriodService bizPssMoRotationEmptyPeriodService;

    /**
     * 获取模型优化-轮空期模型优化表分页
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取-轮空期模型优化表分页")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/page")
    @GetMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/page")
    public CommonResult<Page<BizPssMoRotationEmptyPeriod>> page(BizPssMoRotationEmptyPeriodPageParam bizPssMoRotationEmptyPeriodPageParam) {
        return CommonResult.data(bizPssMoRotationEmptyPeriodService.page(bizPssMoRotationEmptyPeriodPageParam));
    }

    /**
     * 添加模型优化-轮空期模型优化表
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加-轮空期模型优化表")
    @CommonLog("添加-轮空期模型优化表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/add")
    @PostMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/add")
    public CommonResult<String> add(@RequestBody @Valid BizPssMoRotationEmptyPeriodAddParam bizPssMoRotationEmptyPeriodAddParam) {
        bizPssMoRotationEmptyPeriodService.add(bizPssMoRotationEmptyPeriodAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑模型优化-轮空期模型优化表
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑-轮空期模型优化表")
    @CommonLog("编辑-轮空期模型优化表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/edit")
    @PostMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPssMoRotationEmptyPeriodEditParam bizPssMoRotationEmptyPeriodEditParam) {
        bizPssMoRotationEmptyPeriodService.edit(bizPssMoRotationEmptyPeriodEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除模型优化-轮空期模型优化表
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除-轮空期模型优化表")
    @CommonLog("删除-轮空期模型优化表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/delete")
    @PostMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizPssMoRotationEmptyPeriodIdParam> bizPssMoRotationEmptyPeriodIdParamList) {
        bizPssMoRotationEmptyPeriodService.delete(bizPssMoRotationEmptyPeriodIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取模型优化-轮空期模型优化表详情
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("轮空期模型优化表-详情")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/detail")
    @GetMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/detail")
    public CommonResult<BizPssMoRotationEmptyPeriod> detail(@Valid BizPssMoRotationEmptyPeriodIdParam bizPssMoRotationEmptyPeriodIdParam) {
        return CommonResult.data(bizPssMoRotationEmptyPeriodService.detail(bizPssMoRotationEmptyPeriodIdParam));
    }

    /**
     * 获取模型优化-轮空期模型优化表-开启关闭
     *
     * @author hjc
     * @date  2024/06/12 20:03
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("轮空期模型优化表-开启关闭")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/detail")
    @GetMapping("/purchaseAndSalesSupervision/bizPssMoRotationEmptyPeriod/isEnabledById")
    public CommonResult<String> isEnabledById(@Valid BizPssMoRotationEmptyPeriodIsEnabledByIdParam isEnabledByIdParam) {
        bizPssMoRotationEmptyPeriodService.isEnabledById(isEnabledByIdParam);
        return CommonResult.ok();
    }

}
