/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.param.*;
import com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.vo.BizPssRepaymentRiskWarnVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.entity.BizPssRepaymentRiskWarn;
import com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.service.BizPssRepaymentRiskWarnService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 财务类业务监管-偿还风险预警表控制器
 *
 * @author hjc
 * @date  2024/06/13 14:42
 */
@Api(tags = "财务类业务监管-偿还风险预警表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizPssRepaymentRiskWarnController {

    @Resource
    private BizPssRepaymentRiskWarnService bizPssRepaymentRiskWarnService;

    /**
     * 获取财务类业务监管-偿还风险预警表分页
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取财务类业务监管-偿还风险预警表分页")
   // @SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/page")
    @GetMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/page")
    public CommonResult<Page<BizPssRepaymentRiskWarnVO>> page(BizPssRepaymentRiskWarnPageParam bizPssRepaymentRiskWarnPageParam) {
        return CommonResult.data(bizPssRepaymentRiskWarnService.page(bizPssRepaymentRiskWarnPageParam));
    }

    /**
     * 添加财务类业务监管-偿还风险预警表
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加财务类业务监管-偿还风险预警表")
    @CommonLog("添加财务类业务监管-偿还风险预警表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/add")
    @PostMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/add")
    public CommonResult<String> add(@RequestBody @Valid BizPssRepaymentRiskWarnAddParam bizPssRepaymentRiskWarnAddParam) {
        bizPssRepaymentRiskWarnService.add(bizPssRepaymentRiskWarnAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑财务类业务监管-偿还风险预警表
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑财务类业务监管-偿还风险预警表")
    @CommonLog("编辑财务类业务监管-偿还风险预警表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/edit")
    @PostMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPssRepaymentRiskWarnEditParam bizPssRepaymentRiskWarnEditParam) {
        bizPssRepaymentRiskWarnService.edit(bizPssRepaymentRiskWarnEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除财务类业务监管-偿还风险预警表
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除财务类业务监管-偿还风险预警表")
    @CommonLog("删除财务类业务监管-偿还风险预警表")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/delete")
    @PostMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizPssRepaymentRiskWarnIdParam> bizPssRepaymentRiskWarnIdParamList) {
        bizPssRepaymentRiskWarnService.delete(bizPssRepaymentRiskWarnIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取财务类业务监管-偿还风险预警表详情
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取财务类业务监管-偿还风险预警表详情")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/detail")
    @GetMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/detail")
    public CommonResult<BizPssRepaymentRiskWarn> detail(@Valid BizPssRepaymentRiskWarnIdParam bizPssRepaymentRiskWarnIdParam) {
        return CommonResult.data(bizPssRepaymentRiskWarnService.detail(bizPssRepaymentRiskWarnIdParam));
    }

    /**
     * 获取库区信息
     *
     * @author hjc
     * @date  2024/06/13 14:42
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取库区信息")
    //@SaCheckPermission("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/detail")
    @GetMapping("/purchaseAndSalesSupervision/bizPssRepaymentRiskWarn/getOrgInfoIdAndName")
    public CommonResult<List<OrgInfo>> getOrgInfoIdAndName() {
        return CommonResult.data(bizPssRepaymentRiskWarnService.getOrgInfoIdAndName());
    }
}
