/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.bizPssRepaymentRiskWarn.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 财务类业务监管-偿还风险预警表添加参数
 *
 * @author hjc
 * @date  2024/06/13 14:42
 **/
@Getter
@Setter
public class BizPssRepaymentRiskWarnAddParam {

    /** 库区id；外库depot_qh.org_info的id； */
    @ApiModelProperty(value = "库区id；外库depot_qh.org_info的id；", position = 6)
    @NotNull(message = "库区id不能为空")
    private Integer orgId;

    /** 贷款金额 */
    @ApiModelProperty(value = "贷款金额", position = 7)
    @NotNull(message = "贷款金额不能为空")
    private BigDecimal loanAmount;

    /** 贷款时间 */
    @ApiModelProperty(value = "贷款时间", position = 8)
    @NotNull(message = "贷款时间不能为空")
    private Date loanTime;

    /** 贷款年限 */
    @ApiModelProperty(value = "贷款年限", position = 9)
    @NotNull(message = "贷款年限不能为空")
    private Integer loanTerm;

    /** 还款笔数 */
    @ApiModelProperty(value = "还款笔数", position = 10)
    @NotNull(message = "还款笔数不能为空")
    private Integer repaymentCount;

    /** 还款金额 */
    @ApiModelProperty(value = "还款金额", position = 11)
    @NotNull(message = "还款金额不能为空")
    private BigDecimal repaymentAmount;

    /** 最近还款时间 */
    @ApiModelProperty(value = "最近还款时间", position = 12)
    @NotNull(message = "最近还款时间不能为空")
    private Date lastRepaymentTime;

    /** 计息开始日 */
    @ApiModelProperty(value = "计息开始日", position = 13)
    @NotNull(message = "计息开始日不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date interestStartDate;

    /** 计息结束日 */
    @ApiModelProperty(value = "计息结束日", position = 14)
    @NotNull(message = "计息结束日不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date interestEndDate;

    /** 计息天数 */
    @ApiModelProperty(value = "计息天数", position = 15)
    @NotNull(message = "计息天数不能为空")
    private Integer interestDays;

    /** 购粮支出金额 */
    @ApiModelProperty(value = "购粮支出金额", position = 16)
    @NotNull(message = "购粮支出金额不能为空")
    private BigDecimal grainPurchaseExpense;

    /** 售粮收入金额 */
    @ApiModelProperty(value = "售粮收入金额", position = 17)
    @NotNull(message = "售粮收入金额不能为空")
    private BigDecimal grainSaleIncome;

    /** 利率 */
    @ApiModelProperty(value = "利率", position = 18)
    @NotNull(message = "利率不能为空")
    private BigDecimal interestRate;

    /** 应计利息 */
    @ApiModelProperty(value = "应计利息", position = 19)
    @NotNull(message = "应计利息不能为空")
    private BigDecimal accruedInterest;

    /** 实计利息 */
    @ApiModelProperty(value = "实计利息", position = 20)
    @NotNull(message = "实计利息不能为空")
    private BigDecimal actualInterest;

    /** 罚息率 */
    @ApiModelProperty(value = "罚息率", position = 21)
    @NotNull(message = "罚息率不能为空")
    private BigDecimal penaltyRate;

    /** 应计罚息 */
    @ApiModelProperty(value = "应计罚息", position = 22)
    @NotNull(message = "应计罚息不能为空")
    private BigDecimal accruedPenalty;

    /** 实计罚息 */
    @ApiModelProperty(value = "实计罚息", position = 23)
    @NotNull(message = "实计罚息不能为空")
    private BigDecimal actualPenalty;

    /** 贷款资金占用 */
    @ApiModelProperty(value = "贷款资金占用", position = 24)
    @NotNull(message = "贷款资金占用不能为空")
    private BigDecimal loanFundsOccupation;

    /** 预警时间 */
    @ApiModelProperty(value = "预警时间", position = 25)
    @NotNull(message = "预警时间不能为空")
    private Date warningTime;

}
