/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.entity.PssStorageEmptyPeriod;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodAddParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodEditParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodIdParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodPageParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.service.PssStorageEmptyPeriodService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 购销监管-财务类业务监管-轮空期监管表控制器
 *
 * @author ZeroLiYi
 * @date  2024/06/17 10:30
 */
@Api(tags = "购销监管-财务类业务监管-轮空期监管表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PssStorageEmptyPeriodController {

    @Resource
    private PssStorageEmptyPeriodService pssStorageEmptyPeriodService;

    /**
     * 获取购销监管-财务类业务监管-轮空期监管表分页
     *
     * @author ZeroLiYi
     * @date  2024/06/17 10:30
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取购销监管-财务类业务监管-轮空期监管表分页")
    @GetMapping("/purchaseAndSalesSupervision/pssstorageemptyperiod/page")
    public CommonResult<Page<PssStorageEmptyPeriod>> page(PssStorageEmptyPeriodPageParam pssStorageEmptyPeriodPageParam) {
        return CommonResult.data(pssStorageEmptyPeriodService.page(pssStorageEmptyPeriodPageParam));
    }

    /**
     * 添加购销监管-财务类业务监管-轮空期监管表
     *
     * @author ZeroLiYi
     * @date  2024/06/17 10:30
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加购销监管-财务类业务监管-轮空期监管表")
    @CommonLog("添加购销监管-财务类业务监管-轮空期监管表")
    @SaCheckPermission("/purchaseAndSalesSupervision/pssstorageemptyperiod/add")
    @PostMapping("/purchaseAndSalesSupervision/pssstorageemptyperiod/add")
    public CommonResult<String> add(@RequestBody @Valid PssStorageEmptyPeriodAddParam pssStorageEmptyPeriodAddParam) {
        pssStorageEmptyPeriodService.add(pssStorageEmptyPeriodAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑购销监管-财务类业务监管-轮空期监管表
     *
     * @author ZeroLiYi
     * @date  2024/06/17 10:30
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑购销监管-财务类业务监管-轮空期监管表")
    @CommonLog("编辑购销监管-财务类业务监管-轮空期监管表")
    @SaCheckPermission("/purchaseAndSalesSupervision/pssstorageemptyperiod/edit")
    @PostMapping("/purchaseAndSalesSupervision/pssstorageemptyperiod/edit")
    public CommonResult<String> edit(@RequestBody @Valid PssStorageEmptyPeriodEditParam pssStorageEmptyPeriodEditParam) {
        pssStorageEmptyPeriodService.edit(pssStorageEmptyPeriodEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除购销监管-财务类业务监管-轮空期监管表
     *
     * @author ZeroLiYi
     * @date  2024/06/17 10:30
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除购销监管-财务类业务监管-轮空期监管表")
    @CommonLog("删除购销监管-财务类业务监管-轮空期监管表")
    @SaCheckPermission("/purchaseAndSalesSupervision/pssstorageemptyperiod/delete")
    @PostMapping("/purchaseAndSalesSupervision/pssstorageemptyperiod/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PssStorageEmptyPeriodIdParam> pssStorageEmptyPeriodIdParamList) {
        pssStorageEmptyPeriodService.delete(pssStorageEmptyPeriodIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取购销监管-财务类业务监管-轮空期监管表详情
     *
     * @author ZeroLiYi
     * @date  2024/06/17 10:30
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取购销监管-财务类业务监管-轮空期监管表详情")
    @SaCheckPermission("/purchaseAndSalesSupervision/pssstorageemptyperiod/detail")
    @GetMapping("/purchaseAndSalesSupervision/pssstorageemptyperiod/detail")
    public CommonResult<PssStorageEmptyPeriod> detail(@Valid PssStorageEmptyPeriodIdParam pssStorageEmptyPeriodIdParam) {
        return CommonResult.data(pssStorageEmptyPeriodService.detail(pssStorageEmptyPeriodIdParam));
    }
   // 查询所有轮换计划(轮入)记录
}
