/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.grainPriceCollectCitySum.entity.GrainPriceCollectCitySum;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.entity.PssStorageEmptyPeriod;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.mapper.PssStorageEmptyPeriodMapper;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodAddParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodEditParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodIdParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.param.PssStorageEmptyPeriodPageParam;
import com.unis.purchaseAndSalesSupervision.modular.pssstorageemptyperiod.service.PssStorageEmptyPeriodService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 购销监管-财务类业务监管-轮空期监管表Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/06/17 10:30
 **/
@Service
public class PssStorageEmptyPeriodServiceImpl extends ServiceImpl<PssStorageEmptyPeriodMapper, PssStorageEmptyPeriod> implements PssStorageEmptyPeriodService {

    @Resource
    private PssStorageEmptyPeriodMapper pssStorageEmptyPeriodMapper;

    @Override
    public Page<PssStorageEmptyPeriod> page(PssStorageEmptyPeriodPageParam pssStorageEmptyPeriodPageParam) {
        QueryWrapper<PssStorageEmptyPeriod> queryWrapper = new QueryWrapper<>();

        if(StringUtils.isNotBlank(pssStorageEmptyPeriodPageParam.getOrgName())){
            queryWrapper.like("oi.org_name",(pssStorageEmptyPeriodPageParam.getOrgName()));
        }
        if(pssStorageEmptyPeriodPageParam.getRotationYear()!=null){
            queryWrapper.like("psep.plan_year",(pssStorageEmptyPeriodPageParam.getRotationYear()));
        }
        Page<PssStorageEmptyPeriod> p =new Page<>(pssStorageEmptyPeriodPageParam.getCurrent(),pssStorageEmptyPeriodPageParam.getSize());


        Page<PssStorageEmptyPeriod> page = pssStorageEmptyPeriodMapper.selectMyMapsPage(p,queryWrapper);
        return page;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PssStorageEmptyPeriodAddParam pssStorageEmptyPeriodAddParam) {
        PssStorageEmptyPeriod pssStorageEmptyPeriod = BeanUtil.toBean(pssStorageEmptyPeriodAddParam, PssStorageEmptyPeriod.class);
        this.save(pssStorageEmptyPeriod);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PssStorageEmptyPeriodEditParam pssStorageEmptyPeriodEditParam) {
        PssStorageEmptyPeriod pssStorageEmptyPeriod = this.queryEntity(pssStorageEmptyPeriodEditParam.getId());
        BeanUtil.copyProperties(pssStorageEmptyPeriodEditParam, pssStorageEmptyPeriod);
        this.updateById(pssStorageEmptyPeriod);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PssStorageEmptyPeriodIdParam> pssStorageEmptyPeriodIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(pssStorageEmptyPeriodIdParamList, PssStorageEmptyPeriodIdParam::getId));
    }

    @Override
    public PssStorageEmptyPeriod detail(PssStorageEmptyPeriodIdParam pssStorageEmptyPeriodIdParam) {
        return this.queryEntity(pssStorageEmptyPeriodIdParam.getId());
    }

    @Override
    public PssStorageEmptyPeriod queryEntity(String id) {
        PssStorageEmptyPeriod pssStorageEmptyPeriod = this.getById(id);
        if(ObjectUtil.isEmpty(pssStorageEmptyPeriod)) {
            throw new CommonException("购销监管-财务类业务监管-轮空期监管表不存在，id值为：{}", id);
        }
        return pssStorageEmptyPeriod;
    }
}
