/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.reserveLayout.modular.dataKcglKcswDefault.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.common.pojo.CommonResult;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.entity.VO.CrkChartDataVO;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.entity.VO.CrkJyxxDataVO;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.entity.VO.CrkKcswDataVO;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.param.CrkCharParam;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.param.CrkKcswParam;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.param.KcswDefaultPageParam;
import com.unis.reserveLayout.modular.dataKcglKcswDefault.service.KcswDefaultService;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.StorehouseCapacityReportinfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import java.util.List;

/**
 * 储备布局-出入库信息控制器
 *
 * @author TS
 * @date  2024/06/12 14:12
 */
@Api(tags = "储备布局-出入库信息控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class KcswDefaultController {

    @Resource
    private KcswDefaultService dataKcglKcswDefaultService;

    /**
     * 获取原粮出入库检验信息分页
     *
     * @author
     * @date  2024/06/04 11:37
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取原粮出入库检验信息分页")
    @GetMapping("/reserveLayout/kcswDefault/findJyxxPage")
    public CommonResult<IPage<CrkJyxxDataVO>> findJyxxPage(KcswDefaultPageParam pageParam) {
        return CommonResult.data(dataKcglKcswDefaultService.findJyxxPage(pageParam));
    }

    /**
     * 获取原粮出入库检验信息详情
     *
     * @author
     * @date  2024/06/04 11:37
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取原粮出入库检验信息详情")
    @GetMapping("/reserveLayout/kcswDefault/getJyxxDetail")
    public CommonResult<CrkJyxxDataVO> findJyxxPage(@RequestParam("dataId") @NotBlank(message = "不能为空")String dataId) {
        return CommonResult.data(dataKcglKcswDefaultService.getJyxxDetail(dataId));
    }



    /**
     * 获取出入库分析图表数据
     *
     * @author TS
     * @date  2024/06/13 10:02
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("获取出入库分析图表数据")
    @GetMapping("/reserveLayout/kcswDefault/getCrkChartDatas")
    public CommonResult<List<CrkChartDataVO>> getCrkChartDatas(@Valid CrkCharParam crkCharParam) {
        return CommonResult.data(dataKcglKcswDefaultService.getCrkChartDatas(crkCharParam));
    }

    /**
     * 获取出入库库存相关数据
     *
     * @author TS
     * @date  2024/06/13 10:02
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("获取出入库库存相关数据")
    @GetMapping("/reserveLayout/kcswDefault/getCrkKcswDatas")
    public CommonResult<List<CrkKcswDataVO>> getCrkKcswDatas(@Valid CrkKcswParam crkKcswParam) {
        return CommonResult.data(dataKcglKcswDefaultService.getCrkKcswDatas(crkKcswParam));
    }
}
