/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.reserveLayout.modular.grainInspectionArchive.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.reserveLayout.modular.grainInspectionArchive.param.GrainInspectionInfoParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.reserveLayout.modular.grainInspectionArchive.entity.GrainInspectionArchive;
import com.unis.reserveLayout.modular.grainInspectionArchive.param.GrainInspectionArchiveAddParam;
import com.unis.reserveLayout.modular.grainInspectionArchive.param.GrainInspectionArchiveEditParam;
import com.unis.reserveLayout.modular.grainInspectionArchive.param.GrainInspectionArchiveIdParam;
import com.unis.reserveLayout.modular.grainInspectionArchive.param.GrainInspectionArchivePageParam;
import com.unis.reserveLayout.modular.grainInspectionArchive.service.GrainInspectionArchiveService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 粮情检查档案控制器
 *
 * @author QSHan
 * @date  2024/06/07 10:53
 */
@Api(tags = "粮情检查档案控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainInspectionArchiveController {

    @Resource
    private GrainInspectionArchiveService grainInspectionArchiveService;

    /**
     * 获取粮情检查档案分页
     *
     * @author QSHan
     * @date  2024/06/07 10:53
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮情检查档案分页")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/page")
    @GetMapping("/reserveLayout/grainInspectionArchive/page")
    public CommonResult<Page<GrainInspectionArchive>> page(GrainInspectionArchivePageParam grainInspectionArchivePageParam) {
        return CommonResult.data(grainInspectionArchiveService.page(grainInspectionArchivePageParam));
    }

    /**
     * 添加粮情检查档案
     *
     * @author QSHan
     * @date  2024/06/07 10:53
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加粮情检查档案")
    @CommonLog("添加粮情检查档案")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/add")
    @PostMapping("/reserveLayout/grainInspectionArchive/add")
    public CommonResult<String> add(@RequestBody @Valid GrainInspectionArchiveAddParam grainInspectionArchiveAddParam) {
        grainInspectionArchiveService.add(grainInspectionArchiveAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮情检查档案
     *
     * @author QSHan
     * @date  2024/06/07 10:53
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮情检查档案")
    @CommonLog("编辑粮情检查档案")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/edit")
    @PostMapping("/reserveLayout/grainInspectionArchive/edit")
    public CommonResult<String> edit(@RequestBody @Valid GrainInspectionArchiveEditParam grainInspectionArchiveEditParam) {
        grainInspectionArchiveService.edit(grainInspectionArchiveEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮情检查档案
     *
     * @author QSHan
     * @date  2024/06/07 10:53
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除粮情检查档案")
    @CommonLog("删除粮情检查档案")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/delete")
    @PostMapping("/reserveLayout/grainInspectionArchive/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<GrainInspectionArchiveIdParam> grainInspectionArchiveIdParamList) {
        grainInspectionArchiveService.delete(grainInspectionArchiveIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮情检查档案详情
     *
     * @author QSHan
     * @date  2024/06/07 10:53
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮情检查档案详情")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/detail")
    @GetMapping("/reserveLayout/grainInspectionArchive/detail")
    public CommonResult<GrainInspectionArchive> detail(@Valid GrainInspectionArchiveIdParam grainInspectionArchiveIdParam) {
        return CommonResult.data(grainInspectionArchiveService.detail(grainInspectionArchiveIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("详情带出数据")
//    @SaCheckPermission("/reserveLayout/grainInspectionArchive/detail")
    @GetMapping("/reserveLayout/grainInspectionArchive/getDetailInfo/{reportType}/{orgId}/{storehouseId}")
    public CommonResult<GrainInspectionInfoParam> getDetailInfo(@PathVariable("reportType") Integer reportType, @PathVariable("orgId") Integer orgId, @PathVariable("storehouseId") Integer storehouseId) {
        return CommonResult.data(grainInspectionArchiveService.getDetailInfo(reportType ,orgId, storehouseId));
    }
}
