/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.reserveLayout.modular.grainInspectionArchive.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 粮情检查档案编辑参数
 *
 * @author QSHan
 * @date  2024/06/07 10:53
 **/
@Getter
@Setter
public class GrainInspectionArchiveEditParam {

    /** 粮情检查档案记录唯一标识符 */
    @ApiModelProperty(value = "粮情检查档案记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 编号 */
    @ApiModelProperty(value = "编号", position = 6)
    private String archiveNumber;

    /** 粮库；外库depot_qh.org_info的id； */
    @ApiModelProperty(value = "粮库；外库depot_qh.org_info的id；", position = 7)
    private Integer orgId;

    /** 报告类型，1：日报；2：周报；3：月报；4：季报；5：年报 */
    @ApiModelProperty(value = "报告类型，1：日报；2：周报；3：月报；4：季报；5：年报", position = 8)
    private Integer reportType;

    /** 外库depot_qh.basic_storehouse的id；仓房id */
    @ApiModelProperty(value = "外库depot_qh.basic_storehouse的id；仓房id", position = 9)
    private Integer basicStorehouseId;

    /** 外库depot_qh.basic_warehouse的id；货位id; */
    @ApiModelProperty(value = "外库depot_qh.basic_warehouse的id；货位id;", position = 10)
    private Integer warehouseId;

    /** 仓房类型；仓房类型编号（立筒仓等）；外库depot_qh.basic_enum的id； */
    @ApiModelProperty(value = "仓房类型；仓房类型编号（立筒仓等）；外库depot_qh.basic_enum的id；", position = 11)
    private Integer storehouseType;

    /** 粮食品种；basic_enum的id； */
    @ApiModelProperty(value = "粮食品种；basic_enum的id；", position = 12)
    private Integer grainVarietyId;

    /** 保管员 */
    @ApiModelProperty(value = "保管员", position = 13)
    private String keeper;

    /** 提交人；sys_user的id； */
    @ApiModelProperty(value = "提交人；sys_user的id；", position = 14)
    private String submitterId;

    /** 报告日期 */
    @ApiModelProperty(value = "报告日期", position = 15)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone="GMT+8")
    private Date reportDate;

    /** 最高温 */
    @ApiModelProperty(value = "最高温", position = 16)
    private BigDecimal maximumTemperature;

    /** 最低温 */
    @ApiModelProperty(value = "最低温", position = 17)
    private BigDecimal minimumTemperature;

    /** 平均温 */
    @ApiModelProperty(value = "平均温", position = 18)
    private BigDecimal averageTemperature;

    /** 仓外湿 */
    @ApiModelProperty(value = "仓外湿", position = 19)
    private BigDecimal ambientHumidity;

    /** 仓内湿 */
    @ApiModelProperty(value = "仓内湿", position = 20)
    private BigDecimal storeroomHumidity;

    /** 天气情况 */
    @ApiModelProperty(value = "天气情况", position = 21)
    private String weatherCondition;

    /** 虫害情况 */
    @ApiModelProperty(value = "虫害情况", position = 22)
    private String insectHarmCondition;

    /** 是否结露，0：否；1：是； */
    @ApiModelProperty(value = "是否结露，0：否；1：是；", position = 23)
    private Integer isCondensation;

    /** 霉变情况 */
    @ApiModelProperty(value = "霉变情况", position = 24)
    private String moldCondition;

    /** 有无鼠雀，0：否；1：是； */
    @ApiModelProperty(value = "有无鼠雀，0：否；1：是；", position = 25)
    private Integer isRodent;

    /** 仓房有无漏雨，0：否；1：是； */
    @ApiModelProperty(value = "仓房有无漏雨，0：否；1：是；", position = 26)
    private Integer isLeakage;

    /** 是否返潮，0：否；1：是； */
    @ApiModelProperty(value = "是否返潮，0：否；1：是；", position = 27)
    private Integer isReturnDamp;

    /** 清洁卫生情况 */
    @ApiModelProperty(value = "清洁卫生情况", position = 28)
    private String cleanlinessCondition;

    /** 备注 */
    @ApiModelProperty(value = "备注", position = 29)
    private String remarks;

}
