/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.reserveLayout.modular.qualityInspectionOrg.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionWhole;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionWholeDetail;
import com.unis.reserveLayout.modular.qualityInspectionOrg.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionOrg;
import com.unis.reserveLayout.modular.qualityInspectionOrg.service.QualityInspectionOrgService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 粮食质量管理控制器
 *
 * @author QSHan
 * @date  2024/06/07 10:46
 */
@Api(tags = "粮食质量管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class QualityInspectionOrgController {

    @Resource
    private QualityInspectionOrgService qualityInspectionOrgService;

    /**
     * 获取粮食质量管理分页
     *
     * @author QSHan
     * @date  2024/06/07 10:46
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("质检机构-分页")
//    @SaCheckPermission("/reserveLayout/qualityInspectionOrg/page")
    @GetMapping("/reserveLayout/qualityInspectionOrg/page")
    public CommonResult<Page<QualityInspectionOrg>> page(QualityInspectionOrgPageParam qualityInspectionOrgPageParam) {
        return CommonResult.data(qualityInspectionOrgService.page(qualityInspectionOrgPageParam));
    }

    /**
     * 添加粮食质量管理
     *
     * @author QSHan
     * @date  2024/06/07 10:46
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("质检机构-添加")
    @CommonLog("粮食质量管理-添加-质检机构")
//    @SaCheckPermission("/reserveLayout/qualityInspectionOrg/add")
    @PostMapping("/reserveLayout/qualityInspectionOrg/add")
    public CommonResult<String> add(@RequestBody @Valid QualityInspectionOrgAddParam qualityInspectionOrgAddParam) {
        qualityInspectionOrgService.add(qualityInspectionOrgAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食质量管理
     *
     * @author QSHan
     * @date  2024/06/07 10:46
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("质检机构-编辑")
    @CommonLog("编辑粮食质量管理-质检机构")
//    @SaCheckPermission("/reserveLayout/qualityInspectionOrg/edit")
    @PostMapping("/reserveLayout/qualityInspectionOrg/edit")
    public CommonResult<String> edit(@RequestBody @Valid QualityInspectionOrgEditParam qualityInspectionOrgEditParam) {
        qualityInspectionOrgService.edit(qualityInspectionOrgEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食质量管理
     *
     * @author QSHan
     * @date  2024/06/07 10:46
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("质检机构-删除")
    @CommonLog("删除粮食质量管理-质检机构")
//    @SaCheckPermission("/reserveLayout/qualityInspectionOrg/delete")
    @PostMapping("/reserveLayout/qualityInspectionOrg/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<QualityInspectionOrgIdParam> qualityInspectionOrgIdParamList) {
        qualityInspectionOrgService.delete(qualityInspectionOrgIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮食质量管理详情
     *
     * @author QSHan
     * @date  2024/06/07 10:46
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("质检机构-详情")
//    @SaCheckPermission("/reserveLayout/qualityInspectionOrg/detail")
    @GetMapping("/reserveLayout/qualityInspectionOrg/detail")
    public CommonResult<QualityInspectionOrg> detail(@Valid QualityInspectionOrgIdParam qualityInspectionOrgIdParam) {
        return CommonResult.data(qualityInspectionOrgService.detail(qualityInspectionOrgIdParam));
    }

    @ApiOperationSupport(order = 1)
    @ApiOperation("整仓质检-分页")
    @GetMapping("/reserveLayout/qualityInspectionOrg/wholeWarehouseQualityInspectionPage")
    public CommonResult<Page<QualityInspectionWhole>> wholeWarehouseQualityInspectionPage(QualityInspectionOrgPageParam qualityInspectionOrgPageParam) {
        return CommonResult.data(qualityInspectionOrgService.wholeWarehouseQualityInspectionPage(qualityInspectionOrgPageParam));
    }

    @ApiOperationSupport(order = 5)
    @ApiOperation("整仓质检-详情")
    @GetMapping("/reserveLayout/qualityInspectionOrg/wholeWarehouseQualityInspectionDetail/{qualityId}")
    public CommonResult<QualityInspectionWholeDetail> wholeWarehouseQualityInspectionDetail(@PathVariable("qualityId") Integer qualityId) {
        return CommonResult.data(qualityInspectionOrgService.wholeWarehouseQualityInspectionDetail(qualityId));
    }

}
