/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.reserveLayout.modular.qualityInspectionOrg.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.BusinessQcQualityInspectionItem;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionWhole;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionWholeDetail;
import com.unis.reserveLayout.modular.qualityInspectionOrg.param.*;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.reserveLayout.modular.qualityInspectionOrg.entity.QualityInspectionOrg;
import com.unis.reserveLayout.modular.qualityInspectionOrg.mapper.QualityInspectionOrgMapper;
import com.unis.reserveLayout.modular.qualityInspectionOrg.service.QualityInspectionOrgService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 粮食质量管理Service接口实现类
 *
 * @author QSHan
 * @date 2024/06/07 10:46
 **/
@Service
public class QualityInspectionOrgServiceImpl extends ServiceImpl<QualityInspectionOrgMapper, QualityInspectionOrg> implements QualityInspectionOrgService {
    @Resource
    private QualityInspectionOrgMapper qualityInspectionOrgMapper;

    @Override
    public Page<QualityInspectionOrg> page(QualityInspectionOrgPageParam qualityInspectionOrgPageParam) {
        QueryWrapper<QualityInspectionOrg> queryWrapper = new QueryWrapper<>();
        // 模糊查询条件(质检机构名称)
        if (StringUtils.isNotEmpty(qualityInspectionOrgPageParam.getOrganizationName()))
            queryWrapper.lambda().like(QualityInspectionOrg::getOrganizationName, qualityInspectionOrgPageParam.getOrganizationName());
        if (ObjectUtil.isAllNotEmpty(qualityInspectionOrgPageParam.getSortField(), qualityInspectionOrgPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(qualityInspectionOrgPageParam.getSortOrder());
            queryWrapper.orderBy(true, qualityInspectionOrgPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(qualityInspectionOrgPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(QualityInspectionOrg::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(QualityInspectionOrgAddParam qualityInspectionOrgAddParam) {
        QualityInspectionOrg qualityInspectionOrg = BeanUtil.toBean(qualityInspectionOrgAddParam, QualityInspectionOrg.class);
        this.save(qualityInspectionOrg);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(QualityInspectionOrgEditParam qualityInspectionOrgEditParam) {
        QualityInspectionOrg qualityInspectionOrg = this.queryEntity(qualityInspectionOrgEditParam.getId());
        BeanUtil.copyProperties(qualityInspectionOrgEditParam, qualityInspectionOrg);
        this.updateById(qualityInspectionOrg);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<QualityInspectionOrgIdParam> qualityInspectionOrgIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(qualityInspectionOrgIdParamList, QualityInspectionOrgIdParam::getId));
    }

    @Override
    public QualityInspectionOrg detail(QualityInspectionOrgIdParam qualityInspectionOrgIdParam) {
        return this.queryEntity(qualityInspectionOrgIdParam.getId());
    }

    @Override
    public QualityInspectionOrg queryEntity(String id) {
        QualityInspectionOrg qualityInspectionOrg = this.getById(id);
        if (ObjectUtil.isEmpty(qualityInspectionOrg)) {
            throw new CommonException("粮食质量管理不存在，id值为：{}", id);
        }
        return qualityInspectionOrg;
    }

    @Override
    public Page<QualityInspectionWhole> wholeWarehouseQualityInspectionPage(QualityInspectionOrgPageParam param) {
        return qualityInspectionOrgMapper.wholeWarehouseQualityInspectionPage(new Page<>(param.getCurrent(), param.getSize()), param.getStorehouseName());
    }

    @Override
    public QualityInspectionWholeDetail wholeWarehouseQualityInspectionDetail(Integer qualityId) {
        // 查询质检管理主表数据
        QualityInspectionWholeDetail qualityInspection = qualityInspectionOrgMapper.getQualityInspection(qualityId);
        // 查询检验项目及依据
        List<BusinessQcQualityInspectionItem> items = qualityInspectionOrgMapper.getQualityInspectionItem(qualityId);
        if (CollectionUtils.isNotEmpty(items))
            qualityInspection.setItems(items);
        // 返回
        return qualityInspection;
    }


}
