/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.businessrpreport.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessQcQualityInspection;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessRpInbound;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessRpOutbound;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessRpReport;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.vo.BusinessRpReportVO;
import com.unis.rotationPlan.info.modular.businessrpreport.param.BusinessRpReportIdParam;
import com.unis.rotationPlan.info.modular.businessrpreport.param.BusinessRpReportPageParam;
import com.unis.rotationPlan.info.modular.rpBiweeklyReport.entity.RpBiweeklyReport;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 轮换计划-上报Mapper接口
 *
 * @author ZeroLiYi
 * @date  2024/05/14 18:05
 **/
public interface BusinessRpReportMapper extends BaseMapper<BusinessRpReport> {

    /**
     * 获取轮换计划接受列表
     * @param p
     * @param queryWrapper
     * @return
     */
    IPage<Map<String,Object>> selectMyMapsPage(Page<BusinessRpReport> p, @Param(Constants.WRAPPER) QueryWrapper<BusinessRpReport>queryWrapper);

    /**
     * 获取轮换计划上报详情
     * @param id
     * @return
     */
    List<Map<String,Object>> getDetail(@Param("id") Integer id);

    List<BusinessRpReportVO> createReport(@Param("pageParam") BusinessRpReportIdParam pageParam);

    /**
     * 轮换计划接收主表详情
     * @param rpReportId
     * @param
     * @return
     */
    BusinessRpReportVO getRpReportByReportId(@Param("rpReportId") String rpReportId,@Param("orgId") Integer orgId);

    /**
     * 轮换计划接收出库表详情
     * @param rpReportId
     * @param orgId
     * @return
     */
    List<BusinessRpOutbound> findOutByRpReportId(@Param("rpReportId") String rpReportId,@Param("orgId") Integer orgId);

    /**
     * 轮换计划接收入库表详情
     * @param rpReportId
     * @param orgId
     * @return
     */
    List<BusinessRpInbound> findInByRpReportId(@Param("rpReportId") String rpReportId,@Param("orgId") Integer orgId);

    /**
     * 根据货位号和检验类别查询质检报告
     * @param jylb
     * @param warehouseId
     * @return
     */
    List<BusinessQcQualityInspection> getQualityInspectionFindByWarehouseId(@Param("jylb")String jylb,@Param("warehouseId") Integer warehouseId);

    /**
     * 计划信息查询列表
     * @param pageParam
     * @return
     */
    List<Map<String, Object>> selectRecListByPageParam(@Param("pageParam")BusinessRpReportPageParam pageParam);

    /**
     * 计划信息主表入库表详情
     * @param rpReportId
     * @param orgId
     * @return
     */
    BusinessRpReportVO getPlanRpReportByReportId(@Param("rpReportId") String rpReportId,@Param("orgId") Integer orgId);

    /**
     * 计划信息查询出库表详情
     * @param rpReportId
     * @param orgId
     * @return
     */
    List<BusinessRpOutbound> findPlanOutByRpReportId(String rpReportId, Integer orgId);

    /**
     * 计划信息查询入库表详情
     * @param rpReportId
     * @param orgId
     * @return
     */
    List<BusinessRpInbound> findPlanInByRpReportId(String rpReportId, Integer orgId);

    List<BusinessRpReportVO> createReportDetail(@Param("pageParam") BusinessRpReportIdParam pageParam);
}
