/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.rpBiweeklyReport.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.rotationPlan.info.modular.rpBiweeklyReport.param.*;
import com.unis.rotationPlan.info.modular.rpWarnBiweeklyReport.entity.RpWarnBiweeklyReport;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.rotationPlan.info.modular.rpBiweeklyReport.entity.RpBiweeklyReport;
import com.unis.rotationPlan.info.modular.rpBiweeklyReport.mapper.RpBiweeklyReportMapper;
import com.unis.rotationPlan.info.modular.rpBiweeklyReport.service.RpBiweeklyReportService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 轮换计划-轮换半月报表Service接口实现类
 *
 * @author TS
 * @date  2024/05/09 19:15
 **/
@Service
public class RpBiweeklyReportServiceImpl extends ServiceImpl<RpBiweeklyReportMapper, RpBiweeklyReport> implements RpBiweeklyReportService {

    @Resource
    private RpBiweeklyReportMapper rpBiweeklyReportMapper;
    @Override
    public Page<RpBiweeklyReport> page(RpBiweeklyReportPageParam rpBiweeklyReportPageParam) {
        QueryWrapper<RpBiweeklyReport> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(rpBiweeklyReportPageParam.getSortField(), rpBiweeklyReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(rpBiweeklyReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, rpBiweeklyReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(rpBiweeklyReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(RpBiweeklyReport::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RpBiweeklyReportAddParam rpBiweeklyReportAddParam) {
        RpBiweeklyReport rpBiweeklyReport = BeanUtil.toBean(rpBiweeklyReportAddParam, RpBiweeklyReport.class);
        this.save(rpBiweeklyReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RpBiweeklyReportEditParam rpBiweeklyReportEditParam) {
        RpBiweeklyReport rpBiweeklyReport = this.queryEntity(rpBiweeklyReportEditParam.getId());
        BeanUtil.copyProperties(rpBiweeklyReportEditParam, rpBiweeklyReport);
        this.updateById(rpBiweeklyReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RpBiweeklyReportIdParam> rpBiweeklyReportIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(rpBiweeklyReportIdParamList, RpBiweeklyReportIdParam::getId));
    }

    @Override
    public RpBiweeklyReport detail(RpBiweeklyReportIdParam rpBiweeklyReportIdParam) {
        return this.queryEntity(rpBiweeklyReportIdParam.getId());
    }

    @Override
    public List<Map<String,Object>> getDetail(RpBiweeklyReportIdParam rpBiweeklyReportIdParam) {
        List<Map<String,Object>> details = rpBiweeklyReportMapper.getDetail(rpBiweeklyReportIdParam.getId());
        if(ObjectUtil.isEmpty(details)) {
            throw new CommonException("轮换计划-轮换半月报表不存在，id值为：{}", rpBiweeklyReportIdParam.getId());
        }
        return details;
    }

    /**
     * 获取计划进度管控自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPlanPage(RpBiweeklyReportPageParam pageParam) {
        //条形查询器
        QueryWrapper<RpBiweeklyReport> queryWrapper = new QueryWrapper<>();
        //分页相关
        if(StringUtils.isNotBlank(pageParam.getRotationYear())){
            queryWrapper.like("cast(c.rotation_year as char)",pageParam.getRotationYear() );
        }
        if(pageParam.getOrgId() != null){
            queryWrapper.eq("e.org_id",pageParam.getOrgId() );
            queryWrapper.eq("f.org_id",pageParam.getOrgId() );
        }
        Page<RpBiweeklyReport> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());
        IPage<Map<String,Object>> page = rpBiweeklyReportMapper.selectMyPlanMapsPage(p,queryWrapper);
        return page;
    }

    /**
     * 获取计划进度管控详情
     *
     * @param rotationYear
     * @return
     */
    @Override
    public List<Map<String, Object>> getPlanDetail(String rotationYear) {
        List<Map<String,Object>> details = rpBiweeklyReportMapper.getPlanDetail(rotationYear);
        if(ObjectUtil.isEmpty(details)) {
            throw new CommonException("计划进度管控详情不存在，轮换年度为：{}", rotationYear);
        }
        return details;
    }

    /**
     * findPlanDetailPage
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPlanDetailPage(RpBiweeklyReportDetailPageParam pageParam) {
        //条形查询器
        QueryWrapper<RpBiweeklyReport> queryWrapper = new QueryWrapper<>();
        //分页相关
        if(StringUtils.isNotBlank(pageParam.getRotationYear())){
            queryWrapper.eq("cast(c.rotation_year as char)",pageParam.getRotationYear() );
        }
        if(StringUtils.isNotBlank(pageParam.getUnitName())){
            queryWrapper.like("b.dwmc",pageParam.getUnitName() );
        }
        if(StringUtils.isNotBlank(pageParam.getOrgName())){
            queryWrapper.like("d.org_name",pageParam.getOrgName() );
        }
        Page<RpBiweeklyReport> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());
        IPage<Map<String,Object>> page = rpBiweeklyReportMapper.selectMyPlanDetailMapsPage(p,queryWrapper);
        return page;
    }

    @Override
    public RpBiweeklyReport queryEntity(Integer id) {
        RpBiweeklyReport rpBiweeklyReport = this.getById(id);
        if(ObjectUtil.isEmpty(rpBiweeklyReport)) {
            throw new CommonException("轮换计划-轮换半月报表不存在，id值为：{}", id);
        }
        return rpBiweeklyReport;
    }

    /**
     * 获取轮换计划-轮换半月报表自定义分页
     *
     * @param pageParam
     * @return
     */
    @Override
    public IPage<Map<String, Object>> findPage(RpBiweeklyReportPageParam pageParam) {
        //条形查询器
        QueryWrapper<RpBiweeklyReport> queryWrapper = new QueryWrapper<>();
        //分页相关
        if(StringUtils.isNotBlank(pageParam.getOrgName())){
            queryWrapper.like("d.org_name",pageParam.getOrgName() );
        }
        Page<RpBiweeklyReport> p =new Page<>(pageParam.getCurrent(),pageParam.getSize());
        IPage<Map<String,Object>> page = rpBiweeklyReportMapper.selectMyMapsPage(p,queryWrapper);
        return page;
    }
}
