/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.rpIssuance.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.vo.RpIssuanceVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.RpIssuance;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceAddParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceEditParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceIdParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuancePageParam;
import com.unis.rotationPlan.info.modular.rpIssuance.service.RpIssuanceService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 轮换计划-轮换下发控制器
 *
 * @author TS
 * @date  2024/05/08 18:02
 */
@Api(tags = "轮换计划-轮换下发控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class RpIssuanceController {

    @Resource
    private RpIssuanceService rpIssuanceService;

    /**
     * 获取轮换计划-轮换下发分页
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取轮换计划-轮换下发分页")
    @GetMapping("/rotationPlan.info/rpIssuance/page")
    public CommonResult<List<RpIssuanceVO>> page(RpIssuancePageParam rpIssuancePageParam) {
        return CommonResult.data(rpIssuanceService.page(rpIssuancePageParam));
    }

    /**
     * 添加轮换计划-轮换下发
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加轮换计划-轮换下发")
    @CommonLog("添加轮换计划-轮换下发")
    @PostMapping("/rotationPlan.info/rpIssuance/add")
    public CommonResult<String> add(@RequestBody @Valid RpIssuanceAddParam rpIssuanceAddParam) {
        rpIssuanceService.add(rpIssuanceAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑轮换计划-轮换下发
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
//    @ApiOperationSupport(order = 3)
//    @ApiOperation("编辑轮换计划-轮换下发")
//    @CommonLog("编辑轮换计划-轮换下发")
//    @SaCheckPermission("/rotationPlan.info/rpIssuance/edit")
//    @PostMapping("/rotationPlan.info/rpIssuance/edit")
//    public CommonResult<String> edit(@RequestBody @Valid RpIssuanceEditParam rpIssuanceEditParam) {
//        rpIssuanceService.edit(rpIssuanceEditParam);
//        return CommonResult.ok();
//    }

    /**
     * 删除轮换计划-轮换下发
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
//    @ApiOperationSupport(order = 4)
//    @ApiOperation("删除轮换计划-轮换下发")
//    @CommonLog("删除轮换计划-轮换下发")
//    @SaCheckPermission("/rotationPlan.info/rpIssuance/delete")
//    @PostMapping("/rotationPlan.info/rpIssuance/delete")
//    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
//                                                   CommonValidList<RpIssuanceIdParam> rpIssuanceIdParamList) {
//        rpIssuanceService.delete(rpIssuanceIdParamList);
//        return CommonResult.ok();
//    }

    /**
     * 获取轮换计划-轮换下发详情
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取轮换计划-轮换下发详情")
    @GetMapping("/rotationPlan.info/rpIssuance/detail")
    public CommonResult<RpIssuanceVO> detail(RpIssuanceIdParam rpIssuanceIdParam) {
        return CommonResult.data(rpIssuanceService.detail(rpIssuanceIdParam));
    }

    /**
     * 编辑轮换计划-轮换下发
     *
     * @author TS
     * @date  2024/05/08 18:02
     */
//    @ApiOperationSupport(order = 3)
//    @ApiOperation("轮换计划下发")
//    @CommonLog("轮换计划下发")
//    @SaCheckPermission("/rotationPlan.info/rpIssuance/edit")
//    @PostMapping("/rotationPlan.info/rpIssuance/edit")
//    public CommonResult<String> edit(@RequestBody @Valid RpIssuanceEditParam rpIssuanceEditParam) {
//        rpIssuanceService.edit(rpIssuanceEditParam);
//        return CommonResult.ok();
//    }


}
