/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.rpIssuance.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessRpOutbound;
import com.unis.rotationPlan.info.modular.businessrpreport.enums.BusinessRpItem;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.vo.RpIssuanceVO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.RpIssuance;
import com.unis.rotationPlan.info.modular.rpIssuance.mapper.RpIssuanceMapper;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceAddParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceEditParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceIdParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuancePageParam;
import com.unis.rotationPlan.info.modular.rpIssuance.service.RpIssuanceService;

import javax.annotation.Resource;
import java.util.*;

import static com.unis.rotationPlan.info.modular.rpIssuance.util.OutboundDataOrganizer.organizeOutboundData;

/**
 * 轮换计划-轮换下发Service接口实现类
 *
 * @author TS
 * @date  2024/05/08 18:02
 **/
@Service
public class RpIssuanceServiceImpl extends ServiceImpl<RpIssuanceMapper, RpIssuance> implements RpIssuanceService {
//    @Resource
//    private  BusinessRpOutbound

    @Resource
    private RpIssuanceMapper rpIssuanceMapper;


    /**
     * 获取轮换计划-轮换下发分页
     * @param rpIssuancePageParam
     * @return
     */
    @Override
    public List<RpIssuanceVO> page(RpIssuancePageParam rpIssuancePageParam) {
       List<RpIssuanceVO> rpIssuanceVOList = rpIssuanceMapper.selectRIPage(rpIssuancePageParam);
    return rpIssuanceVOList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RpIssuanceAddParam rpIssuanceAddParam) {
        RpIssuance rpIssuance = BeanUtil.toBean(rpIssuanceAddParam, RpIssuance.class);
        rpIssuance.setIssuanceDate(new Date());
        this.save(rpIssuance);
        List<BusinessRpOutbound> outboundList =  rpIssuanceAddParam.getBusinessRpOutboundList();
        for (BusinessRpOutbound out: outboundList
             ) {//根据出库表的id修改 计划数量
            rpIssuanceMapper.updateForOut(out.getPlanQuantity(),out.getId());

        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RpIssuanceEditParam rpIssuanceEditParam) {
        RpIssuance rpIssuance = this.queryEntity(rpIssuanceEditParam.getId());
        BeanUtil.copyProperties(rpIssuanceEditParam, rpIssuance);
        this.updateById(rpIssuance);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RpIssuanceIdParam> rpIssuanceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(rpIssuanceIdParamList, RpIssuanceIdParam::getId));
    }

    @Override
    public RpIssuanceVO detail(RpIssuanceIdParam rpIssuanceIdParam) {
        RpIssuanceVO rpIssuanceVO = new RpIssuanceVO();
        if(rpIssuanceIdParam!=null){
            if(rpIssuanceIdParam.getRpReportId()==null){
                rpIssuanceVO= rpIssuanceMapper.getRpIssuanceByadd(rpIssuanceIdParam);
            }else{
                rpIssuanceVO= rpIssuanceMapper.getRpIssuanceByrpReportId(rpIssuanceIdParam);
            }

        }
        if(rpIssuanceVO==null){
            rpIssuanceVO =  new RpIssuanceVO();
        }
        List<BusinessRpOutbound> outboundList =rpIssuanceMapper.getOutIssuanceByrpReportId(rpIssuanceIdParam);
        // 调用organizeOutboundData方法并处理结果
        List<Map<String, Object>> organizedResult = organizeOutboundData(outboundList);
        if(organizedResult!=null){
            rpIssuanceVO.setComplexDataList(organizedResult);
        }


        return rpIssuanceVO;
    }

    @Override
    public RpIssuance queryEntity(String id) {
        RpIssuance rpIssuance = this.getById(id);
        if(ObjectUtil.isEmpty(rpIssuance)) {
            throw new CommonException("轮换计划-轮换下发不存在，id值为：{}", id);
        }
        return rpIssuance;
    }
}
