/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.entity.RpWarnThresholdconfig;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.mapper.RpWarnThresholdconfigMapper;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.param.RpWarnThresholdconfigAddParam;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.param.RpWarnThresholdconfigEditParam;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.param.RpWarnThresholdconfigIdParam;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.param.RpWarnThresholdconfigPageParam;
import com.unis.rotationPlan.info.modular.rpWarnThresholdconfig.service.RpWarnThresholdconfigService;

import java.util.List;

/**
 * 轮换计划-轮换数量阈值设置表Service接口实现类
 *
 * @author TS
 * @date  2024/05/08 09:29
 **/
@Service
public class RpWarnThresholdconfigServiceImpl extends ServiceImpl<RpWarnThresholdconfigMapper, RpWarnThresholdconfig> implements RpWarnThresholdconfigService {

    @Override
    public Page<RpWarnThresholdconfig> page(RpWarnThresholdconfigPageParam rpWarnThresholdconfigPageParam) {
        QueryWrapper<RpWarnThresholdconfig> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotBlank(rpWarnThresholdconfigPageParam.getWarningName())){
            queryWrapper.lambda().like(RpWarnThresholdconfig::getWarningName,rpWarnThresholdconfigPageParam.getWarningName());
        }
        if(ObjectUtil.isAllNotEmpty(rpWarnThresholdconfigPageParam.getSortField(), rpWarnThresholdconfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(rpWarnThresholdconfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, rpWarnThresholdconfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(rpWarnThresholdconfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(RpWarnThresholdconfig::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RpWarnThresholdconfigAddParam rpWarnThresholdconfigAddParam) {
        RpWarnThresholdconfig rpWarnThresholdconfig = BeanUtil.toBean(rpWarnThresholdconfigAddParam, RpWarnThresholdconfig.class);
        this.save(rpWarnThresholdconfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RpWarnThresholdconfigEditParam rpWarnThresholdconfigEditParam) {
        RpWarnThresholdconfig rpWarnThresholdconfig = this.queryEntity(rpWarnThresholdconfigEditParam.getId());
        BeanUtil.copyProperties(rpWarnThresholdconfigEditParam, rpWarnThresholdconfig);
        this.updateById(rpWarnThresholdconfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RpWarnThresholdconfigIdParam> rpWarnThresholdconfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(rpWarnThresholdconfigIdParamList, RpWarnThresholdconfigIdParam::getId));
    }

    @Override
    public RpWarnThresholdconfig detail(RpWarnThresholdconfigIdParam rpWarnThresholdconfigIdParam) {
        return this.queryEntity(rpWarnThresholdconfigIdParam.getId());
    }

    @Override
    public RpWarnThresholdconfig queryEntity(String id) {
        RpWarnThresholdconfig rpWarnThresholdconfig = this.getById(id);
        if(ObjectUtil.isEmpty(rpWarnThresholdconfig)) {
            throw new CommonException("轮换计划-轮换数量阈值设置表不存在，id值为：{}", id);
        }
        return rpWarnThresholdconfig;
    }
}
