/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.dataKcglKcswDefault.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.dataKcglKcswDefault.entity.DataKcglKcswDefault;
import com.unis.safeStorage.modular.dataKcglKcswDefault.param.DataKcglKcswDefaultAddParam;
import com.unis.safeStorage.modular.dataKcglKcswDefault.param.DataKcglKcswDefaultEditParam;
import com.unis.safeStorage.modular.dataKcglKcswDefault.param.DataKcglKcswDefaultIdParam;
import com.unis.safeStorage.modular.dataKcglKcswDefault.param.DataKcglKcswDefaultPageParam;
import com.unis.safeStorage.modular.dataKcglKcswDefault.service.DataKcglKcswDefaultService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 库存实物表控制器
 *
 * @author hjc
 * @date  2024/06/03 14:57
 */
@Api(tags = "库存实物表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DataKcglKcswDefaultController {

    @Resource
    private DataKcglKcswDefaultService dataKcglKcswDefaultService;

    /**
     * 获取库存实物表分页
     *
     * @author hjc
     * @date  2024/06/03 14:57
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取库存实物表分页")
    @SaCheckPermission("/safeStorage/dataKcglKcswDefault/page")
    @GetMapping("/safeStorage/dataKcglKcswDefault/page")
    public CommonResult<Page<DataKcglKcswDefault>> page(DataKcglKcswDefaultPageParam dataKcglKcswDefaultPageParam) {
        return CommonResult.data(dataKcglKcswDefaultService.page(dataKcglKcswDefaultPageParam));
    }

    /**
     * 添加库存实物表
     *
     * @author hjc
     * @date  2024/06/03 14:57
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加库存实物表")
    @CommonLog("添加库存实物表")
    @SaCheckPermission("/safeStorage/dataKcglKcswDefault/add")
    @PostMapping("/safeStorage/dataKcglKcswDefault/add")
    public CommonResult<String> add(@RequestBody @Valid DataKcglKcswDefaultAddParam dataKcglKcswDefaultAddParam) {
        dataKcglKcswDefaultService.add(dataKcglKcswDefaultAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑库存实物表
     *
     * @author hjc
     * @date  2024/06/03 14:57
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑库存实物表")
    @CommonLog("编辑库存实物表")
    @SaCheckPermission("/safeStorage/dataKcglKcswDefault/edit")
    @PostMapping("/safeStorage/dataKcglKcswDefault/edit")
    public CommonResult<String> edit(@RequestBody @Valid DataKcglKcswDefaultEditParam dataKcglKcswDefaultEditParam) {
        dataKcglKcswDefaultService.edit(dataKcglKcswDefaultEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除库存实物表
     *
     * @author hjc
     * @date  2024/06/03 14:57
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除库存实物表")
    @CommonLog("删除库存实物表")
    @SaCheckPermission("/safeStorage/dataKcglKcswDefault/delete")
    @PostMapping("/safeStorage/dataKcglKcswDefault/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<DataKcglKcswDefaultIdParam> dataKcglKcswDefaultIdParamList) {
        dataKcglKcswDefaultService.delete(dataKcglKcswDefaultIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取库存实物表详情
     *
     * @author hjc
     * @date  2024/06/03 14:57
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取库存实物表详情")
    @SaCheckPermission("/safeStorage/dataKcglKcswDefault/detail")
    @GetMapping("/safeStorage/dataKcglKcswDefault/detail")
    public CommonResult<DataKcglKcswDefault> detail(@Valid DataKcglKcswDefaultIdParam dataKcglKcswDefaultIdParam) {
        return CommonResult.data(dataKcglKcswDefaultService.detail(dataKcglKcswDefaultIdParam));
    }
}
