/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */

package com.unis.safeStorage.modular.device.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.orgInfo.param.OrgInfoPageParam;
import com.unis.safeStorage.modular.device.entity.Devicerepair;
import com.unis.safeStorage.modular.device.service.DeviceService;
import com.unis.safeStorage.modular.sspatrolpoint.param.DevicePageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;


/**
 * 维保管理
 * @author shine
 * @date  2024/05/30 17:34
 */

@Api(tags = "维保管理")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class DeviceController {

    @Resource
    private DeviceService deviceService;

    /**
     * 维保报告
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*维保报告分页")
    @GetMapping("/device/repair/page")
    public CommonResult<IPage<Map<String,Object>>> findPage(DevicePageParam devicePageParam) {
        return CommonResult.data(deviceService.findPage(devicePageParam));
    }


    @ApiOperation(value="*查询数据--详情", notes = "根据id查询数据")
    @GetMapping(value ="/device/repair/loadDataById")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query")
    })
    public CommonResult<Devicerepair> loadDataById(@NotEmpty String id){

        return CommonResult.data(deviceService.loadDataById(id));
    }

    @ApiOperation(value="*更新状态", notes = "根据id更新状态")
    @PostMapping(value ="/device/repair/updateById")
    /*@ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "id", paramType = "query"),
            @ApiImplicitParam(name = "handleStatus", value = "handleStatus", paramType = "query")
    })*/
    public CommonResult<Map<String,Object>> updateById(@RequestBody @NotEmpty Map<String,Object> map){
         deviceService.updateById(map);
         map.put("status",200);
         return CommonResult.data(map);
    }

    @ApiOperationSupport(order = 4)
    @ApiOperation("*维修数量--分页的数量")
    @GetMapping("/device/repair/number")
    public CommonResult<Map<String,Object>> getNumber() {
        return CommonResult.data(deviceService.getNumber());
    }

}

