/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssFireWarn.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.safeStorage.modular.ssFireWarn.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssFireWarn.entity.SsFireWarn;
import com.unis.safeStorage.modular.ssFireWarn.service.SsFireWarnService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-火灾预警表控制器
 *
 * @author hjc
 * @date  2024/06/01 10:19
 */
@Api(tags = "安全仓储-火灾预警表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SsFireWarnController {

    @Resource
    private SsFireWarnService ssFireWarnService;

    /**
     * 获取安全仓储-火灾预警表分页-省平台
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取安全仓储-火灾预警表分页")
    //@SaCheckPermission("/safeStorage/ssFireWarn/page")
    @GetMapping("/safeStorage/ssFireWarn/page")
    public CommonResult<Page<SsFireWarn>> page(SsFireWarnPageParam ssFireWarnPageParam) {
        return CommonResult.data(ssFireWarnService.page(ssFireWarnPageParam));
    }

    /**
     * 添加安全仓储-火灾预警表
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加安全仓储-火灾预警表")
    @CommonLog("添加安全仓储-火灾预警表")
    //@SaCheckPermission("/safeStorage/ssFireWarn/add")
    @PostMapping("/safeStorage/ssFireWarn/add")
    public CommonResult<String> add(@RequestBody @Valid SsFireWarnAddParam ssFireWarnAddParam) {
        ssFireWarnService.add(ssFireWarnAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-火灾预警表
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑安全仓储-火灾预警表")
    @CommonLog("编辑安全仓储-火灾预警表")
    //@SaCheckPermission("/safeStorage/ssFireWarn/edit")
    @PostMapping("/safeStorage/ssFireWarn/edit")
    public CommonResult<String> edit(@RequestBody @Valid SsFireWarnEditParam ssFireWarnEditParam) {
        ssFireWarnService.edit(ssFireWarnEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-火灾预警表
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除安全仓储-火灾预警表")
    @CommonLog("删除安全仓储-火灾预警表")
    //@SaCheckPermission("/safeStorage/ssFireWarn/delete")
    @PostMapping("/safeStorage/ssFireWarn/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<SsFireWarnIdParam> ssFireWarnIdParamList) {
        ssFireWarnService.delete(ssFireWarnIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-火灾预警表详情
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取安全仓储-火灾预警表详情")
    //@SaCheckPermission("/safeStorage/ssFireWarn/detail")
    @GetMapping("/safeStorage/ssFireWarn/detail")
    public CommonResult<SsFireWarn> detail(@Valid SsFireWarnIdParam ssFireWarnIdParam) {
        return CommonResult.data(ssFireWarnService.detail(ssFireWarnIdParam));
    }

    /**
     * ipad-智慧消防分页
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("ipad-智慧消防分页")
    //@SaCheckPermission("/safeStorage/ssFireWarn/page")
    @GetMapping("client/c/safeStorage/ssFireWarn/SmartFireProtectionPage")
    public CommonResult<Page<SsFireWarn>> SmartFireProtectionPage(SsFireWarnStatusPageParam ssFireWarnPageParam) {
        return CommonResult.data(ssFireWarnService.SmartFireProtectionPage(ssFireWarnPageParam));
    }

    /**
     * ipad-智慧消防查看详情
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("ipad-智慧消防查看详情")
    //@SaCheckPermission("/safeStorage/ssFireWarn/page")
    @GetMapping("client/c/safeStorage/ssFireWarn/SmartFireProtectionGetDetail")
    public CommonResult<SsFireWarn> SmartFireProtectionGetDetail(@Valid SsFireWarnIdParam ssFireWarnIdParam) {
        return CommonResult.data(ssFireWarnService.detail(ssFireWarnIdParam));
    }

    /**
     * ipad-智慧消防处理
     *
     * @author hjc
     * @date  2024/06/01 10:19
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("ipad-智慧消防处理")
    //@SaCheckPermission("/safeStorage/ssFireWarn/detail")
    @GetMapping("client/c/safeStorage/ssFireWarn/dispose")
    public CommonResult<String> dispose(@Valid DisposeParam disposeParam) {
       ssFireWarnService.dispose(disposeParam);
        return CommonResult.ok();
    }
}
