/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssFireWarn.service.impl;

import cn.hutool.Hutool;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.safeStorage.modular.ssFireWarn.param.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssFireWarn.entity.SsFireWarn;
import com.unis.safeStorage.modular.ssFireWarn.mapper.SsFireWarnMapper;
import com.unis.safeStorage.modular.ssFireWarn.service.SsFireWarnService;

import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;

/**
 * 安全仓储-火灾预警表Service接口实现类
 *
 * @author hjc
 * @date 2024/06/01 10:19
 **/
@Service
public class SsFireWarnServiceImpl extends ServiceImpl<SsFireWarnMapper, SsFireWarn> implements SsFireWarnService {

    @Autowired
    private SsFireWarnMapper ssFireWarnMapper;

    @Override
    public Page<SsFireWarn> page(SsFireWarnPageParam ssFireWarnPageParam) {
        QueryWrapper<SsFireWarn> queryWrapper = new QueryWrapper<>();

        if (ObjectUtil.isNotEmpty(ssFireWarnPageParam.getAlarmTime())) {
            Date alarmTime = ssFireWarnPageParam.getAlarmTime();

            LocalDateTime localDateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(alarmTime.getTime()), ZoneId.systemDefault());

            // 通过LocalDateTime的 with方法设置某天的最小值和最大值！！
            LocalDateTime minDateTime = localDateTime.with(LocalTime.MIN);
            // 格式化日期
            Date minDate = Date.from(minDateTime.atZone(ZoneId.systemDefault()).toInstant());

            LocalDateTime maxDateTime = localDateTime.with(LocalTime.MAX);
            Date maxDate = Date.from(maxDateTime.atZone(ZoneId.systemDefault()).toInstant());

            queryWrapper.lambda().between(SsFireWarn::getAlarmTime,minDate,maxDate);
        }
        if (ObjectUtil.isAllNotEmpty(ssFireWarnPageParam.getSortField(), ssFireWarnPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssFireWarnPageParam.getSortOrder());
            queryWrapper.orderBy(true, ssFireWarnPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssFireWarnPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(SsFireWarn::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsFireWarnAddParam ssFireWarnAddParam) {
        SsFireWarn ssFireWarn = BeanUtil.toBean(ssFireWarnAddParam, SsFireWarn.class);
        this.save(ssFireWarn);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsFireWarnEditParam ssFireWarnEditParam) {
        SsFireWarn ssFireWarn = this.queryEntity(ssFireWarnEditParam.getId());
        BeanUtil.copyProperties(ssFireWarnEditParam, ssFireWarn);
        this.updateById(ssFireWarn);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsFireWarnIdParam> ssFireWarnIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssFireWarnIdParamList, SsFireWarnIdParam::getId));
    }

    @Override
    public SsFireWarn detail(SsFireWarnIdParam ssFireWarnIdParam) {
        return this.queryEntity(ssFireWarnIdParam.getId());
    }

    @Override
    public SsFireWarn queryEntity(String id) {
        SsFireWarn ssFireWarn = this.getById(id);
        if (ObjectUtil.isEmpty(ssFireWarn)) {
            throw new CommonException("安全仓储-火灾预警表不存在，id值为：{}", id);
        }
        return ssFireWarn;
    }

    /**
     * ipad-分页
     *
     * @author hjc
     * @date 2024/06/01 10:19
     */
    @Override
    public Page<SsFireWarn> SmartFireProtectionPage(SsFireWarnStatusPageParam ssFireWarnPageParam) {
        QueryWrapper<SsFireWarn> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotEmpty(ssFireWarnPageParam.getAlarmType())) {
            queryWrapper.lambda().like(SsFireWarn::getAlarmType, ssFireWarnPageParam.getAlarmType());
        }
        if (ObjectUtil.isAllNotEmpty(ssFireWarnPageParam.getSortField(), ssFireWarnPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssFireWarnPageParam.getSortOrder());
            queryWrapper.orderBy(true, ssFireWarnPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssFireWarnPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(SsFireWarn::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    /**
     * 火灾预警ipad处理
     *
     * @author hjc
     * @date 2024/06/01 10:19
     */
    @Override
    public void dispose(DisposeParam disposeParam) {
        SsFireWarn ssFireWarn = this.queryEntity(disposeParam.getId());
        ssFireWarn.setStatus(disposeParam.getStatus());
        ssFireWarn.setHandleTime(new Date());
        this.updateById(ssFireWarn);
    }
}
