/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssRiskDoublePrevention.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.entity.SsRiskDoublePrevention;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.mapper.SsRiskDoublePreventionMapper;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.param.SsRiskDoublePreventionAddParam;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.param.SsRiskDoublePreventionEditParam;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.param.SsRiskDoublePreventionIdParam;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.param.SsRiskDoublePreventionPageParam;
import com.unis.safeStorage.modular.ssRiskDoublePrevention.service.SsRiskDoublePreventionService;

import java.util.List;

/**
 * 安全仓储-风险双预控管理表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/31 14:34
 **/
@Service
public class SsRiskDoublePreventionServiceImpl extends ServiceImpl<SsRiskDoublePreventionMapper, SsRiskDoublePrevention> implements SsRiskDoublePreventionService {

    @Override
    public Page<SsRiskDoublePrevention> page(SsRiskDoublePreventionPageParam ssRiskDoublePreventionPageParam) {
        QueryWrapper<SsRiskDoublePrevention> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotEmpty(ssRiskDoublePreventionPageParam.getSafetyRiskLevel())){
            queryWrapper.lambda().eq(SsRiskDoublePrevention::getSafetyRiskLevel,ssRiskDoublePreventionPageParam.getSafetyRiskLevel());
        }
        if(ObjectUtil.isAllNotEmpty(ssRiskDoublePreventionPageParam.getSortField(), ssRiskDoublePreventionPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssRiskDoublePreventionPageParam.getSortOrder());
            queryWrapper.orderBy(true, ssRiskDoublePreventionPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssRiskDoublePreventionPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(SsRiskDoublePrevention::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsRiskDoublePreventionAddParam ssRiskDoublePreventionAddParam) {
        SsRiskDoublePrevention ssRiskDoublePrevention = BeanUtil.toBean(ssRiskDoublePreventionAddParam, SsRiskDoublePrevention.class);
        this.save(ssRiskDoublePrevention);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsRiskDoublePreventionEditParam ssRiskDoublePreventionEditParam) {
        SsRiskDoublePrevention ssRiskDoublePrevention = this.queryEntity(ssRiskDoublePreventionEditParam.getId());
        BeanUtil.copyProperties(ssRiskDoublePreventionEditParam, ssRiskDoublePrevention);
        this.updateById(ssRiskDoublePrevention);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsRiskDoublePreventionIdParam> ssRiskDoublePreventionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssRiskDoublePreventionIdParamList, SsRiskDoublePreventionIdParam::getId));
    }

    @Override
    public SsRiskDoublePrevention detail(SsRiskDoublePreventionIdParam ssRiskDoublePreventionIdParam) {
        return this.queryEntity(ssRiskDoublePreventionIdParam.getId());
    }

    @Override
    public SsRiskDoublePrevention queryEntity(String id) {
        SsRiskDoublePrevention ssRiskDoublePrevention = this.getById(id);
        if(ObjectUtil.isEmpty(ssRiskDoublePrevention)) {
            throw new CommonException("安全仓储-风险双预控管理表不存在，id值为：{}", id);
        }
        return ssRiskDoublePrevention;
    }
}
