/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssRiskIntelligentRecognize.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.entity.SsRiskIntelligentRecognize;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeAddParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeEditParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeIdParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizePageParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.service.SsRiskIntelligentRecognizeService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-风险智能识别表控制器
 *
 * @author hjc
 * @date  2024/05/31 14:25
 */
@Api(tags = "安全仓储-风险智能识别表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SsRiskIntelligentRecognizeController {

    @Resource
    private SsRiskIntelligentRecognizeService ssRiskIntelligentRecognizeService;

    /**
     * 获取安全仓储-风险智能识别表分页-省平台
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取安全仓储-风险智能识别表分页")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/page")
    @GetMapping("/safeStorage/ssRiskIntelligentRecognize/page")
    public CommonResult<Page<SsRiskIntelligentRecognize>> page(SsRiskIntelligentRecognizePageParam ssRiskIntelligentRecognizePageParam) {
        return CommonResult.data(ssRiskIntelligentRecognizeService.page(ssRiskIntelligentRecognizePageParam));
    }

    /**
     * 获取安全仓储-风险智能识别表分页-ipad
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取风险智能识别表分页-ipad")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/page")
    @GetMapping("client/c/safeStorage/ssRiskIntelligentRecognize/ipadPage")
    public CommonResult<Page<SsRiskIntelligentRecognize>> ipadPage(SsRiskIntelligentRecognizePageParam ssRiskIntelligentRecognizePageParam) {
        return CommonResult.data(ssRiskIntelligentRecognizeService.page(ssRiskIntelligentRecognizePageParam));
    }

    /**
     * 添加安全仓储-风险智能识别表
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加安全仓储-风险智能识别表")
    @CommonLog("添加安全仓储-风险智能识别表")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/add")
    @PostMapping("/safeStorage/ssRiskIntelligentRecognize/add")
    public CommonResult<String> add(@RequestBody @Valid SsRiskIntelligentRecognizeAddParam ssRiskIntelligentRecognizeAddParam) {
        ssRiskIntelligentRecognizeService.add(ssRiskIntelligentRecognizeAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-风险智能识别表
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑安全仓储-风险智能识别表")
    @CommonLog("编辑安全仓储-风险智能识别表")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/edit")
    @PostMapping("/safeStorage/ssRiskIntelligentRecognize/edit")
    public CommonResult<String> edit(@RequestBody @Valid SsRiskIntelligentRecognizeEditParam ssRiskIntelligentRecognizeEditParam) {
        ssRiskIntelligentRecognizeService.edit(ssRiskIntelligentRecognizeEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-风险智能识别表
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除安全仓储-风险智能识别表")
    @CommonLog("删除安全仓储-风险智能识别表")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/delete")
    @PostMapping("/safeStorage/ssRiskIntelligentRecognize/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<SsRiskIntelligentRecognizeIdParam> ssRiskIntelligentRecognizeIdParamList) {
        ssRiskIntelligentRecognizeService.delete(ssRiskIntelligentRecognizeIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-风险智能识别表详情-省级
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取安全仓储-风险智能识别表详情")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/detail")
    @GetMapping("/safeStorage/ssRiskIntelligentRecognize/detail")
    public CommonResult<SsRiskIntelligentRecognize> detail(@Valid SsRiskIntelligentRecognizeIdParam ssRiskIntelligentRecognizeIdParam) {
        return CommonResult.data(ssRiskIntelligentRecognizeService.detail(ssRiskIntelligentRecognizeIdParam));
    }

    /**
     * 获取安全仓储-风险智能识别表详情-ipad
     *
     * @author hjc
     * @date  2024/05/31 14:25
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取风险智能识别表详情-ipad")
    //@SaCheckPermission("/safeStorage/ssRiskIntelligentRecognize/detail")
    @GetMapping("client/c/safeStorage/ssRiskIntelligentRecognize/ipadDetail")
    public CommonResult<SsRiskIntelligentRecognize> ipadDetail(@Valid SsRiskIntelligentRecognizeIdParam ssRiskIntelligentRecognizeIdParam) {
        return CommonResult.data(ssRiskIntelligentRecognizeService.detail(ssRiskIntelligentRecognizeIdParam));
    }
}
