/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssRiskIntelligentRecognize.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.houbb.heaven.util.lang.StringUtil;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.basic.info.modular.warehouseInfo.entity.WarehouseInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.entity.SsRiskIntelligentRecognize;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.mapper.SsRiskIntelligentRecognizeMapper;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeAddParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeEditParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizeIdParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.param.SsRiskIntelligentRecognizePageParam;
import com.unis.safeStorage.modular.ssRiskIntelligentRecognize.service.SsRiskIntelligentRecognizeService;

import java.util.List;

/**
 * 安全仓储-风险智能识别表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/31 14:25
 **/
@Service
public class SsRiskIntelligentRecognizeServiceImpl extends ServiceImpl<SsRiskIntelligentRecognizeMapper, SsRiskIntelligentRecognize> implements SsRiskIntelligentRecognizeService {

    @Autowired
    private OrgInfoMapper orgInfoMapper;

    @Override
    public Page<SsRiskIntelligentRecognize> page(SsRiskIntelligentRecognizePageParam ssRiskIntelligentRecognizePageParam) {

        QueryWrapper<SsRiskIntelligentRecognize> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotNull(ssRiskIntelligentRecognizePageParam.getRiskType())) {
            queryWrapper.lambda().eq(SsRiskIntelligentRecognize::getRiskType, ssRiskIntelligentRecognizePageParam.getRiskType());
        }
        if (StringUtil.isNotEmpty(ssRiskIntelligentRecognizePageParam.getAlarmUnit())){
            queryWrapper.lambda().like(SsRiskIntelligentRecognize::getAlarmUnit,ssRiskIntelligentRecognizePageParam.getAlarmUnit());
        }

        if (ObjectUtil.isAllNotEmpty(ssRiskIntelligentRecognizePageParam.getSortField(), ssRiskIntelligentRecognizePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssRiskIntelligentRecognizePageParam.getSortOrder());
            queryWrapper.orderBy(true, ssRiskIntelligentRecognizePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssRiskIntelligentRecognizePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(SsRiskIntelligentRecognize::getCreateTime);
        }
        Page<SsRiskIntelligentRecognize> page = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        if (page.getSize() > 0) {
            for (SsRiskIntelligentRecognize recognize : page.getRecords()) {
                OrgInfo orgInfo = orgInfoMapper.selectById(recognize.getOrgId());
                if (ObjectUtil.isNotEmpty(orgInfo)) {
                    recognize.setOrgName(orgInfo.getOrgName());
                }

            }
        }
        return page;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsRiskIntelligentRecognizeAddParam ssRiskIntelligentRecognizeAddParam) {
        SsRiskIntelligentRecognize ssRiskIntelligentRecognize = BeanUtil.toBean(ssRiskIntelligentRecognizeAddParam, SsRiskIntelligentRecognize.class);
        this.save(ssRiskIntelligentRecognize);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsRiskIntelligentRecognizeEditParam ssRiskIntelligentRecognizeEditParam) {
        SsRiskIntelligentRecognize ssRiskIntelligentRecognize = this.queryEntity(ssRiskIntelligentRecognizeEditParam.getId());
        BeanUtil.copyProperties(ssRiskIntelligentRecognizeEditParam, ssRiskIntelligentRecognize);
        this.updateById(ssRiskIntelligentRecognize);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsRiskIntelligentRecognizeIdParam> ssRiskIntelligentRecognizeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssRiskIntelligentRecognizeIdParamList, SsRiskIntelligentRecognizeIdParam::getId));
    }

    @Override
    public SsRiskIntelligentRecognize detail(SsRiskIntelligentRecognizeIdParam ssRiskIntelligentRecognizeIdParam) {
        return this.queryEntity(ssRiskIntelligentRecognizeIdParam.getId());
    }

    @Override
    public SsRiskIntelligentRecognize queryEntity(String id) {
        SsRiskIntelligentRecognize ssRiskIntelligentRecognize = this.getById(id);
        if (ObjectUtil.isEmpty(ssRiskIntelligentRecognize)) {
            throw new CommonException("安全仓储-风险智能识别表不存在，id值为：{}", id);
        }
        return ssRiskIntelligentRecognize;
    }
}
