/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssSafeGrainStorageInspection.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.vo.SsSafeGrainStorageInspectionPageVO;
import com.unis.safeStorage.modular.ssSafeProductInspection.param.SsSafeProductInspectionIdParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.entity.SsSafeGrainStorageInspection;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionAddParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionEditParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionIdParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionPageParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.service.SsSafeGrainStorageInspectionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-安全储粮检查表表控制器
 *
 * @author hjc
 * @date  2024/06/03 09:57
 */
@Api(tags = "安全仓储-安全储粮检查表表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SsSafeGrainStorageInspectionController {

    @Resource
    private SsSafeGrainStorageInspectionService ssSafeGrainStorageInspectionService;

    /**
     * 获取安全仓储-安全储粮检查表表分页
     *
     * @author hjc
     * @date  2024/06/03 09:57
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取安全仓储-安全储粮检查表表分页")
   // @SaCheckPermission("/safeStorage/ssSafeGrainStorageInspection/page")
    @GetMapping("/safeStorage/ssSafeGrainStorageInspection/page")
    public CommonResult<Page<SsSafeGrainStorageInspectionPageVO>> page(SsSafeGrainStorageInspectionPageParam ssSafeGrainStorageInspectionPageParam) {
        return CommonResult.data(ssSafeGrainStorageInspectionService.page(ssSafeGrainStorageInspectionPageParam));
    }

    /**
     * 添加安全仓储-安全储粮检查表表
     *
     * @author hjc
     * @date  2024/06/03 09:57
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加安全仓储-安全储粮检查表表")
    @CommonLog("添加安全仓储-安全储粮检查表表")
    //@SaCheckPermission("/safeStorage/ssSafeGrainStorageInspection/add")
    @PostMapping("/safeStorage/ssSafeGrainStorageInspection/add")
    public CommonResult<String> add(@RequestBody @Valid SsSafeGrainStorageInspectionAddParam ssSafeGrainStorageInspectionAddParam) {
        ssSafeGrainStorageInspectionService.add(ssSafeGrainStorageInspectionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-安全储粮检查表表
     *
     * @author hjc
     * @date  2024/06/03 09:57
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑安全仓储-安全储粮检查表表")
    @CommonLog("编辑安全仓储-安全储粮检查表表")
    //@SaCheckPermission("/safeStorage/ssSafeGrainStorageInspection/edit")
    @PostMapping("/safeStorage/ssSafeGrainStorageInspection/edit")
    public CommonResult<String> edit(@RequestBody @Valid SsSafeGrainStorageInspectionEditParam ssSafeGrainStorageInspectionEditParam) {
        ssSafeGrainStorageInspectionService.edit(ssSafeGrainStorageInspectionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-安全储粮检查表表
     *
     * @author hjc
     * @date  2024/06/03 09:57
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除安全仓储-安全储粮检查表表")
    @CommonLog("删除安全仓储-安全储粮检查表表")
    //@SaCheckPermission("/safeStorage/ssSafeGrainStorageInspection/delete")
    @PostMapping("/safeStorage/ssSafeGrainStorageInspection/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<SsSafeGrainStorageInspectionIdParam> ssSafeGrainStorageInspectionIdParamList) {
        ssSafeGrainStorageInspectionService.delete(ssSafeGrainStorageInspectionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-安全储粮检查表表详情
     *
     * @author hjc
     * @date  2024/06/03 09:57
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取安全仓储-安全储粮检查表表详情")
    //@SaCheckPermission("/safeStorage/ssSafeGrainStorageInspection/detail")
    @GetMapping("/safeStorage/ssSafeGrainStorageInspection/detail")
    public CommonResult<SsSafeGrainStorageInspectionPageVO> detail(@Valid SsSafeGrainStorageInspectionIdParam ssSafeGrainStorageInspectionIdParam) {
        return CommonResult.data(ssSafeGrainStorageInspectionService.detail(ssSafeGrainStorageInspectionIdParam));
    }

    /**
     * 下发
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("下发")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/detail")
    @GetMapping("/safeStorage/ssSafeGrainStorageInspection/issued")
    public CommonResult<String> issued(@Valid SsSafeGrainStorageInspectionIdParam param) {
        ssSafeGrainStorageInspectionService.issued(param);
        return CommonResult.ok();
    }
}
