/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssSafeGrainStorageInspection.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.vo.SsSafeGrainStorageInspectionPageVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.entity.SsSafeGrainStorageInspection;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.mapper.SsSafeGrainStorageInspectionMapper;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionAddParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionEditParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionIdParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.param.SsSafeGrainStorageInspectionPageParam;
import com.unis.safeStorage.modular.ssSafeGrainStorageInspection.service.SsSafeGrainStorageInspectionService;

import java.util.List;

/**
 * 安全仓储-安全储粮检查表表Service接口实现类
 *
 * @author hjc
 * @date  2024/06/03 09:57
 **/
@Service
public class SsSafeGrainStorageInspectionServiceImpl extends ServiceImpl<SsSafeGrainStorageInspectionMapper, SsSafeGrainStorageInspection> implements SsSafeGrainStorageInspectionService {

    @Autowired
    private SsSafeGrainStorageInspectionMapper ssSafeGrainStorageInspectionMapper;

    @Autowired
    private OrgInfoMapper orgInfoMapper;
    @Override
    public Page<SsSafeGrainStorageInspectionPageVO> page(SsSafeGrainStorageInspectionPageParam pageParam) {

        Page<SsSafeGrainStorageInspectionPageVO> page = new Page<>(pageParam.getCurrent(), pageParam.getSize());
        return ssSafeGrainStorageInspectionMapper.selectMyPage(page,pageParam.getOrgName());
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsSafeGrainStorageInspectionAddParam ssSafeGrainStorageInspectionAddParam) {
        SsSafeGrainStorageInspection ssSafeGrainStorageInspection = BeanUtil.toBean(ssSafeGrainStorageInspectionAddParam, SsSafeGrainStorageInspection.class);
        this.save(ssSafeGrainStorageInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsSafeGrainStorageInspectionEditParam ssSafeGrainStorageInspectionEditParam) {
        SsSafeGrainStorageInspection ssSafeGrainStorageInspection = this.queryEntity(ssSafeGrainStorageInspectionEditParam.getId());
        BeanUtil.copyProperties(ssSafeGrainStorageInspectionEditParam, ssSafeGrainStorageInspection);
        this.updateById(ssSafeGrainStorageInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsSafeGrainStorageInspectionIdParam> ssSafeGrainStorageInspectionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssSafeGrainStorageInspectionIdParamList, SsSafeGrainStorageInspectionIdParam::getId));
    }

    @Override
    public SsSafeGrainStorageInspectionPageVO detail(SsSafeGrainStorageInspectionIdParam ssSafeGrainStorageInspectionIdParam) {

        SsSafeGrainStorageInspectionPageVO vo = new SsSafeGrainStorageInspectionPageVO();
        SsSafeGrainStorageInspection ssSafeGrainStorageInspection = this.queryEntity(ssSafeGrainStorageInspectionIdParam.getId());
        BeanUtil.copyProperties(ssSafeGrainStorageInspection,vo);

        OrgInfo orgInfo = orgInfoMapper.selectById(ssSafeGrainStorageInspection.getOrgId());
        vo.setOrgName(orgInfo.getOrgName());

        return vo;
    }

    @Override
    public SsSafeGrainStorageInspection queryEntity(String id) {
        SsSafeGrainStorageInspection ssSafeGrainStorageInspection = this.getById(id);
        if(ObjectUtil.isEmpty(ssSafeGrainStorageInspection)) {
            throw new CommonException("安全仓储-安全储粮检查表表不存在，id值为：{}", id);
        }
        return ssSafeGrainStorageInspection;
    }


    /**
     * 下发
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @Override
    public void issued(SsSafeGrainStorageInspectionIdParam param) {

        SsSafeGrainStorageInspection ssSafeGrainStorageInspection = this.queryEntity(param.getId());
        ssSafeGrainStorageInspection.setStatus(1);

        this.updateById(ssSafeGrainStorageInspection);
    }
}
