/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssSafeProductInspection.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.safeStorage.modular.ssSafeProductInspection.param.*;
import com.unis.safeStorage.modular.ssSafeProductInspection.vo.SsSafeProductInspectionDetailVO;
import com.unis.safeStorage.modular.ssSafeProductInspection.vo.SsSafeProductInspectionPageVO;
import com.unis.safeStorage.modular.ssSafeProductInspection.vo.SsSafeProductInspectionResultPageVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssSafeProductInspection.entity.SsSafeProductInspection;
import com.unis.safeStorage.modular.ssSafeProductInspection.service.SsSafeProductInspectionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 日常安全检查-安全生产检查表控制器
 *
 * @author hjc
 * @date 2024/05/31 16:48
 */
@Api(tags = "日常安全检查-安全生产检查表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SsSafeProductInspectionController {

    @Resource
    private SsSafeProductInspectionService ssSafeProductInspectionService;

    /**
     * 获取日常安全检查-安全生产检查表分页
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取日常安全检查-安全生产检查表分页")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/page")
    @GetMapping("/safeStorage/ssSafeProductInspection/page")
    public CommonResult<Page<SsSafeProductInspectionPageVO>> page(SsSafeProductInspectionPageParam ssSafeProductInspectionPageParam) {
        return CommonResult.data(ssSafeProductInspectionService.page(ssSafeProductInspectionPageParam));
    }

    /**
     * 添加日常安全检查-安全生产检查表
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加日常安全检查-安全生产检查表")
    @CommonLog("添加日常安全检查-安全生产检查表")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/add")
    @PostMapping("/safeStorage/ssSafeProductInspection/add")
    public CommonResult<String> add(@RequestBody @Valid SsSafeProductInspectionAddParam ssSafeProductInspectionAddParam) {
        ssSafeProductInspectionService.add(ssSafeProductInspectionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑日常安全检查-安全生产检查表
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑日常安全检查-安全生产检查表")
    @CommonLog("编辑日常安全检查-安全生产检查表")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/edit")
    @PostMapping("/safeStorage/ssSafeProductInspection/edit")
    public CommonResult<String> edit(@RequestBody @Valid SsSafeProductInspectionEditParam ssSafeProductInspectionEditParam) {
        ssSafeProductInspectionService.edit(ssSafeProductInspectionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除日常安全检查-安全生产检查表
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除日常安全检查-安全生产检查表")
    @CommonLog("删除日常安全检查-安全生产检查表")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/delete")
    @PostMapping("/safeStorage/ssSafeProductInspection/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<SsSafeProductInspectionIdParam> ssSafeProductInspectionIdParamList) {
        ssSafeProductInspectionService.delete(ssSafeProductInspectionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取日常安全检查-安全生产检查表详情
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取日常安全检查-安全生产检查表详情")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/detail")
    @GetMapping("/safeStorage/ssSafeProductInspection/detail")
    public CommonResult<SsSafeProductInspection> detail(@Valid SsSafeProductInspectionIdParam ssSafeProductInspectionIdParam) {
        return CommonResult.data(ssSafeProductInspectionService.detail(ssSafeProductInspectionIdParam));
    }

    /**
     * 获取库区信息
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取库区信息")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/detail")
    @GetMapping("/safeStorage/ssSafeProductInspection/getOrgInfo")
    public CommonResult<List<OrgInfo>> getOrgInfo() {
        return CommonResult.data(ssSafeProductInspectionService.getOrgInfo());
    }

    /**
     * 下发
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("下发")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/detail")
    @GetMapping("/safeStorage/ssSafeProductInspection/issued")
    public CommonResult<String> issued(@Valid SsSafeProductInspectionIdParam ssSafeProductInspectionIdParam) {
        ssSafeProductInspectionService.issued(ssSafeProductInspectionIdParam);
        return CommonResult.ok();
    }


    /**
     * 获取日常安全检查-安全生产检查结果-分页
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("获取日常安全检查-安全生产检查结果-分页")
    //@SaCheckPermission("/safeStorage/ssSafeProductInspection/resultPage")
    @GetMapping("/safeStorage/ssSafeProductInspection/resultPage")
    public CommonResult<Page<SsSafeProductInspectionResultPageVO>> resultPage(SsSafeProductInspectionResultPageParam pageParam) {
        return CommonResult.data(ssSafeProductInspectionService.resultPage(pageParam));
    }

}
