/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssSafeProductInspection.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.safeStorage.modular.ssSafeProductInspection.param.*;
import com.unis.safeStorage.modular.ssSafeProductInspection.vo.SsSafeProductInspectionPageVO;
import com.unis.safeStorage.modular.ssSafeProductInspection.vo.SsSafeProductInspectionResultPageVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssSafeProductInspection.entity.SsSafeProductInspection;
import com.unis.safeStorage.modular.ssSafeProductInspection.mapper.SsSafeProductInspectionMapper;
import com.unis.safeStorage.modular.ssSafeProductInspection.service.SsSafeProductInspectionService;

import java.util.List;

/**
 * 日常安全检查-安全生产检查表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/31 16:48
 **/
@Service
public class SsSafeProductInspectionServiceImpl extends ServiceImpl<SsSafeProductInspectionMapper, SsSafeProductInspection> implements SsSafeProductInspectionService {

    @Autowired
    private SsSafeProductInspectionMapper ssSafeProductInspectionMapper;

    @Autowired
    private OrgInfoMapper orgInfoMapper;

    @Override
    public Page<SsSafeProductInspectionPageVO> page(SsSafeProductInspectionPageParam pageParam) {
        /*QueryWrapper<SsSafeProductInspection> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(ssSafeProductInspectionPageParam.getSortField(), ssSafeProductInspectionPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssSafeProductInspectionPageParam.getSortOrder());
            queryWrapper.orderBy(true, ssSafeProductInspectionPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssSafeProductInspectionPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(SsSafeProductInspection::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);*/

        Page<SsSafeProductInspectionPageVO> page = new Page<>(pageParam.getCurrent(), pageParam.getSize());
        return ssSafeProductInspectionMapper.selectMyPage(page, pageParam.getOrgName());

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsSafeProductInspectionAddParam ssSafeProductInspectionAddParam) {
        SsSafeProductInspection ssSafeProductInspection = BeanUtil.toBean(ssSafeProductInspectionAddParam, SsSafeProductInspection.class);
        this.save(ssSafeProductInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsSafeProductInspectionEditParam ssSafeProductInspectionEditParam) {
        SsSafeProductInspection ssSafeProductInspection = this.queryEntity(ssSafeProductInspectionEditParam.getId());
        BeanUtil.copyProperties(ssSafeProductInspectionEditParam, ssSafeProductInspection);
        this.updateById(ssSafeProductInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsSafeProductInspectionIdParam> ssSafeProductInspectionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssSafeProductInspectionIdParamList, SsSafeProductInspectionIdParam::getId));
    }

    @Override
    public SsSafeProductInspection detail(SsSafeProductInspectionIdParam ssSafeProductInspectionIdParam) {
        return this.queryEntity(ssSafeProductInspectionIdParam.getId());
    }

    @Override
    public SsSafeProductInspection queryEntity(String id) {
        SsSafeProductInspection ssSafeProductInspection = this.getById(id);
        if (ObjectUtil.isEmpty(ssSafeProductInspection)) {
            throw new CommonException("日常安全检查-安全生产检查表不存在，id值为：{}", id);
        }
        return ssSafeProductInspection;
    }

    /**
     * 获取库区信息
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @Override
    public List<OrgInfo> getOrgInfo() {

        return orgInfoMapper.selectList(null);
    }


    /**
     * 下发
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @Override
    public void issued(SsSafeProductInspectionIdParam ssSafeProductInspectionIdParam) {
        SsSafeProductInspection ssSafeProductInspection = this.queryEntity(ssSafeProductInspectionIdParam.getId());
        ssSafeProductInspection.setStatus(1);

        this.updateById(ssSafeProductInspection);
    }

    /**
     * 获取日常安全检查-安全生产检查结果-分页
     *
     * @author hjc
     * @date 2024/05/31 16:48
     */
    @Override
    public Page<SsSafeProductInspectionResultPageVO> resultPage(SsSafeProductInspectionResultPageParam pageParam) {

        Page<SsSafeProductInspectionResultPageVO> page = new Page<>(pageParam.getCurrent(), pageParam.getSize());
        return ssSafeProductInspectionMapper.getSsSafeProductInspectionResultPage(page,
                DateUtil.format(pageParam.getInspectionDate(), "yyyy-MM-dd") ,
                pageParam.getStorehouseName(), pageParam.getOrgName());

    }
}
