/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssVideoLinkage.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssVideoLinkage.entity.SsVideoLinkage;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageAddParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageEditParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageIdParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkagePageParam;
import com.unis.safeStorage.modular.ssVideoLinkage.service.SsVideoLinkageService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-视频联动表控制器
 *
 * @author hjc
 * @date  2024/06/01 10:23
 */
@Api(tags = "安全仓储-视频联动表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class SsVideoLinkageController {

    @Resource
    private SsVideoLinkageService ssVideoLinkageService;

    /**
     * 获取安全仓储-视频联动表分页
     *
     * @author hjc
     * @date  2024/06/01 10:23
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取安全仓储-视频联动表分页")
    //@SaCheckPermission("/safeStorage/ssVideoLinkage/page")
    @GetMapping("/safeStorage/ssVideoLinkage/page")
    public CommonResult<Page<SsVideoLinkage>> page(SsVideoLinkagePageParam ssVideoLinkagePageParam) {
        return CommonResult.data(ssVideoLinkageService.page(ssVideoLinkagePageParam));
    }

    /**
     * 添加安全仓储-视频联动表
     *
     * @author hjc
     * @date  2024/06/01 10:23
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加安全仓储-视频联动表")
    @CommonLog("添加安全仓储-视频联动表")
    //@SaCheckPermission("/safeStorage/ssVideoLinkage/add")
    @PostMapping("/safeStorage/ssVideoLinkage/add")
    public CommonResult<String> add(@RequestBody @Valid SsVideoLinkageAddParam ssVideoLinkageAddParam) {
        ssVideoLinkageService.add(ssVideoLinkageAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-视频联动表
     *
     * @author hjc
     * @date  2024/06/01 10:23
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑安全仓储-视频联动表")
    @CommonLog("编辑安全仓储-视频联动表")
    //@SaCheckPermission("/safeStorage/ssVideoLinkage/edit")
    @PostMapping("/safeStorage/ssVideoLinkage/edit")
    public CommonResult<String> edit(@RequestBody @Valid SsVideoLinkageEditParam ssVideoLinkageEditParam) {
        ssVideoLinkageService.edit(ssVideoLinkageEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-视频联动表
     *
     * @author hjc
     * @date  2024/06/01 10:23
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除安全仓储-视频联动表")
    @CommonLog("删除安全仓储-视频联动表")
    //@SaCheckPermission("/safeStorage/ssVideoLinkage/delete")
    @PostMapping("/safeStorage/ssVideoLinkage/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<SsVideoLinkageIdParam> ssVideoLinkageIdParamList) {
        ssVideoLinkageService.delete(ssVideoLinkageIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-视频联动表详情
     *
     * @author hjc
     * @date  2024/06/01 10:23
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取安全仓储-视频联动表详情")
    //@SaCheckPermission("/safeStorage/ssVideoLinkage/detail")
    @GetMapping("/safeStorage/ssVideoLinkage/detail")
    public CommonResult<SsVideoLinkage> detail(@Valid SsVideoLinkageIdParam ssVideoLinkageIdParam) {
        return CommonResult.data(ssVideoLinkageService.detail(ssVideoLinkageIdParam));
    }
}
