/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssVideoLinkage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssVideoLinkage.entity.SsVideoLinkage;
import com.unis.safeStorage.modular.ssVideoLinkage.mapper.SsVideoLinkageMapper;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageAddParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageEditParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkageIdParam;
import com.unis.safeStorage.modular.ssVideoLinkage.param.SsVideoLinkagePageParam;
import com.unis.safeStorage.modular.ssVideoLinkage.service.SsVideoLinkageService;

import java.util.List;

/**
 * 安全仓储-视频联动表Service接口实现类
 *
 * @author hjc
 * @date  2024/06/01 10:23
 **/
@Service
public class SsVideoLinkageServiceImpl extends ServiceImpl<SsVideoLinkageMapper, SsVideoLinkage> implements SsVideoLinkageService {

    @Autowired
    private SsVideoLinkageMapper ssVideoLinkageMapper;
    @Override
    public Page<SsVideoLinkage> page(SsVideoLinkagePageParam ssVideoLinkagePageParam) {
       /* QueryWrapper<SsVideoLinkage> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(ssVideoLinkagePageParam.getSortField(), ssVideoLinkagePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ssVideoLinkagePageParam.getSortOrder());
            queryWrapper.orderBy(true, ssVideoLinkagePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ssVideoLinkagePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(SsVideoLinkage::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);*/

        Page<SsVideoLinkage> page = new Page<>(ssVideoLinkagePageParam.getCurrent(), ssVideoLinkagePageParam.getSize());
        return ssVideoLinkageMapper.selectMyPage(page,ssVideoLinkagePageParam.getOrgName());
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(SsVideoLinkageAddParam ssVideoLinkageAddParam) {
        SsVideoLinkage ssVideoLinkage = BeanUtil.toBean(ssVideoLinkageAddParam, SsVideoLinkage.class);
        this.save(ssVideoLinkage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(SsVideoLinkageEditParam ssVideoLinkageEditParam) {
        SsVideoLinkage ssVideoLinkage = this.queryEntity(ssVideoLinkageEditParam.getId());
        BeanUtil.copyProperties(ssVideoLinkageEditParam, ssVideoLinkage);
        this.updateById(ssVideoLinkage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<SsVideoLinkageIdParam> ssVideoLinkageIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ssVideoLinkageIdParamList, SsVideoLinkageIdParam::getId));
    }

    @Override
    public SsVideoLinkage detail(SsVideoLinkageIdParam ssVideoLinkageIdParam) {
        return this.queryEntity(ssVideoLinkageIdParam.getId());
    }

    @Override
    public SsVideoLinkage queryEntity(String id) {
        SsVideoLinkage ssVideoLinkage = this.getById(id);
        if(ObjectUtil.isEmpty(ssVideoLinkage)) {
            throw new CommonException("安全仓储-视频联动表不存在，id值为：{}", id);
        }
        return ssVideoLinkage;
    }
}
