/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssfirewatersource.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssfirewatersource.entity.BizSsFireWaterSource;
import com.unis.safeStorage.modular.ssfirewatersource.mapper.BizSsFireWaterSourceMapper;
import com.unis.safeStorage.modular.ssfirewatersource.param.BizSsFireWaterSourceAddParam;
import com.unis.safeStorage.modular.ssfirewatersource.param.BizSsFireWaterSourceEditParam;
import com.unis.safeStorage.modular.ssfirewatersource.param.BizSsFireWaterSourceIdParam;
import com.unis.safeStorage.modular.ssfirewatersource.param.BizSsFireWaterSourcePageParam;
import com.unis.safeStorage.modular.ssfirewatersource.service.BizSsFireWaterSourceService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 安全仓储-消防水源管理表Service接口实现类
 *
 * @author shine
 * @date  2024/06/03 14:27
 **/
@Service
public class BizSsFireWaterSourceServiceImpl extends ServiceImpl<BizSsFireWaterSourceMapper, BizSsFireWaterSource> implements BizSsFireWaterSourceService {

    @Resource
    private OrgInfoMapper orgInfoMapper;
    @Override
    public Page<BizSsFireWaterSource> page(BizSsFireWaterSourcePageParam bizSsFireWaterSourcePageParam) {
        QueryWrapper<BizSsFireWaterSource> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSsFireWaterSourcePageParam.getOrgId())) {
            queryWrapper.lambda().eq(BizSsFireWaterSource::getOrgId, bizSsFireWaterSourcePageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(bizSsFireWaterSourcePageParam.getEquipmentType())) {
            queryWrapper.lambda().eq(BizSsFireWaterSource::getEquipmentType, bizSsFireWaterSourcePageParam.getEquipmentType());
        }
        if(ObjectUtil.isNotEmpty(bizSsFireWaterSourcePageParam.getStartWarningTime()) && ObjectUtil.isNotEmpty(bizSsFireWaterSourcePageParam.getEndWarningTime())) {
            queryWrapper.lambda().between(BizSsFireWaterSource::getWarningTime, bizSsFireWaterSourcePageParam.getStartWarningTime(), bizSsFireWaterSourcePageParam.getEndWarningTime());
        }
        if(ObjectUtil.isAllNotEmpty(bizSsFireWaterSourcePageParam.getSortField(), bizSsFireWaterSourcePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSsFireWaterSourcePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSsFireWaterSourcePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSsFireWaterSourcePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSsFireWaterSource::getId);
        }

        Page<BizSsFireWaterSource> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        if(pageList.getRecords().size()>0){
            for(BizSsFireWaterSource bizSsFireWaterSource:pageList.getRecords()){
                OrgInfo orgInfo = orgInfoMapper.selectById(bizSsFireWaterSource.getOrgId());
                if(ObjectUtil.isNotNull(orgInfo)){
                    bizSsFireWaterSource.setOrgName(orgInfo.getOrgName());
                }
            }
        }

        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSsFireWaterSourceAddParam bizSsFireWaterSourceAddParam) {
        BizSsFireWaterSource bizSsFireWaterSource = BeanUtil.toBean(bizSsFireWaterSourceAddParam, BizSsFireWaterSource.class);
        this.save(bizSsFireWaterSource);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSsFireWaterSourceEditParam bizSsFireWaterSourceEditParam) {
        BizSsFireWaterSource bizSsFireWaterSource = this.queryEntity(bizSsFireWaterSourceEditParam.getId());
        BeanUtil.copyProperties(bizSsFireWaterSourceEditParam, bizSsFireWaterSource);
        this.updateById(bizSsFireWaterSource);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSsFireWaterSourceIdParam> bizSsFireWaterSourceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSsFireWaterSourceIdParamList, BizSsFireWaterSourceIdParam::getId));
    }

    @Override
    public BizSsFireWaterSource detail(BizSsFireWaterSourceIdParam bizSsFireWaterSourceIdParam) {
        return this.queryEntity(bizSsFireWaterSourceIdParam.getId());
    }

    @Override
    public BizSsFireWaterSource queryEntity(String id) {
        BizSsFireWaterSource bizSsFireWaterSource = this.getById(id);
        if(ObjectUtil.isEmpty(bizSsFireWaterSource)) {
            throw new CommonException("安全仓储-消防水源管理表不存在，id值为：{}", id);
        }
        return bizSsFireWaterSource;
    }
}
