/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssfirewatersourcethreshold.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.entity.BizSsFireWaterSourceThreshold;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.mapper.BizSsFireWaterSourceThresholdMapper;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.param.BizSsFireWaterSourceThresholdAddParam;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.param.BizSsFireWaterSourceThresholdEditParam;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.param.BizSsFireWaterSourceThresholdIdParam;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.param.BizSsFireWaterSourceThresholdPageParam;
import com.unis.safeStorage.modular.ssfirewatersourcethreshold.service.BizSsFireWaterSourceThresholdService;

import java.util.List;

/**
 * 安全仓储-消防水源阈值设置表Service接口实现类
 *
 * @author shine
 * @date  2024/06/03 14:40
 **/
@Service
public class BizSsFireWaterSourceThresholdServiceImpl extends ServiceImpl<BizSsFireWaterSourceThresholdMapper, BizSsFireWaterSourceThreshold> implements BizSsFireWaterSourceThresholdService {

    @Override
    public Page<BizSsFireWaterSourceThreshold> page(BizSsFireWaterSourceThresholdPageParam bizSsFireWaterSourceThresholdPageParam) {
        QueryWrapper<BizSsFireWaterSourceThreshold> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSsFireWaterSourceThresholdPageParam.getEquipmentType())) {
            queryWrapper.lambda().eq(BizSsFireWaterSourceThreshold::getEquipmentType, bizSsFireWaterSourceThresholdPageParam.getEquipmentType());
        }
        if(ObjectUtil.isAllNotEmpty(bizSsFireWaterSourceThresholdPageParam.getSortField(), bizSsFireWaterSourceThresholdPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSsFireWaterSourceThresholdPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSsFireWaterSourceThresholdPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSsFireWaterSourceThresholdPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSsFireWaterSourceThreshold::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSsFireWaterSourceThresholdAddParam bizSsFireWaterSourceThresholdAddParam) {
        BizSsFireWaterSourceThreshold bizSsFireWaterSourceThreshold = BeanUtil.toBean(bizSsFireWaterSourceThresholdAddParam, BizSsFireWaterSourceThreshold.class);
        this.save(bizSsFireWaterSourceThreshold);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSsFireWaterSourceThresholdEditParam bizSsFireWaterSourceThresholdEditParam) {
        BizSsFireWaterSourceThreshold bizSsFireWaterSourceThreshold = this.queryEntity(bizSsFireWaterSourceThresholdEditParam.getId());
        BeanUtil.copyProperties(bizSsFireWaterSourceThresholdEditParam, bizSsFireWaterSourceThreshold);
        this.updateById(bizSsFireWaterSourceThreshold);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSsFireWaterSourceThresholdIdParam> bizSsFireWaterSourceThresholdIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSsFireWaterSourceThresholdIdParamList, BizSsFireWaterSourceThresholdIdParam::getId));
    }

    @Override
    public BizSsFireWaterSourceThreshold detail(BizSsFireWaterSourceThresholdIdParam bizSsFireWaterSourceThresholdIdParam) {
        return this.queryEntity(bizSsFireWaterSourceThresholdIdParam.getId());
    }

    @Override
    public BizSsFireWaterSourceThreshold queryEntity(String id) {
        BizSsFireWaterSourceThreshold bizSsFireWaterSourceThreshold = this.getById(id);
        if(ObjectUtil.isEmpty(bizSsFireWaterSourceThreshold)) {
            throw new CommonException("安全仓储-消防水源阈值设置表不存在，id值为：{}", id);
        }
        return bizSsFireWaterSourceThreshold;
    }
}
