/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.sspatrolpoint.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.sspatrolpoint.entity.BizSsPatrolPoint;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointAddParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointEditParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointIdParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointPageParam;
import com.unis.safeStorage.modular.sspatrolpoint.service.BizSsPatrolPointService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-巡检管理-巡查点管理表控制器
 *
 * @author shine
 * @date  2024/05/30 15:28
 */
@Api(tags = "安全仓储-巡检管理-巡查点管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizSsPatrolPointController {

    @Resource
    private BizSsPatrolPointService bizSsPatrolPointService;

    /**
     * 获取安全仓储-巡检管理-巡查点管理表分页
     *
     * @author shine
     * @date  2024/05/30 15:28
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取安全仓储-巡检管理-巡查点管理表分页")
    @GetMapping("/safeStorage/sspatrolpoint/page")
    public CommonResult<Page<BizSsPatrolPoint>> page(BizSsPatrolPointPageParam bizSsPatrolPointPageParam) {
        return CommonResult.data(bizSsPatrolPointService.page(bizSsPatrolPointPageParam));
    }

    /**
     * 添加安全仓储-巡检管理-巡查点管理表
     *
     * @author shine
     * @date  2024/05/30 15:28
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加安全仓储-巡检管理-巡查点管理表")
    @PostMapping("/safeStorage/sspatrolpoint/add")
    public CommonResult<String> add(@RequestBody @Valid BizSsPatrolPointAddParam bizSsPatrolPointAddParam) {
        bizSsPatrolPointService.add(bizSsPatrolPointAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-巡检管理-巡查点管理表
     *
     * @author shine
     * @date  2024/05/30 15:28
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑安全仓储-巡检管理-巡查点管理表")
    @PostMapping("/safeStorage/sspatrolpoint/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSsPatrolPointEditParam bizSsPatrolPointEditParam) {
        bizSsPatrolPointService.edit(bizSsPatrolPointEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-巡检管理-巡查点管理表
     *
     * @author shine
     * @date  2024/05/30 15:28
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除安全仓储-巡检管理-巡查点管理表")
    @PostMapping("/safeStorage/sspatrolpoint/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizSsPatrolPointIdParam> bizSsPatrolPointIdParamList) {
        bizSsPatrolPointService.delete(bizSsPatrolPointIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-巡检管理-巡查点管理表详情
     * @author shine
     * @date  2024/05/30 15:28
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取安全仓储-巡检管理-巡查点管理表详情")
    @GetMapping("/safeStorage/sspatrolpoint/detail")
    public CommonResult<BizSsPatrolPoint> detail(@Valid BizSsPatrolPointIdParam bizSsPatrolPointIdParam) {
        return CommonResult.data(bizSsPatrolPointService.detail(bizSsPatrolPointIdParam));
    }
}
