/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.sspatrolpoint.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.safeStorage.modular.sspatrolreport.entity.BizSsPatrolReport;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.sspatrolpoint.entity.BizSsPatrolPoint;
import com.unis.safeStorage.modular.sspatrolpoint.mapper.BizSsPatrolPointMapper;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointAddParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointEditParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointIdParam;
import com.unis.safeStorage.modular.sspatrolpoint.param.BizSsPatrolPointPageParam;
import com.unis.safeStorage.modular.sspatrolpoint.service.BizSsPatrolPointService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 安全仓储-巡检管理-巡查点管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/30 15:28
 **/
@Service
public class BizSsPatrolPointServiceImpl extends ServiceImpl<BizSsPatrolPointMapper, BizSsPatrolPoint> implements BizSsPatrolPointService {

    @Resource
    private OrgInfoMapper orgInfoMapper;

    @Override
    public Page<BizSsPatrolPoint> page(BizSsPatrolPointPageParam bizSsPatrolPointPageParam) {
        QueryWrapper<BizSsPatrolPoint> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSsPatrolPointPageParam.getOrgId())) {
            queryWrapper.lambda().eq(BizSsPatrolPoint::getOrgId, bizSsPatrolPointPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolPointPageParam.getWarehouseResponsiblePerson())) {
            queryWrapper.lambda().like(BizSsPatrolPoint::getWarehouseResponsiblePerson, bizSsPatrolPointPageParam.getWarehouseResponsiblePerson());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolPointPageParam.getEquipmentName())) {
            queryWrapper.lambda().like(BizSsPatrolPoint::getEquipmentName, bizSsPatrolPointPageParam.getEquipmentName());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolPointPageParam.getMaxPatrolTimeLimit())) {
            queryWrapper.lambda().eq(BizSsPatrolPoint::getMaxPatrolTimeLimit, bizSsPatrolPointPageParam.getMaxPatrolTimeLimit());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolPointPageParam.getMinPatrolTimeLimit())) {
            queryWrapper.lambda().eq(BizSsPatrolPoint::getMinPatrolTimeLimit, bizSsPatrolPointPageParam.getMinPatrolTimeLimit());
        }
        if(ObjectUtil.isAllNotEmpty(bizSsPatrolPointPageParam.getSortField(), bizSsPatrolPointPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSsPatrolPointPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSsPatrolPointPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSsPatrolPointPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSsPatrolPoint::getId);
        }
        Page<BizSsPatrolPoint> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizSsPatrolPoint bizSsPatrolPoint:pageList.getRecords()){
            OrgInfo orgInfo = orgInfoMapper.selectById(bizSsPatrolPoint.getOrgId());
            bizSsPatrolPoint.setOrgName(orgInfo.getOrgName());
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSsPatrolPointAddParam bizSsPatrolPointAddParam) {
        BizSsPatrolPoint bizSsPatrolPoint = BeanUtil.toBean(bizSsPatrolPointAddParam, BizSsPatrolPoint.class);
        this.save(bizSsPatrolPoint);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSsPatrolPointEditParam bizSsPatrolPointEditParam) {
        BizSsPatrolPoint bizSsPatrolPoint = this.queryEntity(bizSsPatrolPointEditParam.getId());
        BeanUtil.copyProperties(bizSsPatrolPointEditParam, bizSsPatrolPoint);
        this.updateById(bizSsPatrolPoint);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSsPatrolPointIdParam> bizSsPatrolPointIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSsPatrolPointIdParamList, BizSsPatrolPointIdParam::getId));
    }

    @Override
    public BizSsPatrolPoint detail(BizSsPatrolPointIdParam bizSsPatrolPointIdParam) {
        return this.queryEntity(bizSsPatrolPointIdParam.getId());
    }

    @Override
    public BizSsPatrolPoint queryEntity(String id) {
        BizSsPatrolPoint bizSsPatrolPoint = this.getById(id);
        if(ObjectUtil.isEmpty(bizSsPatrolPoint)) {
            throw new CommonException("安全仓储-巡检管理-巡查点管理表不存在，id值为：{}", id);
        }
        return bizSsPatrolPoint;
    }
}
