/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.sspatrolreport.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.sspatrolreport.entity.BizSsPatrolReport;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportAddParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportEditParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportIdParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportPageParam;
import com.unis.safeStorage.modular.sspatrolreport.service.BizSsPatrolReportService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 安全仓储-巡检管理-巡查报告表控制器
 *
 * @author shine
 * @date  2024/05/30 15:32
 */
@Api(tags = "安全仓储-巡检管理-巡查报告表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizSsPatrolReportController {

    @Resource
    private BizSsPatrolReportService bizSsPatrolReportService;

    /**
     * 获取安全仓储-巡检管理-巡查报告表分页
     *
     * @author shine
     * @date  2024/05/30 15:32
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取安全仓储-巡检管理-巡查报告表分页")
    @GetMapping("/safeStorage/sspatrolreport/page")
    public CommonResult<Page<BizSsPatrolReport>> page(BizSsPatrolReportPageParam bizSsPatrolReportPageParam) {
        return CommonResult.data(bizSsPatrolReportService.page(bizSsPatrolReportPageParam));
    }

    /**
     * 添加安全仓储-巡检管理-巡查报告表
     *
     * @author shine
     * @date  2024/05/30 15:32
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加安全仓储-巡检管理-巡查报告表")
    @PostMapping("/safeStorage/sspatrolreport/add")
    public CommonResult<String> add(@RequestBody @Valid BizSsPatrolReportAddParam bizSsPatrolReportAddParam) {
        bizSsPatrolReportService.add(bizSsPatrolReportAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-巡检管理-巡查报告表
     * @author shine
     * @date  2024/05/30 15:32
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*编辑安全仓储-巡检管理-巡查报告表")
    @PostMapping("/safeStorage/sspatrolreport/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSsPatrolReportEditParam bizSsPatrolReportEditParam) {
        bizSsPatrolReportService.edit(bizSsPatrolReportEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-巡检管理-巡查报告表
     *
     * @author shine
     * @date  2024/05/30 15:32
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*删除安全仓储-巡检管理-巡查报告表")
    @PostMapping("/safeStorage/sspatrolreport/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizSsPatrolReportIdParam> bizSsPatrolReportIdParamList) {
        bizSsPatrolReportService.delete(bizSsPatrolReportIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-巡检管理-巡查报告表详情
     *
     * @author shine
     * @date  2024/05/30 15:32
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取安全仓储-巡检管理-巡查报告表详情")
    @GetMapping("/safeStorage/sspatrolreport/detail")
    public CommonResult<BizSsPatrolReport> detail(@Valid BizSsPatrolReportIdParam bizSsPatrolReportIdParam) {
        return CommonResult.data(bizSsPatrolReportService.detail(bizSsPatrolReportIdParam));
    }
}
