/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.sspatrolreport.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.sspatrolreport.entity.BizSsPatrolReport;
import com.unis.safeStorage.modular.sspatrolreport.mapper.BizSsPatrolReportMapper;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportAddParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportEditParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportIdParam;
import com.unis.safeStorage.modular.sspatrolreport.param.BizSsPatrolReportPageParam;
import com.unis.safeStorage.modular.sspatrolreport.service.BizSsPatrolReportService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 安全仓储-巡检管理-巡查报告表Service接口实现类
 *
 * @author shine
 * @date  2024/05/30 15:32
 **/
@Service
public class BizSsPatrolReportServiceImpl extends ServiceImpl<BizSsPatrolReportMapper, BizSsPatrolReport> implements BizSsPatrolReportService {

    @Resource
    private OrgInfoMapper orgInfoMapper;
    @Override
    public Page<BizSsPatrolReport> page(BizSsPatrolReportPageParam bizSsPatrolReportPageParam) {
        QueryWrapper<BizSsPatrolReport> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSsPatrolReportPageParam.getOrgId())) {
            queryWrapper.lambda().eq(BizSsPatrolReport::getOrgId, bizSsPatrolReportPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolReportPageParam.getPatrolTime())) {
            queryWrapper.lambda().eq(BizSsPatrolReport::getPatrolTime, bizSsPatrolReportPageParam.getPatrolTime());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolReportPageParam.getWarehouseResponsiblePerson())) {
            queryWrapper.lambda().like(BizSsPatrolReport::getWarehouseResponsiblePerson, bizSsPatrolReportPageParam.getWarehouseResponsiblePerson());
        }
        if(ObjectUtil.isNotEmpty(bizSsPatrolReportPageParam.getPatrolPerson())) {
            queryWrapper.lambda().like(BizSsPatrolReport::getPatrolPerson, bizSsPatrolReportPageParam.getPatrolPerson());
        }
        if(ObjectUtil.isAllNotEmpty(bizSsPatrolReportPageParam.getSortField(), bizSsPatrolReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSsPatrolReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSsPatrolReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSsPatrolReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSsPatrolReport::getId);
        }

        Page<BizSsPatrolReport> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizSsPatrolReport bizSsPatrolReport:pageList.getRecords()){
            OrgInfo orgInfo = orgInfoMapper.selectById(bizSsPatrolReport.getOrgId());
            bizSsPatrolReport.setOrgName(orgInfo.getOrgName());
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSsPatrolReportAddParam bizSsPatrolReportAddParam) {
        BizSsPatrolReport bizSsPatrolReport = BeanUtil.toBean(bizSsPatrolReportAddParam, BizSsPatrolReport.class);
        this.save(bizSsPatrolReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSsPatrolReportEditParam bizSsPatrolReportEditParam) {
        BizSsPatrolReport bizSsPatrolReport = this.queryEntity(bizSsPatrolReportEditParam.getId());
        BeanUtil.copyProperties(bizSsPatrolReportEditParam, bizSsPatrolReport);
        this.updateById(bizSsPatrolReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSsPatrolReportIdParam> bizSsPatrolReportIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSsPatrolReportIdParamList, BizSsPatrolReportIdParam::getId));
    }

    @Override
    public BizSsPatrolReport detail(BizSsPatrolReportIdParam bizSsPatrolReportIdParam) {
        return this.queryEntity(bizSsPatrolReportIdParam.getId());
    }

    @Override
    public BizSsPatrolReport queryEntity(String id) {
        BizSsPatrolReport bizSsPatrolReport = this.getById(id);
        if(ObjectUtil.isEmpty(bizSsPatrolReport)) {
            throw new CommonException("安全仓储-巡检管理-巡查报告表不存在，id值为：{}", id);
        }
        return bizSsPatrolReport;
    }
}
