/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssriskaccident.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.safeStorage.modular.ssriskaccident.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.safeStorage.modular.ssriskaccident.entity.BizSsRiskAccident;
import com.unis.safeStorage.modular.ssriskaccident.service.BizSsRiskAccidentService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 安全仓储-安全风险台账-安全风险事故管理表控制器
 *
 * @author shine
 * @date  2024/05/30 17:34
 */
@Api(tags = "安全仓储-安全风险台账-安全风险事故管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizSsRiskAccidentController {

    @Resource
    private BizSsRiskAccidentService bizSsRiskAccidentService;

    /**
     * 获取安全仓储-安全风险台账-安全风险事故管理表分页
     *
     * @author shine
     * @date  2024/05/30 17:34
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*获取安全仓储-安全风险台账-安全风险事故管理表分页")
    @GetMapping("/safeStorage/ssriskaccident/page")
    public CommonResult<Page<BizSsRiskAccident>> page(BizSsRiskAccidentPageParam bizSsRiskAccidentPageParam) {
        return CommonResult.data(bizSsRiskAccidentService.page(bizSsRiskAccidentPageParam));
    }

    /**
     * 添加安全仓储-安全风险台账-安全风险事故管理表
     *
     * @author shine
     * @date  2024/05/30 17:34
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*添加安全仓储-安全风险台账-安全风险事故管理表")
    @PostMapping("/safeStorage/ssriskaccident/add")
    public CommonResult<String> add(@RequestBody @Valid BizSsRiskAccidentAddParam bizSsRiskAccidentAddParam) {
        bizSsRiskAccidentService.add(bizSsRiskAccidentAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑安全仓储-安全风险台账-安全风险事故管理表
     *
     * @author shine
     * @date  2024/05/30 17:34
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑安全仓储-安全风险台账-安全风险事故管理表")
    @PostMapping("/safeStorage/ssriskaccident/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSsRiskAccidentEditParam bizSsRiskAccidentEditParam) {
        bizSsRiskAccidentService.edit(bizSsRiskAccidentEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除安全仓储-安全风险台账-安全风险事故管理表
     *
     * @author shine
     * @date  2024/05/30 17:34
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除安全仓储-安全风险台账-安全风险事故管理表")
    @PostMapping("/safeStorage/ssriskaccident/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizSsRiskAccidentIdParam> bizSsRiskAccidentIdParamList) {
        bizSsRiskAccidentService.delete(bizSsRiskAccidentIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取安全仓储-安全风险台账-安全风险事故管理表详情
     *
     * @author shine
     * @date  2024/05/30 17:34
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*获取安全仓储-安全风险台账-安全风险事故管理表详情")
    @GetMapping("/safeStorage/ssriskaccident/detail")
    public CommonResult<BizSsRiskAccident> detail(@Valid BizSsRiskAccidentIdParam bizSsRiskAccidentIdParam) {
        return CommonResult.data(bizSsRiskAccidentService.detail(bizSsRiskAccidentIdParam));
    }

    /**
     * 安全风险台账管理--统计图表
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*安全风险台账管理--统计图表")
    @PostMapping("/safeStorage/ssriskaccident/statisticalChart")
    public CommonResult<Map<String, Object>> statisticalChart(@RequestBody StatisticalChartParam StatisticalChartParam) {
        return CommonResult.data(bizSsRiskAccidentService.statisticalChart(StatisticalChartParam));
    }
}
