/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.safeStorage.modular.ssriskaccident.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.basic.info.modular.orgInfo.mapper.OrgInfoMapper;
import com.unis.basic.info.modular.unitInfo.entity.UnitInfo;
import com.unis.basic.info.modular.unitInfo.mapper.UnitInfoMapper;

import com.unis.biz.modular.dict.entity.BizDict;
import com.unis.biz.modular.dict.mapper.BizDictMapper;
import com.unis.safeStorage.modular.ssriskaccident.param.*;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.safeStorage.modular.ssriskaccident.entity.BizSsRiskAccident;
import com.unis.safeStorage.modular.ssriskaccident.mapper.BizSsRiskAccidentMapper;
import com.unis.safeStorage.modular.ssriskaccident.service.BizSsRiskAccidentService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 安全仓储-安全风险台账-安全风险事故管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/30 17:34
 **/
@Service
public class BizSsRiskAccidentServiceImpl extends ServiceImpl<BizSsRiskAccidentMapper, BizSsRiskAccident> implements BizSsRiskAccidentService {

    @Resource
    private OrgInfoMapper orgInfoMapper;

    @Resource
    private UnitInfoMapper unitInfoMapper;

    @Resource
    private BizSsRiskAccidentMapper bizSsRiskAccidentMapper;

    @Resource
    private BizDictMapper bizDictMapper;



    @Override
    public Page<BizSsRiskAccident> page(BizSsRiskAccidentPageParam bizSsRiskAccidentPageParam) {
        if(ObjectUtil.isNotEmpty(bizSsRiskAccidentPageParam.getZcdzCity())) {
            QueryWrapper<UnitInfo> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.lambda().eq(UnitInfo::getZcdzCity, bizSsRiskAccidentPageParam.getZcdzCity());
            List<UnitInfo> list = unitInfoMapper.selectList(queryWrapper1);
            String zcdzCityConcatenated = list.stream()
                    .map(UnitInfo::getZcdzCity)
                    .collect(Collectors.joining(", "));
            bizSsRiskAccidentPageParam.setUnitInfoId(zcdzCityConcatenated);
        }


        QueryWrapper<BizSsRiskAccident> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSsRiskAccidentPageParam.getOrgId())) {
            queryWrapper.lambda().eq(BizSsRiskAccident::getOrgId, bizSsRiskAccidentPageParam.getOrgId());
        }
        if(ObjectUtil.isNotEmpty(bizSsRiskAccidentPageParam.getUnitInfoId())) {
            //queryWrapper.lambda().eq(BizSsRiskAccident::getUnitInfoId, bizSsRiskAccidentPageParam.getUnitInfoId());
            queryWrapper.lambda().in(true,BizSsRiskAccident::getUnitInfoId, bizSsRiskAccidentPageParam.getUnitInfoId());
        }
        if(ObjectUtil.isNotEmpty(bizSsRiskAccidentPageParam.getLocation())) {
            queryWrapper.lambda().like(BizSsRiskAccident::getLocation, bizSsRiskAccidentPageParam.getLocation());
        }
        if(ObjectUtil.isNotEmpty(bizSsRiskAccidentPageParam.getLossSituation())) {
            queryWrapper.lambda().like(BizSsRiskAccident::getLossSituation, bizSsRiskAccidentPageParam.getLossSituation());
        }
        if(ObjectUtil.isAllNotEmpty(bizSsRiskAccidentPageParam.getSortField(), bizSsRiskAccidentPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSsRiskAccidentPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSsRiskAccidentPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSsRiskAccidentPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizSsRiskAccident::getId);
        }
        Page<BizSsRiskAccident> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);
        for(BizSsRiskAccident bizSsRiskAccident:pageList.getRecords()){
            OrgInfo orgInfo = orgInfoMapper.selectById(bizSsRiskAccident.getOrgId());
            bizSsRiskAccident.setOrgName(orgInfo.getOrgName());
        }
        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSsRiskAccidentAddParam bizSsRiskAccidentAddParam) {
        BizSsRiskAccident bizSsRiskAccident = BeanUtil.toBean(bizSsRiskAccidentAddParam, BizSsRiskAccident.class);
        this.save(bizSsRiskAccident);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSsRiskAccidentEditParam bizSsRiskAccidentEditParam) {
        BizSsRiskAccident bizSsRiskAccident = this.queryEntity(bizSsRiskAccidentEditParam.getId());
        BeanUtil.copyProperties(bizSsRiskAccidentEditParam, bizSsRiskAccident);
        this.updateById(bizSsRiskAccident);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSsRiskAccidentIdParam> bizSsRiskAccidentIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSsRiskAccidentIdParamList, BizSsRiskAccidentIdParam::getId));
    }

    @Override
    public BizSsRiskAccident detail(BizSsRiskAccidentIdParam bizSsRiskAccidentIdParam) {
        BizSsRiskAccident bizSsRiskAccident = this.queryEntity(bizSsRiskAccidentIdParam.getId());
        if(bizSsRiskAccident.getAccidentLevel() != null){
            if(bizSsRiskAccident.getAccidentLevel().equals(1)){
                bizSsRiskAccident.setSgdjName("一级");
            }else if(bizSsRiskAccident.getAccidentLevel().equals(2)){
                bizSsRiskAccident.setSgdjName("二级");
            }else if(bizSsRiskAccident.getAccidentLevel().equals(3)){
                bizSsRiskAccident.setSgdjName("三级");
            }
        }

        if(bizSsRiskAccident.getAccidentType() != null){
            if(bizSsRiskAccident.getAccidentType().equals(1)){
                bizSsRiskAccident.setSglxName("熏蒸事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(2)){
                bizSsRiskAccident.setSglxName("火灾事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(3)){
                bizSsRiskAccident.setSglxName("烘干事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(4)){
                bizSsRiskAccident.setSglxName("高空事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(5)){
                bizSsRiskAccident.setSglxName("用电事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(6)){
                bizSsRiskAccident.setSglxName("车辆事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(7)){
                bizSsRiskAccident.setSglxName("吊装事故");
            }else if(bizSsRiskAccident.getAccidentType().equals(8)){
                bizSsRiskAccident.setSglxName("水灾事故");
            }
        }
        UnitInfo unitInfo = unitInfoMapper.selectById(bizSsRiskAccident.getUnitInfoId());
        if(ObjectUtil.isNotNull(unitInfo)){
            bizSsRiskAccident.setZcdzCity(unitInfo.getZcdzCity());
            BizDict bizDict = bizDictMapper.selectById(unitInfo.getZcdzCity());
            if(ObjectUtil.isNotNull(bizDict)){
                bizSsRiskAccident.setZcdzCityName(bizDict.getDictLabel());
            }
        }
        OrgInfo orgInfo = orgInfoMapper.selectById(bizSsRiskAccident.getOrgId());
        if(ObjectUtil.isNotNull(orgInfo)){
            bizSsRiskAccident.setOrgName(orgInfo.getOrgName());
        }
        return bizSsRiskAccident;
    }

    @Override
    public BizSsRiskAccident queryEntity(String id) {
        BizSsRiskAccident bizSsRiskAccident = this.getById(id);
        if(ObjectUtil.isEmpty(bizSsRiskAccident)) {
            throw new CommonException("安全仓储-安全风险台账-安全风险事故管理表不存在，id值为：{}", id);
        }
        return bizSsRiskAccident;
    }

    @Override
    public Map<String, Object> statisticalChart(StatisticalChartParam statisticalChartParam) {
        Map<String,Object> returnMap = new HashMap<String,Object>();

            Map<String,Object> map = new HashMap<String,Object>();
            map.put("startTime",statisticalChartParam.getOccurrenceTimeStart());
            map.put("endTime",statisticalChartParam.getOccurrenceTimeEnd());
            map.put("orgName",statisticalChartParam.getOrgName());
            map.put("zcdzCity",statisticalChartParam.getZcdzCity());

        //各类事故发生次数
        List<Map<String, Object>> list = bizSsRiskAccidentMapper.getNumberByType(map);

        //各市州事故发生次数
        List<Map<String, Object>> list1 = bizSsRiskAccidentMapper.getNumberByZcdzCity(map);

        returnMap.put("type",list);
        returnMap.put("city",list1);

        return returnMap;
    }
}
