/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */

package com.unis.statisticalAnalysis.modular.kcsw.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.statisticalAnalysis.modular.kcsw.param.KcswPageParam;
import com.unis.statisticalAnalysis.modular.kcsw.service.KcswService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Param;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.pojo.CommonResult;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;


/**
 * 统计分析
 * @author shine
 * @date  2024/05/30 17:34
 */

@Api(tags = "统计分析-图表-库存")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class KcswController {

    @Resource
    private KcswService kcswService;

    /**
     * 根据库区，品种，性质等级 分组 计算实物库存
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("*根据库区，品种，性质等级 分组 计算实物库存--分页列表")
    @GetMapping("/statistical/analysis/kcswpage")
    public CommonResult<IPage<List<Map<String,Object>>>> kcswpage(KcswPageParam kcswPageParam) {
        return CommonResult.data(kcswService.kcswpage(kcswPageParam));
    }

    /**
     * 轮换计划 完成/未完成 比例
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("*轮换计划 完成/未完成 比例")
    @GetMapping("/statistical/analysis/lhjhScale")
    public CommonResult<Map<String,Object>> lhjhScale(KcswPageParam kcswPageParam) {
        return CommonResult.data(kcswService.lhjhScale(kcswPageParam.getOrgId()));
    }

    /**
     * 质量统计(等级)
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("*质量统计(等级)")
    @GetMapping("/statistical/analysis/qualityStatistics")
    public CommonResult<List<Map<String,Object>>> qualityStatistics(KcswPageParam kcswPageParam) {
        return CommonResult.data(kcswService.qualityStatistics(kcswPageParam.getOrgId()));
    }

    /**
     * 地方储备粮性质统计
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("*地方储备粮性质统计")
    @GetMapping("/statistical/analysis/grainPropertyStatistics")
    public CommonResult<List<Map<String,Object>>> grainPropertyStatistics(KcswPageParam kcswPageParam) {
        return CommonResult.data(kcswService.grainPropertyStatistics(kcswPageParam.getOrgId()));
    }

    /**
     * 预警次数统计
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("*预警次数统计")
    @GetMapping("/statistical/analysis/numberOfWarning")
    public CommonResult<List<Map<String, Object>>> numberOfWarning(KcswPageParam kcswPageParam) {
        return CommonResult.data(kcswService.numberOfWarning(kcswPageParam.getOrgId()));
    }

    /**
     * 库存、企业数量、库点个数、仓房个数、货位个数
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("*库存、企业数量、库点个数、仓房个数、货位个数")
    @GetMapping("/statistical/analysis/quantity")
    public CommonResult<List<Map<String, Object>>> quantity() {
        return CommonResult.data(kcswService.quantity());
    }


    /**
     * 库存占比分析
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("*库存占比分析")
    @GetMapping("/statistical/analysis/inventoryRatio")
    public CommonResult<List<Map<String, Object>>> inventoryRatio() {
        return CommonResult.data(kcswService.inventoryRatio());
    }

    /**
     * 粮食入库统计
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("*粮食入库统计")
    @GetMapping("/statistical/analysis/grainStorageStatistics")
    public CommonResult<List<Map<String, Object>>> grainStorageStatistics() {
        return CommonResult.data(kcswService.grainStorageStatistics());
    }

    /**
     * 粮食库存和出入库统计
     */
    @ApiOperationSupport(order = 9)
    @ApiOperation("*粮食库存和出入库统计")
    @GetMapping("/statistical/analysis/inventoryInOutStatistics")
    public CommonResult<List<Map<String, Object>>> inventoryInOutStatistics() {
        return CommonResult.data(kcswService.inventoryInOutStatistics());
    }

}

