/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.statisticalReport.info.modular.conReportinfo.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.unis.basic.info.modular.enumInfo.entity.BasicEnum;
import com.unis.emergencySupport.modular.es.entity.EsNetworkEntry;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.ConReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.EsNetworkEntryPageReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.EsNetworkEntryReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.PlanReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.ReserveReportDetailsinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.ReserveReportStorehouseinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.ReserveReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.entity.vo.StorehouseCapacityReportinfo;
import com.unis.statisticalReport.info.modular.conReportinfo.param.EsNetworkEntryReportinfoParam;
import com.unis.statisticalReport.info.modular.conReportinfo.param.PlanReportinfoParam;
import com.unis.statisticalReport.info.modular.conReportinfo.param.ReserveReportinfoParam;
import com.unis.statisticalReport.info.modular.conReportinfo.param.StorehouseCapacityReportinfoParam;

import java.util.List;

/**
 * 统计报表Service接口
 *
 * @author TS
 * @date  2024/05/31 10:02
 **/
public interface ConReportinfoService extends IService<ConReportinfo> {

    /**
     * 获取储备统计图表数据
     * @param reserveReportinfoParam
     * @return
     */
    List<ReserveReportinfo> getReserveChartDatas(ReserveReportinfoParam reserveReportinfoParam);

    /**
     * 获取储备统计图表-仓房数据
     * @param reserveReportinfoParam
     * @return
     */
    IPage<ReserveReportStorehouseinfo> findStorehousePage(ReserveReportinfoParam reserveReportinfoParam);

    /**
     * 获取储备统计图表-仓房数据详情
     * @param orgId
     * @param storehouseId
     * @param warehouseId
     * @return
     */
    ReserveReportDetailsinfo getStorehouseDetails(String orgId, String storehouseId, String warehouseId);

    /**
     * 获取仓容统计图表数据
     * @return
     */
    List<StorehouseCapacityReportinfo> getStorehouseChartDatas();

    /**
     * 获取仓容统计图表-仓房数据
     * @param capacityReportinfoParam
     * @return
     */
    IPage<StorehouseCapacityReportinfo> findStorehouseCapacityPage(StorehouseCapacityReportinfoParam capacityReportinfoParam);

    /**
     * 获取应急保障报表详情
     * @return
     */
    EsNetworkEntryReportinfo getEsNetworkEntryDetails(EsNetworkEntryReportinfoParam esNetworkEntryReportinfoParam);

    /**
     * 获取应急保障报表分页
     * @param esNetworkEntryReportinfoParam
     * @return
     */
    IPage<EsNetworkEntryPageReportinfo> findEsNetworkEntryPage(EsNetworkEntryReportinfoParam esNetworkEntryReportinfoParam);

    /**
     * 获取收购报表分页
     * @param planReportinfoParam
     * @return
     */
    IPage<PlanReportinfo> findBuyPlanPage(PlanReportinfoParam planReportinfoParam);

    /**
     * 获取收购报表详情
     * @param id
     * @return
     */
    PlanReportinfo getBuyPlanDetails(String id);

    /**
     * 获取当日购销报表分页
     * @param planReportinfoParam
     * @return
     */
    IPage<PlanReportinfo> findCurrentPlanPage(PlanReportinfoParam planReportinfoParam);

    /**
     *获取当日购销报表详情
     * @param id
     * @param warehouseId
     * @return
     */
    PlanReportinfo getCurrentPlanDetails(String id, String warehouseId);
}
