/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.statisticalReport.info.modular.grainReserveInspection.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.statisticalReport.info.modular.grainReserveInspection.entity.GrainReserveInspection;
import com.unis.statisticalReport.info.modular.grainReserveInspection.param.GrainReserveInspectionAddParam;
import com.unis.statisticalReport.info.modular.grainReserveInspection.param.GrainReserveInspectionEditParam;
import com.unis.statisticalReport.info.modular.grainReserveInspection.param.GrainReserveInspectionIdParam;
import com.unis.statisticalReport.info.modular.grainReserveInspection.param.GrainReserveInspectionPageParam;
import com.unis.statisticalReport.info.modular.grainReserveInspection.service.GrainReserveInspectionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 储备粮验收检查控制器
 *
 * @author QSHan
 * @date  2024/06/03 11:11
 */
@Api(tags = "储备粮验收检查控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
@RequestMapping("/client/c")
public class GrainReserveInspectionController {

    @Resource
    private GrainReserveInspectionService grainReserveInspectionService;

    /**
     * 获取储备粮验收检查分页
     *
     * @author QSHan
     * @date  2024/06/03 11:11
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取储备粮验收检查分页")
//    @SaCheckPermission("/statisticalReport.info/grainReserveInspection/page")
    @GetMapping("/grainReserveInspection/page")
    public CommonResult<Page<GrainReserveInspection>> page(GrainReserveInspectionPageParam grainReserveInspectionPageParam) {
        return CommonResult.data(grainReserveInspectionService.page(grainReserveInspectionPageParam));
    }

    /**
     * 添加储备粮验收检查
     *
     * @author QSHan
     * @date  2024/06/03 11:11
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加储备粮验收检查")
    @CommonLog("添加储备粮验收检查")
//    @SaCheckPermission("/statisticalReport.info/grainReserveInspection/add")
    @PostMapping("/grainReserveInspection/add")
    public CommonResult<String> add(@RequestBody @Valid GrainReserveInspectionAddParam grainReserveInspectionAddParam) {
        grainReserveInspectionService.add(grainReserveInspectionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑储备粮验收检查
     *
     * @author QSHan
     * @date  2024/06/03 11:11
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑储备粮验收检查")
    @CommonLog("编辑储备粮验收检查")
//    @SaCheckPermission("/statisticalReport.info/grainReserveInspection/edit")
    @PostMapping("/grainReserveInspection/edit")
    public CommonResult<String> edit(@RequestBody @Valid GrainReserveInspectionEditParam grainReserveInspectionEditParam) {
        grainReserveInspectionService.edit(grainReserveInspectionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除储备粮验收检查
     *
     * @author QSHan
     * @date  2024/06/03 11:11
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除储备粮验收检查")
    @CommonLog("删除储备粮验收检查")
//    @SaCheckPermission("/statisticalReport.info/grainReserveInspection/delete")
    @PostMapping("/grainReserveInspection/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<GrainReserveInspectionIdParam> grainReserveInspectionIdParamList) {
        grainReserveInspectionService.delete(grainReserveInspectionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取储备粮验收检查详情
     *
     * @author QSHan
     * @date  2024/06/03 11:11
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取储备粮验收检查详情")
//    @SaCheckPermission("/statisticalReport.info/grainReserveInspection/detail")
    @GetMapping("/grainReserveInspection/detail")
    public CommonResult<GrainReserveInspection> detail(@Valid GrainReserveInspectionIdParam grainReserveInspectionIdParam) {
        return CommonResult.data(grainReserveInspectionService.detail(grainReserveInspectionIdParam));
    }

    // 随机生成-被检查库点
    @ApiOperationSupport(order = 6)
    @ApiOperation("随机生成-被检查库点")
    @GetMapping("/grainReserveInspection/getOrgInfoOnly")
    public CommonResult<Map<String, Object>> getOrgInfoOnly() {
        return CommonResult.data(grainReserveInspectionService.getOrgInfoOnly());
    }

    // 获取 仓房名称 货位名称
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取仓房名称,货位名称(storeHouse!=null返回货位)")
    @GetMapping("/grainReserveInspection/getStorehouseOrWarehouse/{orgId}")
    public CommonResult<List<Map<String, Object>>> getStorehouseOrWarehouse(@PathVariable("orgId") Integer orgId, @RequestParam(required = false) Integer storeHouseId) {
        return CommonResult.data(grainReserveInspectionService.getStorehouseOrWarehouse(orgId, storeHouseId));
    }

    @ApiOperationSupport(order = 8)
    @ApiOperation("获取粮食产地")
    @GetMapping("/grainReserveInspection/getCd/{orgId}/{storeHouseId}/{warehouseId}")
    public CommonResult<String> getCd(@PathVariable("orgId") Integer orgId, @PathVariable("storeHouseId") Integer storeHouseId, @PathVariable("warehouseId") Integer warehouseId) {
        return CommonResult.data(grainReserveInspectionService.getCd(orgId, storeHouseId, warehouseId));
    }

}
