/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.statisticalReport.info.modular.grainReserveInspection.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.entity.GrainReserveInspectionItem;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 储备粮验收检查实体
 *
 * @author QSHan
 * @date 2024/06/03 11:11
 **/
@Getter
@Setter
@TableName("biz_ipad_grain_reserve_inspection")
public class GrainReserveInspection {

    /**
     * 储备粮验收检查唯一标识符
     */
    @TableId
    @ApiModelProperty(value = "储备粮验收检查唯一标识符", position = 1)
    private String id;

    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间", position = 2)
    @TableField(fill = FieldFill.INSERT)
    private Date createTime;

    /**
     * 创建用户
     */
    @ApiModelProperty(value = "创建用户", position = 3)
    @TableField(fill = FieldFill.INSERT)
    private String createUser;

    /**
     * 修改时间
     */
    @ApiModelProperty(value = "修改时间", position = 4)
    @TableField(fill = FieldFill.UPDATE)
    private Date updateTime;

    /**
     * 修改用户
     */
    @ApiModelProperty(value = "修改用户", position = 5)
    @TableField(fill = FieldFill.UPDATE)
    private String updateUser;

    /**
     * 检查人；sys_user的id；
     */
    @ApiModelProperty(value = "检查人；sys_user的id；", position = 6)
    private String inspectorId;

    /**
     * 被检查库点；外库depot_qh.org_info的id；
     */
    @ApiModelProperty(value = "被检查库点；外库depot_qh.org_info的id；", position = 7)
    private Integer orgId;

    /**
     * 外库depot_qh.basic_storehouse的id；仓房id
     */
    @ApiModelProperty(value = "外库depot_qh.basic_storehouse的id；仓房id", position = 8)
    private Integer basicStorehouseId;

    /**
     * 外库depot_qh.basic_warehouse的id；货位id;
     */
    @ApiModelProperty(value = "外库depot_qh.basic_warehouse的id；货位id;", position = 9)
    private Integer warehouseId;

    /**
     * 粮食品种；外库depot_qh.basic_enum的id；
     */
    @ApiModelProperty(value = "粮食品种；外库depot_qh.basic_enum的id；", position = 10)
    private Integer grainVarietyId;

    /**
     * 粮食等级；外库depot_qh.basic_enum的id；
     */
    @ApiModelProperty(value = "粮食等级；外库depot_qh.basic_enum的id；", position = 11)
    private Integer grainGradeId;

    /**
     * 收获年度
     */
    @ApiModelProperty(value = "收获年度", position = 12)
    private String receiveYear;

    /**
     * 保管员
     */
    @ApiModelProperty(value = "保管员", position = 13)
    private String keeper;

    /**
     * 检查日期
     */
    @ApiModelProperty(value = "检查日期", position = 14)
    private Date inspectionDate;

    /**
     * 粮食产地
     */
    @ApiModelProperty(value = "粮食产地", position = 15)
    private String produceArea;

    /**
     * 检查依据
     */
    @ApiModelProperty(value = "检查依据", position = 16)
    private String jyyj;

    /**
     * 检查结果，0：不合格；1：合格；
     */
    @ApiModelProperty(value = "检查结果，0：不合格；1：合格；", position = 17)
    private Integer checkResult;

    /**
     * 抽样日期
     */
    @ApiModelProperty(value = "抽样日期", position = 18)
    private Date qysj;

    /**
     * 抽样单编号
     */
    @ApiModelProperty(value = "抽样单编号", position = 19)
    private String qydbh;

    /**
     * 样品数量
     */
    @ApiModelProperty(value = "样品数量", position = 20)
    private BigDecimal ypsl;

    /**
     * 抽样基数
     */
    @ApiModelProperty(value = "抽样基数", position = 21)
    private BigDecimal samplingBase;

    /**
     * 样品等级
     */
    @ApiModelProperty(value = "样品等级", position = 22)
    private String ypdj;

    /**
     * 图片，多个图片用","分隔
     */
    @ApiModelProperty(value = "图片，多个图片用,分隔", position = 23)
    private String images;

    /**
     * 检查结论
     */
    @ApiModelProperty(value = "检查结论", position = 24)
    private String inspectionConclusion;

    @ApiModelProperty(value = "指标类别，7602: 质量指标检验, 7603：储存品质检验, 7604：食品安全检验", position = 25)
    private String zblb;

    @ApiModelProperty(value = "代表数量，单位：公斤", position = 26)
    private String dbsl;

    @ApiModelProperty(value = "仓房名称", position = 27)
    @TableField(exist = false)
    private String storehouseName;

    @ApiModelProperty(value = "货位名称", position = 28)
    @TableField(exist = false)
    private String warehouseName;

    @ApiModelProperty(value = "粮食品种名称", position = 29)
    @TableField(exist = false)
    private String grainVarietyName;

    @ApiModelProperty(value = "检验项目及依据", position = 30)
    @TableField(exist = false)
    private List<GrainReserveInspectionItem> granItem;
}
