/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.statisticalReport.info.modular.grainReserveInspectionItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.entity.GrainReserveInspectionItem;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.mapper.GrainReserveInspectionItemMapper;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.param.GrainReserveInspectionItemAddParam;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.param.GrainReserveInspectionItemEditParam;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.param.GrainReserveInspectionItemIdParam;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.param.GrainReserveInspectionItemPageParam;
import com.unis.statisticalReport.info.modular.grainReserveInspectionItem.service.GrainReserveInspectionItemService;

import java.util.List;

/**
 * 检验项目及依据Service接口实现类
 *
 * @author QSHan
 * @date  2024/06/03 11:14
 **/
@Service
public class GrainReserveInspectionItemServiceImpl extends ServiceImpl<GrainReserveInspectionItemMapper, GrainReserveInspectionItem> implements GrainReserveInspectionItemService {

    @Override
    public Page<GrainReserveInspectionItem> page(GrainReserveInspectionItemPageParam grainReserveInspectionItemPageParam) {
        QueryWrapper<GrainReserveInspectionItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(grainReserveInspectionItemPageParam.getSortField(), grainReserveInspectionItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(grainReserveInspectionItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, grainReserveInspectionItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(grainReserveInspectionItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(GrainReserveInspectionItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(GrainReserveInspectionItemAddParam grainReserveInspectionItemAddParam) {
        GrainReserveInspectionItem grainReserveInspectionItem = BeanUtil.toBean(grainReserveInspectionItemAddParam, GrainReserveInspectionItem.class);
        this.save(grainReserveInspectionItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(GrainReserveInspectionItemEditParam grainReserveInspectionItemEditParam) {
        GrainReserveInspectionItem grainReserveInspectionItem = this.queryEntity(grainReserveInspectionItemEditParam.getId());
        BeanUtil.copyProperties(grainReserveInspectionItemEditParam, grainReserveInspectionItem);
        this.updateById(grainReserveInspectionItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<GrainReserveInspectionItemIdParam> grainReserveInspectionItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(grainReserveInspectionItemIdParamList, GrainReserveInspectionItemIdParam::getId));
    }

    @Override
    public GrainReserveInspectionItem detail(GrainReserveInspectionItemIdParam grainReserveInspectionItemIdParam) {
        return this.queryEntity(grainReserveInspectionItemIdParam.getId());
    }

    @Override
    public GrainReserveInspectionItem queryEntity(String id) {
        GrainReserveInspectionItem grainReserveInspectionItem = this.getById(id);
        if(ObjectUtil.isEmpty(grainReserveInspectionItem)) {
            throw new CommonException("检验项目及依据不存在，id值为：{}", id);
        }
        return grainReserveInspectionItem;
    }
}
