/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.statisticalReport.info.modular.ssSafeProductInspectionResult.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 日常安全检查-安全生产检查-结果表添加参数
 *
 * @author hjc
 * @date  2024/06/01 14:49
 **/
@Getter
@Setter
public class SsSafeProductInspectionResultAddParam {

    /** biz_ss_safe_product_inspection的id； */
    @ApiModelProperty(value = "biz_ss_safe_product_inspection的id；", position = 6)
    private String ssSafeProductInspectionId;

    /** 外库depot_qh.basic_storehouse的id；仓房id */
    @ApiModelProperty(value = "外库depot_qh.basic_storehouse的id；仓房id", position = 7)
    private Integer basicStorehouseId;

    /** 外库depot_qh.basic_warehouse的id；货位id; */
    @ApiModelProperty(value = "外库depot_qh.basic_warehouse的id；货位id;", position = 8)
    private Integer warehouseId;

    /** 检查人 */
    @ApiModelProperty(value = "检查人", position = 10)
    private String inspector;

    /** 保管员 */
    @ApiModelProperty(value = "保管员", position = 11)
    private String keeper;

    /** 检查日期 */
    @ApiModelProperty(value = "检查日期", position = 12)
    private Date inspectionDate;

    /** 粮温℃ */
    @ApiModelProperty(value = "粮温℃", position = 13)
    private BigDecimal grainTemperature;

    /** 仓温℃ */
    @ApiModelProperty(value = "仓温℃", position = 14)
    private BigDecimal storeroomTemperature;

    /** 气温℃ */
    @ApiModelProperty(value = "气温℃", position = 15)
    private BigDecimal ambientTemperature;

    /** 仓内湿% */
    @ApiModelProperty(value = "仓内湿%", position = 16)
    private BigDecimal storeroomHumidity;

    /** 仓外湿% */
    @ApiModelProperty(value = "仓外湿%", position = 17)
    private BigDecimal ambientHumidity;

    /** 是否超限装粮，0：否；1：是； */
    @ApiModelProperty(value = "是否超限装粮，0：否；1：是；", position = 18)
    private Boolean isOverloaded;

    /** 装粮高度 */
    @ApiModelProperty(value = "装粮高度", position = 19)
    private BigDecimal grainHeight;

    /** 仓容 */
    @ApiModelProperty(value = "仓容", position = 20)
    private BigDecimal storageCapacity;

    /** 粮仓使用年限，单位：年 */
    @ApiModelProperty(value = "粮仓使用年限，单位：年", position = 21)
    private Integer usageYears;

    /** 仓房有无渗漏，0：否；1：是； */
    @ApiModelProperty(value = "仓房有无渗漏，0：否；1：是；", position = 22)
    private Boolean isLeakage;

    /** 墙壁有无裂缝，0：否；1：是； */
    @ApiModelProperty(value = "墙壁有无裂缝，0：否；1：是；", position = 23)
    private Boolean isWallCrack;

    /** 地面有无裂缝，0：否；1：是； */
    @ApiModelProperty(value = "地面有无裂缝，0：否；1：是；", position = 24)
    private Boolean isFloorCrack;

    /** 地面有无沉降，0：否；1：是； */
    @ApiModelProperty(value = "地面有无沉降，0：否；1：是；", position = 25)
    private Boolean isGroundSubmersion;

    /** 门窗有无损坏，0：否；1：是； */
    @ApiModelProperty(value = "门窗有无损坏，0：否；1：是；", position = 26)
    private Boolean isDoorWindowDamage;

    /** 附属设施是否完好，0：否；1：是； */
    @ApiModelProperty(value = "附属设施是否完好，0：否；1：是；", position = 27)
    private Boolean isAccessoryFacilityIntact;

    /** 钢板仓房锈漆是否剥落，0：否；1：是； */
    @ApiModelProperty(value = "钢板仓房锈漆是否剥落，0：否；1：是；", position = 28)
    private Boolean isPaintPeel;

    /** 螺栓、垫片是否松动，0：否；1：是； */
    @ApiModelProperty(value = "螺栓、垫片是否松动，0：否；1：是；", position = 29)
    private Boolean isBoltLoose;

    /** 支座部位有无异常，0：否；1：是； */
    @ApiModelProperty(value = "支座部位有无异常，0：否；1：是；", position = 30)
    private Boolean isSupportAbnormal;

    /** 油罐焊缝是否完好，0：否；1：是； */
    @ApiModelProperty(value = "油罐焊缝是否完好，0：否；1：是；", position = 31)
    private Boolean isWeldSeamIntact;

    /** 罐顶盖、人孔、测量孔、通气孔是否正常，0：否；1：是； */
    @ApiModelProperty(value = "罐顶盖、人孔、测量孔、通气孔是否正常，0：否；1：是；", position = 32)
    private Boolean isTankCoverNormal;

    /** 垫片是否完好，0：否；1：是； */
    @ApiModelProperty(value = "垫片是否完好，0：否；1：是；", position = 33)
    private Boolean isGasketIntact;

    /** 罐区、管线阀门施封情况是否牢靠，0：否；1：是； */
    @ApiModelProperty(value = "罐区、管线阀门施封情况是否牢靠，0：否；1：是；", position = 34)
    private Boolean isValveSealReliable;

    /** 图片，多个图片用","分隔 */
    @ApiModelProperty(value = "图片，多个图片用,分隔", position = 35)
    private String images;

}
