/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.visualization.modular.grainOilPurchaseSales.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.grainReserves.modular.gopsPlan.entity.GopsPlan;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.CurrentCrkStock;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.CurrentCrkWork;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.DeoptRotationPalnDetail;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.GopsPlanSum;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.RotationPlanMapChart;
import com.unis.visualization.modular.grainOilPurchaseSales.entity.VO.RotationPlanVarietyChart;
import com.unis.visualization.modular.grainOilPurchaseSales.param.GopsPlanSumParam;
import com.unis.visualization.modular.grainOilReserve.entity.VO.CurrentCrkCapacityChart;
import com.unis.visualization.modular.grainOilReserve.param.GrainOilReserveParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.pojo.CommonResult;
import com.unis.visualization.modular.grainOilPurchaseSales.service.GrainOilPurchaseSalesService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 可视化-购销管理控制器
 *
 * @author TS
 * @date  2024/06/21 10:49
 */
@Api(tags = "可视化-购销管理控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainOilPurchaseSalesController {

    @Resource
    private GrainOilPurchaseSalesService grainOilPurchaseSalesService;

    /**
     * 获取轮换计划-品种轮换数量
     *
     * @author TS
     * @date  2024/06/21 10:49
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取轮换计划-品种轮换数量")
    @GetMapping("/visualization/grainOilPurchaseSales/getRotationPalnVarietyChartDatas")
    public CommonResult<List<RotationPlanVarietyChart>> getRotationPalnVarietyChartDatas() {
        return CommonResult.data(grainOilPurchaseSalesService.getRotationPalnVarietyChartDatas());
    }
    /**
     * 获取轮换计划地图信息
     *
     * @author TS
     * @date  2024/06/21 10:49
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取轮换计划地图信息")
    @GetMapping("/visualization/grainOilPurchaseSales/getRotationPalnMapChartDatas")
    public CommonResult<List<RotationPlanMapChart>> getRotationPalnMapChartDatas() {
        return CommonResult.data(grainOilPurchaseSalesService.getRotationPalnMapChartDatas());
    }

    /**
     * 获取购销计划数量统计信息
     *
     * @author TS
     * @date  2024/06/22 10:49
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("获取购销计划数量统计信息")
    @GetMapping("/visualization/grainOilPurchaseSales/getGopsPalnSumList")
    public CommonResult<List<GopsPlanSum>> getGopsPalnSumList(@Valid GopsPlanSumParam gopsPlanSumParam) {
        return CommonResult.data(grainOilPurchaseSalesService.getGopsPalnSumList(gopsPlanSumParam));
    }

    /**
     * 获取当日出入库作业信息
     *
     * @author TS
     * @date  2024/06/18 17:41
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("获取当日出入库统计图表信息")
    @GetMapping("/visualization/grainOilPurchaseSales/getCurrentCrkWorkList")
    public CommonResult<List<CurrentCrkWork>> getCurrentCrkWorkList(GrainOilReserveParam param) {
        return CommonResult.data(grainOilPurchaseSalesService.getCurrentCrkWorkList(param));
    }
    /**
     * 获取当日出入库作业库存数量信息
     *
     * @author TS
     * @date  2024/06/18 17:41
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取当日出入库统计图表信息")
    @GetMapping("/visualization/grainOilPurchaseSales/getCurrentCrkWorkStock")
    public CommonResult<CurrentCrkStock> getCurrentCrkWorkStock() {
        return CommonResult.data(grainOilPurchaseSalesService.getCurrentCrkWorkStock());
    }

    /**
     * 获取库区轮换计划详情
     *
     * @author TS
     * @date  2024/06/28 17:41
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取库区轮换计划详情")
    @GetMapping("/visualization/grainOilPurchaseSales/getDeoptRotationPalnDetail")
    public CommonResult<DeoptRotationPalnDetail> getDeoptRotationPalnDetail(@RequestParam("orgId") @NotNull(message = "库区id不能为空") Integer orgId) {
        return CommonResult.data(grainOilPurchaseSalesService.getDeoptRotationPalnDetail(orgId));
    }
}
