/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.visualization.modular.grainOilReserve.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.common.pojo.CommonResult;
import com.unis.visualization.modular.grainOilReserve.entity.VO.CityVarietyCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.CurrentCrkCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockDetail;
import com.unis.visualization.modular.grainOilReserve.entity.VO.GradeCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.RotationPlanChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.StorehouseCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.VarietyCapacityChart;
import com.unis.visualization.modular.grainOilReserve.param.DepotStockParam;
import com.unis.visualization.modular.grainOilReserve.param.GrainOilReserveParam;
import com.unis.visualization.modular.grainOilReserve.service.GrainOilReserveService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 可视化-粮油储备控制器
 *
 * @author TS
 * @date  2024/06/18 11:08
 */
@Api(tags = "可视化-粮油储备控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainOilReserveController {

    @Resource
    private GrainOilReserveService grainOilReserveService;

    /**
     * 获取仓容统计图表信息
     *
     * @author TS
     * @date  2024/06/18 11:08
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取仓容统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getStorehouseChartDatas")
    public CommonResult<StorehouseCapacityChart> getStorehouseChartDatas() {
        return CommonResult.data(grainOilReserveService.getStorehouseChartDatas());
    }

    /**
     * 获取品种统计图表信息
     *
     * @author TS
     * @date  2024/06/18 11:08
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取品种统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getVarietyChartDatas")
    public CommonResult<List<VarietyCapacityChart>> getVarietyChartDatas() {
        return CommonResult.data(grainOilReserveService.getVarietyChartDatas());
    }

    /**
     * 获取等级统计图表信息
     *
     * @author TS
     * @date  2024/06/18 11:08
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("获取等级统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getGradeChartDatas")
    public CommonResult<List<GradeCapacityChart>> getGradeChartDatas() {
        return CommonResult.data(grainOilReserveService.getGradeChartDatas());
    }

    /**
     * 获取各市州品种统计图表信息
     *
     * @author TS
     * @date  2024/06/18 11:08
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("获取各市州品种统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getCityVarietyChartDatas")
    public CommonResult<List<CityVarietyCapacityChart>> getCityVarietyChartDatas() {
        return CommonResult.data(grainOilReserveService.getCityVarietyChartDatas());
    }

    /**
     * 获取轮换计划统计图表信息
     *
     * @author TS
     * @date  2024/06/18 11:08
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取轮换计划统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getRotationPalnChartDatas")
    public CommonResult<RotationPlanChart> getRotationPalnChartDatas() {
        return CommonResult.data(grainOilReserveService.getRotationPalnChartDatas());
    }

    /**
     * 获取当日出入库统计图表信息
     *
     * @author TS
     * @date  2024/06/18 17:41
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取当日出入库统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getCurrentCrkChartDatas")
    public CommonResult<List<CurrentCrkCapacityChart>> getCurrentCrkChartDatas(GrainOilReserveParam param) {
        return CommonResult.data(grainOilReserveService.getCurrentCrkChartDatas(param));
    }
    /**
     * 获取库区库存分布统计图表信息
     *
     * @author TS
     * @date  2024/06/18 17:41
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("获取库区库存分布统计图表信息")
    @GetMapping("/visualization/grainOilReserve/getDepotStockChartDatas")
    public CommonResult<List<DeportStockChart>> getDepotStockChartDatas(@Valid DepotStockParam param) {
        return CommonResult.data(grainOilReserveService.getDepotStockChartDatas(param));
    }

    /**
     * 获取库区详情信息
     *
     * @author TS
     * @date  2024/06/18 17:41
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("获取库区详情信息")
    @GetMapping("/visualization/grainOilReserve/getDepotStockDetail")
    public CommonResult<DeportStockDetail> getDepotStockDetail(@RequestParam("orgId") @NotNull(message = "库区id不能为空") Integer orgId) {
        return CommonResult.data(grainOilReserveService.getDepotStockDetail(orgId));
    }


}
