/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.visualization.modular.grainOilReserve.service;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.unis.common.constant.DBConstant;
import com.unis.visualization.modular.grainOilReserve.entity.VO.CityVarietyCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.CurrentCrkCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockDetail;
import com.unis.visualization.modular.grainOilReserve.entity.VO.GradeCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.RotationPlanChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.StorehouseCapacityChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.VarietyCapacityChart;
import com.unis.visualization.modular.grainOilReserve.param.DepotStockParam;
import com.unis.visualization.modular.grainOilReserve.param.GrainOilReserveParam;

import java.util.List;

/**
 * 可视化-粮油储备Service接口
 *
 * @author TS
 * @date  2024/06/18 11:08
 **/
@DS(DBConstant.DS_DEPOT)
public interface GrainOilReserveService  {

    /**
     * 获取仓容统计图表信息
     * @return
     */
    StorehouseCapacityChart getStorehouseChartDatas();

    /**
     * 获取品种统计图表信息
     * @return
     */
    List<VarietyCapacityChart> getVarietyChartDatas();

    /**
     *获取等级统计图表信息
     * @return
     */
    List<GradeCapacityChart> getGradeChartDatas();

    /**
     *获取各市州品种统计图表信息
     * @return
     */
    List<CityVarietyCapacityChart> getCityVarietyChartDatas();

    /**
     * 获取当日出入库统计图表信息
     * @param param
     * @return
     */
    List<CurrentCrkCapacityChart> getCurrentCrkChartDatas(GrainOilReserveParam param);

    /**
     * 获取轮换计划统计图表信息
     * @return
     */
    RotationPlanChart getRotationPalnChartDatas();

    /**
     *获取库区库存分布统计图表信息
     * @return
     */
    List<DeportStockChart> getDepotStockChartDatas(DepotStockParam param);

    /**
     * 获取库区详情信息
     * @param orgId
     * @return
     */
    DeportStockDetail getDepotStockDetail(Integer orgId);
}
