/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.visualization.modular.grainSituationDetection.controller;

import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.common.pojo.CommonResult;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockChart;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockDetail;
import com.unis.visualization.modular.grainOilReserve.param.DepotStockParam;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.DeportLqDetail;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionChart;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionOnline;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarn;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarnAvg;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarnCount;
import com.unis.visualization.modular.grainSituationDetection.param.GrainSituationDetectionPageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import com.unis.visualization.modular.grainSituationDetection.service.GrainSituationDetectionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 可视化-粮情检测控制器
 *
 * @author TS
 * @date  2024/06/20 10:16
 */
@Api(tags = "可视化-粮情检测控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainSituationDetectionController {

    @Resource
    private GrainSituationDetectionService grainSituationDetectionService;

    /**
     * 获取库区库存粮情图表信息
     *
     * @author TS
     * @date  2024/06/20 17:41
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取库区库存粮情图表信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotStockLqChartDatas")
    public CommonResult<List<GrainSituationDetectionChart>> getDepotStockLqChartDatas() {
        return CommonResult.data(grainSituationDetectionService.getDepotStockLqChartDatas());
    }

    /**
     * 获取库区粮情温度预警图表信息
     *
     * @author TS
     * @date  2024/06/21 9:41
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("获取库区粮情温度预警图表信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotLqWarnList")
    public CommonResult<List<GrainSituationDetectionWarn>> getDepotLqWarnList() {
        return CommonResult.data(grainSituationDetectionService.getDepotLqWarnList());
    }

    /**
     * 获取库区粮情温度预警次数信息
     *
     * @author TS
     * @date  2024/06/25 9:41
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("获取粮情温度预警次数信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotLqWarnCount")
    public CommonResult<List<GrainSituationDetectionWarnCount>> getDepotLqWarnCount(@Valid GrainSituationDetectionPageParam pageParam) {
        return CommonResult.data(grainSituationDetectionService.getDepotLqWarnCount(pageParam));
    }

    /**
     * 获取库区粮情温度预警平均温度信息
     *
     * @author TS
     * @date  2024/06/25 9:41
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("获取粮情温度预警平均温度信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotLqWarnAvg")
    public CommonResult<List<GrainSituationDetectionWarnAvg>> getDepotLqWarnAvg() {
        return CommonResult.data(grainSituationDetectionService.getDepotLqWarnAvg());
    }
    /**
     * 获取库区粮情温度设备在线情况信息
     *
     * @author TS
     * @date  2024/06/25 9:41
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("获取库区粮情温度设备在线情况信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotLqOnlineInfo")
    public CommonResult<GrainSituationDetectionOnline> getDepotLqOnlineInfo() {
        return CommonResult.data(grainSituationDetectionService.getDepotLqOnlineInfo());
    }

    /**
     * 获取库区粮情详情信息
     *
     * @author TS
     * @date  2024/06/27 14:41
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取库区粮情详情信息")
    @GetMapping("/visualization/grainSituationDetection/getDepotLqDetail")
    public CommonResult<DeportLqDetail> getDepotLqDetail(@RequestParam("orgId") @NotNull(message = "库区id不能为空") Integer orgId) {
        return CommonResult.data(grainSituationDetectionService.getDepotLqDetail(orgId));
    }

}
