/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.visualization.modular.grainSituationDetection.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.NumberUtil;
import com.unis.visualization.modular.grainOilReserve.entity.VO.DeportStockDetail;
import com.unis.visualization.modular.grainOilReserve.entity.VO.StockDetail;
import com.unis.visualization.modular.grainOilReserve.mapper.GrainOilReserveMapper;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.DeportLqDetail;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionChart;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionOnline;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarn;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarnAvg;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.GrainSituationDetectionWarnCount;
import com.unis.visualization.modular.grainSituationDetection.entity.VO.LqDetail;
import com.unis.visualization.modular.grainSituationDetection.mapper.GrainSituationDetectionMapper;
import com.unis.visualization.modular.grainSituationDetection.param.GrainSituationDetectionPageParam;
import org.springframework.stereotype.Service;
import com.unis.visualization.modular.grainSituationDetection.service.GrainSituationDetectionService;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.List;

/**
 * 可视化-粮情检测Service接口实现类
 *
 * @author TS
 * @date  2024/06/20 10:16
 **/
@Service
public class GrainSituationDetectionServiceImpl  implements  GrainSituationDetectionService{
    @Resource
    private GrainSituationDetectionMapper grainSituationDetectionMapper;
    @Resource
    private GrainOilReserveMapper grainOilReserveMapper;
    /**
     * 获取库区库存粮情分图表信息
     *
     * @return
     */
    @Override
    public List<GrainSituationDetectionChart> getDepotStockLqChartDatas() {
        return grainSituationDetectionMapper.getDepotStockLqChartDatas();
    }

    /**
     * 获取库区粮情温度预警图表信息
     *
     * @return
     */
    @Override
    public List<GrainSituationDetectionWarn> getDepotLqWarnList() {
        return grainSituationDetectionMapper.getDepotLqWarnList();
    }

    /**
     * 获取库区粮情温度预警次数信息
     *
     * @param pageParam
     * @return
     */
    @Override
    public List<GrainSituationDetectionWarnCount> getDepotLqWarnCount(GrainSituationDetectionPageParam pageParam) {
        return grainSituationDetectionMapper.getDepotLqWarnCount(pageParam.getLqWarnCountQuery());
    }

    /**
     * 获取库区粮情温度预警平均温度信息
     *
     * @return
     */
    @Override
    public List<GrainSituationDetectionWarnAvg> getDepotLqWarnAvg() {
        return grainSituationDetectionMapper.getDepotLqWarnAvg();
    }

    /**
     * 获取库区粮情温度设备在线情况信息
     *
     * @return
     */
    @Override
    public GrainSituationDetectionOnline getDepotLqOnlineInfo() {
        GrainSituationDetectionOnline totalCountObject = grainSituationDetectionMapper.getTotalCount();
        GrainSituationDetectionOnline onlineCountObject = grainSituationDetectionMapper.getOnlineCount();
        Integer  onlineCount = onlineCountObject.getOnlineCount(); //在线 设备数据
        Integer offlineCount = totalCountObject.getTotalCount()-onlineCount; //离线设备数据
        BigDecimal onlineRate = NumberUtil.toBigDecimal(0);
        if (totalCountObject.getTotalCount().intValue() != 0){
            onlineRate = NumberUtil.mul(NumberUtil.div(onlineCount,totalCountObject.getTotalCount()),100);
        }
        totalCountObject.setOnlineCount(onlineCount);
        totalCountObject.setOfflineCount(offlineCount);
        totalCountObject.setOnlineRate(onlineRate);
        return totalCountObject;
    }

    /**
     * 获取库区粮情详情信息
     *
     * @param orgId
     * @return
     */
    @Override
    public DeportLqDetail getDepotLqDetail(Integer orgId) {
            DeportLqDetail deportLqDetail = grainSituationDetectionMapper.getDepotStockDetail(orgId);
            //得到仓房容量
            DeportStockDetail storehouse = grainOilReserveMapper.getStorehouseDetail(orgId);
            if (storehouse != null){
                deportLqDetail.setDesignCapacity(storehouse.getDesignCapacity());
                deportLqDetail.setStorehouseCount(storehouse.getStorehouseCount());
            }
            //得到油罐容量
            DeportStockDetail tank = grainOilReserveMapper.getTankDetail(orgId);
            if (tank != null){
                deportLqDetail.setTankCapacity(tank.getTankCapacity());
                deportLqDetail.setTankCount(tank.getTankCount());
            }
            //库存粮情信息
            List<LqDetail> lqDetailList = grainSituationDetectionMapper.getLqDetail(orgId);
            deportLqDetail.setLqDetailList(lqDetailList);
            return deportLqDetail;
    }
}
