/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.dev.modular.job.task;

import cn.hutool.core.collection.CollectionUtil;
import com.unis.common.timer.CommonTimerTaskRunner;
import com.unis.dev.modular.log.entity.DevLog;
import com.unis.dev.modular.log.mapper.DevLogMapper;
import lombok.extern.slf4j.Slf4j;
import org.joda.time.LocalDateTime;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.Instant;
import java.time.LocalDate;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.time.temporal.ChronoUnit;
import java.util.Date;
import java.util.List;

/**
 * 清除1个月前的dev_log数据
 * <p>
 * 频率：每天2:00点
 *
 * @author xuyuxiang
 * @date 2022/8/5 15:52
 **/
@Slf4j
@Component
public class DelectDevLogTaskRunner implements CommonTimerTaskRunner {

    @Autowired
    private DevLogMapper devLogMapper;

    @Override
    public void action() {

        log.info("----------开始清除1个月前的dev_log数据----------");

        // 获取当前日期
        LocalDate today = LocalDate.now();
        // 计算一个月前的日期
        LocalDate oneMonthAgo = today.minusMonths(1);
        // 格式化日期
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String oneMonthAgoFormatted = oneMonthAgo.format(formatter);
        List<DevLog> devLogList = devLogMapper.selectData(oneMonthAgoFormatted);
        if (CollectionUtil.isNotEmpty(devLogList)) {

            try {
                devLogMapper.deleteBatchIds(devLogList);
            } catch (Exception e) {
                log.error("清除1个月前的dev_log数据失败：{}", e.getMessage());
                throw new RuntimeException(e);
            }
        }


    }
}
